(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1010137,      19042]*)
(*NotebookOutlinePosition[   1010803,      19065]*)
(*  CellTagsIndexPosition[   1010759,      19061]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["1. DwassAltD Arbitrary Precision", "Section"],

Cell["\<\
The following is the code of the Mathematica function \
DwassAltDKS1SidedOneSampleRTArbPrecision that calculates the right tail \
p-value using the DwassAltD formula with test statistic dIn and sample size \
sampleSizeIn.  Internally the function uses arbitrary precision arithmetic \
with internalPrecisionIn digits of precision.  The code for Mathematica \
function DwassAltDKS1SidedOneSampleRTArbPrecisionNonRationalTestStatistic is \
also giveen and is simply the code for the Mathematica function \
DwassAltDKS1SidedOneSampleRTArbPrecision where the test statistic dIn is not \
converted to a rational number.    Sample output is given in subsection \
1.1.\
\>", "Text"],

Cell[BoxData[
    \(DwassAltDKS1SidedOneSampleRTArbPrecision[dIn_, sampleSizeIn_, \ 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ 
          rightTailProbability, \ binomialCoefficient, \ secondTerm, \ 
          thirdTerm, \ sumTerms}, \[IndentingNewLine] (*\ 
          Dwass\ Alternate\ Direct\ formula\ to\ calculate\ the\ KS\ 1\ Sided\
\ one\ *) \[IndentingNewLine] (*\ \ \ \ sample\ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ arithmetic\ *) \[IndentingNewLine] (*\ \ \ \ with\ an\ internal\ \
precision\ of\ \(\(internalPrecisionIn\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ 
              d]; \[IndentingNewLine]binomialCoefficient\  = \ 
          1; \[IndentingNewLine]secondTerm\ \  = \ 
          N[sampleSize\  + \ d\ *\ sampleSize, \ 
            internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ \(-d\)\ *\ 
            sampleSize; \[IndentingNewLine]sumTerms\  = \ 
          N[secondTerm^\((sampleSize - 1)\), \ 
            internalPrecision]; \[IndentingNewLine]If[jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]binomialCoefficient\  = \ 
            N[binomialCoefficient\ *\ \((sampleSize\  - \ j\  + \ 1)\)/\ 
                  j\ , \ internalPrecision]; \[IndentingNewLine]secondTerm\  \
= \ N[secondTerm\  - \ 1\ , 
              internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ 
            N[thirdTerm\  + \ 1\ , 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + \((binomialCoefficient\ *\ 
                    secondTerm^\((sampleSize\  - \ j\  - \ 1)\)\ *\ 
                    thirdTerm^j)\), \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1\  - \ \((d\ *\ 
                  sumTerms/sampleSize^\((sampleSize\  - \ 1)\))\), \ 
            internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassAltDKS1SidedOneSampleRTArbPrecisionNonRationalTestStatistic[dIn_, 
        sampleSizeIn_, \ 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ 
          rightTailProbability, \ binomialCoefficient, \ secondTerm, \ 
          thirdTerm, \ sumTerms}, \[IndentingNewLine] (*\ 
          Dwass\ Alternate\ Direct\ formula\ to\ calculate\ the\ KS\ 1\ Sided\
\ one\ *) \[IndentingNewLine] (*\ \ \ \ sample\ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ arithmetic\ *) \[IndentingNewLine] (*\ \ \ \ with\ an\ internal\ \
precision\ of\ internalPrecisionIn\ *) \[IndentingNewLine] (*\ \ \ \ where\ \
dIn\ is\ not\ converted\ to\ a\ rational\ \(\(number\)\(.\)\)\ \
*) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          dIn; \ \  (*\ 
          dIn\ is\ not\ converted\ to\ a\ rational\ \(\(number\)\(.\)\)\ \
*) \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ 
              d]; \[IndentingNewLine]binomialCoefficient\  = \ 
          1; \[IndentingNewLine]secondTerm\ \  = \ 
          N[sampleSize\  + \ d\ *\ sampleSize, \ 
            internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ \(-d\)\ *\ 
            sampleSize; \[IndentingNewLine]sumTerms\  = \ 
          N[secondTerm^\((sampleSize - 1)\), \ 
            internalPrecision]; \[IndentingNewLine]If[jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]binomialCoefficient\  = \ 
            N[binomialCoefficient\ *\ \((sampleSize\  - \ j\  + \ 1)\)/\ 
                  j\ , \ internalPrecision]; \[IndentingNewLine]secondTerm\  \
= \ N[secondTerm\  - \ 1\ , 
              internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ 
            N[thirdTerm\  + \ 1\ , 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + \((binomialCoefficient\ *\ 
                    secondTerm^\((sampleSize\  - \ j\  - \ 1)\)\ *\ 
                    thirdTerm^j)\), \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1\  - \ \((d\ *\ 
                  sumTerms/sampleSize^\((sampleSize\  - \ 1)\))\), \ 
            internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[CellGroupData[{

Cell["1.1  DwassAltD Arbitrary Precision Sample Output", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(DwassAltDKS1SidedOneSampleRTArbPrecision[0.0199760, 2000, \ 
      60]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.199998648779404946563706459535437273240061223433`35.\
79890296682812\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Precision[
      DwassAltDKS1SidedOneSampleRTArbPrecision[0.0199760, 2000, \ 
        60]\ ]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`35.79890296682812`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(DwassAltDKS1SidedOneSampleRTArbPrecisionNonRationalTestStatistic[
      0.0199760, 2000, \ 60]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(-1.5207053713068687`*^6\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Precision[
      DwassAltDKS1SidedOneSampleRTArbPrecisionNonRationalTestStatistic[
        0.0199760, 2000, \ 60]\ ]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`MachinePrecision\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(DwassAltDKS1SidedOneSampleRTArbPrecision[0.105632, 100, \ 
      30]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.09997990380077079963347414081953758852`22.\
4690972294866\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Precision[
      DwassAltDKS1SidedOneSampleRTArbPrecision[0.105632, 100, \ 
        30]\ ]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`22.469097229486596`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(DwassAltDKS1SidedOneSampleRTArbPrecisionNonRationalTestStatistic[
      0.105632, 100, \ 30]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.09997990379937771`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Precision[
      DwassAltDKS1SidedOneSampleRTArbPrecisionNonRationalTestStatistic[
        0.105632, 100, \ 30]\ ]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`MachinePrecision\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Precision[
      DwassAltDKS1SidedOneSampleRTArbPrecision[0.0185679, 10000, \ 
        127]\ ]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`19.488873157402946`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Precision[
      DwassAltDKS1SidedOneSampleRTArbPrecision[0.0185679, 10000, \ 
        128]\ ]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`20.488873157397354`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Precision[
      DwassAltDKS1SidedOneSampleRTArbPrecision[0.0185679, 10000, \ 
        207]\ ]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`99.48887315740228`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Precision[
      DwassAltDKS1SidedOneSampleRTArbPrecision[0.0185679, 10000, \ 
        208]\ ]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`100.48887315739668`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Precision[
      DwassAltDKS1SidedOneSampleRTArbPrecision[0.00587530, 100000, \ 
        351]\ ]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`19.87191874414899`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Precision[
      DwassAltDKS1SidedOneSampleRTArbPrecision[0.00587530, 100000, \ 
        352]\ ]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`20.871918744134632`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(DwassAltDKS1SidedOneSampleRTArbPrecision[0.00587530, 100000, \ 
      20]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0``-308.1280685475167\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Precision[
      DwassAltDKS1SidedOneSampleRTArbPrecision[0.00587530, 100000, \ 
        20]\ ]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.`\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. DwassAltD Minimum Precision Minus Desired Precision", "Section"],

Cell["\<\
The following is the code of the Mathematica function \
MinPrecisionMinusDesiredPrecisionDwassAltD that calculates the minimum \
precision minus desired precision needed for the arbitrary precision \
DwassAltD formula with test statistic testStatistic and sample size \
sampleSize to calculate the right tail p-value to a precision of desired \
precision desiredPrecision.  Sample intermediate output is given in \
subsection 2.1.\
\>", "Text"],

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionDwassAltD[testStatistic_, \ 
        sampleSize_, \ desiredPrecision_, \ intermediateOutput_]\  := \ 
      Module[{internalPrecisionLowLimit, \ internalPrecisionHighLimit, \ 
          setInternalPrecision, \ currentPrecision, \ SquareRootN, \ 
          numberTries, \ rightTailProbability, \ 
          minPrecisionMinusDesiredPrecision}, \[IndentingNewLine] (*\ 
          Determine\ the\ minimum\ precision\ minus\ desired\ precision\ \
needed\ for\ the\ *) \[IndentingNewLine] (*\ \ \ \ Dwass\ Alternate\ Direct\ \
formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ *) \[IndentingNewLine] (*\ \ \
\ \ sample\ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSize\ and\ *) \[IndentingNewLine] \
(*\ \ \ \ test\ statistic\ testStatistic\ using\ arbitrary\ precision\ \
arithmetic\ *) \[IndentingNewLine] (*\ \ \ \ so\ that\ the\ calculated\ p - 
            value\ has\ a\ precision\ of\ \(\(desiredPrecision\)\(.\)\)\ \
*) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ 
          pp . \ 1024 - 1028. \ *) \[IndentingNewLine]SquareRootN\  = \ 
          Ceiling[Sqrt[sampleSize]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 1, \ 
          Print["\<MinPrecisionMinusDesiredPrecisionDwassAltD:\>", \ "\< \
sampleSize = \>", \ sampleSize, \ "\<   testStatistic = \>", \ 
            testStatistic, "\< = \>", \ 
            N[testStatistic, 6], \ \ "\<    desiredPrecision = \>", \ 
            desiredPrecision]]; \[IndentingNewLine]numberTries\  = \ 
          0; \[IndentingNewLine]internalPrecisionLowLimit\  = \ 
          desiredPrecision; \[IndentingNewLine]internalPrecisionHighLimit\  = \
\ SquareRootN\  + \ \ desiredPrecision; \
\[IndentingNewLine]setInternalPrecision\  = \ 
          internalPrecisionHighLimit; \[IndentingNewLine] (*\ 
          Determine\ a\ high\ limit\ for\ minimumPrecision\ \
*) \[IndentingNewLine]Label[
          DetermineInternalPrecisionHighLimit]; \
\[IndentingNewLine]numberTries\  = \ 
          numberTries\ \  + \ 
            1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassAltDKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   FindHighLimit: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision = \>", \ \ \
currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  \[GreaterEqual] \ desiredPrecision, \ 
          Goto[HighLimitFound], \ 
          Goto[HighLimitTooSmall]]; \[IndentingNewLine] (*\ 
          Current\ high\ limit\ too\ small\ *) \[IndentingNewLine]Label[
          HighLimitTooSmall]; \[IndentingNewLine]internalPrecisionLowLimit\  \
= \ internalPrecisionHighLimit; \[IndentingNewLine]internalPrecisionHighLimit\
\  = \ internalPrecisionHighLimit\  + \ desiredPrecision\  - \ 
            currentPrecision; \[IndentingNewLine]setInternalPrecision\  = \ 
          internalPrecisionHighLimit; \[IndentingNewLine]Goto[
          DetermineInternalPrecisionHighLimit]; \[IndentingNewLine] (*\ 
          High\ limit\ found\ *) \[IndentingNewLine]Label[
          HighLimitFound]; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Bisection\ search\ to\ find\ minimumPrecision\ between\ \
internalPrecisionLowLimit\ and\ internalPrecisionHighLimit\ \
*) \[IndentingNewLine]Label[
          BisectionIteration]; \[IndentingNewLine]setInternalPrecision\  = \ 
          Floor[\((internalPrecisionLowLimit\  + \ 
                  internalPrecisionHighLimit)\)/2]; \[IndentingNewLine]If[
          setInternalPrecision\ \  \[LessEqual] \ 
            internalPrecisionLowLimit, \ 
          setInternalPrecision\ \  = \ 
            internalPrecisionLowLimit\  + \ 1, \[IndentingNewLine]\(If[
              setInternalPrecision\ \  \[GreaterEqual] \ \ \
internalPrecisionHighLimit, \ 
              setInternalPrecision\ \  = \ 
                internalPrecisionHighLimit\  - \ 
                  1];\)\[IndentingNewLine]]; \[IndentingNewLine]numberTries\  \
= \ numberTries\ \  + \ 1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassAltDKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   Bisection Search: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision = \>", \ \ \
currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  \[GreaterEqual] \ desiredPrecision, \ 
          Goto[ResetHighLimit], \ 
          Goto[ResetLowLimit]]; \[IndentingNewLine] (*\ 
          Reset\ internalPrecisionHighLimit\ to\ currentPrecision\ \
*) \[IndentingNewLine]Label[
          ResetHighLimit]; \[IndentingNewLine]internalPrecisionHighLimit\  = \
\ setInternalPrecision; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Reset\ internalPrecisionLowLimit\ to\ currentPrecision\ \
*) \[IndentingNewLine]Label[
          ResetLowLimit]; \[IndentingNewLine]internalPrecisionLowLimit\  = \ 
          setInternalPrecision; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Minimum\ internal\ precision\ found\ *) \[IndentingNewLine]Label[
          MinInternalPrecisionFound]; \[IndentingNewLine]setInternalPrecision\
\  = \ internalPrecisionLowLimit; \[IndentingNewLine]numberTries\  = \ 
          numberTries\ \  + \ 
            1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassAltDKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   Determine whether low or high limit is minimum \
precision: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision for low limit = \>", \ \
\ currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  < \ desiredPrecision, \ 
          setInternalPrecision\  = \ internalPrecisionHighLimit, \ 
          setInternalPrecision\  = \ 
            internalPrecisionLowLimit]; \
\[IndentingNewLine]minPrecisionMinusDesiredPrecision\  = \ 
          setInternalPrecision\  - \ \ desiredPrecision; \
\[IndentingNewLine]If[\ intermediateOutput \[GreaterEqual] \ 1, \ 
          Print["\<   Minimum Internal Precision Found: \>", \ "\< sampleSize \
= \>", \ sampleSize, \ "\<   testStatistic = \>", \ 
            testStatistic, "\< = \>", \ 
            N[testStatistic, 6], \ \ "\<    desiredPrecision = \>", \ 
            desiredPrecision, \ "\<   numberTries = \>", \ 
            numberTries, \ "\<   minimumInternalPrecision = \>", \ 
            setInternalPrecision, \ "\<   minPrecisionMinusDesiredPrecision = \
\>", \ minPrecisionMinusDesiredPrecision\ ]]; \
\[IndentingNewLine]{numberTries, \ 
          minPrecisionMinusDesiredPrecision}\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassAltDKS1SidedOneSampleRTArbPrecision[dIn_, sampleSizeIn_, \ 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ 
          rightTailProbability, \ binomialCoefficient, \ secondTerm, \ 
          thirdTerm, \ sumTerms}, \[IndentingNewLine] (*\ 
          Dwass\ Alternate\ Direct\ formula\ to\ calculate\ the\ KS\ 1\ Sided\
\ one\ *) \[IndentingNewLine] (*\ \ \ \ sample\ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ arithmetic\ *) \[IndentingNewLine] (*\ \ \ \ with\ an\ internal\ \
precision\ of\ \(\(internalPrecisionIn\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ 
              d]; \[IndentingNewLine]binomialCoefficient\  = \ 
          1; \[IndentingNewLine]secondTerm\ \  = \ 
          N[sampleSize\  + \ d\ *\ sampleSize, \ 
            internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ \(-d\)\ *\ 
            sampleSize; \[IndentingNewLine]sumTerms\  = \ 
          N[secondTerm^\((sampleSize - 1)\), \ 
            internalPrecision]; \[IndentingNewLine]If[jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]binomialCoefficient\  = \ 
            N[binomialCoefficient\ *\ \((sampleSize\  - \ j\  + \ 1)\)/\ 
                  j\ , \ internalPrecision]; \[IndentingNewLine]secondTerm\  \
= \ N[secondTerm\  - \ 1\ , 
              internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ 
            N[thirdTerm\  + \ 1\ , 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + \((binomialCoefficient\ *\ 
                    secondTerm^\((sampleSize\  - \ j\  - \ 1)\)\ *\ 
                    thirdTerm^j)\), \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1\  - \ \((d\ *\ 
                  sumTerms/sampleSize^\((sampleSize\  - \ 1)\))\), \ 
            internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
2.1  DwassAltD Minimum Precision Minus Desired Precision Sample Intermediate \
Output\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionDwassAltD[\[InvisibleSpace]0.0185679, \
\ 10000\[InvisibleSpace], \ 20, \ 2]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("MinPrecisionMinusDesiredPrecisionDwassAltD:"\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.0185679`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0185679`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]20\),
        SequenceForm[ 
        "MinPrecisionMinusDesiredPrecisionDwassAltD:", " sampleSize = ", 
          10000, "   testStatistic = ", .018567899999999998, 
          " = ", .018567899999999998, "    desiredPrecision = ", 20],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   FindHighLimit: numberTries = \
"\[InvisibleSpace]1\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]20\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]120\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]120\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]12\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.0009996621833282029441256229`12.488873157398295\),
        SequenceForm[ 
        "   FindHighLimit: numberTries = ", 1, 
          ", internalPrecisionLowLimit = ", 20, ", setInternalPrecision = ", 
          120, ", internalPrecisionHighLimit = ", 120, 
          ", desiredPrecision = ", 20, ", currentPrecision = ", 12, 
          ", rightTailProbability = ", 
          0.0009996621833282029441256229`12.488873157398295],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   FindHighLimit: numberTries = \
"\[InvisibleSpace]2\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]120\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]128\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]128\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.00099966218332820294412562155045771191`20.488873157397354\)\
,
        SequenceForm[ 
        "   FindHighLimit: numberTries = ", 2, 
          ", internalPrecisionLowLimit = ", 120, ", setInternalPrecision = ", 
          128, ", internalPrecisionHighLimit = ", 128, 
          ", desiredPrecision = ", 20, ", currentPrecision = ", 20, 
          ", rightTailProbability = ", 
          0.00099966218332820294412562155045771191`20.488873157397354],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]3\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]120\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]124\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]128\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]16\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.00099966218332820294412562155031956659`16.488873157402203\)\
,
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 3, 
          ", internalPrecisionLowLimit = ", 120, ", setInternalPrecision = ", 
          124, ", internalPrecisionHighLimit = ", 128, 
          ", desiredPrecision = ", 20, ", currentPrecision = ", 16, 
          ", rightTailProbability = ", 
          0.00099966218332820294412562155031956659`16.488873157402203],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]4\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]124\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]126\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]128\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]18\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.00099966218332820294412562155045655197`18.48887315739978\),
        
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 4, 
          ", internalPrecisionLowLimit = ", 124, ", setInternalPrecision = ", 
          126, ", internalPrecisionHighLimit = ", 128, 
          ", desiredPrecision = ", 20, ", currentPrecision = ", 18, 
          ", rightTailProbability = ", 
          0.00099966218332820294412562155045655197`18.48887315739978],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]5\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]126\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]127\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]128\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]19\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.00099966218332820294412562155045761093`19.488873157402946\)\
,
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 5, 
          ", internalPrecisionLowLimit = ", 126, ", setInternalPrecision = ", 
          127, ", internalPrecisionHighLimit = ", 128, 
          ", desiredPrecision = ", 20, ", currentPrecision = ", 19, 
          ", rightTailProbability = ", 
          0.00099966218332820294412562155045761093`19.488873157402946],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Determine whether low or high limit is minimum \
precision: numberTries = "\[InvisibleSpace]6\[InvisibleSpace]", \
internalPrecisionLowLimit = "\[InvisibleSpace]127\[InvisibleSpace]", \
setInternalPrecision = "\[InvisibleSpace]127\[InvisibleSpace]", \
internalPrecisionHighLimit = "\[InvisibleSpace]128\[InvisibleSpace]", \
desiredPrecision = "\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision \
for low limit = "\[InvisibleSpace]19\[InvisibleSpace]", rightTailProbability \
= "\[InvisibleSpace]0.00099966218332820294412562155045761093`19.\
488873157402946\),
        SequenceForm[ 
        "   Determine whether low or high limit is minimum precision: \
numberTries = ", 6, ", internalPrecisionLowLimit = ", 127, 
          ", setInternalPrecision = ", 127, ", internalPrecisionHighLimit = ",
           128, ", desiredPrecision = ", 20, 
          ", currentPrecision for low limit = ", 19, 
          ", rightTailProbability = ", 
          0.00099966218332820294412562155045761093`19.488873157402946],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Minimum Internal Precision Found: "\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.0185679`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0185679`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]20\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]6\
\[InvisibleSpace]"   minimumInternalPrecision = "\[InvisibleSpace]128\
\[InvisibleSpace]"   minPrecisionMinusDesiredPrecision = \
"\[InvisibleSpace]108\),
        SequenceForm[ 
        "   Minimum Internal Precision Found: ", " sampleSize = ", 10000, 
          "   testStatistic = ", .018567899999999998, 
          " = ", .018567899999999998, "    desiredPrecision = ", 20, 
          "   numberTries = ", 6, "   minimumInternalPrecision = ", 128, 
          "   minPrecisionMinusDesiredPrecision = ", 108],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`{6, 108}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionDwassAltD[\[InvisibleSpace]0.0185679, \
\ 10000\[InvisibleSpace], \ 100, \ 2]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("MinPrecisionMinusDesiredPrecisionDwassAltD:"\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.0185679`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0185679`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]100\),
        SequenceForm[ 
        "MinPrecisionMinusDesiredPrecisionDwassAltD:", " sampleSize = ", 
          10000, "   testStatistic = ", .018567899999999998, 
          " = ", .018567899999999998, "    desiredPrecision = ", 100],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   FindHighLimit: numberTries = \
"\[InvisibleSpace]1\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]100\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]200\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]200\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]92\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
000999662183328202944125621550457714894310537494670134398443417283814375958241\
391148705746267497047391913`92.48887315739763\),
        SequenceForm[ 
        "   FindHighLimit: numberTries = ", 1, 
          ", internalPrecisionLowLimit = ", 100, ", setInternalPrecision = ", 
          200, ", internalPrecisionHighLimit = ", 200, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 92, 
          ", rightTailProbability = ", 
          0.000999662183328202944125621550457714894310537494670134398443417283\
814375958241391148705746267497047391913`92.48887315739763],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   FindHighLimit: numberTries = \
"\[InvisibleSpace]2\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]200\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]208\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]208\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
000999662183328202944125621550457714894310537494670134398443417283814375958241\
3911487057462674970473919133895829913`100.4888731573967\),
        SequenceForm[ 
        "   FindHighLimit: numberTries = ", 2, 
          ", internalPrecisionLowLimit = ", 200, ", setInternalPrecision = ", 
          208, ", internalPrecisionHighLimit = ", 208, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 100, 
          ", rightTailProbability = ", 
          0.000999662183328202944125621550457714894310537494670134398443417283\
8143759582413911487057462674970473919133895829913`100.4888731573967],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]3\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]200\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]204\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]208\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]96\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
000999662183328202944125621550457714894310537494670134398443417283814375958241\
3911487057462674970473919133895779183`96.48887315740154\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 3, 
          ", internalPrecisionLowLimit = ", 200, ", setInternalPrecision = ", 
          204, ", internalPrecisionHighLimit = ", 208, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 96, 
          ", rightTailProbability = ", 
          0.000999662183328202944125621550457714894310537494670134398443417283\
8143759582413911487057462674970473919133895779183`96.48887315740154],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]4\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]204\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]206\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]208\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]98\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
000999662183328202944125621550457714894310537494670134398443417283814375958241\
3911487057462674970473919133895830306`98.48887315739911\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 4, 
          ", internalPrecisionLowLimit = ", 204, ", setInternalPrecision = ", 
          206, ", internalPrecisionHighLimit = ", 208, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 98, 
          ", rightTailProbability = ", 
          0.000999662183328202944125621550457714894310537494670134398443417283\
8143759582413911487057462674970473919133895830306`98.48887315739911],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]5\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]206\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]207\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]208\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]99\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
000999662183328202944125621550457714894310537494670134398443417283814375958241\
391148705746267497047391913389582987`99.48887315740228\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 5, 
          ", internalPrecisionLowLimit = ", 206, ", setInternalPrecision = ", 
          207, ", internalPrecisionHighLimit = ", 208, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 99, 
          ", rightTailProbability = ", 
          0.000999662183328202944125621550457714894310537494670134398443417283\
814375958241391148705746267497047391913389582987`99.48887315740228],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Determine whether low or high limit is minimum \
precision: numberTries = "\[InvisibleSpace]6\[InvisibleSpace]", \
internalPrecisionLowLimit = "\[InvisibleSpace]207\[InvisibleSpace]", \
setInternalPrecision = "\[InvisibleSpace]207\[InvisibleSpace]", \
internalPrecisionHighLimit = "\[InvisibleSpace]208\[InvisibleSpace]", \
desiredPrecision = "\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision \
for low limit = "\[InvisibleSpace]99\[InvisibleSpace]", rightTailProbability \
= "\[InvisibleSpace]0.\
000999662183328202944125621550457714894310537494670134398443417283814375958241\
391148705746267497047391913389582987`99.48887315740228\),
        SequenceForm[ 
        "   Determine whether low or high limit is minimum precision: \
numberTries = ", 6, ", internalPrecisionLowLimit = ", 207, 
          ", setInternalPrecision = ", 207, ", internalPrecisionHighLimit = ",
           208, ", desiredPrecision = ", 100, 
          ", currentPrecision for low limit = ", 99, 
          ", rightTailProbability = ", 
          0.000999662183328202944125621550457714894310537494670134398443417283\
814375958241391148705746267497047391913389582987`99.48887315740228],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Minimum Internal Precision Found: "\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.0185679`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0185679`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]100\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]6\
\[InvisibleSpace]"   minimumInternalPrecision = "\[InvisibleSpace]208\
\[InvisibleSpace]"   minPrecisionMinusDesiredPrecision = \
"\[InvisibleSpace]108\),
        SequenceForm[ 
        "   Minimum Internal Precision Found: ", " sampleSize = ", 10000, 
          "   testStatistic = ", .018567899999999998, 
          " = ", .018567899999999998, "    desiredPrecision = ", 100, 
          "   numberTries = ", 6, "   minimumInternalPrecision = ", 208, 
          "   minPrecisionMinusDesiredPrecision = ", 108],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`{6, 108}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionDwassAltD[\[InvisibleSpace]0.00227855, \
\ 10000\[InvisibleSpace], \ 20, \ 2]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("MinPrecisionMinusDesiredPrecisionDwassAltD:"\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.00227855`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.00227855`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]20\),
        SequenceForm[ 
        "MinPrecisionMinusDesiredPrecisionDwassAltD:", " sampleSize = ", 
          10000, "   testStatistic = ", .0022785499999999998, 
          " = ", .0022785499999999998, "    desiredPrecision = ", 20],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   FindHighLimit: numberTries = \
"\[InvisibleSpace]1\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]20\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]120\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]120\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]106\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
57423203977333122521487532944587443655971221671`106.06375660428371\),
        SequenceForm[ 
        "   FindHighLimit: numberTries = ", 1, 
          ", internalPrecisionLowLimit = ", 20, ", setInternalPrecision = ", 
          120, ", internalPrecisionHighLimit = ", 120, 
          ", desiredPrecision = ", 20, ", currentPrecision = ", 106, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
43202665708657423203977333122521487532944587443655971221671`106.\
06375660428371],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]2\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]20\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]70\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]120\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]56\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
9000070970533918622476850392621992484318540400200748312358947518535`56.\
06375660428301\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 2, 
          ", internalPrecisionLowLimit = ", 20, ", setInternalPrecision = ", 
          70, ", internalPrecisionHighLimit = ", 120, ", desiredPrecision = ",
           20, ", currentPrecision = ", 56, ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
5`56.06375660428301],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]3\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]20\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]45\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]70\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]31\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.900007097053391862247685039262199248431857434747`31.\
063756604282673\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 3, 
          ", internalPrecisionLowLimit = ", 20, ", setInternalPrecision = ", 
          45, ", internalPrecisionHighLimit = ", 70, ", desiredPrecision = ", 
          20, ", currentPrecision = ", 31, ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431857434747`31.\
063756604282673],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]4\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]20\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]32\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]45\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]18\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.9000070970533918622476850393`18.0637566042853\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 4, 
          ", internalPrecisionLowLimit = ", 20, ", setInternalPrecision = ", 
          32, ", internalPrecisionHighLimit = ", 45, ", desiredPrecision = ", 
          20, ", currentPrecision = ", 18, ", rightTailProbability = ", 
          0.9000070970533918622476850393`18.0637566042853],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]5\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]32\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]38\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]45\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]24\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.90000709705339186224768503926219928177`24.06375660427802\),
        
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 5, 
          ", internalPrecisionLowLimit = ", 32, ", setInternalPrecision = ", 
          38, ", internalPrecisionHighLimit = ", 45, ", desiredPrecision = ", 
          20, ", currentPrecision = ", 24, ", rightTailProbability = ", 
          0.90000709705339186224768503926219928177`24.06375660427802],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]6\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]32\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]35\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]38\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]21\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.90000709705339186224768503926217511928`21.06375660427728\),
        
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 6, 
          ", internalPrecisionLowLimit = ", 32, ", setInternalPrecision = ", 
          35, ", internalPrecisionHighLimit = ", 38, ", desiredPrecision = ", 
          20, ", currentPrecision = ", 21, ", rightTailProbability = ", 
          0.90000709705339186224768503926217511928`21.06375660427728],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]7\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]32\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]33\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]35\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]19\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.9000070970533918622476850393`19.063756604279703\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 7, 
          ", internalPrecisionLowLimit = ", 32, ", setInternalPrecision = ", 
          33, ", internalPrecisionHighLimit = ", 35, ", desiredPrecision = ", 
          20, ", currentPrecision = ", 19, ", rightTailProbability = ", 
          0.9000070970533918622476850393`19.063756604279703],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]8\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]33\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]34\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]35\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.90000709705339186224768503926214635994`20.063756604282872\)\
,
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 8, 
          ", internalPrecisionLowLimit = ", 33, ", setInternalPrecision = ", 
          34, ", internalPrecisionHighLimit = ", 35, ", desiredPrecision = ", 
          20, ", currentPrecision = ", 20, ", rightTailProbability = ", 
          0.90000709705339186224768503926214635994`20.063756604282872],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Determine whether low or high limit is minimum \
precision: numberTries = "\[InvisibleSpace]9\[InvisibleSpace]", \
internalPrecisionLowLimit = "\[InvisibleSpace]33\[InvisibleSpace]", \
setInternalPrecision = "\[InvisibleSpace]33\[InvisibleSpace]", \
internalPrecisionHighLimit = "\[InvisibleSpace]34\[InvisibleSpace]", \
desiredPrecision = "\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision \
for low limit = "\[InvisibleSpace]19\[InvisibleSpace]", rightTailProbability \
= "\[InvisibleSpace]0.9000070970533918622476850393`19.063756604279703\),
        SequenceForm[ 
        "   Determine whether low or high limit is minimum precision: \
numberTries = ", 9, ", internalPrecisionLowLimit = ", 33, 
          ", setInternalPrecision = ", 33, ", internalPrecisionHighLimit = ", 
          34, ", desiredPrecision = ", 20, 
          ", currentPrecision for low limit = ", 19, 
          ", rightTailProbability = ", 
          0.9000070970533918622476850393`19.063756604279703],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Minimum Internal Precision Found: "\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.00227855`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.00227855`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]20\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]9\
\[InvisibleSpace]"   minimumInternalPrecision = "\[InvisibleSpace]34\
\[InvisibleSpace]"   minPrecisionMinusDesiredPrecision = "\[InvisibleSpace]14\
\),
        SequenceForm[ 
        "   Minimum Internal Precision Found: ", " sampleSize = ", 10000, 
          "   testStatistic = ", .0022785499999999998, 
          " = ", .0022785499999999998, "    desiredPrecision = ", 20, 
          "   numberTries = ", 9, "   minimumInternalPrecision = ", 34, 
          "   minPrecisionMinusDesiredPrecision = ", 14],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`{9, 14}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionDwassAltD[\[InvisibleSpace]0.00227855, \
\ 10000\[InvisibleSpace], \ 100, \ 2]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("MinPrecisionMinusDesiredPrecisionDwassAltD:"\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.00227855`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.00227855`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]100\),
        SequenceForm[ 
        "MinPrecisionMinusDesiredPrecisionDwassAltD:", " sampleSize = ", 
          10000, "   testStatistic = ", .0022785499999999998, 
          " = ", .0022785499999999998, "    desiredPrecision = ", 100],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   FindHighLimit: numberTries = \
"\[InvisibleSpace]1\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]100\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]200\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]200\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]186\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
574232039773331225214875329445874436559343337822145489039989694596584351287545\
726852706842276766499548842342096857080712659`186.06375660428301\),
        SequenceForm[ 
        "   FindHighLimit: numberTries = ", 1, 
          ", internalPrecisionLowLimit = ", 100, ", setInternalPrecision = ", 
          200, ", internalPrecisionHighLimit = ", 200, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 186, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
432026657086574232039773331225214875329445874436559343337822145489039989694596\
584351287545726852706842276766499548842342096857080712659`186.06375660428301],
        
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]2\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]100\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]150\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]200\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]136\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
5742320397733312252148753294458744365593433378221454890399896945965869627665`\
136.06375660428236\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 2, 
          ", internalPrecisionLowLimit = ", 100, ", setInternalPrecision = ", 
          150, ", internalPrecisionHighLimit = ", 200, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 136, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
432026657086574232039773331225214875329445874436559343337822145489039989694596\
5869627665`136.06375660428236],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]3\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]100\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]125\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]150\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]111\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
57423203977333122521487532944587443655934333956`111.06375660428203\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 3, 
          ", internalPrecisionLowLimit = ", 100, ", setInternalPrecision = ", 
          125, ", internalPrecisionHighLimit = ", 150, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 111, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
43202665708657423203977333122521487532944587443655934333956`111.\
06375660428203],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]4\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]100\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]112\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]125\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]98\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
574232039773331225214875329446226253`98.06375660428465\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 4, 
          ", internalPrecisionLowLimit = ", 100, ", setInternalPrecision = ", 
          112, ", internalPrecisionHighLimit = ", 125, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 98, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
432026657086574232039773331225214875329446226253`98.06375660428465],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]5\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]112\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]118\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]125\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]104\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
5742320397733312252148753294458744367`104.06375660427737\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 5, 
          ", internalPrecisionLowLimit = ", 112, ", setInternalPrecision = ", 
          118, ", internalPrecisionHighLimit = ", 125, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 104, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
4320266570865742320397733312252148753294458744367`104.06375660427737],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]6\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]112\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]115\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]118\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]101\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
574232039773331225214875329445874318`101.0637566042854\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 6, 
          ", internalPrecisionLowLimit = ", 112, ", setInternalPrecision = ", 
          115, ", internalPrecisionHighLimit = ", 118, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 101, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
432026657086574232039773331225214875329445874318`101.0637566042854],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]7\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]112\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]113\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]115\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]99\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
5742320397733312252148753294458918185`99.06375660427906\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 7, 
          ", internalPrecisionLowLimit = ", 112, ", setInternalPrecision = ", 
          113, ", internalPrecisionHighLimit = ", 115, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 99, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
4320266570865742320397733312252148753294458918185`99.06375660427906],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]8\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]113\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]114\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]115\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
5742320397733312252148753294458710261`100.06375660428223\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 8, 
          ", internalPrecisionLowLimit = ", 113, ", setInternalPrecision = ", 
          114, ", internalPrecisionHighLimit = ", 115, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 100, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
4320266570865742320397733312252148753294458710261`100.06375660428223],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Determine whether low or high limit is minimum \
precision: numberTries = "\[InvisibleSpace]9\[InvisibleSpace]", \
internalPrecisionLowLimit = "\[InvisibleSpace]113\[InvisibleSpace]", \
setInternalPrecision = "\[InvisibleSpace]113\[InvisibleSpace]", \
internalPrecisionHighLimit = "\[InvisibleSpace]114\[InvisibleSpace]", \
desiredPrecision = "\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision \
for low limit = "\[InvisibleSpace]99\[InvisibleSpace]", rightTailProbability \
= "\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
5742320397733312252148753294458918185`99.06375660427906\),
        SequenceForm[ 
        "   Determine whether low or high limit is minimum precision: \
numberTries = ", 9, ", internalPrecisionLowLimit = ", 113, 
          ", setInternalPrecision = ", 113, ", internalPrecisionHighLimit = ",
           114, ", desiredPrecision = ", 100, 
          ", currentPrecision for low limit = ", 99, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
4320266570865742320397733312252148753294458918185`99.06375660427906],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Minimum Internal Precision Found: "\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.00227855`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.00227855`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]100\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]9\
\[InvisibleSpace]"   minimumInternalPrecision = "\[InvisibleSpace]114\
\[InvisibleSpace]"   minPrecisionMinusDesiredPrecision = "\[InvisibleSpace]14\
\),
        SequenceForm[ 
        "   Minimum Internal Precision Found: ", " sampleSize = ", 10000, 
          "   testStatistic = ", .0022785499999999998, 
          " = ", .0022785499999999998, "    desiredPrecision = ", 100, 
          "   numberTries = ", 9, "   minimumInternalPrecision = ", 114, 
          "   minPrecisionMinusDesiredPrecision = ", 14],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`{9, 14}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. Maag and Dicaire Test Statistic Approximation", "Section"],

Cell["\<\
The following is the code of the Mathematica function \
KS1SidedOneSampleTestStatisticByMaagDicaire that calculates an approximation \
of the test statistic d corresponding to the right tail p-value alphaIn and \
sample size sampleSizeIn  using the Maag and Dicaire approximation.   Sample \
output is given in subsection 3.1.\
\>", "Text"],

Cell[BoxData[
    \(KS1SidedOneSampleTestStatisticByMaagDicaire[alphaIn_, sampleSizeIn_, \ 
        rho_]\  := \[IndentingNewLine]Module[{d, \ alpha, \ 
          sampleSize}, \[IndentingNewLine] (*\ 
          For\ the\ KS\ 1\ sided\ one\ sample\ test, \ 
          the\ Maag\ and\ Dicaire\ formula\ is\ used\ *) \[IndentingNewLine] \
(*\ \ \ \ to\ approximate\ the\ test\ statistic\ corresponding\ to\ a\ right\ \
tail\ *) \[IndentingNewLine] (*\ \ \ \ probability\ of\ alphaIn . \ \ The\ \
test\ statistic\ d\ is\ calculated\ to\ *) \[IndentingNewLine] (*\ \ \ \ rho\ \
number\ of\ decimal\ \(\(digits\)\(.\)\)\ *) \[IndentingNewLine]alpha\  = 
          Rationalize[alphaIn, \ 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine] (*\ 
          Use\ Maag\ and\ Dicaire\ \(\(MD\)\(.\)\)\ *) \[IndentingNewLine]d\  \
= \ N[Sqrt[Log[alpha]/\((\(-2\)*sampleSize)\)] - \ \((1/\((6*
                      sampleSize)\))\), 
            rho\ \  + \ 17]; \[IndentingNewLine]d\  = \ 
          N[d, rho]; \[IndentingNewLine]d\[IndentingNewLine]]\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
3.1 Maag and Dicaire Test Statistic Approximation Sample Output\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(KS1SidedOneSampleTestStatisticByMaagDicaire[0.001, 1000, \ 
      10]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.0586030333452533237866187934`10. \)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(KS1SidedOneSampleTestStatisticByMaagDicaire[0.9, 7000000, \ 
      10]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.0000867272776072239660430192`10. \)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(KS1SidedOneSampleTestStatisticByMaagDicaire[0.001, 1000000, \ 
      6]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.0018582944277582526`6. \)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["4. Calculation Time for DwassAltD", "Section"],

Cell["\<\
The following is the code of the Mathematica function \
TimingDwassAltDKS1SidedOneSampleRTArbPrecision.  Sample output is given in \
subsection 4.1.\
\>", "Text"],

Cell[BoxData[
    \(TimingDwassAltDKS1SidedOneSampleRTArbPrecision[alpha_, \ 
        sampleSizeIn_, \ desiredPrecisionIn_, \ 
        testStatisticDesiredPrecisionIn_]\ \  := 
      Module[{d, \ \ sampleSize, \ minimumPrecision, \ desiredPrecision, \ 
          testStatisticDesiredPrecision, \ functionOutput, \ 
          rightTailProbability, rightTailProbabilityPrecision, \ 
          functionTimeString, \ timeString}, \[IndentingNewLine] (*\ 
          For\ the\ KS\ 1\ sided\ one\ sample\ test, \ 
          the\ Maag\ and\ Dicaire\ formula\ is\ used\ *) \[IndentingNewLine] \
(*\ \ \ \ for\ sample\ size\ sampleSizeIn\ and\ right\ tail\ p - 
            value\ alpha\ to\ produce\ a\ *) \[IndentingNewLine] (*\ \ \ \ \
test\ statistic\ d\ with\ testStatisticDesiredPrecisionIn\ decimal\ digits\ \
of\ *) \[IndentingNewLine] (*\ \ \ \ accuracy . \ \ Then\ the\ minimum\ \
precision\ minimumPrecision\ needed\ for\ the\ *) \[IndentingNewLine] (*\ \ \ \
\ arbitrary\ precision\ DwassAltD\ formula\ to\ calculate\ a\ right\ tail\ \
*) \[IndentingNewLine] (*\ \ \ \ probability\ with\ desiredPrecisionIn\ \
digits\ of\ precision\ for\ test\ *) \[IndentingNewLine] (*\ \ \ \ statistic\ \
d\ and\ sample\ size\ sampleSizeIn\ is\ \(\(calculated\)\(.\)\)\ \
*) \[IndentingNewLine] (*\ \ \ \ Finally, \ 
          the\ time\ in\ seconds\ for\ the\ arbitrary\ precision\ DwassAltD\ \
*) \[IndentingNewLine] (*\ \ \ \ formula\ to\ calculate\ the\ right\ tail\ \
probability\ for\ test\ statistic\ d\ *) \[IndentingNewLine] (*\ \ \ \ and\ \
sample\ size\ sampleSizeIn\ with\ an\ internal\ precision\ of\ \
*) \[IndentingNewLine] (*\ \ \ \ minimumPrecision\ is\ found\ and\ \
\(\(printed\)\(.\)\)\ *) \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]desiredPrecision\  = \ 
          Floor[desiredPrecisionIn]; \
\[IndentingNewLine]testStatisticDesiredPrecision\  = \ 
          Floor[testStatisticDesiredPrecisionIn]; \[IndentingNewLine]d\  = \ 
          KS1SidedOneSampleTestStatisticByMaagDicaire[alpha, sampleSize, \ 
            
            testStatisticDesiredPrecision]; \[IndentingNewLine]functionOutput\
\  = MinPrecisionMinusDesiredPrecisionDwassAltD[d, \ sampleSize, \ 
            desiredPrecision, \ 0]; \[IndentingNewLine]minimumPrecision\  = \ 
          functionOutput[\([2]\)]; \[IndentingNewLine]minimumPrecision\  = \ 
          minimumPrecision\  + \ 
            desiredPrecision; \[IndentingNewLine]functionOutput\  = \ 
          Timing[DwassAltDKS1SidedOneSampleRTArbPrecision[d, \ sampleSize, \ 
              minimumPrecision]]; \[IndentingNewLine]rightTailProbability\  = \
\ functionOutput[\([2]\)]; \[IndentingNewLine]rightTailProbabilityPrecision\  \
= \ Floor[Precision[
              rightTailProbability]]; \[IndentingNewLine]functionTimeString\  \
= \ functionOutput[\([1]\)]; \[IndentingNewLine]timeString\  = \ 
          functionTimeString\  /. \ 
            Second \[Rule] 
              1; \[IndentingNewLine]Print["\<\
TimingDwassAltDKS1SidedOneSampleRTArbPrecision: sampleSize = \>", \ 
          sampleSize, \ "\<   alpha = \>", \ 
          alpha, \ "\<  desiredPrecision = \>", \ 
          desiredPrecision, \ "\<   testStatisticDesiredPrecision = \>", \ 
          testStatisticDesiredPrecision, \ "\<   d = \>", \ 
          d, \ "\<   minimumPrecision = \>", \ 
          minimumPrecision, \ \ \ "\<   rightTailProbability = \>", \ 
          rightTailProbability, \ "\<  rightTailProbabilityPrecision = \>", \ 
          rightTailProbabilityPrecision, \ "\<   time in seconds = \>", \ 
          timeString\ ]; \
\[IndentingNewLine]sampleSize\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(KS1SidedOneSampleTestStatisticByMaagDicaire[alphaIn_, sampleSizeIn_, \ 
        rho_]\  := \[IndentingNewLine]Module[{d, \ alpha, \ 
          sampleSize}, \[IndentingNewLine] (*\ 
          For\ the\ KS\ 1\ sided\ one\ sample\ test, \ 
          the\ Maag\ and\ Dicaire\ formula\ is\ used\ *) \[IndentingNewLine] \
(*\ \ \ \ to\ approximate\ the\ test\ statistic\ corresponding\ to\ a\ right\ \
tail\ *) \[IndentingNewLine] (*\ \ \ \ probability\ of\ alphaIn . \ \ The\ \
test\ statistic\ d\ is\ calculated\ to\ *) \[IndentingNewLine] (*\ \ \ \ rho\ \
number\ of\ decimal\ \(\(digits\)\(.\)\)\ *) \[IndentingNewLine]alpha\  = 
          Rationalize[alphaIn, \ 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine] (*\ 
          Use\ Maag\ and\ Dicaire\ \(\(MD\)\(.\)\)\ *) \[IndentingNewLine]d\  \
= \ N[Sqrt[Log[alpha]/\((\(-2\)*sampleSize)\)] - \ \((1/\((6*
                      sampleSize)\))\), 
            rho\ \  + \ 17]; \[IndentingNewLine]d\  = \ 
          N[d, rho]; \[IndentingNewLine]d\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionDwassAltD[testStatistic_, \ 
        sampleSize_, \ desiredPrecision_, \ intermediateOutput_]\  := \ 
      Module[{internalPrecisionLowLimit, \ internalPrecisionHighLimit, \ 
          setInternalPrecision, \ currentPrecision, \ SquareRootN, \ 
          numberTries, \ rightTailProbability, \ 
          minPrecisionMinusDesiredPrecision}, \[IndentingNewLine] (*\ 
          Determine\ the\ minimum\ precision\ minus\ desired\ precision\ \
needed\ for\ the\ *) \[IndentingNewLine] (*\ \ \ \ Dwass\ Alternate\ Direct\ \
formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ *) \[IndentingNewLine] (*\ \ \
\ \ sample\ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSize\ and\ *) \[IndentingNewLine] \
(*\ \ \ \ test\ statistic\ testStatistic\ using\ arbitrary\ precision\ \
arithmetic\ *) \[IndentingNewLine] (*\ \ \ \ so\ that\ the\ calculated\ p - 
            value\ has\ a\ precision\ of\ \(\(desiredPrecision\)\(.\)\)\ \
*) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ 
          pp . \ 1024 - 1028. \ *) \[IndentingNewLine]SquareRootN\  = \ 
          Ceiling[Sqrt[sampleSize]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 1, \ 
          Print["\<MinPrecisionMinusDesiredPrecisionDwassAltD:\>", \ "\< \
sampleSize = \>", \ sampleSize, \ "\<   testStatistic = \>", \ 
            testStatistic, "\< = \>", \ 
            N[testStatistic, 6], \ \ "\<    desiredPrecision = \>", \ 
            desiredPrecision]]; \[IndentingNewLine]numberTries\  = \ 
          0; \[IndentingNewLine]internalPrecisionLowLimit\  = \ 
          desiredPrecision; \[IndentingNewLine]internalPrecisionHighLimit\  = \
\ SquareRootN\  + \ \ desiredPrecision; \
\[IndentingNewLine]setInternalPrecision\  = \ 
          internalPrecisionHighLimit; \[IndentingNewLine] (*\ 
          Determine\ a\ high\ limit\ for\ minimumPrecision\ \
*) \[IndentingNewLine]Label[
          DetermineInternalPrecisionHighLimit]; \
\[IndentingNewLine]numberTries\  = \ 
          numberTries\ \  + \ 
            1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassAltDKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   FindHighLimit: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision = \>", \ \ \
currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  \[GreaterEqual] \ desiredPrecision, \ 
          Goto[HighLimitFound], \ 
          Goto[HighLimitTooSmall]]; \[IndentingNewLine] (*\ 
          Current\ high\ limit\ too\ small\ *) \[IndentingNewLine]Label[
          HighLimitTooSmall]; \[IndentingNewLine]internalPrecisionLowLimit\  \
= \ internalPrecisionHighLimit; \[IndentingNewLine]internalPrecisionHighLimit\
\  = \ internalPrecisionHighLimit\  + \ desiredPrecision\  - \ 
            currentPrecision; \[IndentingNewLine]setInternalPrecision\  = \ 
          internalPrecisionHighLimit; \[IndentingNewLine]Goto[
          DetermineInternalPrecisionHighLimit]; \[IndentingNewLine] (*\ 
          High\ limit\ found\ *) \[IndentingNewLine]Label[
          HighLimitFound]; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Bisection\ search\ to\ find\ minimumPrecision\ between\ \
internalPrecisionLowLimit\ and\ internalPrecisionHighLimit\ \
*) \[IndentingNewLine]Label[
          BisectionIteration]; \[IndentingNewLine]setInternalPrecision\  = \ 
          Floor[\((internalPrecisionLowLimit\  + \ 
                  internalPrecisionHighLimit)\)/2]; \[IndentingNewLine]If[
          setInternalPrecision\ \  \[LessEqual] \ 
            internalPrecisionLowLimit, \ 
          setInternalPrecision\ \  = \ 
            internalPrecisionLowLimit\  + \ 1, \[IndentingNewLine]\(If[
              setInternalPrecision\ \  \[GreaterEqual] \ \ \
internalPrecisionHighLimit, \ 
              setInternalPrecision\ \  = \ 
                internalPrecisionHighLimit\  - \ 
                  1];\)\[IndentingNewLine]]; \[IndentingNewLine]numberTries\  \
= \ numberTries\ \  + \ 1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassAltDKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   Bisection Search: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision = \>", \ \ \
currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  \[GreaterEqual] \ desiredPrecision, \ 
          Goto[ResetHighLimit], \ 
          Goto[ResetLowLimit]]; \[IndentingNewLine] (*\ 
          Reset\ internalPrecisionHighLimit\ to\ currentPrecision\ \
*) \[IndentingNewLine]Label[
          ResetHighLimit]; \[IndentingNewLine]internalPrecisionHighLimit\  = \
\ setInternalPrecision; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Reset\ internalPrecisionLowLimit\ to\ currentPrecision\ \
*) \[IndentingNewLine]Label[
          ResetLowLimit]; \[IndentingNewLine]internalPrecisionLowLimit\  = \ 
          setInternalPrecision; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Minimum\ internal\ precision\ found\ *) \[IndentingNewLine]Label[
          MinInternalPrecisionFound]; \[IndentingNewLine]setInternalPrecision\
\  = \ internalPrecisionLowLimit; \[IndentingNewLine]numberTries\  = \ 
          numberTries\ \  + \ 
            1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassAltDKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   Determine whether low or high limit is minimum \
precision: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision for low limit = \>", \ \
\ currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  < \ desiredPrecision, \ 
          setInternalPrecision\  = \ internalPrecisionHighLimit, \ 
          setInternalPrecision\  = \ 
            internalPrecisionLowLimit]; \
\[IndentingNewLine]minPrecisionMinusDesiredPrecision\  = \ 
          setInternalPrecision\  - \ \ desiredPrecision; \
\[IndentingNewLine]If[\ intermediateOutput \[GreaterEqual] \ 1, \ 
          Print["\<   Minimum Internal Precision Found: \>", \ "\< sampleSize \
= \>", \ sampleSize, \ "\<   testStatistic = \>", \ 
            testStatistic, "\< = \>", \ 
            N[testStatistic, 6], \ \ "\<    desiredPrecision = \>", \ 
            desiredPrecision, \ "\<   numberTries = \>", \ 
            numberTries, \ "\<   minimumInternalPrecision = \>", \ 
            setInternalPrecision, \ "\<   minPrecisionMinusDesiredPrecision = \
\>", \ minPrecisionMinusDesiredPrecision\ ]]; \
\[IndentingNewLine]{numberTries, \ 
          minPrecisionMinusDesiredPrecision}\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassAltDKS1SidedOneSampleRTArbPrecision[dIn_, sampleSizeIn_, \ 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ 
          rightTailProbability, \ binomialCoefficient, \ secondTerm, \ 
          thirdTerm, \ sumTerms}, \[IndentingNewLine] (*\ 
          Dwass\ Alternate\ Direct\ formula\ to\ calculate\ the\ KS\ 1\ Sided\
\ one\ *) \[IndentingNewLine] (*\ \ \ \ sample\ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ arithmetic\ *) \[IndentingNewLine] (*\ \ \ \ with\ an\ internal\ \
precision\ of\ \(\(internalPrecisionIn\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ 
              d]; \[IndentingNewLine]binomialCoefficient\  = \ 
          1; \[IndentingNewLine]secondTerm\ \  = \ 
          N[sampleSize\  + \ d\ *\ sampleSize, \ 
            internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ \(-d\)\ *\ 
            sampleSize; \[IndentingNewLine]sumTerms\  = \ 
          N[secondTerm^\((sampleSize - 1)\), \ 
            internalPrecision]; \[IndentingNewLine]If[jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]binomialCoefficient\  = \ 
            N[binomialCoefficient\ *\ \((sampleSize\  - \ j\  + \ 1)\)/\ 
                  j\ , \ internalPrecision]; \[IndentingNewLine]secondTerm\  \
= \ N[secondTerm\  - \ 1\ , 
              internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ 
            N[thirdTerm\  + \ 1\ , 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + \((binomialCoefficient\ *\ 
                    secondTerm^\((sampleSize\  - \ j\  - \ 1)\)\ *\ 
                    thirdTerm^j)\), \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1\  - \ \((d\ *\ 
                  sumTerms/sampleSize^\((sampleSize\  - \ 1)\))\), \ 
            internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
4.1  Calculation Time for DwassAltD Sample Output on a 3.4 GHz Pentium IV\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassAltDKS1SidedOneSampleRTArbPrecision[0.001, \ 1000000, \ 
      20, \ 6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassAltDKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]1000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.001`\[InvisibleSpace]"  desiredPrecision = "\
\[InvisibleSpace]20\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0018582944277582526`6. \[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]1058\[InvisibleSpace]"   \
rightTailProbability = \
"\[InvisibleSpace]0.00100000519945517771720304317323963141`20.806806630847024\
\[InvisibleSpace]"  rightTailProbabilityPrecision = "\[InvisibleSpace]20\
\[InvisibleSpace]"   time in seconds = "\[InvisibleSpace]3.828000000000003`\),
        
        SequenceForm[ 
        "TimingDwassAltDKS1SidedOneSampleRTArbPrecision: sampleSize = ", 
          1000000, "   alpha = ", .001, "  desiredPrecision = ", 20, 
          "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0018582944277582526`6., "   minimumPrecision = ", 1058, 
          "   rightTailProbability = ", 
          0.00100000519945517771720304317323963141`20.806806630847024, 
          "  rightTailProbabilityPrecision = ", 20, "   time in seconds = ", 
          3.828000000000003],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`1000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassAltDKS1SidedOneSampleRTArbPrecision[0.001, \ 1000000, \ 
      100, \ 6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassAltDKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]1000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.001`\[InvisibleSpace]"  desiredPrecision = "\
\[InvisibleSpace]100\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0018582944277582526`6. \[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]1138\[InvisibleSpace]"   \
rightTailProbability = \
"\[InvisibleSpace]0.\
001000005199455177717203043173239657016576905944280063055591650077084956245924\
2870800970192444170276407025055827626`100.80680663082008\[InvisibleSpace]"  \
rightTailProbabilityPrecision = "\[InvisibleSpace]100\[InvisibleSpace]"   \
time in seconds = "\[InvisibleSpace]4.061999999999998`\),
        SequenceForm[ 
        "TimingDwassAltDKS1SidedOneSampleRTArbPrecision: sampleSize = ", 
          1000000, "   alpha = ", .001, "  desiredPrecision = ", 100, 
          "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0018582944277582526`6., "   minimumPrecision = ", 1138, 
          "   rightTailProbability = ", 
          0.001000005199455177717203043173239657016576905944280063055591650077\
0849562459242870800970192444170276407025055827626`100.80680663082008, 
          "  rightTailProbabilityPrecision = ", 100, "   time in seconds = ", 
          4.0619999999999976],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`1000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassAltDKS1SidedOneSampleRTArbPrecision[0.9, \ 1000000, \ 20, \ 
      6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassAltDKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]1000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.9`\[InvisibleSpace]"  desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0002293551358465437218400548`6.000000000000002\
\[InvisibleSpace]"   minimumPrecision = \
"\[InvisibleSpace]150\[InvisibleSpace]"   rightTailProbability = "\
\[InvisibleSpace]0.90000015781059704546078396499606643892`20.367069030711914\
\[InvisibleSpace]"  rightTailProbabilityPrecision = "\[InvisibleSpace]20\
\[InvisibleSpace]"   time in seconds = \
"\[InvisibleSpace]1.2190000000000083`\),
        SequenceForm[ 
        "TimingDwassAltDKS1SidedOneSampleRTArbPrecision: sampleSize = ", 
          1000000, "   alpha = ", .90000000000000002, "  desiredPrecision = ",
           20, "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0002293551358465437218400548`6.000000000000002, 
          "   minimumPrecision = ", 150, "   rightTailProbability = ", 
          0.90000015781059704546078396499606643892`20.367069030711914, 
          "  rightTailProbabilityPrecision = ", 20, "   time in seconds = ", 
          1.2190000000000083],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`1000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassAltDKS1SidedOneSampleRTArbPrecision[0.001, \ 5000000, \ 
      20, \ 6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassAltDKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]5000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.001`\[InvisibleSpace]"  desiredPrecision = "\
\[InvisibleSpace]20\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0008310957348012216`5.999999999999999\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]2334\[InvisibleSpace]"   \
rightTailProbability = \
"\[InvisibleSpace]0.00099999870917696091267298145583196376`20.990954168882336\
\[InvisibleSpace]"  rightTailProbabilityPrecision = "\[InvisibleSpace]20\
\[InvisibleSpace]"   time in seconds = \
"\[InvisibleSpace]42.985000000000014`\),
        SequenceForm[ 
        "TimingDwassAltDKS1SidedOneSampleRTArbPrecision: sampleSize = ", 
          5000000, "   alpha = ", .001, "  desiredPrecision = ", 20, 
          "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0008310957348012216`5.999999999999999, "   minimumPrecision = ", 
          2334, "   rightTailProbability = ", 
          0.00099999870917696091267298145583196376`20.990954168882336, 
          "  rightTailProbabilityPrecision = ", 20, "   time in seconds = ", 
          42.985000000000014],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`5000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassAltDKS1SidedOneSampleRTArbPrecision[0.001, \ 5000000, \ 
      100, \ 6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassAltDKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]5000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.001`\[InvisibleSpace]"  desiredPrecision = "\
\[InvisibleSpace]100\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0008310957348012216`5.999999999999999\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]2414\[InvisibleSpace]"   \
rightTailProbability = \
"\[InvisibleSpace]0.\
000999998709176960912672981455831968819987827596090744225002676475244134381205\
6948730480676837976559845189726002165`100.99095416885538\[InvisibleSpace]"  \
rightTailProbabilityPrecision = "\[InvisibleSpace]100\[InvisibleSpace]"   \
time in seconds = "\[InvisibleSpace]44.452999999999975`\),
        SequenceForm[ 
        "TimingDwassAltDKS1SidedOneSampleRTArbPrecision: sampleSize = ", 
          5000000, "   alpha = ", .001, "  desiredPrecision = ", 100, 
          "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0008310957348012216`5.999999999999999, "   minimumPrecision = ", 
          2414, "   rightTailProbability = ", 
          0.000999998709176960912672981455831968819987827596090744225002676475\
2441343812056948730480676837976559845189726002165`100.99095416885538, 
          "  rightTailProbabilityPrecision = ", 100, "   time in seconds = ", 
          44.452999999999975],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`5000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassAltDKS1SidedOneSampleRTArbPrecision[0.9, \ 5000000, \ 20, \ 
      6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassAltDKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]5000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.9`\[InvisibleSpace]"  desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0001026119372142307669068612`6.000000000000002\
\[InvisibleSpace]"   minimumPrecision = \
"\[InvisibleSpace]308\[InvisibleSpace]"   rightTailProbability = "\
\[InvisibleSpace]0.90000000829283041495172335768067881348`20.49602493711992\
\[InvisibleSpace]"  rightTailProbabilityPrecision = "\[InvisibleSpace]20\
\[InvisibleSpace]"   time in seconds = "\[InvisibleSpace]8.937999999999988`\),
        
        SequenceForm[ 
        "TimingDwassAltDKS1SidedOneSampleRTArbPrecision: sampleSize = ", 
          5000000, "   alpha = ", .90000000000000002, "  desiredPrecision = ",
           20, "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0001026119372142307669068612`6.000000000000002, 
          "   minimumPrecision = ", 308, "   rightTailProbability = ", 
          0.90000000829283041495172335768067881348`20.49602493711992, 
          "  rightTailProbabilityPrecision = ", 20, "   time in seconds = ", 
          8.9379999999999882],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`5000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassAltDKS1SidedOneSampleRTArbPrecision[0.001, \ 10000000, \ 
      20, \ 6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassAltDKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]10000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.001`\[InvisibleSpace]"  desiredPrecision = "\
\[InvisibleSpace]20\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0005876803334525333`6.000000000000002\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]3289\[InvisibleSpace]"   \
rightTailProbability = \
"\[InvisibleSpace]0.00100000539120678945192816085831250106`20.110689981126793\
\[InvisibleSpace]"  rightTailProbabilityPrecision = "\[InvisibleSpace]20\
\[InvisibleSpace]"   time in seconds = \
"\[InvisibleSpace]110.93799999999987`\),
        SequenceForm[ 
        "TimingDwassAltDKS1SidedOneSampleRTArbPrecision: sampleSize = ", 
          10000000, "   alpha = ", .001, "  desiredPrecision = ", 20, 
          "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0005876803334525333`6.000000000000002, "   minimumPrecision = ", 
          3289, "   rightTailProbability = ", 
          0.00100000539120678945192816085831250106`20.110689981126793, 
          "  rightTailProbabilityPrecision = ", 20, "   time in seconds = ", 
          110.93799999999987],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`10000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassAltDKS1SidedOneSampleRTArbPrecision[0.001, \ 10000000, \ 
      100, \ 6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassAltDKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]10000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.001`\[InvisibleSpace]"  desiredPrecision = "\
\[InvisibleSpace]100\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0005876803334525333`6.000000000000002\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]3369\[InvisibleSpace]"   \
rightTailProbability = \
"\[InvisibleSpace]0.\
001000005391206789451928160858312602629537126695141170964778858883896442362026\
2012939158261205589577311062122224035`100.11068997661415\[InvisibleSpace]"  \
rightTailProbabilityPrecision = "\[InvisibleSpace]100\[InvisibleSpace]"   \
time in seconds = "\[InvisibleSpace]110.38999999999987`\),
        SequenceForm[ 
        "TimingDwassAltDKS1SidedOneSampleRTArbPrecision: sampleSize = ", 
          10000000, "   alpha = ", .001, "  desiredPrecision = ", 100, 
          "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0005876803334525333`6.000000000000002, "   minimumPrecision = ", 
          3369, "   rightTailProbability = ", 
          0.001000005391206789451928160858312602629537126695141170964778858883\
8964423620262012939158261205589577311062122224035`100.11068997661415, 
          "  rightTailProbabilityPrecision = ", 100, "   time in seconds = ", 
          110.38999999999987],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`10000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassAltDKS1SidedOneSampleRTArbPrecision[0.9, \ 10000000, \ 20, \ 
      6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassAltDKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]10000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.9`\[InvisibleSpace]"  desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0000725645001942437127574416`6.000000000000002\
\[InvisibleSpace]"   minimumPrecision = \
"\[InvisibleSpace]426\[InvisibleSpace]"   rightTailProbability = "\
\[InvisibleSpace]0.89999987106638007733105785714795811695`20.311419703264765\
\[InvisibleSpace]"  rightTailProbabilityPrecision = "\[InvisibleSpace]20\
\[InvisibleSpace]"   time in seconds = \
"\[InvisibleSpace]22.639999999999873`\),
        SequenceForm[ 
        "TimingDwassAltDKS1SidedOneSampleRTArbPrecision: sampleSize = ", 
          10000000, "   alpha = ", .90000000000000002, 
          "  desiredPrecision = ", 20, "   testStatisticDesiredPrecision = ", 
          6, "   d = ", 0.0000725645001942437127574416`6.000000000000002, 
          "   minimumPrecision = ", 426, "   rightTailProbability = ", 
          0.89999987106638007733105785714795811695`20.311419703264765, 
          "  rightTailProbabilityPrecision = ", 20, "   time in seconds = ", 
          22.639999999999873],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`10000000\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
5. DwassAltD Minimum Precision Minus Desired Precision To File\
\>", "Section"],

Cell["\<\
The following is the code of the Mathematica function \
MinPrecisionMinusDesiredPrecisionToFileDwassAltD that calculates the minimum \
precision minus desired precision needed for the arbitrary precision \
DwassAltD formula and the sample sizes in the vector sampleSizeVectorIn, the \
desired precisions in the vector desiredPrecisionVectorIn, and the Maag and \
Dicaire test statistic to six digits of precision for the p-values in the \
vector alphaVectorIn.  The results are written to file outputFileName which \
can be read by Execel if separatorString is a comma.  Sample intermediate \
output is given in subsection 5.1.  The sample output file generated by the \
example in subsection 5.1 is given in subsection 5.2.\
\>", "Text"],

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionToFileDwassAltD[sampleSizeVectorIn_, \ 
        desiredPrecisionVectorIn_, \ alphaVectorIn_, \ intermediateOutput_, \ 
        outputFileName_, \ howToOpenFile_, \ separatorString_]\  := \ 
      Module[{numberSampleSizes, \ numberDesiredPrecisions, \ numberAlphas, \ 
          VectorDimensions, \ sampleSize, \ desiredPrecision, \ alpha, \ 
          numberDesiredPrecisionsAndAlphas, \ minimumPrecision, \ 
          sampleSizeIndex, \ desiredPrecisionIndex, \ alphaIndex, \ 
          outputFileNumber, \ minimumPrecisionArray, \ d, \ numExp, \ 
          nOutputString, \ numberTermsOutputString, \ 
          desiredPrecisionOutputString, \ minimumPrecisionOutputString, \ 
          stringIndex, \ functionOutput}, \[IndentingNewLine] (*\ 
          Generate\ minimumPrecision - 
            desiredPrecision\ for\ arbitrary\ precision\ \[IndentingNewLine]\ \
\ \ \ \ \ \ DwassAltD\ and\ put\ into\ file, \ 
          outputFileName\ *) \[IndentingNewLine] (*\ 
          Open\ \(file : \ howToOpenFile\) = 0, \ 
          use\ OpenWrite\ which\ creates\ a\ new\ file\[IndentingNewLine]\ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ and\ destroys\ an\ old\ \
file\ *) \ \[IndentingNewLine] (*\ \ \ \ \ \ \ \ \ \ \ \ howToOpenFile = 1, \ 
          use\ OpenAppend\ which\ opens\ file\ and\[IndentingNewLine]\ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ appends\ output\ to\ end\ \
of\ that\ \(\(file\)\(.\)\)\ \ *) \[IndentingNewLine]VectorDimensions\  = \ 
          Dimensions[
            sampleSizeVectorIn]; \[IndentingNewLine]numberSampleSizes\  = \ \ \
VectorDimensions[\([1]\)]; \[IndentingNewLine]VectorDimensions\  = \ 
          Dimensions[
            desiredPrecisionVectorIn]; \
\[IndentingNewLine]numberDesiredPrecisions\  = \ \ VectorDimensions[\([1]\)]; \
\[IndentingNewLine]VectorDimensions\  = \ 
          Dimensions[
            alphaVectorIn]; \[IndentingNewLine]numberAlphas\  = \ \ \
VectorDimensions[\([1]\)]; \
\[IndentingNewLine]numberDesiredPrecisionsAndAlphas\  = \ 
          numberDesiredPrecisions\ *\ 
            numberAlphas; \[IndentingNewLine]minimumPrecisionArray\  = \ 
          Array[
            0, \ {numberSampleSizes, \ numberDesiredPrecisions, \ 
              numberAlphas}]; \[IndentingNewLine]If[
          howToOpenFile\  \[LessEqual] \ 0, \ 
          outputFileNumber\  = \ OpenWrite[outputFileName], \ 
          outputFileNumber\  = \ 
            OpenAppend[outputFileName]]; \[IndentingNewLine]If[
          howToOpenFile\  \[LessEqual] \ 0, \ \[IndentingNewLine] (*\ 
            Output\ all\ the\ minimum\ precisions\ in\ a\ vector\ \
*) \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<DwassAltD:\n\>"]; \
\[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<Desired\>", \ \ separatorString, \ 
            separatorString, \ "\<Sample\>", \ 
            separatorString, \ \ "\<Minimum\>", 
            separatorString, "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<Precision\>", \ \ separatorString, \ 
            separatorString, \ "\<Size\>", \ 
            separatorString, \ "\<Precision\>", \ 
            separatorString, "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<dp\>", \ \ separatorString, \ "\<alpha\>", \
\ separatorString, \ "\<n\>", \ separatorString, \ "\<mp\>", \ 
            separatorString, \ "\<mp - dp\>", "\<\n\>"\ \
];\[IndentingNewLine]]; \[IndentingNewLine]If[
          intermediateOutput\  \[GreaterEqual] \ 
            1, \[IndentingNewLine]\(Print["\<\
MinPrecisionMinusDesiredPrecisionToFileDwassAltD:  For \>", \ 
              numberSampleSizes, "\< sampleSizes \>", \ \ sampleSizeVectorIn, \
\ "\<; \>", \ numberDesiredPrecisions, "\< desiredPrecisions \>", 
              desiredPrecisionVectorIn, \ \ "\<; and \>", \ 
              numberAlphas, "\< alphas \>", 
              alphaVectorIn, \ "\<, outputFileName = \>", \ 
              outputFileName, \ "\<, howToOpenFile = \>", \ 
              howToOpenFile, \ "\<, and separatorString = '\>", \ 
              separatorString, \ "\<'\>", \ "\<   intermediateOutput = \>", \ 
              intermediateOutput];\)\[IndentingNewLine]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]sampleSize\  = \ 
            sampleSizeVectorIn[\([sampleSizeIndex]\)]; \[IndentingNewLine]Do[\
\[IndentingNewLine]desiredPrecision\  = \ 
              desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)]; \
\[IndentingNewLine]Do[\[IndentingNewLine]alpha\  = \ \ \
alphaVectorIn[\([alphaIndex]\)]; \[IndentingNewLine]d\  = \ 
                Rationalize[
                  KS1SidedOneSampleTestStatisticByMaagDicaire[alpha, 
                    sampleSize, \ 6], 
                  0]; \[IndentingNewLine]functionOutput\  = 
                MinPrecisionMinusDesiredPrecisionDwassAltD[d, \ sampleSize, \ 
                  desiredPrecision, \ 
                  0]; \[IndentingNewLine]minimumPrecision\  = \ 
                functionOutput[\([2]\)]; \[IndentingNewLine]minimumPrecision\ \
 = \ minimumPrecision\  + \ 
                  desiredPrecision; \[IndentingNewLine]minimumPrecisionArray[\
\([sampleSizeIndex, \ desiredPrecisionIndex, \ alphaIndex]\)]\  = \ 
                minimumPrecision; \[IndentingNewLine]WriteString[
                outputFileNumber, \ 
                ToString[\ desiredPrecision, \ 
                  FortranForm], \ \ separatorString, \ 
                ToString[\ alpha, \ FortranForm], \ \ separatorString, \ 
                ToString[\ sampleSize, \ FortranForm], \ \ separatorString, \ 
                ToString[\ 
                  minimumPrecisionArray[\([sampleSizeIndex, \ 
                      desiredPrecisionIndex, \ alphaIndex]\)], \ 
                  FortranForm], \ \ separatorString, \ \ ToString[\ 
                  minimumPrecisionArray[\([sampleSizeIndex, \ 
                        desiredPrecisionIndex, \ alphaIndex]\)]\  - \ 
                    desiredPrecision\ , \ 
                  FortranForm], \ "\<\n\>"]; \[IndentingNewLine]If[
                intermediateOutput\  \[GreaterEqual] \ 
                  2, \[IndentingNewLine]\(Print["\<    sampleSize = \>", \ \ \
sampleSize, \ "\<   desiredPrecision = \>", \ 
                    desiredPrecision, \ "\<   alpha = \>", \ 
                    alpha, \ "\<   d = \>", \ d, \ "\< = \>", \ 
                    N[d, \ 6], \ "\<   minimumPrecision = \>", \ 
                    minimumPrecision];\)\[IndentingNewLine]];\
\[IndentingNewLine], {alphaIndex, \ 1, \ \ numberAlphas, \ 
                1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 1, \ 
              numberDesiredPrecisions, \ 
              1}];\[IndentingNewLine], {sampleSizeIndex, \ 1, \ 
            numberSampleSizes, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\n\n\>"\ ]; \[IndentingNewLine] (*\ 
          Minimum\ precision\ by\ desiredPrecision\ by\ alpha\ \
*) \[IndentingNewLine]WriteString[
          
          outputFileNumber, \ "\<DwassAltD:\>", \ \ separatorString, \ \
"\<Minimum Precision mp\>"]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
              outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{stringIndex, \ 1, \ numberDesiredPrecisionsAndAlphas\  - \ 1\ , \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Sample\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ separatorString, \ "\<Desired Precision dp \
= \>", \ ToString[\ desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)], \ 
              FortranForm]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{\ alphaIndex, \ 1\ , \ numberAlphas\  - \ 1, \ 
              1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 
            1, \ \ numberDesiredPrecisions, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Size\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ \ separatorString, \ "\<alpha\>"]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{\ alphaIndex, \ 1\ , \ numberAlphas\  - \ 1, \ 
              1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 
            1, \ \ numberDesiredPrecisions, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<n\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]\(WriteString[
                  outputFileNumber, \ \ separatorString, \ 
                  ToString[\ alphaVectorIn[\([alphaIndex]\)], \ 
                    FortranForm]];\)\[IndentingNewLine], {\ alphaIndex, \ 
                1\ , \ numberAlphas, \ 
                1}];\)\[IndentingNewLine], {desiredPrecisionIndex, \ 
            1, \ \ numberDesiredPrecisions, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]Do[\
\[IndentingNewLine]sampleSize\  = \ 
            sampleSizeVectorIn[\([sampleSizeIndex]\)]; \
\[IndentingNewLine]WriteString[outputFileNumber, \ 
            ToString[\ sampleSize, \ 
              FortranForm]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]desiredPrecision\  = \ 
              desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)]; \
\[IndentingNewLine]Do[\[IndentingNewLine]alpha\  = \ \ \
alphaVectorIn[\([alphaIndex]\)]; \[IndentingNewLine]WriteString[
                outputFileNumber, \ \ separatorString, \ 
                ToString[\ 
                  minimumPrecisionArray[\([sampleSizeIndex, \ 
                      desiredPrecisionIndex, \ alphaIndex]\)], \ 
                  FortranForm]];\[IndentingNewLine], {alphaIndex, \ 
                1, \ \ numberAlphas, \ 
                1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 1, \ 
              numberDesiredPrecisions, \ 1}]; \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<\n\>"\ ];\[IndentingNewLine], \
{sampleSizeIndex, \ 1, \ numberSampleSizes, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\n\n\>"\ ]; \[IndentingNewLine] (*\ 
          Minimum\ precision\ by\ alpha\ by\ desiredPrecision\ \
*) \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<DwassAltD:\>", \ \ separatorString, \ \
"\<Minimum Precision mp\>"]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
              outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{stringIndex, \ 1, \ numberDesiredPrecisionsAndAlphas\  - \ 1\ , \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Sample\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ separatorString, \ "\<alpha = \>", \ 
            ToString[\ alphaVectorIn[\([alphaIndex]\)], \ 
              FortranForm]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ \ numberDesiredPrecisions\  - \ 1, \ 
              1}];\[IndentingNewLine], {\ alphaIndex, \ 1\ , \ 
            numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Size\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]\(WriteString[
                  outputFileNumber, \ \ separatorString, \ "\<dp\>"];\)\
\[IndentingNewLine], {desiredPrecisionIndex, \ 
                1, \ \ numberDesiredPrecisions, \ 
                1}];\)\[IndentingNewLine], {\ alphaIndex, \ 1\ , \ 
            numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<n\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]\(WriteString[
                  outputFileNumber, \ \ separatorString, \ 
                  ToString[\ 
                    desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)], \ 
                    FortranForm]];\)\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ \ numberDesiredPrecisions, \ 
                1}];\)\[IndentingNewLine], {\ alphaIndex, \ 1\ , \ 
            numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]Do[\
\[IndentingNewLine]sampleSize\  = \ 
            sampleSizeVectorIn[\([sampleSizeIndex]\)]; \
\[IndentingNewLine]WriteString[outputFileNumber, \ 
            ToString[\ sampleSize, \ 
              FortranForm]]; \[IndentingNewLine]Do[\[IndentingNewLine]\(Do[\
\[IndentingNewLine]\(WriteString[outputFileNumber, \ \ separatorString, \ 
                    ToString[\ 
                      minimumPrecisionArray[\([sampleSizeIndex, \ 
                          desiredPrecisionIndex, \ alphaIndex]\)], \ 
                      FortranForm]];\)\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ numberDesiredPrecisions, \ 
                  1}];\)\[IndentingNewLine], {alphaIndex, \ 
              1, \ \ numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<\n\>"\ ];\[IndentingNewLine], \
{sampleSizeIndex, \ 1, \ numberSampleSizes, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\n\n\>"\ ]; \[IndentingNewLine] (*\ 
          Minimum\ precision\ minus\ desired\ precision\ by\ desiredPrecision\
\ by\ alpha\ *) \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<DwassAltD:\>", \ \ separatorString, \ \
"\<Minimum Precision Minus Desired Precision mp - dp\>"]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
              outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{stringIndex, \ 1, \ numberDesiredPrecisionsAndAlphas\  - \ 1\ , \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Sample\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ separatorString, \ "\<Desired Precision dp \
= \>", \ ToString[\ desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)], \ 
              FortranForm]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{\ alphaIndex, \ 1\ , \ numberAlphas\  - \ 1, \ 
              1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 
            1, \ \ numberDesiredPrecisions, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Size\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ \ separatorString, \ "\<alpha\>"]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{\ alphaIndex, \ 1\ , \ numberAlphas\  - \ 1, \ 
              1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 
            1, \ \ numberDesiredPrecisions, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<n\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]\(WriteString[
                  outputFileNumber, \ \ separatorString, \ 
                  ToString[\ alphaVectorIn[\([alphaIndex]\)], \ 
                    FortranForm]];\)\[IndentingNewLine], {\ alphaIndex, \ 
                1\ , \ numberAlphas, \ 
                1}];\)\[IndentingNewLine], {desiredPrecisionIndex, \ 
            1, \ \ numberDesiredPrecisions, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]Do[\
\[IndentingNewLine]sampleSize\  = \ 
            sampleSizeVectorIn[\([sampleSizeIndex]\)]; \
\[IndentingNewLine]WriteString[outputFileNumber, \ 
            ToString[\ sampleSize, \ 
              FortranForm]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]desiredPrecision\  = \ 
              desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)]; \
\[IndentingNewLine]Do[\[IndentingNewLine]alpha\  = \ \ \
alphaVectorIn[\([alphaIndex]\)]; \[IndentingNewLine]WriteString[
                outputFileNumber, \ \ separatorString, \ 
                ToString[\ 
                  minimumPrecisionArray[\([sampleSizeIndex, \ 
                        desiredPrecisionIndex, \ alphaIndex]\)]\  - \ 
                    desiredPrecision, \ 
                  FortranForm]];\[IndentingNewLine], {alphaIndex, \ 
                1, \ \ numberAlphas, \ 
                1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 1, \ 
              numberDesiredPrecisions, \ 1}]; \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<\n\>"\ ];\[IndentingNewLine], \
{sampleSizeIndex, \ 1, \ numberSampleSizes, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\n\n\>"\ ]; \[IndentingNewLine] (*\ 
          Minimum\ precision\ minus\ desired\ precision\ by\ alpha\ by\ \
desiredPrecision\ *) \[IndentingNewLine]WriteString[
          outputFileNumber, \ \ "\<DwassAltD:\>", \ \ separatorString, \ \
"\<Minimum Precision Minus Desired Precision mp - dp\>"]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
              outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{stringIndex, \ 1, \ numberDesiredPrecisionsAndAlphas\  - \ 1\ , \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Sample\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ separatorString, \ "\<alpha = \>", \ 
            ToString[\ alphaVectorIn[\([alphaIndex]\)], \ 
              FortranForm]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ \ numberDesiredPrecisions\  - \ 1, \ 
              1}];\[IndentingNewLine], {\ alphaIndex, \ 1\ , \ 
            numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Size\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]\(WriteString[
                  outputFileNumber, \ \ separatorString, \ "\<dp\>"];\)\
\[IndentingNewLine], {desiredPrecisionIndex, \ 
                1, \ \ numberDesiredPrecisions, \ 
                1}];\)\[IndentingNewLine], {\ alphaIndex, \ 1\ , \ 
            numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<n\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]\(WriteString[
                  outputFileNumber, \ \ separatorString, \ 
                  ToString[\ 
                    desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)], \ 
                    FortranForm]];\)\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ \ numberDesiredPrecisions, \ 
                1}];\)\[IndentingNewLine], {\ alphaIndex, \ 1\ , \ 
            numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]Do[\
\[IndentingNewLine]sampleSize\  = \ 
            sampleSizeVectorIn[\([sampleSizeIndex]\)]; \
\[IndentingNewLine]WriteString[outputFileNumber, \ 
            ToString[\ sampleSize, \ 
              FortranForm]]; \[IndentingNewLine]Do[\[IndentingNewLine]\(Do[\
\[IndentingNewLine]desiredPrecision\  = \ 
                  desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)]; \
\[IndentingNewLine]WriteString[outputFileNumber, \ \ separatorString, \ 
                  ToString[\ 
                    minimumPrecisionArray[\([sampleSizeIndex, \ 
                          desiredPrecisionIndex, \ alphaIndex]\)]\  - \ 
                      desiredPrecision\ , \ 
                    FortranForm]];\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ numberDesiredPrecisions, \ 
                  1}];\)\[IndentingNewLine], {alphaIndex, \ 
              1, \ \ numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<\n\>"\ ];\[IndentingNewLine], \
{sampleSizeIndex, \ 1, \ numberSampleSizes, \ 1}]; \[IndentingNewLine]Close[
          
          outputFileNumber]; \[IndentingNewLine]minimumPrecisionArray\
\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(KS1SidedOneSampleTestStatisticByMaagDicaire[alphaIn_, sampleSizeIn_, \ 
        rho_]\  := \[IndentingNewLine]Module[{d, \ alpha, \ 
          sampleSize}, \[IndentingNewLine] (*\ 
          For\ the\ KS\ 1\ sided\ one\ sample\ test, \ 
          the\ Maag\ and\ Dicaire\ formula\ is\ used\ *) \[IndentingNewLine] \
(*\ \ \ \ to\ approximate\ the\ test\ statistic\ corresponding\ to\ a\ right\ \
tail\ *) \[IndentingNewLine] (*\ \ \ \ probability\ of\ alphaIn . \ \ The\ \
test\ statistic\ d\ is\ calculated\ to\ *) \[IndentingNewLine] (*\ \ \ \ rho\ \
number\ of\ decimal\ \(\(digits\)\(.\)\)\ *) \[IndentingNewLine]alpha\  = 
          Rationalize[alphaIn, \ 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine] (*\ 
          Use\ Maag\ and\ Dicaire\ \(\(MD\)\(.\)\)\ *) \[IndentingNewLine]d\  \
= \ N[Sqrt[Log[alpha]/\((\(-2\)*sampleSize)\)] - \ \((1/\((6*
                      sampleSize)\))\), 
            rho\ \  + \ 17]; \[IndentingNewLine]d\  = \ 
          N[d, rho]; \[IndentingNewLine]d\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionDwassAltD[testStatistic_, \ 
        sampleSize_, \ desiredPrecision_, \ intermediateOutput_]\  := \ 
      Module[{internalPrecisionLowLimit, \ internalPrecisionHighLimit, \ 
          setInternalPrecision, \ currentPrecision, \ SquareRootN, \ 
          numberTries, \ rightTailProbability, \ 
          minPrecisionMinusDesiredPrecision}, \[IndentingNewLine] (*\ 
          Determine\ the\ minimum\ precision\ minus\ desired\ precision\ \
needed\ for\ the\ *) \[IndentingNewLine] (*\ \ \ \ Dwass\ Alternate\ Direct\ \
formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ *) \[IndentingNewLine] (*\ \ \
\ \ sample\ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSize\ and\ *) \[IndentingNewLine] \
(*\ \ \ \ test\ statistic\ testStatistic\ using\ arbitrary\ precision\ \
arithmetic\ *) \[IndentingNewLine] (*\ \ \ \ so\ that\ the\ calculated\ p - 
            value\ has\ a\ precision\ of\ \(\(desiredPrecision\)\(.\)\)\ \
*) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ 
          pp . \ 1024 - 1028. \ *) \[IndentingNewLine]SquareRootN\  = \ 
          Ceiling[Sqrt[sampleSize]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 1, \ 
          Print["\<MinPrecisionMinusDesiredPrecisionDwassAltD:\>", \ "\< \
sampleSize = \>", \ sampleSize, \ "\<   testStatistic = \>", \ 
            testStatistic, "\< = \>", \ 
            N[testStatistic, 6], \ \ "\<    desiredPrecision = \>", \ 
            desiredPrecision]]; \[IndentingNewLine]numberTries\  = \ 
          0; \[IndentingNewLine]internalPrecisionLowLimit\  = \ 
          desiredPrecision; \[IndentingNewLine]internalPrecisionHighLimit\  = \
\ SquareRootN\  + \ \ desiredPrecision; \
\[IndentingNewLine]setInternalPrecision\  = \ 
          internalPrecisionHighLimit; \[IndentingNewLine] (*\ 
          Determine\ a\ high\ limit\ for\ minimumPrecision\ \
*) \[IndentingNewLine]Label[
          DetermineInternalPrecisionHighLimit]; \
\[IndentingNewLine]numberTries\  = \ 
          numberTries\ \  + \ 
            1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassAltDKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   FindHighLimit: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision = \>", \ \ \
currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  \[GreaterEqual] \ desiredPrecision, \ 
          Goto[HighLimitFound], \ 
          Goto[HighLimitTooSmall]]; \[IndentingNewLine] (*\ 
          Current\ high\ limit\ too\ small\ *) \[IndentingNewLine]Label[
          HighLimitTooSmall]; \[IndentingNewLine]internalPrecisionLowLimit\  \
= \ internalPrecisionHighLimit; \[IndentingNewLine]internalPrecisionHighLimit\
\  = \ internalPrecisionHighLimit\  + \ desiredPrecision\  - \ 
            currentPrecision; \[IndentingNewLine]setInternalPrecision\  = \ 
          internalPrecisionHighLimit; \[IndentingNewLine]Goto[
          DetermineInternalPrecisionHighLimit]; \[IndentingNewLine] (*\ 
          High\ limit\ found\ *) \[IndentingNewLine]Label[
          HighLimitFound]; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Bisection\ search\ to\ find\ minimumPrecision\ between\ \
internalPrecisionLowLimit\ and\ internalPrecisionHighLimit\ \
*) \[IndentingNewLine]Label[
          BisectionIteration]; \[IndentingNewLine]setInternalPrecision\  = \ 
          Floor[\((internalPrecisionLowLimit\  + \ 
                  internalPrecisionHighLimit)\)/2]; \[IndentingNewLine]If[
          setInternalPrecision\ \  \[LessEqual] \ 
            internalPrecisionLowLimit, \ 
          setInternalPrecision\ \  = \ 
            internalPrecisionLowLimit\  + \ 1, \[IndentingNewLine]\(If[
              setInternalPrecision\ \  \[GreaterEqual] \ \ \
internalPrecisionHighLimit, \ 
              setInternalPrecision\ \  = \ 
                internalPrecisionHighLimit\  - \ 
                  1];\)\[IndentingNewLine]]; \[IndentingNewLine]numberTries\  \
= \ numberTries\ \  + \ 1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassAltDKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   Bisection Search: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision = \>", \ \ \
currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  \[GreaterEqual] \ desiredPrecision, \ 
          Goto[ResetHighLimit], \ 
          Goto[ResetLowLimit]]; \[IndentingNewLine] (*\ 
          Reset\ internalPrecisionHighLimit\ to\ currentPrecision\ \
*) \[IndentingNewLine]Label[
          ResetHighLimit]; \[IndentingNewLine]internalPrecisionHighLimit\  = \
\ setInternalPrecision; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Reset\ internalPrecisionLowLimit\ to\ currentPrecision\ \
*) \[IndentingNewLine]Label[
          ResetLowLimit]; \[IndentingNewLine]internalPrecisionLowLimit\  = \ 
          setInternalPrecision; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Minimum\ internal\ precision\ found\ *) \[IndentingNewLine]Label[
          MinInternalPrecisionFound]; \[IndentingNewLine]setInternalPrecision\
\  = \ internalPrecisionLowLimit; \[IndentingNewLine]numberTries\  = \ 
          numberTries\ \  + \ 
            1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassAltDKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   Determine whether low or high limit is minimum \
precision: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision for low limit = \>", \ \
\ currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  < \ desiredPrecision, \ 
          setInternalPrecision\  = \ internalPrecisionHighLimit, \ 
          setInternalPrecision\  = \ 
            internalPrecisionLowLimit]; \
\[IndentingNewLine]minPrecisionMinusDesiredPrecision\  = \ 
          setInternalPrecision\  - \ \ desiredPrecision; \
\[IndentingNewLine]If[\ intermediateOutput \[GreaterEqual] \ 1, \ 
          Print["\<   Minimum Internal Precision Found: \>", \ "\< sampleSize \
= \>", \ sampleSize, \ "\<   testStatistic = \>", \ 
            testStatistic, "\< = \>", \ 
            N[testStatistic, 6], \ \ "\<    desiredPrecision = \>", \ 
            desiredPrecision, \ "\<   numberTries = \>", \ 
            numberTries, \ "\<   minimumInternalPrecision = \>", \ 
            setInternalPrecision, \ "\<   minPrecisionMinusDesiredPrecision = \
\>", \ minPrecisionMinusDesiredPrecision\ ]]; \
\[IndentingNewLine]{numberTries, \ 
          minPrecisionMinusDesiredPrecision}\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassAltDKS1SidedOneSampleRTArbPrecision[dIn_, sampleSizeIn_, \ 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ 
          rightTailProbability, \ binomialCoefficient, \ secondTerm, \ 
          thirdTerm, \ sumTerms}, \[IndentingNewLine] (*\ 
          Dwass\ Alternate\ Direct\ formula\ to\ calculate\ the\ KS\ 1\ Sided\
\ one\ *) \[IndentingNewLine] (*\ \ \ \ sample\ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ arithmetic\ *) \[IndentingNewLine] (*\ \ \ \ with\ an\ internal\ \
precision\ of\ \(\(internalPrecisionIn\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ 
              d]; \[IndentingNewLine]binomialCoefficient\  = \ 
          1; \[IndentingNewLine]secondTerm\ \  = \ 
          N[sampleSize\  + \ d\ *\ sampleSize, \ 
            internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ \(-d\)\ *\ 
            sampleSize; \[IndentingNewLine]sumTerms\  = \ 
          N[secondTerm^\((sampleSize - 1)\), \ 
            internalPrecision]; \[IndentingNewLine]If[jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]binomialCoefficient\  = \ 
            N[binomialCoefficient\ *\ \((sampleSize\  - \ j\  + \ 1)\)/\ 
                  j\ , \ internalPrecision]; \[IndentingNewLine]secondTerm\  \
= \ N[secondTerm\  - \ 1\ , 
              internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ 
            N[thirdTerm\  + \ 1\ , 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + \((binomialCoefficient\ *\ 
                    secondTerm^\((sampleSize\  - \ j\  - \ 1)\)\ *\ 
                    thirdTerm^j)\), \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1\  - \ \((d\ *\ 
                  sumTerms/sampleSize^\((sampleSize\  - \ 1)\))\), \ 
            internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
5.1  DwassAltD Minimum Precision Minus Desired Precision To File Sample \
Intermediate Output\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionToFileDwassAltD[{100, \ 500}, \ {20, \ 
        100}, \ {0.001, \ 0.9}, \ 
      2, \ "\<C:/KSoutput/KS1SidedOneSampleDwassAltDmpMINUSdpN100and500.csv\>\
", \ 0, \ "\<,\>"]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("MinPrecisionMinusDesiredPrecisionToFileDwassAltD:  \
For "\[InvisibleSpace]2\[InvisibleSpace]" sampleSizes "\[InvisibleSpace]{100, 
            500}\[InvisibleSpace]"; "\[InvisibleSpace]2\[InvisibleSpace]" \
desiredPrecisions "\[InvisibleSpace]{20, 
            100}\[InvisibleSpace]"; and "\[InvisibleSpace]2\[InvisibleSpace]" \
alphas "\[InvisibleSpace]{0.001`, 
            0.9`}\[InvisibleSpace]", outputFileName = \
"\[InvisibleSpace]"C:/KSoutput/KS1SidedOneSampleDwassAltDmpMINUSdpN100and500.\
csv"\[InvisibleSpace]", howToOpenFile = \
"\[InvisibleSpace]0\[InvisibleSpace]", and separatorString = '"\
\[InvisibleSpace]","\[InvisibleSpace]"'"\[InvisibleSpace]"   \
intermediateOutput = "\[InvisibleSpace]2\),
        SequenceForm[ 
        "MinPrecisionMinusDesiredPrecisionToFileDwassAltD:  For ", 2, 
          " sampleSizes ", {100, 500}, "; ", 2, " desiredPrecisions ", {20, 
          100}, "; and ", 2, " alphas ", {.001, .90000000000000002}, 
          ", outputFileName = ", 
          "C:/KSoutput/KS1SidedOneSampleDwassAltDmpMINUSdpN100and500.csv", 
          ", howToOpenFile = ", 0, ", and separatorString = '", ",", "'", 
          "   intermediateOutput = ", 2],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]100\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.001`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]156\/847\[InvisibleSpace]" = "\
\[InvisibleSpace]0.184179456906729634`6. \[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]34\),
        SequenceForm[ 
        "    sampleSize = ", 100, "   desiredPrecision = ", 20, 
          "   alpha = ", .001, "   d = ", 
          Rational[ 156, 847], " = ", 0.184179456906729634`6., 
          "   minimumPrecision = ", 34],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]100\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.9`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]203\/9537\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0212855195554157492`5.999999999999999\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]22\),
        SequenceForm[ 
        "    sampleSize = ", 100, "   desiredPrecision = ", 20, 
          "   alpha = ", .90000000000000002, "   d = ", 
          Rational[ 203, 9537], " = ", 
          0.0212855195554157492`5.999999999999999, "   minimumPrecision = ", 
          22],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]100\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.001`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]156\/847\[InvisibleSpace]" = "\
\[InvisibleSpace]0.184179456906729634`6. \[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]114\),
        SequenceForm[ 
        "    sampleSize = ", 100, "   desiredPrecision = ", 100, 
          "   alpha = ", .001, "   d = ", 
          Rational[ 156, 847], " = ", 0.184179456906729634`6., 
          "   minimumPrecision = ", 114],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]100\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.9`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]203\/9537\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0212855195554157492`5.999999999999999\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]102\),
        SequenceForm[ 
        "    sampleSize = ", 100, "   desiredPrecision = ", 100, 
          "   alpha = ", .90000000000000002, "   d = ", 
          Rational[ 203, 9537], " = ", 
          0.0212855195554157492`5.999999999999999, "   minimumPrecision = ", 
          102],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]500\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.001`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]299\/3612\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0827796234772978959`6. \[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]47\),
        SequenceForm[ 
        "    sampleSize = ", 500, "   desiredPrecision = ", 20, 
          "   alpha = ", .001, "   d = ", 
          Rational[ 299, 3612], " = ", 0.0827796234772978959`6., 
          "   minimumPrecision = ", 47],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]500\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.9`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]140\/14097\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0099311910335532383`5.999999999999999\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]24\),
        SequenceForm[ 
        "    sampleSize = ", 500, "   desiredPrecision = ", 20, 
          "   alpha = ", .90000000000000002, "   d = ", 
          Rational[ 140, 14097], " = ", 
          0.0099311910335532383`5.999999999999999, "   minimumPrecision = ", 
          24],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]500\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.001`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]299\/3612\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0827796234772978959`6. \[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]127\),
        SequenceForm[ 
        "    sampleSize = ", 500, "   desiredPrecision = ", 100, 
          "   alpha = ", .001, "   d = ", 
          Rational[ 299, 3612], " = ", 0.0827796234772978959`6., 
          "   minimumPrecision = ", 127],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]500\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.9`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]140\/14097\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0099311910335532383`5.999999999999999\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]104\),
        SequenceForm[ 
        "    sampleSize = ", 500, "   desiredPrecision = ", 100, 
          "   alpha = ", .90000000000000002, "   d = ", 
          Rational[ 140, 14097], " = ", 
          0.0099311910335532383`5.999999999999999, "   minimumPrecision = ", 
          104],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({34, 22}\), \({114, 102}\)},
            {\({47, 24}\), \({127, 104}\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
5.2  DwassAltD Minimum Precision Minus Desired Precision Sample Output File, \
C:/KSoutput/KS1SidedOneSampleDwassAltDmpMINUSdpN100and500.csv\
\>", "Subsection"],

Cell[BoxData[{
    \(DwassAltD : Desired, , Sample, Minimum, Precision, , Size, Precision, 
    dp, alpha, n, mp, mp - dp\), "\n", 
    \(20, 0.001, 100, 34, 14\), "\n", 
    \(20, 0.9, 100, 22, 2\), "\n", 
    \(100, 0.001, 100, 114, 14\), "\n", 
    \(100, 0.9, 100, 102, 2\), "\n", 
    \(20, 0.001, 500, 47, 27\), "\n", 
    \(20, 0.9, 500, 24, 4\), "\n", 
    \(100, 0.001, 500, 127, 27\), "\n", 
    \(\(\(100, 0.9, 500, 104, 
    4\)\(\[IndentingNewLine]\)\(\n\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(DwassAltD\)\(:\)\), Minimum\ Precision\ mp, , , Sample, 
    Desired\ Precision\ dp = 20, , Desired\ Precision\ dp = 100, Size, 
    alpha, , alpha, n, 0.001, 0.9, 0.001, 0.9\), "\n", 
    \(100, 34, 22, 114, 102\), "\n", 
    \(\(\(500, 47, 24, 127, 
    104\)\(\[IndentingNewLine]\)\(\n\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(DwassAltD\)\(:\)\), Minimum\ Precision\ mp, , , Sample, 
    alpha = 0.001, , alpha = 0.9, Size, dp, dp, dp, dp\), "\n", 
    \(n, 20, 100, 20, 100\), "\n", 
    \(100, 34, 114, 22, 102\), "\n", 
    \(\(\(500, 47, 127, 24, 
    104\)\(\[IndentingNewLine]\)\(\n\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(DwassAltD\)\(:\)\), 
    Minimum\ Precision\ Minus\ Desired\ Precision\ mp - dp, , , Sample, 
    Desired\ Precision\ dp = 20, , Desired\ Precision\ dp = 100, Size, 
    alpha, , alpha, n, 0.001, 0.9, 0.001, 0.9\), "\n", 
    \(100, 14, 2, 14, 2\), "\n", 
    \(\(\(500, 27, 4, 27, 
    4\)\(\[IndentingNewLine]\)\(\n\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(DwassAltD\)\(:\)\), 
    Minimum\ Precision\ Minus\ Desired\ Precision\ mp - dp, , , Sample, 
    alpha = 0.001, , alpha = 0.9, Size, dp, dp, dp, dp\), "\n", 
    \(n, 20, 100, 20, 100\), "\n", 
    \(100, 14, 14, 2, 2\), "\n", 
    \(500, 27, 27, 4, 4\), "\n", 
    \(\)}], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["6. DwassAltD Desired Precision", "Section"],

Cell["\<\
The following is the code of the Mathematica function \
DwassAltDKS1SidedOneSampleRTdesiredPrecision that calculates the right tail \
p-value to desiredPrecisionIn digits of precision.  Sample output is given in \
subsection 6.1.\
\>", "Text"],

Cell[BoxData[
    \(DwassAltDKS1SidedOneSampleRTdesiredPrecision[dIn_, sampleSizeIn_, \ 
        desiredPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ desiredPrecision, \ internalPrecision, \ j, \ 
          jLowLimit, \ term, \ leftTailProbability, \ rightTailProbability, \ 
          binomialCoefficient, \ secondTerm, \ thirdTerm, \ sumTerms, \ 
          numberIterations, \ alphaPredict, \ 
          resultPrecision}, \[IndentingNewLine] (*\ 
          DwassAltD\ formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ sample\ \
*) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ to\ desiredPrecisionIn\ digits\ of\ *) \[IndentingNewLine] \
(*\ \ \ \ precision\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine]d = 
          Rationalize[dIn, \ 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]desiredPrecision\  = \ 
          Ceiling[desiredPrecisionIn]; \[IndentingNewLine] (*\ 
          Maag\ and\ Dicaire\ approximation\ \
*) \[IndentingNewLine]alphaPredict\  = \ 
          Exp[\(-2\)\ *\ d^2\ *\ 
                sampleSize\  - \ \((2\ *
                  d\ /\ 3)\)\  - \ \((1/\((18\ *\ 
                      sampleSize)\))\)]; \[IndentingNewLine]internalPrecision\
\  = \ Ceiling[
              3\  + \ \((4.84\  + \ 1.033\ *\ Sqrt[sampleSize])\)\ *\ \((\ 
                    0.611\  - \ 0.0904*\ alphaPredict\  - \ 
                      0.357\ *\ alphaPredict^\((1/3)\)\  - \ 
                      0.0998\ *\ alphaPredict^4\  - \ 
                      0.0616\ *\ Log[alphaPredict])\)]\  + \ 
            desiredPrecision; \[IndentingNewLine]numberIterations\  = \ 
          0; \[IndentingNewLine]Label[
          AnotherIteration]; \[IndentingNewLine]numberIterations\  = \ 
          numberIterations\  + \ 
            1; \[IndentingNewLine]rightTailProbability\ \  = \ 
          DwassAltDKS1SidedOneSampleRTArbPrecision[d, sampleSize, 
            internalPrecision]; \[IndentingNewLine]resultPrecision\  = \ 
          Precision[rightTailProbability]; \[IndentingNewLine]If[
          resultPrecision\  < \ 
            desiredPrecision, \[IndentingNewLine]internalPrecision\  = \ 
            internalPrecision\  + \ desiredPrecision; \[IndentingNewLine]Goto[
            AnotherIteration];\[IndentingNewLine]]; \
\[IndentingNewLine]rightTailProbability\ \[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassAltDKS1SidedOneSampleRTArbPrecision[dIn_, sampleSizeIn_, \ 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ 
          rightTailProbability, \ binomialCoefficient, \ secondTerm, \ 
          thirdTerm, \ sumTerms}, \[IndentingNewLine] (*\ 
          Dwass\ Alternate\ Direct\ formula\ to\ calculate\ the\ KS\ 1\ Sided\
\ one\ *) \[IndentingNewLine] (*\ \ \ \ sample\ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ arithmetic\ *) \[IndentingNewLine] (*\ \ \ \ with\ an\ internal\ \
precision\ of\ \(\(internalPrecisionIn\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ 
              d]; \[IndentingNewLine]binomialCoefficient\  = \ 
          1; \[IndentingNewLine]secondTerm\ \  = \ 
          N[sampleSize\  + \ d\ *\ sampleSize, \ 
            internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ \(-d\)\ *\ 
            sampleSize; \[IndentingNewLine]sumTerms\  = \ 
          N[secondTerm^\((sampleSize - 1)\), \ 
            internalPrecision]; \[IndentingNewLine]If[jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]binomialCoefficient\  = \ 
            N[binomialCoefficient\ *\ \((sampleSize\  - \ j\  + \ 1)\)/\ 
                  j\ , \ internalPrecision]; \[IndentingNewLine]secondTerm\  \
= \ N[secondTerm\  - \ 1\ , 
              internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ 
            N[thirdTerm\  + \ 1\ , 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + \((binomialCoefficient\ *\ 
                    secondTerm^\((sampleSize\  - \ j\  - \ 1)\)\ *\ 
                    thirdTerm^j)\), \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1\  - \ \((d\ *\ 
                  sumTerms/sampleSize^\((sampleSize\  - \ 1)\))\), \ 
            internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[CellGroupData[{

Cell["6.1  DwassAltD Desired Precision Sample Output", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DwassAltDKS1SidedOneSampleRTdesiredPrecision[0.000831096, 5000000, \ 
      30]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.\
000999994849501232127646860949510285878397398530265686987`36.99030816338198\)]\
, "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DwassAltDKS1SidedOneSampleRTdesiredPrecision[0.000339290, 10000000, \ 
      40]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.\
100000480993207370350317616589677055270014407449947732644`46.98592129581308\)]\
, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["7. DwassD Arbitrary Precision", "Section"],

Cell["\<\
The following is the code of the Mathematica function \
DwassDKS1SidedOneSampleRTArbPrecision that calculates the right tail p-value \
using the DwassD formula with test statistic dIn and sample size \
sampleSizeIn.  Internally the function uses arbitrary precision arithmetic \
with internalPrecisionIn digits of precision.   Sample output is given in \
subsection 7.1.\
\>", "Text"],

Cell[BoxData[
    \(DwassDKS1SidedOneSampleRTArbPrecision[dIn_, sampleSizeIn_, 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ 
          rightTailProbability, \ binomialCoefficient, \ secondTerm, \ 
          thirdTerm, \ sumTerms}, \[IndentingNewLine] (*\ 
          Dwass\ Direct\ formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ \
sample\ *) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ 
              d]; \[IndentingNewLine]binomialCoefficient\  = \ 
          1; \[IndentingNewLine]secondTerm\ \  = \ 
          N[1\  + \ d, \ 
            internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ \(-d\); \
\[IndentingNewLine]sumTerms\  = \ 
          N[secondTerm^\((sampleSize - 1)\), \ 
            internalPrecision]; \[IndentingNewLine]If[jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]binomialCoefficient\  = \ 
            N[binomialCoefficient\ *\ \((sampleSize\  - \ j\  + \ 1)\)/\ 
                  j\ , \ internalPrecision]; \[IndentingNewLine]secondTerm\  \
= \ N[secondTerm\  - \ \((1/sampleSize)\)\ , 
              internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ 
            N[thirdTerm\  + \ \((1/sampleSize)\)\ , 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + \((binomialCoefficient\ *\ 
                    secondTerm^\((sampleSize\  - \ j\  - \ 1)\)\ *\ 
                    thirdTerm^j)\), \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1\  - \ \((d\ *\ sumTerms)\), \ 
            internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[CellGroupData[{

Cell["7.1  DwassD Arbitrary Precision Sample Output", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(DwassDKS1SidedOneSampleRTArbPrecision[0.105632, 100, \ 
      30]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.09997990380077079963347414081953758852`22.\
46909722948659\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Precision[
      DwassDKS1SidedOneSampleRTArbPrecision[0.105632, 100, \ 
        30]\ ]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`22.46909722948659`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(DwassDKS1SidedOneSampleRTArbPrecision[0.0199760, 2000, \ 
      60]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.19999864877940494656370645953543727324006122344`35.\
79890296682809\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Precision[
      DwassDKS1SidedOneSampleRTArbPrecision[0.0199760, 2000, \ 
        60]\ ]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`35.79890296682809`\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["8. DwassD Minimum Precision Minus Desired Precision", "Section"],

Cell["\<\
The following is the code of the Mathematica function \
MinPrecisionMinusDesiredPrecisionDwassD that calculates the minimum precision \
minus desired precision needed for the arbitrary precision DwassD formula \
with test statistic testStatistic and sample size sampleSize to calculate the \
right tail p-value to a precision of desired precision desiredPrecision.  \
Sample intermediate output is given in subsection 8.1.\
\>", "Text"],

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionDwassD[testStatistic_, \ 
        sampleSize_, \ desiredPrecision_, \ intermediateOutput_]\  := \ 
      Module[{internalPrecisionLowLimit, \ internalPrecisionHighLimit, \ 
          setInternalPrecision, \ currentPrecision, \ SquareRootN, \ 
          numberTries, \ rightTailProbability, \ 
          rightTailProbabilityToDesiredPrecision, \ 
          minPrecisionMinusDesiredPrecision, \ mantissaExp, \ numExp, \ 
          prop}, \[IndentingNewLine]SquareRootN\  = \ 
          Ceiling[Sqrt[sampleSize]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 1, \ 
          Print["\<MinPrecisionMinusDesiredPrecisionDwassD:\>", \ "\< \
sampleSize = \>", \ sampleSize, \ "\<   testStatistic = \>", \ 
            testStatistic, "\< = \>", \ 
            N[testStatistic, 6], \ \ "\<    desiredPrecision = \>", \ 
            desiredPrecision]]; \[IndentingNewLine]numberTries\  = \ 
          0; \[IndentingNewLine]internalPrecisionLowLimit\  = \ 
          desiredPrecision; \[IndentingNewLine]internalPrecisionHighLimit\  = \
\ SquareRootN\  + \ \ desiredPrecision; \
\[IndentingNewLine]setInternalPrecision\  = \ 
          internalPrecisionHighLimit; \[IndentingNewLine] (*\ 
          Determine\ a\ high\ limit\ for\ minimumPrecision\ \
*) \[IndentingNewLine]Label[
          DetermineInternalPrecisionHighLimit]; \
\[IndentingNewLine]numberTries\  = \ 
          numberTries\ \  + \ 
            1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassDKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   FindHighLimit: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision = \>", \ \ \
currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  \[GreaterEqual] \ desiredPrecision, \ 
          Goto[HighLimitFound], \ 
          Goto[HighLimitTooSmall]]; \[IndentingNewLine] (*\ 
          Current\ high\ limit\ too\ small\ *) \[IndentingNewLine]Label[
          HighLimitTooSmall]; \[IndentingNewLine]internalPrecisionLowLimit\  \
= \ internalPrecisionHighLimit; \[IndentingNewLine]internalPrecisionHighLimit\
\  = \ internalPrecisionHighLimit\  + \ desiredPrecision\  - \ 
            currentPrecision; \[IndentingNewLine]setInternalPrecision\  = \ 
          internalPrecisionHighLimit; \[IndentingNewLine]Goto[
          DetermineInternalPrecisionHighLimit]; \[IndentingNewLine] (*\ 
          High\ limit\ found\ *) \[IndentingNewLine]Label[
          HighLimitFound]; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Bisection\ search\ to\ find\ minimumPrecision\ between\ \
\[IndentingNewLine]\ \ \ \ internalPrecisionLowLimit\ and\ \
internalPrecisionHighLimit\ *) \[IndentingNewLine]Label[
          BisectionIteration]; \[IndentingNewLine]setInternalPrecision\  = \ 
          Floor[\((internalPrecisionLowLimit\  + \ 
                  internalPrecisionHighLimit)\)/2]; \[IndentingNewLine]If[
          setInternalPrecision\ \  \[LessEqual] \ 
            internalPrecisionLowLimit, \ 
          setInternalPrecision\ \  = \ 
            internalPrecisionLowLimit\  + \ 1, \[IndentingNewLine]\(If[
              setInternalPrecision\ \  \[GreaterEqual] \ \ \
internalPrecisionHighLimit, \ 
              setInternalPrecision\ \  = \ 
                internalPrecisionHighLimit\  - \ 
                  1];\)\[IndentingNewLine]]; \[IndentingNewLine]numberTries\  \
= \ numberTries\ \  + \ 1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassDKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   Bisection Search: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision = \>", \ \ \
currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  \[GreaterEqual] \ desiredPrecision, \ 
          Goto[ResetHighLimit], \ 
          Goto[ResetLowLimit]]; \[IndentingNewLine] (*\ 
          Reset\ internalPrecisionHighLimit\ to\ currentPrecision\ \
*) \[IndentingNewLine]Label[
          ResetHighLimit]; \[IndentingNewLine]internalPrecisionHighLimit\  = \
\ setInternalPrecision; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Reset\ internalPrecisionLowLimit\ to\ currentPrecision\ \
*) \[IndentingNewLine]Label[
          ResetLowLimit]; \[IndentingNewLine]internalPrecisionLowLimit\  = \ 
          setInternalPrecision; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Minimum\ internal\ precision\ found\ *) \[IndentingNewLine]Label[
          MinInternalPrecisionFound]; \[IndentingNewLine]setInternalPrecision\
\  = \ internalPrecisionHighLimit; \[IndentingNewLine]setInternalPrecision\  \
= \ internalPrecisionLowLimit; \[IndentingNewLine]numberTries\  = \ 
          numberTries\ \  + \ 
            1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassDKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   Determine whether low or high limit is minimum \
precision: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision for low limit = \>", \ \
\ currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  < \ desiredPrecision, \ 
          setInternalPrecision\  = \ internalPrecisionHighLimit, \ 
          setInternalPrecision\  = \ 
            internalPrecisionLowLimit]; \
\[IndentingNewLine]minPrecisionMinusDesiredPrecision\  = \ 
          setInternalPrecision\  - \ \ desiredPrecision; \
\[IndentingNewLine]If[\ intermediateOutput \[GreaterEqual] \ 1, \ 
          Print["\<   Minimum Internal Precision Found: \>", \ "\< sampleSize \
= \>", \ sampleSize, \ "\<   testStatistic = \>", \ 
            testStatistic, \ "\< = \>", \ 
            N[testStatistic, 6], \ "\<    desiredPrecision = \>", \ 
            desiredPrecision, \ "\<   numberTries = \>", \ 
            numberTries, \ "\<   minimumInternalPrecision = \>", \ 
            setInternalPrecision, \ "\<   minPrecisionMinusDesiredPrecision = \
\>", \ minPrecisionMinusDesiredPrecision\ ]]; \
\[IndentingNewLine]{numberTries, \ 
          minPrecisionMinusDesiredPrecision}\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassDKS1SidedOneSampleRTArbPrecision[dIn_, sampleSizeIn_, 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ 
          rightTailProbability, \ binomialCoefficient, \ secondTerm, \ 
          thirdTerm, \ sumTerms}, \[IndentingNewLine] (*\ 
          Dwass\ Direct\ formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ \
sample\ *) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ 
              d]; \[IndentingNewLine]binomialCoefficient\  = \ 
          1; \[IndentingNewLine]secondTerm\ \  = \ 
          N[1\  + \ d, \ 
            internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ \(-d\); \
\[IndentingNewLine]sumTerms\  = \ 
          N[secondTerm^\((sampleSize - 1)\), \ 
            internalPrecision]; \[IndentingNewLine]If[jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]binomialCoefficient\  = \ 
            N[binomialCoefficient\ *\ \((sampleSize\  - \ j\  + \ 1)\)/\ 
                  j\ , \ internalPrecision]; \[IndentingNewLine]secondTerm\  \
= \ N[secondTerm\  - \ \((1/sampleSize)\)\ , 
              internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ 
            N[thirdTerm\  + \ \((1/sampleSize)\)\ , 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + \((binomialCoefficient\ *\ 
                    secondTerm^\((sampleSize\  - \ j\  - \ 1)\)\ *\ 
                    thirdTerm^j)\), \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1\  - \ \((d\ *\ sumTerms)\), \ 
            internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
8.1  DwassD Minimum Precision Minus Desired Precision Sample Intermediate \
Output\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionDwassD[\[InvisibleSpace]0.0185679, \ 
      10000\[InvisibleSpace], \ 20, \ 2]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("MinPrecisionMinusDesiredPrecisionDwassD:"\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.0185679`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0185679`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]20\),
        SequenceForm[ 
        "MinPrecisionMinusDesiredPrecisionDwassD:", " sampleSize = ", 10000, 
          "   testStatistic = ", .018567899999999998, 
          " = ", .018567899999999998, "    desiredPrecision = ", 20],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   FindHighLimit: numberTries = \
"\[InvisibleSpace]1\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]20\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]120\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]120\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]12\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.0009996621833282029441256229`12.488873157389792\),
        SequenceForm[ 
        "   FindHighLimit: numberTries = ", 1, 
          ", internalPrecisionLowLimit = ", 20, ", setInternalPrecision = ", 
          120, ", internalPrecisionHighLimit = ", 120, 
          ", desiredPrecision = ", 20, ", currentPrecision = ", 12, 
          ", rightTailProbability = ", 
          0.0009996621833282029441256229`12.488873157389792],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   FindHighLimit: numberTries = \
"\[InvisibleSpace]2\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]120\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]128\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]128\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.00099966218332820294412562155045767909`20.488873157389772\)\
,
        SequenceForm[ 
        "   FindHighLimit: numberTries = ", 2, 
          ", internalPrecisionLowLimit = ", 120, ", setInternalPrecision = ", 
          128, ", internalPrecisionHighLimit = ", 128, 
          ", desiredPrecision = ", 20, ", currentPrecision = ", 20, 
          ", rightTailProbability = ", 
          0.00099966218332820294412562155045767909`20.488873157389772],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]3\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]120\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]124\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]128\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]16\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.00099966218332820294412562154985084689`16.488873157389765\)\
,
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 3, 
          ", internalPrecisionLowLimit = ", 120, ", setInternalPrecision = ", 
          124, ", internalPrecisionHighLimit = ", 128, 
          ", desiredPrecision = ", 20, ", currentPrecision = ", 16, 
          ", rightTailProbability = ", 
          0.00099966218332820294412562154985084689`16.488873157389765],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]4\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]124\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]126\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]128\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]18\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.00099966218332820294412562155045209522`18.48887315738977\),
        
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 4, 
          ", internalPrecisionLowLimit = ", 124, ", setInternalPrecision = ", 
          126, ", internalPrecisionHighLimit = ", 128, 
          ", desiredPrecision = ", 20, ", currentPrecision = ", 18, 
          ", rightTailProbability = ", 
          0.00099966218332820294412562155045209522`18.48887315738977],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]5\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]126\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]127\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]128\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]19\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.00099966218332820294412562155045773336`19.488873157389786\)\
,
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 5, 
          ", internalPrecisionLowLimit = ", 126, ", setInternalPrecision = ", 
          127, ", internalPrecisionHighLimit = ", 128, 
          ", desiredPrecision = ", 20, ", currentPrecision = ", 19, 
          ", rightTailProbability = ", 
          0.00099966218332820294412562155045773336`19.488873157389786],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Determine whether low or high limit is minimum \
precision: numberTries = "\[InvisibleSpace]6\[InvisibleSpace]", \
internalPrecisionLowLimit = "\[InvisibleSpace]127\[InvisibleSpace]", \
setInternalPrecision = "\[InvisibleSpace]127\[InvisibleSpace]", \
internalPrecisionHighLimit = "\[InvisibleSpace]128\[InvisibleSpace]", \
desiredPrecision = "\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision \
for low limit = "\[InvisibleSpace]19\[InvisibleSpace]", rightTailProbability \
= "\[InvisibleSpace]0.00099966218332820294412562155045773336`19.\
488873157389786\),
        SequenceForm[ 
        "   Determine whether low or high limit is minimum precision: \
numberTries = ", 6, ", internalPrecisionLowLimit = ", 127, 
          ", setInternalPrecision = ", 127, ", internalPrecisionHighLimit = ",
           128, ", desiredPrecision = ", 20, 
          ", currentPrecision for low limit = ", 19, 
          ", rightTailProbability = ", 
          0.00099966218332820294412562155045773336`19.488873157389786],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Minimum Internal Precision Found: "\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.0185679`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0185679`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]20\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]6\
\[InvisibleSpace]"   minimumInternalPrecision = "\[InvisibleSpace]128\
\[InvisibleSpace]"   minPrecisionMinusDesiredPrecision = \
"\[InvisibleSpace]108\),
        SequenceForm[ 
        "   Minimum Internal Precision Found: ", " sampleSize = ", 10000, 
          "   testStatistic = ", .018567899999999998, 
          " = ", .018567899999999998, "    desiredPrecision = ", 20, 
          "   numberTries = ", 6, "   minimumInternalPrecision = ", 128, 
          "   minPrecisionMinusDesiredPrecision = ", 108],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`{6, 108}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionDwassD[\[InvisibleSpace]0.0185679, \ 
      10000\[InvisibleSpace], \ 100, \ 2]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("MinPrecisionMinusDesiredPrecisionDwassD:"\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.0185679`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0185679`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]100\),
        SequenceForm[ 
        "MinPrecisionMinusDesiredPrecisionDwassD:", " sampleSize = ", 10000, 
          "   testStatistic = ", .018567899999999998, 
          " = ", .018567899999999998, "    desiredPrecision = ", 100],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   FindHighLimit: numberTries = \
"\[InvisibleSpace]1\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]100\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]200\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]200\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]92\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
000999662183328202944125621550457714894310537494670134398443417283814375958241\
391148705746267497047391913`92.48887315738983\),
        SequenceForm[ 
        "   FindHighLimit: numberTries = ", 1, 
          ", internalPrecisionLowLimit = ", 100, ", setInternalPrecision = ", 
          200, ", internalPrecisionHighLimit = ", 200, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 92, 
          ", rightTailProbability = ", 
          0.000999662183328202944125621550457714894310537494670134398443417283\
814375958241391148705746267497047391913`92.48887315738983],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   FindHighLimit: numberTries = \
"\[InvisibleSpace]2\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]200\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]208\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]208\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
000999662183328202944125621550457714894310537494670134398443417283814375958241\
3911487057462674970473919133895829918`100.48887315738985\),
        SequenceForm[ 
        "   FindHighLimit: numberTries = ", 2, 
          ", internalPrecisionLowLimit = ", 200, ", setInternalPrecision = ", 
          208, ", internalPrecisionHighLimit = ", 208, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 100, 
          ", rightTailProbability = ", 
          0.000999662183328202944125621550457714894310537494670134398443417283\
8143759582413911487057462674970473919133895829918`100.48887315738985],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]3\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]200\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]204\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]208\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]96\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
000999662183328202944125621550457714894310537494670134398443417283814375958241\
3911487057462674970473919133895848619`96.48887315738983\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 3, 
          ", internalPrecisionLowLimit = ", 200, ", setInternalPrecision = ", 
          204, ", internalPrecisionHighLimit = ", 208, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 96, 
          ", rightTailProbability = ", 
          0.000999662183328202944125621550457714894310537494670134398443417283\
8143759582413911487057462674970473919133895848619`96.48887315738983],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]4\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]204\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]206\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]208\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]98\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
000999662183328202944125621550457714894310537494670134398443417283814375958241\
391148705746267497047391913389582987`98.4888731573898\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 4, 
          ", internalPrecisionLowLimit = ", 204, ", setInternalPrecision = ", 
          206, ", internalPrecisionHighLimit = ", 208, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 98, 
          ", rightTailProbability = ", 
          0.000999662183328202944125621550457714894310537494670134398443417283\
814375958241391148705746267497047391913389582987`98.4888731573898],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]5\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]206\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]207\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]208\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]99\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
000999662183328202944125621550457714894310537494670134398443417283814375958241\
391148705746267497047391913389582987`99.48887315738983\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 5, 
          ", internalPrecisionLowLimit = ", 206, ", setInternalPrecision = ", 
          207, ", internalPrecisionHighLimit = ", 208, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 99, 
          ", rightTailProbability = ", 
          0.000999662183328202944125621550457714894310537494670134398443417283\
814375958241391148705746267497047391913389582987`99.48887315738983],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Determine whether low or high limit is minimum \
precision: numberTries = "\[InvisibleSpace]6\[InvisibleSpace]", \
internalPrecisionLowLimit = "\[InvisibleSpace]207\[InvisibleSpace]", \
setInternalPrecision = "\[InvisibleSpace]207\[InvisibleSpace]", \
internalPrecisionHighLimit = "\[InvisibleSpace]208\[InvisibleSpace]", \
desiredPrecision = "\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision \
for low limit = "\[InvisibleSpace]99\[InvisibleSpace]", rightTailProbability \
= "\[InvisibleSpace]0.\
000999662183328202944125621550457714894310537494670134398443417283814375958241\
391148705746267497047391913389582987`99.48887315738983\),
        SequenceForm[ 
        "   Determine whether low or high limit is minimum precision: \
numberTries = ", 6, ", internalPrecisionLowLimit = ", 207, 
          ", setInternalPrecision = ", 207, ", internalPrecisionHighLimit = ",
           208, ", desiredPrecision = ", 100, 
          ", currentPrecision for low limit = ", 99, 
          ", rightTailProbability = ", 
          0.000999662183328202944125621550457714894310537494670134398443417283\
814375958241391148705746267497047391913389582987`99.48887315738983],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Minimum Internal Precision Found: "\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.0185679`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0185679`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]100\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]6\
\[InvisibleSpace]"   minimumInternalPrecision = "\[InvisibleSpace]208\
\[InvisibleSpace]"   minPrecisionMinusDesiredPrecision = \
"\[InvisibleSpace]108\),
        SequenceForm[ 
        "   Minimum Internal Precision Found: ", " sampleSize = ", 10000, 
          "   testStatistic = ", .018567899999999998, 
          " = ", .018567899999999998, "    desiredPrecision = ", 100, 
          "   numberTries = ", 6, "   minimumInternalPrecision = ", 208, 
          "   minPrecisionMinusDesiredPrecision = ", 108],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`{6, 108}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionDwassD[\[InvisibleSpace]0.00227855, \ 
      10000\[InvisibleSpace], \ 20, \ 2]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("MinPrecisionMinusDesiredPrecisionDwassD:"\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.00227855`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.00227855`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]20\),
        SequenceForm[ 
        "MinPrecisionMinusDesiredPrecisionDwassD:", " sampleSize = ", 10000, 
          "   testStatistic = ", .0022785499999999998, 
          " = ", .0022785499999999998, "    desiredPrecision = ", 20],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   FindHighLimit: numberTries = \
"\[InvisibleSpace]1\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]20\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]120\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]120\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]106\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
57423203977333122521487532944587443655896044916`106.06375660427807\),
        SequenceForm[ 
        "   FindHighLimit: numberTries = ", 1, 
          ", internalPrecisionLowLimit = ", 20, ", setInternalPrecision = ", 
          120, ", internalPrecisionHighLimit = ", 120, 
          ", desiredPrecision = ", 20, ", currentPrecision = ", 106, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
43202665708657423203977333122521487532944587443655896044916`106.\
06375660427807],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]2\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]20\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]70\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]120\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]56\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
9000070970533918622476850392621992484318540400200748312358947518536`56.\
063756604278076\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 2, 
          ", internalPrecisionLowLimit = ", 20, ", setInternalPrecision = ", 
          70, ", internalPrecisionHighLimit = ", 120, ", desiredPrecision = ",
           20, ", currentPrecision = ", 56, ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
6`56.063756604278076],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]3\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]20\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]45\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]70\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]31\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.90000709705339186224768503926219924843187082686`31.\
063756604278083\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 3, 
          ", internalPrecisionLowLimit = ", 20, ", setInternalPrecision = ", 
          45, ", internalPrecisionHighLimit = ", 70, ", desiredPrecision = ", 
          20, ", currentPrecision = ", 31, ", rightTailProbability = ", 
          0.90000709705339186224768503926219924843187082686`31.\
063756604278083],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]4\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]20\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]32\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]45\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]18\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.9000070970533918622476850393`18.063756604278087\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 4, 
          ", internalPrecisionLowLimit = ", 20, ", setInternalPrecision = ", 
          32, ", internalPrecisionHighLimit = ", 45, ", desiredPrecision = ", 
          20, ", currentPrecision = ", 18, ", rightTailProbability = ", 
          0.9000070970533918622476850393`18.063756604278087],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]5\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]32\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]38\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]45\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]24\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.90000709705339186224768503926219924643`24.063756604278094\)\
,
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 5, 
          ", internalPrecisionLowLimit = ", 32, ", setInternalPrecision = ", 
          38, ", internalPrecisionHighLimit = ", 45, ", desiredPrecision = ", 
          20, ", currentPrecision = ", 24, ", rightTailProbability = ", 
          0.90000709705339186224768503926219924643`24.063756604278094],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]6\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]32\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]35\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]38\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]21\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.90000709705339186224768503926220387863`21.06375660427809\),
        
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 6, 
          ", internalPrecisionLowLimit = ", 32, ", setInternalPrecision = ", 
          35, ", internalPrecisionHighLimit = ", 38, ", desiredPrecision = ", 
          20, ", currentPrecision = ", 21, ", rightTailProbability = ", 
          0.90000709705339186224768503926220387863`21.06375660427809],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]7\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]32\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]33\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]35\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]19\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.9000070970533918622476850393`19.063756604278087\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 7, 
          ", internalPrecisionLowLimit = ", 32, ", setInternalPrecision = ", 
          33, ", internalPrecisionHighLimit = ", 35, ", desiredPrecision = ", 
          20, ", currentPrecision = ", 19, ", rightTailProbability = ", 
          0.9000070970533918622476850393`19.063756604278087],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]8\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]33\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]34\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]35\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.90000709705339186224768503926223263797`20.06375660427809\),
        
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 8, 
          ", internalPrecisionLowLimit = ", 33, ", setInternalPrecision = ", 
          34, ", internalPrecisionHighLimit = ", 35, ", desiredPrecision = ", 
          20, ", currentPrecision = ", 20, ", rightTailProbability = ", 
          0.90000709705339186224768503926223263797`20.06375660427809],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Determine whether low or high limit is minimum \
precision: numberTries = "\[InvisibleSpace]9\[InvisibleSpace]", \
internalPrecisionLowLimit = "\[InvisibleSpace]33\[InvisibleSpace]", \
setInternalPrecision = "\[InvisibleSpace]33\[InvisibleSpace]", \
internalPrecisionHighLimit = "\[InvisibleSpace]34\[InvisibleSpace]", \
desiredPrecision = "\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision \
for low limit = "\[InvisibleSpace]19\[InvisibleSpace]", rightTailProbability \
= "\[InvisibleSpace]0.9000070970533918622476850393`19.063756604278087\),
        SequenceForm[ 
        "   Determine whether low or high limit is minimum precision: \
numberTries = ", 9, ", internalPrecisionLowLimit = ", 33, 
          ", setInternalPrecision = ", 33, ", internalPrecisionHighLimit = ", 
          34, ", desiredPrecision = ", 20, 
          ", currentPrecision for low limit = ", 19, 
          ", rightTailProbability = ", 
          0.9000070970533918622476850393`19.063756604278087],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Minimum Internal Precision Found: "\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.00227855`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.00227855`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]20\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]9\
\[InvisibleSpace]"   minimumInternalPrecision = "\[InvisibleSpace]34\
\[InvisibleSpace]"   minPrecisionMinusDesiredPrecision = "\[InvisibleSpace]14\
\),
        SequenceForm[ 
        "   Minimum Internal Precision Found: ", " sampleSize = ", 10000, 
          "   testStatistic = ", .0022785499999999998, 
          " = ", .0022785499999999998, "    desiredPrecision = ", 20, 
          "   numberTries = ", 9, "   minimumInternalPrecision = ", 34, 
          "   minPrecisionMinusDesiredPrecision = ", 14],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`{9, 14}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionDwassD[\[InvisibleSpace]0.00227855, \ 
      10000\[InvisibleSpace], \ 100, \ 2]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("MinPrecisionMinusDesiredPrecisionDwassD:"\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.00227855`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.00227855`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]100\),
        SequenceForm[ 
        "MinPrecisionMinusDesiredPrecisionDwassD:", " sampleSize = ", 10000, 
          "   testStatistic = ", .0022785499999999998, 
          " = ", .0022785499999999998, "    desiredPrecision = ", 100],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   FindHighLimit: numberTries = \
"\[InvisibleSpace]1\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]100\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]200\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]200\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]186\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
574232039773331225214875329445874436559343337822145489039989694596584351287545\
7268527068422767664995488423420968570807068068`186.06375660427815\),
        SequenceForm[ 
        "   FindHighLimit: numberTries = ", 1, 
          ", internalPrecisionLowLimit = ", 100, ", setInternalPrecision = ", 
          200, ", internalPrecisionHighLimit = ", 200, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 186, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
432026657086574232039773331225214875329445874436559343337822145489039989694596\
5843512875457268527068422767664995488423420968570807068068`186.06375660427815]\
,
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]2\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]100\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]150\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]200\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]136\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
5742320397733312252148753294458744365593433378221454890399896945965833132894`\
136.06375660427807\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 2, 
          ", internalPrecisionLowLimit = ", 100, ", setInternalPrecision = ", 
          150, ", internalPrecisionHighLimit = ", 200, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 136, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
432026657086574232039773331225214875329445874436559343337822145489039989694596\
5833132894`136.06375660427807],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]3\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]100\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]125\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]150\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]111\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
57423203977333122521487532944587443655934333322`111.06375660427805\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 3, 
          ", internalPrecisionLowLimit = ", 100, ", setInternalPrecision = ", 
          125, ", internalPrecisionHighLimit = ", 150, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 111, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
43202665708657423203977333122521487532944587443655934333322`111.\
06375660427805],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]4\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]100\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]112\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]125\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]98\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
574232039773331225214875329446226253`98.06375660427807\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 4, 
          ", internalPrecisionLowLimit = ", 100, ", setInternalPrecision = ", 
          112, ", internalPrecisionHighLimit = ", 125, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 98, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
432026657086574232039773331225214875329446226253`98.06375660427807],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]5\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]112\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]118\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]125\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]104\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
5742320397733312252148753294458744363`104.06375660427805\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 5, 
          ", internalPrecisionLowLimit = ", 112, ", setInternalPrecision = ", 
          118, ", internalPrecisionHighLimit = ", 125, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 104, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
4320266570865742320397733312252148753294458744363`104.06375660427805],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]6\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]112\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]115\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]118\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]101\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
5742320397733312252148753294458744706`101.06375660427807\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 6, 
          ", internalPrecisionLowLimit = ", 112, ", setInternalPrecision = ", 
          115, ", internalPrecisionHighLimit = ", 118, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 101, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
4320266570865742320397733312252148753294458744706`101.06375660427807],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]7\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]112\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]113\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]115\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]99\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
5742320397733312252148753294458835397`99.06375660427807\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 7, 
          ", internalPrecisionLowLimit = ", 112, ", setInternalPrecision = ", 
          113, ", internalPrecisionHighLimit = ", 115, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 99, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
4320266570865742320397733312252148753294458835397`99.06375660427807],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]8\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]113\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]114\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]115\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
5742320397733312252148753294458743071`100.06375660427807\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 8, 
          ", internalPrecisionLowLimit = ", 113, ", setInternalPrecision = ", 
          114, ", internalPrecisionHighLimit = ", 115, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 100, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
4320266570865742320397733312252148753294458743071`100.06375660427807],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Determine whether low or high limit is minimum \
precision: numberTries = "\[InvisibleSpace]9\[InvisibleSpace]", \
internalPrecisionLowLimit = "\[InvisibleSpace]113\[InvisibleSpace]", \
setInternalPrecision = "\[InvisibleSpace]113\[InvisibleSpace]", \
internalPrecisionHighLimit = "\[InvisibleSpace]114\[InvisibleSpace]", \
desiredPrecision = "\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision \
for low limit = "\[InvisibleSpace]99\[InvisibleSpace]", rightTailProbability \
= "\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
5742320397733312252148753294458835397`99.06375660427807\),
        SequenceForm[ 
        "   Determine whether low or high limit is minimum precision: \
numberTries = ", 9, ", internalPrecisionLowLimit = ", 113, 
          ", setInternalPrecision = ", 113, ", internalPrecisionHighLimit = ",
           114, ", desiredPrecision = ", 100, 
          ", currentPrecision for low limit = ", 99, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
4320266570865742320397733312252148753294458835397`99.06375660427807],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Minimum Internal Precision Found: "\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.00227855`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.00227855`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]100\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]9\
\[InvisibleSpace]"   minimumInternalPrecision = "\[InvisibleSpace]114\
\[InvisibleSpace]"   minPrecisionMinusDesiredPrecision = "\[InvisibleSpace]14\
\),
        SequenceForm[ 
        "   Minimum Internal Precision Found: ", " sampleSize = ", 10000, 
          "   testStatistic = ", .0022785499999999998, 
          " = ", .0022785499999999998, "    desiredPrecision = ", 100, 
          "   numberTries = ", 9, "   minimumInternalPrecision = ", 114, 
          "   minPrecisionMinusDesiredPrecision = ", 14],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`{9, 14}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["9. Calculation Time for DwassD", "Section"],

Cell["\<\
The following is the code of the Mathematica function \
TimingDwassDKS1SidedOneSampleRTArbPrecision.  Sample output is given in \
subsection 9.1.\
\>", "Text"],

Cell[BoxData[
    \(TimingDwassDKS1SidedOneSampleRTArbPrecision[alpha_, \ sampleSizeIn_, \ 
        desiredPrecisionIn_, \ testStatisticDesiredPrecisionIn_]\ \  := 
      Module[{d, \ \ sampleSize, \ minimumPrecision, \ desiredPrecision, \ 
          testStatisticDesiredPrecision, \ functionOutput, \ 
          rightTailProbability, rightTailProbabilityPrecision, \ 
          functionTimeString, \ timeString}, \[IndentingNewLine] (*\ 
          For\ the\ KS\ 1\ sided\ one\ sample\ test, \ 
          the\ Maag\ and\ Dicaire\ formula\ is\ used\ *) \[IndentingNewLine] \
(*\ \ \ \ for\ sample\ size\ sampleSizeIn\ and\ right\ tail\ p - 
            value\ alpha\ to\ produce\ a\ *) \[IndentingNewLine] (*\ \ \ \ \
test\ statistic\ d\ with\ testStatisticDesiredPrecisionIn\ decimal\ digits\ \
of\ *) \[IndentingNewLine] (*\ \ \ \ accuracy . \ \ Then\ the\ minimum\ \
precision\ minimumPrecision\ needed\ for\ the\ *) \[IndentingNewLine] (*\ \ \ \
\ arbitrary\ precision\ DwassD\ formula\ to\ calculate\ a\ right\ tail\ \
*) \[IndentingNewLine] (*\ \ \ \ probability\ with\ desiredPrecisionIn\ \
digits\ of\ precision\ for\ test\ *) \[IndentingNewLine] (*\ \ \ \ statistic\ \
d\ and\ sample\ size\ sampleSizeIn\ is\ \(\(calculated\)\(.\)\)\ \
*) \[IndentingNewLine] (*\ \ \ \ Finally, \ 
          the\ time\ in\ seconds\ for\ the\ arbitrary\ precision\ DwassD\ \
*) \[IndentingNewLine] (*\ \ \ \ formula\ to\ calculate\ the\ right\ tail\ \
probability\ for\ test\ statistic\ d\ *) \[IndentingNewLine] (*\ \ \ \ and\ \
sample\ size\ sampleSizeIn\ with\ an\ internal\ precision\ of\ \
*) \[IndentingNewLine] (*\ \ \ \ minimumPrecision\ is\ found\ and\ \
\(\(printed\)\(.\)\)\ *) \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]desiredPrecision\  = \ 
          Floor[desiredPrecisionIn]; \
\[IndentingNewLine]testStatisticDesiredPrecision\  = \ 
          Floor[testStatisticDesiredPrecisionIn]; \[IndentingNewLine]d\  = \ 
          KS1SidedOneSampleTestStatisticByMaagDicaire[alpha, sampleSize, \ 
            
            testStatisticDesiredPrecision]; \[IndentingNewLine]functionOutput\
\  = MinPrecisionMinusDesiredPrecisionDwassD[d, \ sampleSize, \ 
            desiredPrecision, \ 0]; \[IndentingNewLine]minimumPrecision\  = \ 
          functionOutput[\([2]\)]; \[IndentingNewLine]minimumPrecision\  = \ 
          minimumPrecision\  + \ 
            desiredPrecision; \[IndentingNewLine]functionOutput\  = \ 
          Timing[DwassDKS1SidedOneSampleRTArbPrecision[d, \ sampleSize, \ 
              minimumPrecision]]; \[IndentingNewLine]rightTailProbability\  = \
\ functionOutput[\([2]\)]; \[IndentingNewLine]rightTailProbabilityPrecision\  \
= \ Floor[Precision[
              rightTailProbability]]; \[IndentingNewLine]functionTimeString\  \
= \ functionOutput[\([1]\)]; \[IndentingNewLine]timeString\  = \ 
          functionTimeString\  /. \ 
            Second \[Rule] 
              1; \[IndentingNewLine]Print["\<\
TimingDwassDKS1SidedOneSampleRTArbPrecision: sampleSize = \>", \ 
          sampleSize, \ "\<   alpha = \>", \ 
          alpha, \ "\<  desiredPrecision = \>", \ 
          desiredPrecision, \ "\<   testStatisticDesiredPrecision = \>", \ 
          testStatisticDesiredPrecision, \ "\<   d = \>", \ 
          d, \ "\<   minimumPrecision = \>", \ 
          minimumPrecision, \ \ \ "\<   rightTailProbability = \>", \ 
          rightTailProbability, \ "\<  rightTailProbabilityPrecision = \>", \ 
          rightTailProbabilityPrecision, \ "\<   time in seconds = \>", \ 
          timeString\ ]; \
\[IndentingNewLine]sampleSize\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(KS1SidedOneSampleTestStatisticByMaagDicaire[alphaIn_, sampleSizeIn_, \ 
        rho_]\  := \[IndentingNewLine]Module[{d, \ alpha, \ 
          sampleSize}, \[IndentingNewLine] (*\ 
          For\ the\ KS\ 1\ sided\ one\ sample\ test, \ 
          the\ Maag\ and\ Dicaire\ formula\ is\ used\ *) \[IndentingNewLine] \
(*\ \ \ \ to\ approximate\ the\ test\ statistic\ corresponding\ to\ a\ right\ \
tail\ *) \[IndentingNewLine] (*\ \ \ \ probability\ of\ alphaIn . \ \ The\ \
test\ statistic\ d\ is\ calculated\ to\ *) \[IndentingNewLine] (*\ \ \ \ rho\ \
number\ of\ decimal\ \(\(digits\)\(.\)\)\ *) \[IndentingNewLine]alpha\  = 
          Rationalize[alphaIn, \ 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine] (*\ 
          Use\ Maag\ and\ Dicaire\ \(\(MD\)\(.\)\)\ *) \[IndentingNewLine]d\  \
= \ N[Sqrt[Log[alpha]/\((\(-2\)*sampleSize)\)] - \ \((1/\((6*
                      sampleSize)\))\), 
            rho\ \  + \ 17]; \[IndentingNewLine]d\  = \ 
          N[d, rho]; \[IndentingNewLine]d\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionDwassD[testStatistic_, \ 
        sampleSize_, \ desiredPrecision_, \ intermediateOutput_]\  := \ 
      Module[{internalPrecisionLowLimit, \ internalPrecisionHighLimit, \ 
          setInternalPrecision, \ currentPrecision, \ SquareRootN, \ 
          numberTries, \ rightTailProbability, \ 
          rightTailProbabilityToDesiredPrecision, \ 
          minPrecisionMinusDesiredPrecision, \ mantissaExp, \ numExp, \ 
          prop}, \[IndentingNewLine]SquareRootN\  = \ 
          Ceiling[Sqrt[sampleSize]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 1, \ 
          Print["\<MinPrecisionMinusDesiredPrecisionDwassD:\>", \ "\< \
sampleSize = \>", \ sampleSize, \ "\<   testStatistic = \>", \ 
            testStatistic, "\< = \>", \ 
            N[testStatistic, 6], \ \ "\<    desiredPrecision = \>", \ 
            desiredPrecision]]; \[IndentingNewLine]numberTries\  = \ 
          0; \[IndentingNewLine]internalPrecisionLowLimit\  = \ 
          desiredPrecision; \[IndentingNewLine]internalPrecisionHighLimit\  = \
\ SquareRootN\  + \ \ desiredPrecision; \
\[IndentingNewLine]setInternalPrecision\  = \ 
          internalPrecisionHighLimit; \[IndentingNewLine] (*\ 
          Determine\ a\ high\ limit\ for\ minimumPrecision\ \
*) \[IndentingNewLine]Label[
          DetermineInternalPrecisionHighLimit]; \
\[IndentingNewLine]numberTries\  = \ 
          numberTries\ \  + \ 
            1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassDKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   FindHighLimit: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision = \>", \ \ \
currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  \[GreaterEqual] \ desiredPrecision, \ 
          Goto[HighLimitFound], \ 
          Goto[HighLimitTooSmall]]; \[IndentingNewLine] (*\ 
          Current\ high\ limit\ too\ small\ *) \[IndentingNewLine]Label[
          HighLimitTooSmall]; \[IndentingNewLine]internalPrecisionLowLimit\  \
= \ internalPrecisionHighLimit; \[IndentingNewLine]internalPrecisionHighLimit\
\  = \ internalPrecisionHighLimit\  + \ desiredPrecision\  - \ 
            currentPrecision; \[IndentingNewLine]setInternalPrecision\  = \ 
          internalPrecisionHighLimit; \[IndentingNewLine]Goto[
          DetermineInternalPrecisionHighLimit]; \[IndentingNewLine] (*\ 
          High\ limit\ found\ *) \[IndentingNewLine]Label[
          HighLimitFound]; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Bisection\ search\ to\ find\ minimumPrecision\ between\ \
\[IndentingNewLine]\ \ \ \ internalPrecisionLowLimit\ and\ \
internalPrecisionHighLimit\ *) \[IndentingNewLine]Label[
          BisectionIteration]; \[IndentingNewLine]setInternalPrecision\  = \ 
          Floor[\((internalPrecisionLowLimit\  + \ 
                  internalPrecisionHighLimit)\)/2]; \[IndentingNewLine]If[
          setInternalPrecision\ \  \[LessEqual] \ 
            internalPrecisionLowLimit, \ 
          setInternalPrecision\ \  = \ 
            internalPrecisionLowLimit\  + \ 1, \[IndentingNewLine]\(If[
              setInternalPrecision\ \  \[GreaterEqual] \ \ \
internalPrecisionHighLimit, \ 
              setInternalPrecision\ \  = \ 
                internalPrecisionHighLimit\  - \ 
                  1];\)\[IndentingNewLine]]; \[IndentingNewLine]numberTries\  \
= \ numberTries\ \  + \ 1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassDKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   Bisection Search: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision = \>", \ \ \
currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  \[GreaterEqual] \ desiredPrecision, \ 
          Goto[ResetHighLimit], \ 
          Goto[ResetLowLimit]]; \[IndentingNewLine] (*\ 
          Reset\ internalPrecisionHighLimit\ to\ currentPrecision\ \
*) \[IndentingNewLine]Label[
          ResetHighLimit]; \[IndentingNewLine]internalPrecisionHighLimit\  = \
\ setInternalPrecision; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Reset\ internalPrecisionLowLimit\ to\ currentPrecision\ \
*) \[IndentingNewLine]Label[
          ResetLowLimit]; \[IndentingNewLine]internalPrecisionLowLimit\  = \ 
          setInternalPrecision; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Minimum\ internal\ precision\ found\ *) \[IndentingNewLine]Label[
          MinInternalPrecisionFound]; \[IndentingNewLine]setInternalPrecision\
\  = \ internalPrecisionHighLimit; \[IndentingNewLine]setInternalPrecision\  \
= \ internalPrecisionLowLimit; \[IndentingNewLine]numberTries\  = \ 
          numberTries\ \  + \ 
            1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassDKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   Determine whether low or high limit is minimum \
precision: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision for low limit = \>", \ \
\ currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  < \ desiredPrecision, \ 
          setInternalPrecision\  = \ internalPrecisionHighLimit, \ 
          setInternalPrecision\  = \ 
            internalPrecisionLowLimit]; \
\[IndentingNewLine]minPrecisionMinusDesiredPrecision\  = \ 
          setInternalPrecision\  - \ \ desiredPrecision; \
\[IndentingNewLine]If[\ intermediateOutput \[GreaterEqual] \ 1, \ 
          Print["\<   Minimum Internal Precision Found: \>", \ "\< sampleSize \
= \>", \ sampleSize, \ "\<   testStatistic = \>", \ 
            testStatistic, \ "\< = \>", \ 
            N[testStatistic, 6], \ "\<    desiredPrecision = \>", \ 
            desiredPrecision, \ "\<   numberTries = \>", \ 
            numberTries, \ "\<   minimumInternalPrecision = \>", \ 
            setInternalPrecision, \ "\<   minPrecisionMinusDesiredPrecision = \
\>", \ minPrecisionMinusDesiredPrecision\ ]]; \
\[IndentingNewLine]{numberTries, \ 
          minPrecisionMinusDesiredPrecision}\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassDKS1SidedOneSampleRTArbPrecision[dIn_, sampleSizeIn_, 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ 
          rightTailProbability, \ binomialCoefficient, \ secondTerm, \ 
          thirdTerm, \ sumTerms}, \[IndentingNewLine] (*\ 
          Dwass\ Direct\ formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ \
sample\ *) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ 
              d]; \[IndentingNewLine]binomialCoefficient\  = \ 
          1; \[IndentingNewLine]secondTerm\ \  = \ 
          N[1\  + \ d, \ 
            internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ \(-d\); \
\[IndentingNewLine]sumTerms\  = \ 
          N[secondTerm^\((sampleSize - 1)\), \ 
            internalPrecision]; \[IndentingNewLine]If[jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]binomialCoefficient\  = \ 
            N[binomialCoefficient\ *\ \((sampleSize\  - \ j\  + \ 1)\)/\ 
                  j\ , \ internalPrecision]; \[IndentingNewLine]secondTerm\  \
= \ N[secondTerm\  - \ \((1/sampleSize)\)\ , 
              internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ 
            N[thirdTerm\  + \ \((1/sampleSize)\)\ , 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + \((binomialCoefficient\ *\ 
                    secondTerm^\((sampleSize\  - \ j\  - \ 1)\)\ *\ 
                    thirdTerm^j)\), \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1\  - \ \((d\ *\ sumTerms)\), \ 
            internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
9.1  Calculation Time for DwassD Sample Output on a 3.4 GHz Pentium IV\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassDKS1SidedOneSampleRTArbPrecision[0.001, \ 1000000, \ 20, \ 
      6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassDKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]1000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.001`\[InvisibleSpace]"  desiredPrecision = "\
\[InvisibleSpace]20\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0018582944277582526`6. \[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]1058\[InvisibleSpace]"   \
rightTailProbability = \
"\[InvisibleSpace]0.00100000519945517771720304317323965659`20.806806628450566\
\[InvisibleSpace]"  rightTailProbabilityPrecision = "\[InvisibleSpace]20\
\[InvisibleSpace]"   time in seconds = \
"\[InvisibleSpace]2.6409999999999982`\),
        SequenceForm[ 
        "TimingDwassDKS1SidedOneSampleRTArbPrecision: sampleSize = ", 1000000,
           "   alpha = ", .001, "  desiredPrecision = ", 20, 
          "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0018582944277582526`6., "   minimumPrecision = ", 1058, 
          "   rightTailProbability = ", 
          0.00100000519945517771720304317323965659`20.806806628450566, 
          "  rightTailProbabilityPrecision = ", 20, "   time in seconds = ", 
          2.6409999999999982],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`1000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassDKS1SidedOneSampleRTArbPrecision[0.001, \ 1000000, \ 100, \ 
      6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassDKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]1000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.001`\[InvisibleSpace]"  desiredPrecision = "\
\[InvisibleSpace]100\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0018582944277582526`6. \[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]1138\[InvisibleSpace]"   \
rightTailProbability = \
"\[InvisibleSpace]0.\
001000005199455177717203043173239657016576905944280063055591650077084956245924\
2870800970192444170276407025055827627`100.80680662845042\[InvisibleSpace]"  \
rightTailProbabilityPrecision = "\[InvisibleSpace]100\[InvisibleSpace]"   \
time in seconds = "\[InvisibleSpace]2.8599999999999994`\),
        SequenceForm[ 
        "TimingDwassDKS1SidedOneSampleRTArbPrecision: sampleSize = ", 1000000,
           "   alpha = ", .001, "  desiredPrecision = ", 100, 
          "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0018582944277582526`6., "   minimumPrecision = ", 1138, 
          "   rightTailProbability = ", 
          0.001000005199455177717203043173239657016576905944280063055591650077\
0849562459242870800970192444170276407025055827627`100.80680662845042, 
          "  rightTailProbabilityPrecision = ", 100, "   time in seconds = ", 
          2.8599999999999994],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`1000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassDKS1SidedOneSampleRTArbPrecision[0.9, \ 1000000, \ 20, \ 
      6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassDKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]1000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.9`\[InvisibleSpace]"  desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0002293551358465437218400548`6.000000000000002\
\[InvisibleSpace]"   minimumPrecision = \
"\[InvisibleSpace]150\[InvisibleSpace]"   rightTailProbability = "\
\[InvisibleSpace]0.90000015781059704546078396499617933875`20.36706903131426\
\[InvisibleSpace]"  rightTailProbabilityPrecision = "\[InvisibleSpace]20\
\[InvisibleSpace]"   time in seconds = \
"\[InvisibleSpace]0.030999999999998806`\),
        SequenceForm[ 
        "TimingDwassDKS1SidedOneSampleRTArbPrecision: sampleSize = ", 1000000,
           "   alpha = ", .90000000000000002, "  desiredPrecision = ", 20, 
          "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0002293551358465437218400548`6.000000000000002, 
          "   minimumPrecision = ", 150, "   rightTailProbability = ", 
          0.90000015781059704546078396499617933875`20.36706903131426, 
          "  rightTailProbabilityPrecision = ", 20, 
          "   time in seconds = ", .030999999999998806],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`1000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassDKS1SidedOneSampleRTArbPrecision[0.001, \ 5000000, \ 20, \ 
      6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassDKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]5000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.001`\[InvisibleSpace]"  desiredPrecision = "\
\[InvisibleSpace]20\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0008310957348012216`5.999999999999999\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]2334\[InvisibleSpace]"   \
rightTailProbability = \
"\[InvisibleSpace]0.00099999870917696091267298145583197186`20.990954163265926\
\[InvisibleSpace]"  rightTailProbabilityPrecision = "\[InvisibleSpace]20\
\[InvisibleSpace]"   time in seconds = \
"\[InvisibleSpace]35.389999999999986`\),
        SequenceForm[ 
        "TimingDwassDKS1SidedOneSampleRTArbPrecision: sampleSize = ", 5000000,
           "   alpha = ", .001, "  desiredPrecision = ", 20, 
          "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0008310957348012216`5.999999999999999, "   minimumPrecision = ", 
          2334, "   rightTailProbability = ", 
          0.00099999870917696091267298145583197186`20.990954163265926, 
          "  rightTailProbabilityPrecision = ", 20, "   time in seconds = ", 
          35.389999999999986],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`5000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassDKS1SidedOneSampleRTArbPrecision[0.001, \ 5000000, \ 100, \ 
      6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassDKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]5000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.001`\[InvisibleSpace]"  desiredPrecision = "\
\[InvisibleSpace]100\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0008310957348012216`5.999999999999999\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]2414\[InvisibleSpace]"   \
rightTailProbability = \
"\[InvisibleSpace]0.\
000999998709176960912672981455831968819987827596090744225002676475244134381205\
6948730480676837976559845189726002165`100.99095416326578\[InvisibleSpace]"  \
rightTailProbabilityPrecision = "\[InvisibleSpace]100\[InvisibleSpace]"   \
time in seconds = "\[InvisibleSpace]37.09400000000005`\),
        SequenceForm[ 
        "TimingDwassDKS1SidedOneSampleRTArbPrecision: sampleSize = ", 5000000,
           "   alpha = ", .001, "  desiredPrecision = ", 100, 
          "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0008310957348012216`5.999999999999999, "   minimumPrecision = ", 
          2414, "   rightTailProbability = ", 
          0.000999998709176960912672981455831968819987827596090744225002676475\
2441343812056948730480676837976559845189726002165`100.99095416326578, 
          "  rightTailProbabilityPrecision = ", 100, "   time in seconds = ", 
          37.094000000000051],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`5000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassDKS1SidedOneSampleRTArbPrecision[0.9, \ 5000000, \ 20, \ 
      6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassDKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]5000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.9`\[InvisibleSpace]"  desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0001026119372142307669068612`6.000000000000002\
\[InvisibleSpace]"   minimumPrecision = \
"\[InvisibleSpace]308\[InvisibleSpace]"   rightTailProbability = "\
\[InvisibleSpace]0.90000000829283041495172335768069824065`20.49602492413544\
\[InvisibleSpace]"  rightTailProbabilityPrecision = "\[InvisibleSpace]20\
\[InvisibleSpace]"   time in seconds = "\[InvisibleSpace]0.20299999999997453`\
\),
        SequenceForm[ 
        "TimingDwassDKS1SidedOneSampleRTArbPrecision: sampleSize = ", 5000000,
           "   alpha = ", .90000000000000002, "  desiredPrecision = ", 20, 
          "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0001026119372142307669068612`6.000000000000002, 
          "   minimumPrecision = ", 308, "   rightTailProbability = ", 
          0.90000000829283041495172335768069824065`20.49602492413544, 
          "  rightTailProbabilityPrecision = ", 20, 
          "   time in seconds = ", .20299999999997453],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`5000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassDKS1SidedOneSampleRTArbPrecision[0.001, \ 10000000, \ 20, \ 
      6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassDKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]10000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.001`\[InvisibleSpace]"  desiredPrecision = "\
\[InvisibleSpace]20\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0005876803334525333`6.000000000000002\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]3289\[InvisibleSpace]"   \
rightTailProbability = \
"\[InvisibleSpace]0.00100000539120678945192816085831272584`20.110689938229516\
\[InvisibleSpace]"  rightTailProbabilityPrecision = "\[InvisibleSpace]20\
\[InvisibleSpace]"   time in seconds = "\[InvisibleSpace]87.29700000000003`\),
        
        SequenceForm[ 
        "TimingDwassDKS1SidedOneSampleRTArbPrecision: sampleSize = ", 
          10000000, "   alpha = ", .001, "  desiredPrecision = ", 20, 
          "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0005876803334525333`6.000000000000002, "   minimumPrecision = ", 
          3289, "   rightTailProbability = ", 
          0.00100000539120678945192816085831272584`20.110689938229516, 
          "  rightTailProbabilityPrecision = ", 20, "   time in seconds = ", 
          87.297000000000025],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`10000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassDKS1SidedOneSampleRTArbPrecision[0.001, \ 10000000, \ 100, \ 
      6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassDKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]10000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.001`\[InvisibleSpace]"  desiredPrecision = "\
\[InvisibleSpace]100\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0005876803334525333`6.000000000000002\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]3369\[InvisibleSpace]"   \
rightTailProbability = \
"\[InvisibleSpace]0.\
001000005391206789451928160858312602629537126695141170964778858883896442362026\
2012939158261205589577311062122224045`100.11068993822983\[InvisibleSpace]"  \
rightTailProbabilityPrecision = "\[InvisibleSpace]100\[InvisibleSpace]"   \
time in seconds = "\[InvisibleSpace]89.95299999999997`\),
        SequenceForm[ 
        "TimingDwassDKS1SidedOneSampleRTArbPrecision: sampleSize = ", 
          10000000, "   alpha = ", .001, "  desiredPrecision = ", 100, 
          "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0005876803334525333`6.000000000000002, "   minimumPrecision = ", 
          3369, "   rightTailProbability = ", 
          0.001000005391206789451928160858312602629537126695141170964778858883\
8964423620262012939158261205589577311062122224045`100.11068993822983, 
          "  rightTailProbabilityPrecision = ", 100, "   time in seconds = ", 
          89.952999999999975],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`10000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassDKS1SidedOneSampleRTArbPrecision[0.9, \ 10000000, \ 20, \ 
      6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassDKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]10000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.9`\[InvisibleSpace]"  desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0000725645001942437127574416`6.000000000000002\
\[InvisibleSpace]"   minimumPrecision = \
"\[InvisibleSpace]426\[InvisibleSpace]"   rightTailProbability = "\
\[InvisibleSpace]0.89999987106638007733105785714798467786`20.311419745026917\
\[InvisibleSpace]"  rightTailProbabilityPrecision = "\[InvisibleSpace]20\
\[InvisibleSpace]"   time in seconds = "\[InvisibleSpace]0.28099999999994907`\
\),
        SequenceForm[ 
        "TimingDwassDKS1SidedOneSampleRTArbPrecision: sampleSize = ", 
          10000000, "   alpha = ", .90000000000000002, 
          "  desiredPrecision = ", 20, "   testStatisticDesiredPrecision = ", 
          6, "   d = ", 0.0000725645001942437127574416`6.000000000000002, 
          "   minimumPrecision = ", 426, "   rightTailProbability = ", 
          0.89999987106638007733105785714798467786`20.311419745026917, 
          "  rightTailProbabilityPrecision = ", 20, 
          "   time in seconds = ", .28099999999994907],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`10000000\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["10. DwassD Minimum Precision Minus Desired Precision To File", "Section"],

Cell["\<\
The following is the code of the Mathematica function \
MinPrecisionMinusDesiredPrecisionToFileDwassD that calculates the minimum \
precision minus desired precision needed for the arbitrary precision DwassD \
formula and the sample sizes in the vector sampleSizeVectorIn, the desired \
precisions in the vector desiredPrecisionVectorIn, and the Maag and Dicaire \
test statistic to six digits of precision for the p-values in the vector \
alphaVectorIn.  The results are written to file outputFileName which can be \
read by Execel if separatorString is a comma.  Sample intermediate output is \
given in subsection 10.1.  The sample output file generated by the example in \
subsection 10.1 is given in subsection 10.2.\
\>", "Text"],

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionToFileDwassD[sampleSizeVectorIn_, \ 
        desiredPrecisionVectorIn_, \ alphaVectorIn_, \ intermediateOutput_, \ 
        outputFileName_, \ howToOpenFile_, \ separatorString_]\  := \ 
      Module[{numberSampleSizes, \ numberDesiredPrecisions, \ numberAlphas, \ 
          VectorDimensions, \ sampleSize, \ desiredPrecision, \ alpha, \ 
          numberDesiredPrecisionsAndAlphas, \ minimumPrecision, \ 
          sampleSizeIndex, \ desiredPrecisionIndex, \ alphaIndex, \ 
          outputFileNumber, \ minimumPrecisionArray, \ d, \ numExp, \ 
          nOutputString, \ numberTermsOutputString, \ 
          desiredPrecisionOutputString, \ minimumPrecisionOutputString, \ 
          stringIndex, \ functionOutput}, \[IndentingNewLine] (*\ 
          Generate\ minimumPrecision - 
            desiredPrecision\ for\ arbitrary\ precision\ \[IndentingNewLine]\ \
\ \ \ \ \ \ DwassD\ and\ put\ into\ file, \ 
          outputFileName\ *) \[IndentingNewLine] (*\ 
          Open\ \(file : \ howToOpenFile\) = 0, \ 
          use\ OpenWrite\ which\ creates\ a\ new\ file\[IndentingNewLine]\ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ and\ destroys\ an\ old\ \
file\ *) \ \[IndentingNewLine] (*\ \ \ \ \ \ \ \ \ \ \ \ howToOpenFile = 1, \ 
          use\ OpenAppend\ which\ opens\ file\ and\[IndentingNewLine]\ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ appends\ output\ to\ end\ \
of\ that\ \(\(file\)\(.\)\)\ \ *) \[IndentingNewLine]VectorDimensions\  = \ 
          Dimensions[
            sampleSizeVectorIn]; \[IndentingNewLine]numberSampleSizes\  = \ \ \
VectorDimensions[\([1]\)]; \[IndentingNewLine]VectorDimensions\  = \ 
          Dimensions[
            desiredPrecisionVectorIn]; \
\[IndentingNewLine]numberDesiredPrecisions\  = \ \ VectorDimensions[\([1]\)]; \
\[IndentingNewLine]VectorDimensions\  = \ 
          Dimensions[
            alphaVectorIn]; \[IndentingNewLine]numberAlphas\  = \ \ \
VectorDimensions[\([1]\)]; \
\[IndentingNewLine]numberDesiredPrecisionsAndAlphas\  = \ 
          numberDesiredPrecisions\ *\ 
            numberAlphas; \[IndentingNewLine]minimumPrecisionArray\  = \ 
          Array[
            0, \ {numberSampleSizes, \ numberDesiredPrecisions, \ 
              numberAlphas}]; \[IndentingNewLine]If[
          howToOpenFile\  \[LessEqual] \ 0, \ 
          outputFileNumber\  = \ OpenWrite[outputFileName], \ 
          outputFileNumber\  = \ 
            OpenAppend[outputFileName]]; \[IndentingNewLine]If[
          howToOpenFile\  \[LessEqual] \ 0, \ \[IndentingNewLine] (*\ 
            Output\ all\ the\ minimum\ precisions\ in\ a\ vector\ \
*) \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<DwassD:\n\>"]; \
\[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<Desired\>", \ \ separatorString, \ 
            separatorString, \ "\<Sample\>", \ 
            separatorString, \ \ "\<Minimum\>", 
            separatorString, "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<Precision\>", \ \ separatorString, \ 
            separatorString, \ "\<Size\>", \ 
            separatorString, \ "\<Precision\>", \ 
            separatorString, "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<dp\>", \ \ separatorString, \ "\<alpha\>", \
\ separatorString, \ "\<n\>", \ separatorString, \ "\<mp\>", \ 
            separatorString, \ "\<mp - dp\>", "\<\n\>"\ \
];\[IndentingNewLine]]; \[IndentingNewLine]If[
          intermediateOutput\  \[GreaterEqual] \ 
            1, \[IndentingNewLine]\(Print["\<\
MinPrecisionMinusDesiredPrecisionToFileDwassD:  For \>", \ 
              numberSampleSizes, "\< sampleSizes \>", \ \ sampleSizeVectorIn, \
\ "\<; \>", \ numberDesiredPrecisions, "\< desiredPrecisions \>", 
              desiredPrecisionVectorIn, \ \ "\<; and \>", \ 
              numberAlphas, "\< alphas \>", 
              alphaVectorIn, \ "\<, outputFileName = \>", \ 
              outputFileName, \ "\<, howToOpenFile = \>", \ 
              howToOpenFile, \ "\<, and separatorString = '\>", \ 
              separatorString, \ "\<'\>", \ "\<   intermediateOutput = \>", \ 
              intermediateOutput];\)\[IndentingNewLine]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]sampleSize\  = \ 
            sampleSizeVectorIn[\([sampleSizeIndex]\)]; \[IndentingNewLine]Do[\
\[IndentingNewLine]desiredPrecision\  = \ 
              desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)]; \
\[IndentingNewLine]Do[\[IndentingNewLine]alpha\  = \ \ \
alphaVectorIn[\([alphaIndex]\)]; \[IndentingNewLine]d\  = \ 
                Rationalize[
                  KS1SidedOneSampleTestStatisticByMaagDicaire[alpha, 
                    sampleSize, \ 6], 
                  0]; \[IndentingNewLine]functionOutput\  = 
                MinPrecisionMinusDesiredPrecisionDwassD[d, \ sampleSize, \ 
                  desiredPrecision, \ 
                  0]; \[IndentingNewLine]minimumPrecision\  = \ 
                functionOutput[\([2]\)]; \[IndentingNewLine]minimumPrecision\ \
 = \ minimumPrecision\  + \ 
                  desiredPrecision; \[IndentingNewLine]minimumPrecisionArray[\
\([sampleSizeIndex, \ desiredPrecisionIndex, \ alphaIndex]\)]\  = \ 
                minimumPrecision; \[IndentingNewLine]WriteString[
                outputFileNumber, \ 
                ToString[\ desiredPrecision, \ 
                  FortranForm], \ \ separatorString, \ 
                ToString[\ alpha, \ FortranForm], \ \ separatorString, \ 
                ToString[\ sampleSize, \ FortranForm], \ \ separatorString, \ 
                ToString[\ 
                  minimumPrecisionArray[\([sampleSizeIndex, \ 
                      desiredPrecisionIndex, \ alphaIndex]\)], \ 
                  FortranForm], \ \ separatorString, \ \ ToString[\ 
                  minimumPrecisionArray[\([sampleSizeIndex, \ 
                        desiredPrecisionIndex, \ alphaIndex]\)]\  - \ 
                    desiredPrecision\ , \ 
                  FortranForm], \ "\<\n\>"]; \[IndentingNewLine]If[
                intermediateOutput\  \[GreaterEqual] \ 
                  2, \[IndentingNewLine]\(Print["\<    sampleSize = \>", \ \ \
sampleSize, \ "\<   desiredPrecision = \>", \ 
                    desiredPrecision, \ "\<   alpha = \>", \ 
                    alpha, \ "\<   d = \>", \ d, \ "\< = \>", \ 
                    N[d, \ 6], \ "\<   minimumPrecision = \>", \ 
                    minimumPrecision];\)\[IndentingNewLine]];\
\[IndentingNewLine], {alphaIndex, \ 1, \ \ numberAlphas, \ 
                1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 1, \ 
              numberDesiredPrecisions, \ 
              1}];\[IndentingNewLine], {sampleSizeIndex, \ 1, \ 
            numberSampleSizes, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\n\n\>"\ ]; \[IndentingNewLine] (*\ 
          Minimum\ precision\ by\ desiredPrecision\ by\ alpha\ \
*) \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<DwassD:\>", \ \ separatorString, \ \
"\<Minimum Precision mp\>"]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
              outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{stringIndex, \ 1, \ numberDesiredPrecisionsAndAlphas\  - \ 1\ , \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Sample\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ separatorString, \ "\<Desired Precision dp \
= \>", \ ToString[\ desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)], \ 
              FortranForm]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{\ alphaIndex, \ 1\ , \ numberAlphas\  - \ 1, \ 
              1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 
            1, \ \ numberDesiredPrecisions, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Size\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ \ separatorString, \ "\<alpha\>"]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{\ alphaIndex, \ 1\ , \ numberAlphas\  - \ 1, \ 
              1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 
            1, \ \ numberDesiredPrecisions, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<n\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]\(WriteString[
                  outputFileNumber, \ \ separatorString, \ 
                  ToString[\ alphaVectorIn[\([alphaIndex]\)], \ 
                    FortranForm]];\)\[IndentingNewLine], {\ alphaIndex, \ 
                1\ , \ numberAlphas, \ 
                1}];\)\[IndentingNewLine], {desiredPrecisionIndex, \ 
            1, \ \ numberDesiredPrecisions, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]Do[\
\[IndentingNewLine]sampleSize\  = \ 
            sampleSizeVectorIn[\([sampleSizeIndex]\)]; \
\[IndentingNewLine]WriteString[outputFileNumber, \ 
            ToString[\ sampleSize, \ 
              FortranForm]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]desiredPrecision\  = \ 
              desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)]; \
\[IndentingNewLine]Do[\[IndentingNewLine]alpha\  = \ \ \
alphaVectorIn[\([alphaIndex]\)]; \[IndentingNewLine]WriteString[
                outputFileNumber, \ \ separatorString, \ 
                ToString[\ 
                  minimumPrecisionArray[\([sampleSizeIndex, \ 
                      desiredPrecisionIndex, \ alphaIndex]\)], \ 
                  FortranForm]];\[IndentingNewLine], {alphaIndex, \ 
                1, \ \ numberAlphas, \ 
                1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 1, \ 
              numberDesiredPrecisions, \ 1}]; \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<\n\>"\ ];\[IndentingNewLine], \
{sampleSizeIndex, \ 1, \ numberSampleSizes, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\n\n\>"\ ]; \[IndentingNewLine] (*\ 
          Minimum\ precision\ by\ alpha\ by\ desiredPrecision\ \
*) \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<DwassD:\>", \ \ separatorString, \ \
"\<Minimum Precision mp\>"]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
              outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{stringIndex, \ 1, \ numberDesiredPrecisionsAndAlphas\  - \ 1\ , \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Sample\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ separatorString, \ "\<alpha = \>", \ 
            ToString[\ alphaVectorIn[\([alphaIndex]\)], \ 
              FortranForm]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ \ numberDesiredPrecisions\  - \ 1, \ 
              1}];\[IndentingNewLine], {\ alphaIndex, \ 1\ , \ 
            numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Size\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]\(WriteString[
                  outputFileNumber, \ \ separatorString, \ "\<dp\>"];\)\
\[IndentingNewLine], {desiredPrecisionIndex, \ 
                1, \ \ numberDesiredPrecisions, \ 
                1}];\)\[IndentingNewLine], {\ alphaIndex, \ 1\ , \ 
            numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<n\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]\(WriteString[
                  outputFileNumber, \ \ separatorString, \ 
                  ToString[\ 
                    desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)], \ 
                    FortranForm]];\)\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ \ numberDesiredPrecisions, \ 
                1}];\)\[IndentingNewLine], {\ alphaIndex, \ 1\ , \ 
            numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]Do[\
\[IndentingNewLine]sampleSize\  = \ 
            sampleSizeVectorIn[\([sampleSizeIndex]\)]; \
\[IndentingNewLine]WriteString[outputFileNumber, \ 
            ToString[\ sampleSize, \ 
              FortranForm]]; \[IndentingNewLine]Do[\[IndentingNewLine]\(Do[\
\[IndentingNewLine]\(WriteString[outputFileNumber, \ \ separatorString, \ 
                    ToString[\ 
                      minimumPrecisionArray[\([sampleSizeIndex, \ 
                          desiredPrecisionIndex, \ alphaIndex]\)], \ 
                      FortranForm]];\)\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ numberDesiredPrecisions, \ 
                  1}];\)\[IndentingNewLine], {alphaIndex, \ 
              1, \ \ numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<\n\>"\ ];\[IndentingNewLine], \
{sampleSizeIndex, \ 1, \ numberSampleSizes, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\n\n\>"\ ]; \[IndentingNewLine] (*\ 
          Minimum\ precision\ minus\ desired\ precision\ by\ desiredPrecision\
\ by\ alpha\ *) \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<DwassD:\>", \ \ separatorString, \ \
"\<Minimum Precision Minus Desired Precision mp - dp\>"]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
              outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{stringIndex, \ 1, \ numberDesiredPrecisionsAndAlphas\  - \ 1\ , \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Sample\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ separatorString, \ "\<Desired Precision dp \
= \>", \ ToString[\ desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)], \ 
              FortranForm]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{\ alphaIndex, \ 1\ , \ numberAlphas\  - \ 1, \ 
              1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 
            1, \ \ numberDesiredPrecisions, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Size\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ \ separatorString, \ "\<alpha\>"]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{\ alphaIndex, \ 1\ , \ numberAlphas\  - \ 1, \ 
              1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 
            1, \ \ numberDesiredPrecisions, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<n\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]\(WriteString[
                  outputFileNumber, \ \ separatorString, \ 
                  ToString[\ alphaVectorIn[\([alphaIndex]\)], \ 
                    FortranForm]];\)\[IndentingNewLine], {\ alphaIndex, \ 
                1\ , \ numberAlphas, \ 
                1}];\)\[IndentingNewLine], {desiredPrecisionIndex, \ 
            1, \ \ numberDesiredPrecisions, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]Do[\
\[IndentingNewLine]sampleSize\  = \ 
            sampleSizeVectorIn[\([sampleSizeIndex]\)]; \
\[IndentingNewLine]WriteString[outputFileNumber, \ 
            ToString[\ sampleSize, \ 
              FortranForm]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]desiredPrecision\  = \ 
              desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)]; \
\[IndentingNewLine]Do[\[IndentingNewLine]alpha\  = \ \ \
alphaVectorIn[\([alphaIndex]\)]; \[IndentingNewLine]WriteString[
                outputFileNumber, \ \ separatorString, \ 
                ToString[\ 
                  minimumPrecisionArray[\([sampleSizeIndex, \ 
                        desiredPrecisionIndex, \ alphaIndex]\)]\  - \ 
                    desiredPrecision, \ 
                  FortranForm]];\[IndentingNewLine], {alphaIndex, \ 
                1, \ \ numberAlphas, \ 
                1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 1, \ 
              numberDesiredPrecisions, \ 1}]; \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<\n\>"\ ];\[IndentingNewLine], \
{sampleSizeIndex, \ 1, \ numberSampleSizes, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\n\n\>"\ ]; \[IndentingNewLine] (*\ 
          Minimum\ precision\ minus\ desired\ precision\ by\ alpha\ by\ \
desiredPrecision\ *) \[IndentingNewLine]WriteString[
          outputFileNumber, \ \ "\<DwassD:\>", \ \ separatorString, \ \
"\<Minimum Precision Minus Desired Precision mp - dp\>"]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
              outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{stringIndex, \ 1, \ numberDesiredPrecisionsAndAlphas\  - \ 1\ , \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Sample\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ separatorString, \ "\<alpha = \>", \ 
            ToString[\ alphaVectorIn[\([alphaIndex]\)], \ 
              FortranForm]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ \ numberDesiredPrecisions\  - \ 1, \ 
              1}];\[IndentingNewLine], {\ alphaIndex, \ 1\ , \ 
            numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Size\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]\(WriteString[
                  outputFileNumber, \ \ separatorString, \ "\<dp\>"];\)\
\[IndentingNewLine], {desiredPrecisionIndex, \ 
                1, \ \ numberDesiredPrecisions, \ 
                1}];\)\[IndentingNewLine], {\ alphaIndex, \ 1\ , \ 
            numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<n\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]\(WriteString[
                  outputFileNumber, \ \ separatorString, \ 
                  ToString[\ 
                    desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)], \ 
                    FortranForm]];\)\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ \ numberDesiredPrecisions, \ 
                1}];\)\[IndentingNewLine], {\ alphaIndex, \ 1\ , \ 
            numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]Do[\
\[IndentingNewLine]sampleSize\  = \ 
            sampleSizeVectorIn[\([sampleSizeIndex]\)]; \
\[IndentingNewLine]WriteString[outputFileNumber, \ 
            ToString[\ sampleSize, \ 
              FortranForm]]; \[IndentingNewLine]Do[\[IndentingNewLine]\(Do[\
\[IndentingNewLine]desiredPrecision\  = \ 
                  desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)]; \
\[IndentingNewLine]WriteString[outputFileNumber, \ \ separatorString, \ 
                  ToString[\ 
                    minimumPrecisionArray[\([sampleSizeIndex, \ 
                          desiredPrecisionIndex, \ alphaIndex]\)]\  - \ 
                      desiredPrecision\ , \ 
                    FortranForm]];\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ numberDesiredPrecisions, \ 
                  1}];\)\[IndentingNewLine], {alphaIndex, \ 
              1, \ \ numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<\n\>"\ ];\[IndentingNewLine], \
{sampleSizeIndex, \ 1, \ numberSampleSizes, \ 1}]; \[IndentingNewLine]Close[
          
          outputFileNumber]; \[IndentingNewLine]minimumPrecisionArray\
\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(KS1SidedOneSampleTestStatisticByMaagDicaire[alphaIn_, sampleSizeIn_, \ 
        rho_]\  := \[IndentingNewLine]Module[{d, \ alpha, \ 
          sampleSize}, \[IndentingNewLine] (*\ 
          For\ the\ KS\ 1\ sided\ one\ sample\ test, \ 
          the\ Maag\ and\ Dicaire\ formula\ is\ used\ *) \[IndentingNewLine] \
(*\ \ \ \ to\ approximate\ the\ test\ statistic\ corresponding\ to\ a\ right\ \
tail\ *) \[IndentingNewLine] (*\ \ \ \ probability\ of\ alphaIn . \ \ The\ \
test\ statistic\ d\ is\ calculated\ to\ *) \[IndentingNewLine] (*\ \ \ \ rho\ \
number\ of\ decimal\ \(\(digits\)\(.\)\)\ *) \[IndentingNewLine]alpha\  = 
          Rationalize[alphaIn, \ 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine] (*\ 
          Use\ Maag\ and\ Dicaire\ \(\(MD\)\(.\)\)\ *) \[IndentingNewLine]d\  \
= \ N[Sqrt[Log[alpha]/\((\(-2\)*sampleSize)\)] - \ \((1/\((6*
                      sampleSize)\))\), 
            rho\ \  + \ 17]; \[IndentingNewLine]d\  = \ 
          N[d, rho]; \[IndentingNewLine]d\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionDwassD[testStatistic_, \ 
        sampleSize_, \ desiredPrecision_, \ intermediateOutput_]\  := \ 
      Module[{internalPrecisionLowLimit, \ internalPrecisionHighLimit, \ 
          setInternalPrecision, \ currentPrecision, \ SquareRootN, \ 
          numberTries, \ rightTailProbability, \ 
          rightTailProbabilityToDesiredPrecision, \ 
          minPrecisionMinusDesiredPrecision, \ mantissaExp, \ numExp, \ 
          prop}, \[IndentingNewLine]SquareRootN\  = \ 
          Ceiling[Sqrt[sampleSize]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 1, \ 
          Print["\<MinPrecisionMinusDesiredPrecisionDwassD:\>", \ "\< \
sampleSize = \>", \ sampleSize, \ "\<   testStatistic = \>", \ 
            testStatistic, "\< = \>", \ 
            N[testStatistic, 6], \ \ "\<    desiredPrecision = \>", \ 
            desiredPrecision]]; \[IndentingNewLine]numberTries\  = \ 
          0; \[IndentingNewLine]internalPrecisionLowLimit\  = \ 
          desiredPrecision; \[IndentingNewLine]internalPrecisionHighLimit\  = \
\ SquareRootN\  + \ \ desiredPrecision; \
\[IndentingNewLine]setInternalPrecision\  = \ 
          internalPrecisionHighLimit; \[IndentingNewLine] (*\ 
          Determine\ a\ high\ limit\ for\ minimumPrecision\ \
*) \[IndentingNewLine]Label[
          DetermineInternalPrecisionHighLimit]; \
\[IndentingNewLine]numberTries\  = \ 
          numberTries\ \  + \ 
            1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassDKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   FindHighLimit: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision = \>", \ \ \
currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  \[GreaterEqual] \ desiredPrecision, \ 
          Goto[HighLimitFound], \ 
          Goto[HighLimitTooSmall]]; \[IndentingNewLine] (*\ 
          Current\ high\ limit\ too\ small\ *) \[IndentingNewLine]Label[
          HighLimitTooSmall]; \[IndentingNewLine]internalPrecisionLowLimit\  \
= \ internalPrecisionHighLimit; \[IndentingNewLine]internalPrecisionHighLimit\
\  = \ internalPrecisionHighLimit\  + \ desiredPrecision\  - \ 
            currentPrecision; \[IndentingNewLine]setInternalPrecision\  = \ 
          internalPrecisionHighLimit; \[IndentingNewLine]Goto[
          DetermineInternalPrecisionHighLimit]; \[IndentingNewLine] (*\ 
          High\ limit\ found\ *) \[IndentingNewLine]Label[
          HighLimitFound]; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Bisection\ search\ to\ find\ minimumPrecision\ between\ \
\[IndentingNewLine]\ \ \ \ internalPrecisionLowLimit\ and\ \
internalPrecisionHighLimit\ *) \[IndentingNewLine]Label[
          BisectionIteration]; \[IndentingNewLine]setInternalPrecision\  = \ 
          Floor[\((internalPrecisionLowLimit\  + \ 
                  internalPrecisionHighLimit)\)/2]; \[IndentingNewLine]If[
          setInternalPrecision\ \  \[LessEqual] \ 
            internalPrecisionLowLimit, \ 
          setInternalPrecision\ \  = \ 
            internalPrecisionLowLimit\  + \ 1, \[IndentingNewLine]\(If[
              setInternalPrecision\ \  \[GreaterEqual] \ \ \
internalPrecisionHighLimit, \ 
              setInternalPrecision\ \  = \ 
                internalPrecisionHighLimit\  - \ 
                  1];\)\[IndentingNewLine]]; \[IndentingNewLine]numberTries\  \
= \ numberTries\ \  + \ 1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassDKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   Bisection Search: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision = \>", \ \ \
currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  \[GreaterEqual] \ desiredPrecision, \ 
          Goto[ResetHighLimit], \ 
          Goto[ResetLowLimit]]; \[IndentingNewLine] (*\ 
          Reset\ internalPrecisionHighLimit\ to\ currentPrecision\ \
*) \[IndentingNewLine]Label[
          ResetHighLimit]; \[IndentingNewLine]internalPrecisionHighLimit\  = \
\ setInternalPrecision; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Reset\ internalPrecisionLowLimit\ to\ currentPrecision\ \
*) \[IndentingNewLine]Label[
          ResetLowLimit]; \[IndentingNewLine]internalPrecisionLowLimit\  = \ 
          setInternalPrecision; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Minimum\ internal\ precision\ found\ *) \[IndentingNewLine]Label[
          MinInternalPrecisionFound]; \[IndentingNewLine]setInternalPrecision\
\  = \ internalPrecisionHighLimit; \[IndentingNewLine]setInternalPrecision\  \
= \ internalPrecisionLowLimit; \[IndentingNewLine]numberTries\  = \ 
          numberTries\ \  + \ 
            1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassDKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   Determine whether low or high limit is minimum \
precision: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision for low limit = \>", \ \
\ currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  < \ desiredPrecision, \ 
          setInternalPrecision\  = \ internalPrecisionHighLimit, \ 
          setInternalPrecision\  = \ 
            internalPrecisionLowLimit]; \
\[IndentingNewLine]minPrecisionMinusDesiredPrecision\  = \ 
          setInternalPrecision\  - \ \ desiredPrecision; \
\[IndentingNewLine]If[\ intermediateOutput \[GreaterEqual] \ 1, \ 
          Print["\<   Minimum Internal Precision Found: \>", \ "\< sampleSize \
= \>", \ sampleSize, \ "\<   testStatistic = \>", \ 
            testStatistic, \ "\< = \>", \ 
            N[testStatistic, 6], \ "\<    desiredPrecision = \>", \ 
            desiredPrecision, \ "\<   numberTries = \>", \ 
            numberTries, \ "\<   minimumInternalPrecision = \>", \ 
            setInternalPrecision, \ "\<   minPrecisionMinusDesiredPrecision = \
\>", \ minPrecisionMinusDesiredPrecision\ ]]; \
\[IndentingNewLine]{numberTries, \ 
          minPrecisionMinusDesiredPrecision}\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassDKS1SidedOneSampleRTArbPrecision[dIn_, sampleSizeIn_, 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ 
          rightTailProbability, \ binomialCoefficient, \ secondTerm, \ 
          thirdTerm, \ sumTerms}, \[IndentingNewLine] (*\ 
          Dwass\ Direct\ formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ \
sample\ *) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ 
              d]; \[IndentingNewLine]binomialCoefficient\  = \ 
          1; \[IndentingNewLine]secondTerm\ \  = \ 
          N[1\  + \ d, \ 
            internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ \(-d\); \
\[IndentingNewLine]sumTerms\  = \ 
          N[secondTerm^\((sampleSize - 1)\), \ 
            internalPrecision]; \[IndentingNewLine]If[jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]binomialCoefficient\  = \ 
            N[binomialCoefficient\ *\ \((sampleSize\  - \ j\  + \ 1)\)/\ 
                  j\ , \ internalPrecision]; \[IndentingNewLine]secondTerm\  \
= \ N[secondTerm\  - \ \((1/sampleSize)\)\ , 
              internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ 
            N[thirdTerm\  + \ \((1/sampleSize)\)\ , 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + \((binomialCoefficient\ *\ 
                    secondTerm^\((sampleSize\  - \ j\  - \ 1)\)\ *\ 
                    thirdTerm^j)\), \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1\  - \ \((d\ *\ sumTerms)\), \ 
            internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
10.1  DwassD Minimum Precision Minus Desired Precision To File Sample \
Intermediate Output\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionToFileDwassD[{100, \ 500}, \ {20, \ 
        100}, \ {0.001, \ 0.9}, \ 
      2, \ "\<C:/KSoutput/KS1SidedOneSampleDwassDmpMINUSdpN100and500.csv\>", \
\ 0, \ "\<,\>"]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("MinPrecisionMinusDesiredPrecisionToFileDwassD:  \
For "\[InvisibleSpace]2\[InvisibleSpace]" sampleSizes "\[InvisibleSpace]{100, 
            500}\[InvisibleSpace]"; "\[InvisibleSpace]2\[InvisibleSpace]" \
desiredPrecisions "\[InvisibleSpace]{20, 
            100}\[InvisibleSpace]"; and "\[InvisibleSpace]2\[InvisibleSpace]" \
alphas "\[InvisibleSpace]{0.001`, 
            0.9`}\[InvisibleSpace]", outputFileName = \
"\[InvisibleSpace]"C:/KSoutput/KS1SidedOneSampleDwassDmpMINUSdpN100and500.\
csv"\[InvisibleSpace]", howToOpenFile = \
"\[InvisibleSpace]0\[InvisibleSpace]", and separatorString = '"\
\[InvisibleSpace]","\[InvisibleSpace]"'"\[InvisibleSpace]"   \
intermediateOutput = "\[InvisibleSpace]2\),
        SequenceForm[ 
        "MinPrecisionMinusDesiredPrecisionToFileDwassD:  For ", 2, 
          " sampleSizes ", {100, 500}, "; ", 2, " desiredPrecisions ", {20, 
          100}, "; and ", 2, " alphas ", {.001, .90000000000000002}, 
          ", outputFileName = ", 
          "C:/KSoutput/KS1SidedOneSampleDwassDmpMINUSdpN100and500.csv", 
          ", howToOpenFile = ", 0, ", and separatorString = '", ",", "'", 
          "   intermediateOutput = ", 2],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]100\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.001`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]156\/847\[InvisibleSpace]" = "\
\[InvisibleSpace]0.184179456906729634`6. \[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]34\),
        SequenceForm[ 
        "    sampleSize = ", 100, "   desiredPrecision = ", 20, 
          "   alpha = ", .001, "   d = ", 
          Rational[ 156, 847], " = ", 0.184179456906729634`6., 
          "   minimumPrecision = ", 34],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]100\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.9`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]203\/9537\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0212855195554157492`5.999999999999999\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]22\),
        SequenceForm[ 
        "    sampleSize = ", 100, "   desiredPrecision = ", 20, 
          "   alpha = ", .90000000000000002, "   d = ", 
          Rational[ 203, 9537], " = ", 
          0.0212855195554157492`5.999999999999999, "   minimumPrecision = ", 
          22],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]100\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.001`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]156\/847\[InvisibleSpace]" = "\
\[InvisibleSpace]0.184179456906729634`6. \[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]114\),
        SequenceForm[ 
        "    sampleSize = ", 100, "   desiredPrecision = ", 100, 
          "   alpha = ", .001, "   d = ", 
          Rational[ 156, 847], " = ", 0.184179456906729634`6., 
          "   minimumPrecision = ", 114],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]100\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.9`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]203\/9537\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0212855195554157492`5.999999999999999\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]102\),
        SequenceForm[ 
        "    sampleSize = ", 100, "   desiredPrecision = ", 100, 
          "   alpha = ", .90000000000000002, "   d = ", 
          Rational[ 203, 9537], " = ", 
          0.0212855195554157492`5.999999999999999, "   minimumPrecision = ", 
          102],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]500\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.001`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]299\/3612\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0827796234772978959`6. \[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]47\),
        SequenceForm[ 
        "    sampleSize = ", 500, "   desiredPrecision = ", 20, 
          "   alpha = ", .001, "   d = ", 
          Rational[ 299, 3612], " = ", 0.0827796234772978959`6., 
          "   minimumPrecision = ", 47],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]500\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.9`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]140\/14097\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0099311910335532383`5.999999999999999\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]24\),
        SequenceForm[ 
        "    sampleSize = ", 500, "   desiredPrecision = ", 20, 
          "   alpha = ", .90000000000000002, "   d = ", 
          Rational[ 140, 14097], " = ", 
          0.0099311910335532383`5.999999999999999, "   minimumPrecision = ", 
          24],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]500\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.001`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]299\/3612\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0827796234772978959`6. \[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]127\),
        SequenceForm[ 
        "    sampleSize = ", 500, "   desiredPrecision = ", 100, 
          "   alpha = ", .001, "   d = ", 
          Rational[ 299, 3612], " = ", 0.0827796234772978959`6., 
          "   minimumPrecision = ", 127],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]500\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.9`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]140\/14097\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0099311910335532383`5.999999999999999\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]104\),
        SequenceForm[ 
        "    sampleSize = ", 500, "   desiredPrecision = ", 100, 
          "   alpha = ", .90000000000000002, "   d = ", 
          Rational[ 140, 14097], " = ", 
          0.0099311910335532383`5.999999999999999, "   minimumPrecision = ", 
          104],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({34, 22}\), \({114, 102}\)},
            {\({47, 24}\), \({127, 104}\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
10.2  DwassD Minimum Precision Minus Desired Precision Sample Output File, \
C:/KSoutput/KS1SidedOneSampleDwassDmpMINUSdpN100and500.csv\
\>", "Subsection"],

Cell[BoxData[{
    \(DwassD : Desired, , Sample, Minimum, Precision, , Size, Precision, dp, 
    alpha, n, mp, mp - dp\), "\n", 
    \(20, 0.001, 100, 34, 14\), "\n", 
    \(20, 0.9, 100, 22, 2\), "\n", 
    \(100, 0.001, 100, 114, 14\), "\n", 
    \(100, 0.9, 100, 102, 2\), "\n", 
    \(20, 0.001, 500, 47, 27\), "\n", 
    \(20, 0.9, 500, 24, 4\), "\n", 
    \(100, 0.001, 500, 127, 27\), "\n", 
    \(\(\(100, 0.9, 500, 104, 
    4\)\(\n\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(DwassD\)\(:\)\), Minimum\ Precision\ mp, , , Sample, 
    Desired\ Precision\ dp = 20, , Desired\ Precision\ dp = 100, Size, 
    alpha, , alpha, n, 0.001, 0.9, 0.001, 0.9\), "\n", 
    \(100, 34, 22, 114, 102\), "\n", 
    \(\(\(500, 47, 24, 127, 
    104\)\(\n\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(DwassD\)\(:\)\), Minimum\ Precision\ mp, , , Sample, 
    alpha = 0.001, , alpha = 0.9, Size, dp, dp, dp, dp\), "\n", 
    \(n, 20, 100, 20, 100\), "\n", 
    \(100, 34, 114, 22, 102\), "\n", 
    \(\(\(500, 47, 127, 24, 
    104\)\(\n\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(DwassD\)\(:\)\), 
    Minimum\ Precision\ Minus\ Desired\ Precision\ mp - dp, , , Sample, 
    Desired\ Precision\ dp = 20, , Desired\ Precision\ dp = 100, Size, 
    alpha, , alpha, n, 0.001, 0.9, 0.001, 0.9\), "\n", 
    \(100, 14, 2, 14, 2\), "\n", 
    \(\(\(500, 27, 4, 27, 
    4\)\(\n\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(DwassD\)\(:\)\), 
    Minimum\ Precision\ Minus\ Desired\ Precision\ mp - dp, , , Sample, 
    alpha = 0.001, , alpha = 0.9, Size, dp, dp, dp, dp\), "\n", 
    \(n, 20, 100, 20, 100\), "\n", 
    \(100, 14, 14, 2, 2\), "\n", 
    \(500, 27, 27, 4, 4\), "\n", 
    \(\)}], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["11. DwassD Desired Precision", "Section"],

Cell["\<\
The following is the code of the Mathematica function \
DwassDKS1SidedOneSampleRTdesiredPrecision that calculates the right tail \
p-value to desiredPrecisionIn digits of precision.  Sample output is given in \
subsection 11.1.\
\>", "Text"],

Cell[BoxData[
    \(DwassDKS1SidedOneSampleRTdesiredPrecision[dIn_, sampleSizeIn_, \ 
        desiredPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ desiredPrecision, \ internalPrecision, \ j, \ 
          jLowLimit, \ term, \ leftTailProbability, \ rightTailProbability, \ 
          binomialCoefficient, \ secondTerm, \ thirdTerm, \ sumTerms, \ 
          numberIterations, \ alphaPredict, \ 
          resultPrecision}, \[IndentingNewLine] (*\ 
          DwassD\ formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ sample\ \
*) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ to\ desiredPrecisionIn\ digits\ of\ *) \[IndentingNewLine] \
(*\ \ \ \ precision\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine]d = 
          Rationalize[dIn, \ 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]desiredPrecision\  = \ 
          Ceiling[desiredPrecisionIn]; \[IndentingNewLine] (*\ 
          Maag\ and\ Dicaire\ approximation\ \
*) \[IndentingNewLine]alphaPredict\  = \ 
          Exp[\(-2\)\ *\ d^2\ *\ 
                sampleSize\  - \ \((2\ *
                  d\ /\ 3)\)\  - \ \((1/\((18\ *\ 
                      sampleSize)\))\)]; \[IndentingNewLine]internalPrecision\
\  = \ Ceiling[
              3\  + \ \((4.84\  + \ 1.033\ *\ Sqrt[sampleSize])\)\ *\ \((\ 
                    0.611\  - \ 0.0904*\ alphaPredict\  - \ 
                      0.357\ *\ alphaPredict^\((1/3)\)\  - \ 
                      0.0998\ *\ alphaPredict^4\  - \ 
                      0.0616\ *\ Log[alphaPredict])\)]\  + \ 
            desiredPrecision; \[IndentingNewLine]numberIterations\  = \ 
          0; \[IndentingNewLine]Label[
          AnotherIteration]; \[IndentingNewLine]numberIterations\  = \ 
          numberIterations\  + \ 
            1; \[IndentingNewLine]rightTailProbability\ \  = \ 
          DwassDKS1SidedOneSampleRTArbPrecision[d, sampleSize, 
            internalPrecision]; \[IndentingNewLine]resultPrecision\  = \ 
          Precision[rightTailProbability]; \[IndentingNewLine]If[
          resultPrecision\  < \ 
            desiredPrecision, \[IndentingNewLine]internalPrecision\  = \ 
            internalPrecision\  + \ desiredPrecision; \[IndentingNewLine]Goto[
            AnotherIteration];\[IndentingNewLine]]; \
\[IndentingNewLine]rightTailProbability\ \[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassDKS1SidedOneSampleRTArbPrecision[dIn_, sampleSizeIn_, 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ 
          rightTailProbability, \ binomialCoefficient, \ secondTerm, \ 
          thirdTerm, \ sumTerms}, \[IndentingNewLine] (*\ 
          Dwass\ Direct\ formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ \
sample\ *) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ 
              d]; \[IndentingNewLine]binomialCoefficient\  = \ 
          1; \[IndentingNewLine]secondTerm\ \  = \ 
          N[1\  + \ d, \ 
            internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ \(-d\); \
\[IndentingNewLine]sumTerms\  = \ 
          N[secondTerm^\((sampleSize - 1)\), \ 
            internalPrecision]; \[IndentingNewLine]If[jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]binomialCoefficient\  = \ 
            N[binomialCoefficient\ *\ \((sampleSize\  - \ j\  + \ 1)\)/\ 
                  j\ , \ internalPrecision]; \[IndentingNewLine]secondTerm\  \
= \ N[secondTerm\  - \ \((1/sampleSize)\)\ , 
              internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ 
            N[thirdTerm\  + \ \((1/sampleSize)\)\ , 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + \((binomialCoefficient\ *\ 
                    secondTerm^\((sampleSize\  - \ j\  - \ 1)\)\ *\ 
                    thirdTerm^j)\), \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1\  - \ \((d\ *\ sumTerms)\), \ 
            internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[CellGroupData[{

Cell["11.1  DwassD Desired Precision Sample Output", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DwassDKS1SidedOneSampleRTdesiredPrecision[0.000831096, 5000000, \ 
      30]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.\
000999994849501232127646860949510285878397398530260000397`36.9903081752465\)],\
 "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DwassDKS1SidedOneSampleRTdesiredPrecision[0.000339290, 10000000, \ 
      40]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.\
100000480993207370350317616589677055270014407449947732644`46.98592126728779\)]\
, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["12. DwassI Arbitrary Precision", "Section"],

Cell["\<\
The following is the code of the Mathematica function \
DwassIKS1SidedOneSampleRTArbPrecision that calculates the right tail p-value \
using the DwassI formula with test statistic dIn and sample size \
sampleSizeIn.  Internally the function uses arbitrary precision arithmetic \
with internalPrecisionIn digits of precision.   Sample output is given in \
subsection 12.1.\
\>", "Text"],

Cell[BoxData[
    \(DwassIKS1SidedOneSampleRTArbPrecision[dIn_, sampleSizeIn_, \ 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ term, \ 
          leftTailProbability, \ rightTailProbability, \ sumTerms, \ 
          NminusjMinusOne, \ NminusjPlusOne, \ dN, \ jMinusdN, \ 
          nMINUSjPlusOnePLUSdn, \ jMINUSdnMinusOne}, \[IndentingNewLine] (*\ 
          Dwass\ Iterative\ formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ \
sample\ *) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ d]; \[IndentingNewLine]sumTerms\  = \ 
          N[\ d\ *\ \((1\  + \ d)\)^\((sampleSize - 1)\), \ 
            internalPrecision]; \[IndentingNewLine]term\  = \ 
          sumTerms; \[IndentingNewLine]NminusjMinusOne\  = \ 
          N[sampleSize\  - \ 1, \ 
            internalPrecision]; \[IndentingNewLine]NminusjPlusOne\  = \ 
          N[sampleSize\  + \ 1, \ 
            internalPrecision]; \[IndentingNewLine]dN\  = \ 
          N[d\ *\ sampleSize, \ 
            internalPrecision]; \[IndentingNewLine]jHighLimit\  = \ 
          Floor[dN]; \[IndentingNewLine]jMinusdN\  = \ \(-\ 
            dN\); \[IndentingNewLine]nMINUSjPlusOnePLUSdn\  = \ 
          N[\ sampleSize\  + \ 1\  + \ dN, \ 
            internalPrecision]; \[IndentingNewLine]jMINUSdnMinusOne\  = \ 
          N[\(-\ dN\)\  - \ 1, \ internalPrecision]; \[IndentingNewLine]If[
          jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]NminusjMinusOne\  = \ 
            N[NminusjMinusOne\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]NminusjPlusOne\  = \ 
            N[NminusjPlusOne\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]jMinusdN\  = \ 
            N[jMinusdN\  + \ 1\ , \ 
              internalPrecision]; \[IndentingNewLine]nMINUSjPlusOnePLUSdn\  = \
\ N[\ nMINUSjPlusOnePLUSdn\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]jMINUSdnMinusOne\  = \ 
            N[jMINUSdnMinusOne\  + \ 1, \ 
              internalPrecision]; \[IndentingNewLine]term\  = \ 
            N[\ \((\((NminusjPlusOne\ *\ jMinusdN)\)/\((j\ *\ 
                        nMINUSjPlusOnePLUSdn)\))\)*\ \((1\  - \ \((1/
                          nMINUSjPlusOnePLUSdn)\))\)^
                  NminusjMinusOne\ *\ \((1\  + \ \((1/
                          jMINUSdnMinusOne)\))\)^\((j - 1)\)*term, \ 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + term, \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1 - sumTerms, \ internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[CellGroupData[{

Cell["12.1  DwassI Arbitrary Precision Sample Output", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(DwassIKS1SidedOneSampleRTArbPrecision[0.105632, 100, \ 
      30]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.09997990380077079963347414081954329952`23.\
391302012069687\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Precision[
      DwassIKS1SidedOneSampleRTArbPrecision[0.105632, 100, \ 
        30]\ ]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`23.391302012069684`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(DwassIKS1SidedOneSampleRTArbPrecision[0.0199760, 2000, \ 
      60]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.199998648779404946563706459535437273240059330283`37.\
439113291451086\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Precision[
      DwassIKS1SidedOneSampleRTArbPrecision[0.0199760, 2000, \ 
        60]\ ]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`37.439113291451086`\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["13. DwassI Minimum Precision Minus Desired Precision", "Section"],

Cell["\<\
The following is the code of the Mathematica function \
MinPrecisionMinusDesiredPrecisionDwassI that calculates the minimum precision \
minus desired precision needed for the arbitrary precision DwassI formula \
with test statistic testStatistic and sample size sampleSize to calculate the \
right tail p-value to a precision of desired precision desiredPrecision.  \
Sample intermediate output is given in subsection 13.1.\
\>", "Text"],

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionDwassI[testStatistic_, \ 
        sampleSize_, \ desiredPrecision_, \ intermediateOutput_]\  := \ 
      Module[{internalPrecisionLowLimit, \ internalPrecisionHighLimit, \ 
          setInternalPrecision, \ currentPrecision, \ SquareRootN, \ 
          numberTries, \ rightTailProbability, \ 
          rightTailProbabilityToDesiredPrecision, \ 
          minPrecisionMinusDesiredPrecision, \ mantissaExp, \ numExp, \ 
          prop}, \[IndentingNewLine]SquareRootN\  = \ 
          Ceiling[Sqrt[sampleSize]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 1, \ 
          Print["\<MinPrecisionMinusDesiredPrecisionDwassI:\>", \ "\< \
sampleSize = \>", \ sampleSize, \ "\<   testStatistic = \>", \ 
            testStatistic, "\< = \>", \ 
            N[testStatistic, 6], \ \ "\<    desiredPrecision = \>", \ 
            desiredPrecision]]; \[IndentingNewLine]numberTries\  = \ 
          0; \[IndentingNewLine]internalPrecisionLowLimit\  = \ 
          desiredPrecision; \[IndentingNewLine]internalPrecisionHighLimit\  = \
\ SquareRootN\  + \ \ desiredPrecision; \
\[IndentingNewLine]setInternalPrecision\  = \ 
          internalPrecisionHighLimit; \[IndentingNewLine] (*\ 
          Determine\ a\ high\ limit\ for\ minimumPrecision\ \
*) \[IndentingNewLine]Label[
          DetermineInternalPrecisionHighLimit]; \
\[IndentingNewLine]numberTries\  = \ 
          numberTries\ \  + \ 
            1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassIKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   FindHighLimit: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision = \>", \ \ \
currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  \[GreaterEqual] \ desiredPrecision, \ 
          Goto[HighLimitFound], \ 
          Goto[HighLimitTooSmall]]; \[IndentingNewLine] (*\ 
          Current\ high\ limit\ too\ small\ *) \[IndentingNewLine]Label[
          HighLimitTooSmall]; \[IndentingNewLine]internalPrecisionLowLimit\  \
= \ internalPrecisionHighLimit; \[IndentingNewLine]internalPrecisionHighLimit\
\  = \ internalPrecisionHighLimit\  + \ desiredPrecision\  - \ 
            currentPrecision; \[IndentingNewLine]setInternalPrecision\  = \ 
          internalPrecisionHighLimit; \[IndentingNewLine]Goto[
          DetermineInternalPrecisionHighLimit]; \[IndentingNewLine] (*\ 
          High\ limit\ found\ *) \[IndentingNewLine]Label[
          HighLimitFound]; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Bisection\ search\ to\ find\ minimumPrecision\ between\ \
internalPrecisionLowLimit\ and\ internalPrecisionHighLimit\ \
*) \[IndentingNewLine]Label[
          BisectionIteration]; \[IndentingNewLine]setInternalPrecision\  = \ 
          Floor[\((internalPrecisionLowLimit\  + \ 
                  internalPrecisionHighLimit)\)/2]; \[IndentingNewLine]If[
          setInternalPrecision\ \  \[LessEqual] \ 
            internalPrecisionLowLimit, \ 
          setInternalPrecision\ \  = \ 
            internalPrecisionLowLimit\  + \ 1, \[IndentingNewLine]\(If[
              setInternalPrecision\ \  \[GreaterEqual] \ \ \
internalPrecisionHighLimit, \ 
              setInternalPrecision\ \  = \ 
                internalPrecisionHighLimit\  - \ 
                  1];\)\[IndentingNewLine]]; \[IndentingNewLine]numberTries\  \
= \ numberTries\ \  + \ 1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassIKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   Bisection Search: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision = \>", \ \ \
currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  \[GreaterEqual] \ desiredPrecision, \ 
          Goto[ResetHighLimit], \ 
          Goto[ResetLowLimit]]; \[IndentingNewLine] (*\ 
          Reset\ internalPrecisionHighLimit\ to\ currentPrecision\ \
*) \[IndentingNewLine]Label[
          ResetHighLimit]; \[IndentingNewLine]internalPrecisionHighLimit\  = \
\ setInternalPrecision; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Reset\ internalPrecisionLowLimit\ to\ currentPrecision\ \
*) \[IndentingNewLine]Label[
          ResetLowLimit]; \[IndentingNewLine]internalPrecisionLowLimit\  = \ 
          setInternalPrecision; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Minimum\ internal\ precision\ found\ *) \[IndentingNewLine]Label[
          MinInternalPrecisionFound]; \[IndentingNewLine]setInternalPrecision\
\  = \ internalPrecisionLowLimit; \[IndentingNewLine]numberTries\  = \ 
          numberTries\ \  + \ 
            1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassIKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          
          Print["\<   Determine whether low or high limit is minimum \
precision: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision for low limit = \>", \ \
\ currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  < \ desiredPrecision, \ 
          setInternalPrecision\  = \ internalPrecisionHighLimit, \ 
          setInternalPrecision\  = \ 
            internalPrecisionLowLimit]; \
\[IndentingNewLine]minPrecisionMinusDesiredPrecision\  = \ 
          setInternalPrecision\  - \ \ desiredPrecision; \
\[IndentingNewLine]If[\ intermediateOutput \[GreaterEqual] \ 1, \ 
          Print["\<   Minimum Internal Precision Found: \>", \ "\< sampleSize \
= \>", \ sampleSize, \ "\<   testStatistic = \>", \ 
            testStatistic, "\< = \>", \ 
            N[testStatistic, 6], \ \ "\<    desiredPrecision = \>", \ 
            desiredPrecision, \ "\<   numberTries = \>", \ 
            numberTries, \ "\<   minimumInternalPrecision = \>", \ 
            setInternalPrecision, \ "\<   minPrecisionMinusDesiredPrecision = \
\>", \ minPrecisionMinusDesiredPrecision\ ]]; \
\[IndentingNewLine]{numberTries, \ 
          minPrecisionMinusDesiredPrecision}\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassIKS1SidedOneSampleRTArbPrecision[dIn_, sampleSizeIn_, \ 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ term, \ 
          leftTailProbability, \ rightTailProbability, \ sumTerms, \ 
          NminusjMinusOne, \ NminusjPlusOne, \ dN, \ jMinusdN, \ 
          nMINUSjPlusOnePLUSdn, \ jMINUSdnMinusOne}, \[IndentingNewLine] (*\ 
          Dwass\ Iterative\ formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ \
sample\ *) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ d]; \[IndentingNewLine]sumTerms\  = \ 
          N[\ d\ *\ \((1\  + \ d)\)^\((sampleSize - 1)\), \ 
            internalPrecision]; \[IndentingNewLine]term\  = \ 
          sumTerms; \[IndentingNewLine]NminusjMinusOne\  = \ 
          N[sampleSize\  - \ 1, \ 
            internalPrecision]; \[IndentingNewLine]NminusjPlusOne\  = \ 
          N[sampleSize\  + \ 1, \ 
            internalPrecision]; \[IndentingNewLine]dN\  = \ 
          N[d\ *\ sampleSize, \ 
            internalPrecision]; \[IndentingNewLine]jHighLimit\  = \ 
          Floor[dN]; \[IndentingNewLine]jMinusdN\  = \ \(-\ 
            dN\); \[IndentingNewLine]nMINUSjPlusOnePLUSdn\  = \ 
          N[\ sampleSize\  + \ 1\  + \ dN, \ 
            internalPrecision]; \[IndentingNewLine]jMINUSdnMinusOne\  = \ 
          N[\(-\ dN\)\  - \ 1, \ internalPrecision]; \[IndentingNewLine]If[
          jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]NminusjMinusOne\  = \ 
            N[NminusjMinusOne\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]NminusjPlusOne\  = \ 
            N[NminusjPlusOne\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]jMinusdN\  = \ 
            N[jMinusdN\  + \ 1\ , \ 
              internalPrecision]; \[IndentingNewLine]nMINUSjPlusOnePLUSdn\  = \
\ N[\ nMINUSjPlusOnePLUSdn\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]jMINUSdnMinusOne\  = \ 
            N[jMINUSdnMinusOne\  + \ 1, \ 
              internalPrecision]; \[IndentingNewLine]term\  = \ 
            N[\ \((\((NminusjPlusOne\ *\ jMinusdN)\)/\((j\ *\ 
                        nMINUSjPlusOnePLUSdn)\))\)*\ \((1\  - \ \((1/
                          nMINUSjPlusOnePLUSdn)\))\)^
                  NminusjMinusOne\ *\ \((1\  + \ \((1/
                          jMINUSdnMinusOne)\))\)^\((j - 1)\)*term, \ 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + term, \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1 - sumTerms, \ internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
13.1  DwassI Minimum Precision Minus Desired Precision Sample Intermediate \
Output\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionDwassI[\[InvisibleSpace]0.0185679, \ 
      10000\[InvisibleSpace], \ 20, \ 2]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("MinPrecisionMinusDesiredPrecisionDwassI:"\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.0185679`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0185679`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]20\),
        SequenceForm[ 
        "MinPrecisionMinusDesiredPrecisionDwassI:", " sampleSize = ", 10000, 
          "   testStatistic = ", .018567899999999998, 
          " = ", .018567899999999998, "    desiredPrecision = ", 20],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   FindHighLimit: numberTries = \
"\[InvisibleSpace]1\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]20\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]120\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]120\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]14\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.0009996621833282029441213374`14.1633493704216\),
        SequenceForm[ 
        "   FindHighLimit: numberTries = ", 1, 
          ", internalPrecisionLowLimit = ", 20, ", setInternalPrecision = ", 
          120, ", internalPrecisionHighLimit = ", 120, 
          ", desiredPrecision = ", 20, ", currentPrecision = ", 14, 
          ", rightTailProbability = ", 
          0.0009996621833282029441213374`14.1633493704216],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   FindHighLimit: numberTries = \
"\[InvisibleSpace]2\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]120\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]126\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]126\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.00099966218332820294412562226362553163`20.16334937042159\),
        
        SequenceForm[ 
        "   FindHighLimit: numberTries = ", 2, 
          ", internalPrecisionLowLimit = ", 120, ", setInternalPrecision = ", 
          126, ", internalPrecisionHighLimit = ", 126, 
          ", desiredPrecision = ", 20, ", currentPrecision = ", 20, 
          ", rightTailProbability = ", 
          0.00099966218332820294412562226362553163`20.16334937042159],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]3\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]120\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]123\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]126\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]17\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.00099966218332820294412551680603830336`17.1633493704216\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 3, 
          ", internalPrecisionLowLimit = ", 120, ", setInternalPrecision = ", 
          123, ", internalPrecisionHighLimit = ", 126, 
          ", desiredPrecision = ", 20, ", currentPrecision = ", 17, 
          ", rightTailProbability = ", 
          0.00099966218332820294412551680603830336`17.1633493704216],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]4\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]123\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]124\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]126\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]18\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.00099966218332820294412562226362553156`18.163349370421585\)\
,
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 4, 
          ", internalPrecisionLowLimit = ", 123, ", setInternalPrecision = ", 
          124, ", internalPrecisionHighLimit = ", 126, 
          ", desiredPrecision = ", 20, ", currentPrecision = ", 18, 
          ", rightTailProbability = ", 
          0.00099966218332820294412562226362553156`18.163349370421585],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]5\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]124\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]125\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]126\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]19\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.00099966218332820294412562226362553762`19.16334937042159\),
        
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 5, 
          ", internalPrecisionLowLimit = ", 124, ", setInternalPrecision = ", 
          125, ", internalPrecisionHighLimit = ", 126, 
          ", desiredPrecision = ", 20, ", currentPrecision = ", 19, 
          ", rightTailProbability = ", 
          0.00099966218332820294412562226362553762`19.16334937042159],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Determine whether low or high limit is minimum \
precision: numberTries = "\[InvisibleSpace]6\[InvisibleSpace]", \
internalPrecisionLowLimit = "\[InvisibleSpace]125\[InvisibleSpace]", \
setInternalPrecision = "\[InvisibleSpace]125\[InvisibleSpace]", \
internalPrecisionHighLimit = "\[InvisibleSpace]126\[InvisibleSpace]", \
desiredPrecision = "\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision \
for low limit = "\[InvisibleSpace]19\[InvisibleSpace]", rightTailProbability \
= "\[InvisibleSpace]0.00099966218332820294412562226362553762`19.\
16334937042159\),
        SequenceForm[ 
        "   Determine whether low or high limit is minimum precision: \
numberTries = ", 6, ", internalPrecisionLowLimit = ", 125, 
          ", setInternalPrecision = ", 125, ", internalPrecisionHighLimit = ",
           126, ", desiredPrecision = ", 20, 
          ", currentPrecision for low limit = ", 19, 
          ", rightTailProbability = ", 
          0.00099966218332820294412562226362553762`19.16334937042159],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Minimum Internal Precision Found: "\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.0185679`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0185679`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]20\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]6\
\[InvisibleSpace]"   minimumInternalPrecision = "\[InvisibleSpace]126\
\[InvisibleSpace]"   minPrecisionMinusDesiredPrecision = \
"\[InvisibleSpace]106\),
        SequenceForm[ 
        "   Minimum Internal Precision Found: ", " sampleSize = ", 10000, 
          "   testStatistic = ", .018567899999999998, 
          " = ", .018567899999999998, "    desiredPrecision = ", 20, 
          "   numberTries = ", 6, "   minimumInternalPrecision = ", 126, 
          "   minPrecisionMinusDesiredPrecision = ", 106],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`{6, 106}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionDwassI[\[InvisibleSpace]0.0185679, \ 
      10000\[InvisibleSpace], \ 100, \ 2]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("MinPrecisionMinusDesiredPrecisionDwassI:"\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.0185679`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0185679`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]100\),
        SequenceForm[ 
        "MinPrecisionMinusDesiredPrecisionDwassI:", " sampleSize = ", 10000, 
          "   testStatistic = ", .018567899999999998, 
          " = ", .018567899999999998, "    desiredPrecision = ", 100],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   FindHighLimit: numberTries = \
"\[InvisibleSpace]1\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]100\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]200\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]200\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]94\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
000999662183328202944125621550457714894310537494670134398443417283814375958241\
3911487057462674970473919129189317997`94.16334937042143\),
        SequenceForm[ 
        "   FindHighLimit: numberTries = ", 1, 
          ", internalPrecisionLowLimit = ", 100, ", setInternalPrecision = ", 
          200, ", internalPrecisionHighLimit = ", 200, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 94, 
          ", rightTailProbability = ", 
          0.000999662183328202944125621550457714894310537494670134398443417283\
8143759582413911487057462674970473919129189317997`94.16334937042143],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   FindHighLimit: numberTries = \
"\[InvisibleSpace]2\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]200\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]206\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]206\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
000999662183328202944125621550457714894310537494670134398443417283814375958241\
3911487057462674970473919133896126884`100.16334937042144\),
        SequenceForm[ 
        "   FindHighLimit: numberTries = ", 2, 
          ", internalPrecisionLowLimit = ", 200, ", setInternalPrecision = ", 
          206, ", internalPrecisionHighLimit = ", 206, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 100, 
          ", rightTailProbability = ", 
          0.000999662183328202944125621550457714894310537494670134398443417283\
8143759582413911487057462674970473919133896126884`100.16334937042144],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]3\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]200\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]203\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]206\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]97\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
000999662183328202944125621550457714894310537494670134398443417283814375958241\
3911487057462674970473919129189319721`97.16334937042146\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 3, 
          ", internalPrecisionLowLimit = ", 200, ", setInternalPrecision = ", 
          203, ", internalPrecisionHighLimit = ", 206, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 97, 
          ", rightTailProbability = ", 
          0.000999662183328202944125621550457714894310537494670134398443417283\
8143759582413911487057462674970473919129189319721`97.16334937042146],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]4\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]203\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]204\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]206\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]98\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
000999662183328202944125621550457714894310537494670134398443417283814375958241\
3911487057462674970473919133896126884`98.16334937042144\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 4, 
          ", internalPrecisionLowLimit = ", 203, ", setInternalPrecision = ", 
          204, ", internalPrecisionHighLimit = ", 206, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 98, 
          ", rightTailProbability = ", 
          0.000999662183328202944125621550457714894310537494670134398443417283\
8143759582413911487057462674970473919133896126884`98.16334937042144],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]5\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]204\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]205\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]206\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]99\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
000999662183328202944125621550457714894310537494670134398443417283814375958241\
3911487057462674970473919133896126884`99.16334937042143\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 5, 
          ", internalPrecisionLowLimit = ", 204, ", setInternalPrecision = ", 
          205, ", internalPrecisionHighLimit = ", 206, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 99, 
          ", rightTailProbability = ", 
          0.000999662183328202944125621550457714894310537494670134398443417283\
8143759582413911487057462674970473919133896126884`99.16334937042143],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Determine whether low or high limit is minimum \
precision: numberTries = "\[InvisibleSpace]6\[InvisibleSpace]", \
internalPrecisionLowLimit = "\[InvisibleSpace]205\[InvisibleSpace]", \
setInternalPrecision = "\[InvisibleSpace]205\[InvisibleSpace]", \
internalPrecisionHighLimit = "\[InvisibleSpace]206\[InvisibleSpace]", \
desiredPrecision = "\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision \
for low limit = "\[InvisibleSpace]99\[InvisibleSpace]", rightTailProbability \
= "\[InvisibleSpace]0.\
000999662183328202944125621550457714894310537494670134398443417283814375958241\
3911487057462674970473919133896126884`99.16334937042143\),
        SequenceForm[ 
        "   Determine whether low or high limit is minimum precision: \
numberTries = ", 6, ", internalPrecisionLowLimit = ", 205, 
          ", setInternalPrecision = ", 205, ", internalPrecisionHighLimit = ",
           206, ", desiredPrecision = ", 100, 
          ", currentPrecision for low limit = ", 99, 
          ", rightTailProbability = ", 
          0.000999662183328202944125621550457714894310537494670134398443417283\
8143759582413911487057462674970473919133896126884`99.16334937042143],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Minimum Internal Precision Found: "\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.0185679`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0185679`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]100\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]6\
\[InvisibleSpace]"   minimumInternalPrecision = "\[InvisibleSpace]206\
\[InvisibleSpace]"   minPrecisionMinusDesiredPrecision = \
"\[InvisibleSpace]106\),
        SequenceForm[ 
        "   Minimum Internal Precision Found: ", " sampleSize = ", 10000, 
          "   testStatistic = ", .018567899999999998, 
          " = ", .018567899999999998, "    desiredPrecision = ", 100, 
          "   numberTries = ", 6, "   minimumInternalPrecision = ", 206, 
          "   minPrecisionMinusDesiredPrecision = ", 106],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`{6, 106}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionDwassI[\[InvisibleSpace]0.00227855, \ 
      10000\[InvisibleSpace], \ 20, \ 2]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("MinPrecisionMinusDesiredPrecisionDwassI:"\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.00227855`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.00227855`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]20\),
        SequenceForm[ 
        "MinPrecisionMinusDesiredPrecisionDwassI:", " sampleSize = ", 10000, 
          "   testStatistic = ", .0022785499999999998, 
          " = ", .0022785499999999998, "    desiredPrecision = ", 20],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   FindHighLimit: numberTries = \
"\[InvisibleSpace]1\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]20\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]120\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]120\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]108\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
57423203977333122521487532944587444071511818591`108.64024442254828\),
        SequenceForm[ 
        "   FindHighLimit: numberTries = ", 1, 
          ", internalPrecisionLowLimit = ", 20, ", setInternalPrecision = ", 
          120, ", internalPrecisionHighLimit = ", 120, 
          ", desiredPrecision = ", 20, ", currentPrecision = ", 108, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
43202665708657423203977333122521487532944587444071511818591`108.\
64024442254828],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]2\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]20\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]70\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]120\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]58\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
90000709705339186224768503926219924843185404002007483123589475715261223695033`\
58.64024442254827\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 2, 
          ", internalPrecisionLowLimit = ", 20, ", setInternalPrecision = ", 
          70, ", internalPrecisionHighLimit = ", 120, ", desiredPrecision = ",
           20, ", currentPrecision = ", 58, ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894757152\
61223695033`58.64024442254827],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]3\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]20\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]45\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]70\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]33\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.900007097053391862247685039262199248460649358605`33.\
640244422548264\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 3, 
          ", internalPrecisionLowLimit = ", 20, ", setInternalPrecision = ", 
          45, ", internalPrecisionHighLimit = ", 70, ", desiredPrecision = ", 
          20, ", currentPrecision = ", 33, ", rightTailProbability = ", 
          0.900007097053391862247685039262199248460649358605`33.\
640244422548264],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]4\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]20\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]32\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]45\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.90000709705339186224768503894589398901`20.640244422548268\)\
,
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 4, 
          ", internalPrecisionLowLimit = ", 20, ", setInternalPrecision = ", 
          32, ", internalPrecisionHighLimit = ", 45, ", desiredPrecision = ", 
          20, ", currentPrecision = ", 20, ", rightTailProbability = ", 
          0.90000709705339186224768503894589398901`20.640244422548268],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]5\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]20\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]26\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]32\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]14\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.9000070970533918622476850389`14.640244422548275\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 5, 
          ", internalPrecisionLowLimit = ", 20, ", setInternalPrecision = ", 
          26, ", internalPrecisionHighLimit = ", 32, ", desiredPrecision = ", 
          20, ", currentPrecision = ", 14, ", rightTailProbability = ", 
          0.9000070970533918622476850389`14.640244422548275],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]6\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]26\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]29\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]32\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]17\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.9000070970533918622476850389`17.64024442254827\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 6, 
          ", internalPrecisionLowLimit = ", 26, ", setInternalPrecision = ", 
          29, ", internalPrecisionHighLimit = ", 32, ", desiredPrecision = ", 
          20, ", currentPrecision = ", 17, ", rightTailProbability = ", 
          0.9000070970533918622476850389`17.64024442254827],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]7\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]29\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]30\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]32\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]18\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.9000070970533918622476850389`18.640244422548275\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 7, 
          ", internalPrecisionLowLimit = ", 29, ", setInternalPrecision = ", 
          30, ", internalPrecisionHighLimit = ", 32, ", desiredPrecision = ", 
          20, ", currentPrecision = ", 18, ", rightTailProbability = ", 
          0.9000070970533918622476850389`18.640244422548275],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]8\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]30\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]31\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]32\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]19\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.90000709705339186224768503894589398901`19.640244422548268\)\
,
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 8, 
          ", internalPrecisionLowLimit = ", 30, ", setInternalPrecision = ", 
          31, ", internalPrecisionHighLimit = ", 32, ", desiredPrecision = ", 
          20, ", currentPrecision = ", 19, ", rightTailProbability = ", 
          0.90000709705339186224768503894589398901`19.640244422548268],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Determine whether low or high limit is minimum \
precision: numberTries = "\[InvisibleSpace]9\[InvisibleSpace]", \
internalPrecisionLowLimit = "\[InvisibleSpace]31\[InvisibleSpace]", \
setInternalPrecision = "\[InvisibleSpace]31\[InvisibleSpace]", \
internalPrecisionHighLimit = "\[InvisibleSpace]32\[InvisibleSpace]", \
desiredPrecision = "\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision \
for low limit = "\[InvisibleSpace]19\[InvisibleSpace]", rightTailProbability \
= "\[InvisibleSpace]0.90000709705339186224768503894589398901`19.\
640244422548268\),
        SequenceForm[ 
        "   Determine whether low or high limit is minimum precision: \
numberTries = ", 9, ", internalPrecisionLowLimit = ", 31, 
          ", setInternalPrecision = ", 31, ", internalPrecisionHighLimit = ", 
          32, ", desiredPrecision = ", 20, 
          ", currentPrecision for low limit = ", 19, 
          ", rightTailProbability = ", 
          0.90000709705339186224768503894589398901`19.640244422548268],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Minimum Internal Precision Found: "\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.00227855`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.00227855`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]20\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]9\
\[InvisibleSpace]"   minimumInternalPrecision = "\[InvisibleSpace]32\
\[InvisibleSpace]"   minPrecisionMinusDesiredPrecision = "\[InvisibleSpace]12\
\),
        SequenceForm[ 
        "   Minimum Internal Precision Found: ", " sampleSize = ", 10000, 
          "   testStatistic = ", .0022785499999999998, 
          " = ", .0022785499999999998, "    desiredPrecision = ", 20, 
          "   numberTries = ", 9, "   minimumInternalPrecision = ", 32, 
          "   minPrecisionMinusDesiredPrecision = ", 12],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`{9, 12}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionDwassI[\[InvisibleSpace]0.00227855, \ 
      10000\[InvisibleSpace], \ 100, \ 2]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("MinPrecisionMinusDesiredPrecisionDwassI:"\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.00227855`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.00227855`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]100\),
        SequenceForm[ 
        "MinPrecisionMinusDesiredPrecisionDwassI:", " sampleSize = ", 10000, 
          "   testStatistic = ", .0022785499999999998, 
          " = ", .0022785499999999998, "    desiredPrecision = ", 100],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   FindHighLimit: numberTries = \
"\[InvisibleSpace]1\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]100\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]200\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]200\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]188\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
574232039773331225214875329445874436559343337822145489039989694596584351287545\
726852706842276766499548842342096857080614039`188.6402444225482\),
        SequenceForm[ 
        "   FindHighLimit: numberTries = ", 1, 
          ", internalPrecisionLowLimit = ", 100, ", setInternalPrecision = ", 
          200, ", internalPrecisionHighLimit = ", 200, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 188, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
432026657086574232039773331225214875329445874436559343337822145489039989694596\
584351287545726852706842276766499548842342096857080614039`188.6402444225482],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]2\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]100\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]150\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]200\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]138\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
5742320397733312252148753294458744365593433378221454890399896946178684541267`\
138.64024442254828\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 2, 
          ", internalPrecisionLowLimit = ", 100, ", setInternalPrecision = ", 
          150, ", internalPrecisionHighLimit = ", 200, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 138, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
432026657086574232039773331225214875329445874436559343337822145489039989694617\
8684541267`138.64024442254828],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]3\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]100\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]125\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]150\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]113\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
57423203977333122521487532944587443655929757628`113.64024442254826\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 3, 
          ", internalPrecisionLowLimit = ", 100, ", setInternalPrecision = ", 
          125, ", internalPrecisionHighLimit = ", 150, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 113, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
43202665708657423203977333122521487532944587443655929757628`113.\
64024442254826],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]4\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]100\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]112\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]125\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
5742320397733312252148753292201826876`100.64024442254828\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 4, 
          ", internalPrecisionLowLimit = ", 100, ", setInternalPrecision = ", 
          112, ", internalPrecisionHighLimit = ", 125, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 100, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
4320266570865742320397733312252148753292201826876`100.64024442254828],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]5\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]100\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]106\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]112\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]94\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
574232039773331225214276952`94.64024442254828\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 5, 
          ", internalPrecisionLowLimit = ", 100, ", setInternalPrecision = ", 
          106, ", internalPrecisionHighLimit = ", 112, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 94, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
432026657086574232039773331225214276952`94.64024442254828],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]6\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]106\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]109\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]112\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]97\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
5742320397733312252148751474842358357`97.64024442254826\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 6, 
          ", internalPrecisionLowLimit = ", 106, ", setInternalPrecision = ", 
          109, ", internalPrecisionHighLimit = ", 112, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 97, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
4320266570865742320397733312252148751474842358357`97.64024442254826],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]7\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]109\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]110\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]112\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]98\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
5742320397733312252148753707694570417`98.64024442254828\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 7, 
          ", internalPrecisionLowLimit = ", 109, ", setInternalPrecision = ", 
          110, ", internalPrecisionHighLimit = ", 112, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 98, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
4320266570865742320397733312252148753707694570417`98.64024442254828],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]8\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]110\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]111\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]112\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]99\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
5742320397733312252148753707694571554`99.64024442254828\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 8, 
          ", internalPrecisionLowLimit = ", 110, ", setInternalPrecision = ", 
          111, ", internalPrecisionHighLimit = ", 112, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 99, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
4320266570865742320397733312252148753707694571554`99.64024442254828],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Determine whether low or high limit is minimum \
precision: numberTries = "\[InvisibleSpace]9\[InvisibleSpace]", \
internalPrecisionLowLimit = "\[InvisibleSpace]111\[InvisibleSpace]", \
setInternalPrecision = "\[InvisibleSpace]111\[InvisibleSpace]", \
internalPrecisionHighLimit = "\[InvisibleSpace]112\[InvisibleSpace]", \
desiredPrecision = "\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision \
for low limit = "\[InvisibleSpace]99\[InvisibleSpace]", rightTailProbability \
= "\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
5742320397733312252148753707694571554`99.64024442254828\),
        SequenceForm[ 
        "   Determine whether low or high limit is minimum precision: \
numberTries = ", 9, ", internalPrecisionLowLimit = ", 111, 
          ", setInternalPrecision = ", 111, ", internalPrecisionHighLimit = ",
           112, ", desiredPrecision = ", 100, 
          ", currentPrecision for low limit = ", 99, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
4320266570865742320397733312252148753707694571554`99.64024442254828],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Minimum Internal Precision Found: "\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.00227855`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.00227855`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]100\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]9\
\[InvisibleSpace]"   minimumInternalPrecision = "\[InvisibleSpace]112\
\[InvisibleSpace]"   minPrecisionMinusDesiredPrecision = "\[InvisibleSpace]12\
\),
        SequenceForm[ 
        "   Minimum Internal Precision Found: ", " sampleSize = ", 10000, 
          "   testStatistic = ", .0022785499999999998, 
          " = ", .0022785499999999998, "    desiredPrecision = ", 100, 
          "   numberTries = ", 9, "   minimumInternalPrecision = ", 112, 
          "   minPrecisionMinusDesiredPrecision = ", 12],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`{9, 12}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["14. Calculation Time for DwassI", "Section"],

Cell["\<\
The following is the code of the Mathematica function \
TimingDwassIKS1SidedOneSampleRTArbPrecision.  Sample output is given in \
subsection 14.1.\
\>", "Text"],

Cell[BoxData[
    \(TimingDwassIKS1SidedOneSampleRTArbPrecision[alpha_, \ sampleSizeIn_, \ 
        desiredPrecisionIn_, \ testStatisticDesiredPrecisionIn_]\ \  := 
      Module[{d, \ \ sampleSize, \ minimumPrecision, \ desiredPrecision, \ 
          testStatisticDesiredPrecision, \ functionOutput, \ 
          rightTailProbability, rightTailProbabilityPrecision, \ 
          functionTimeString, \ timeString}, \[IndentingNewLine] (*\ 
          For\ the\ KS\ 1\ sided\ one\ sample\ test, \ 
          the\ Maag\ and\ Dicaire\ formula\ is\ used\ *) \[IndentingNewLine] \
(*\ \ \ \ for\ sample\ size\ sampleSizeIn\ and\ right\ tail\ p - 
            value\ alpha\ to\ produce\ a\ *) \[IndentingNewLine] (*\ \ \ \ \
test\ statistic\ d\ with\ testStatisticDesiredPrecisionIn\ decimal\ digits\ \
of\ *) \[IndentingNewLine] (*\ \ \ \ accuracy . \ \ Then\ the\ minimum\ \
precision\ minimumPrecision\ needed\ for\ the\ *) \[IndentingNewLine] (*\ \ \ \
\ arbitrary\ precision\ DwassI\ formula\ to\ calculate\ a\ right\ tail\ \
*) \[IndentingNewLine] (*\ \ \ \ probability\ with\ desiredPrecisionIn\ \
digits\ of\ precision\ for\ test\ *) \[IndentingNewLine] (*\ \ \ \ statistic\ \
d\ and\ sample\ size\ sampleSizeIn\ is\ \(\(calculated\)\(.\)\)\ \
*) \[IndentingNewLine] (*\ \ \ \ Finally, \ 
          the\ time\ in\ seconds\ for\ the\ arbitrary\ precision\ DwassI\ \
*) \[IndentingNewLine] (*\ \ \ \ formula\ to\ calculate\ the\ right\ tail\ \
probability\ for\ test\ statistic\ d\ *) \[IndentingNewLine] (*\ \ \ \ and\ \
sample\ size\ sampleSizeIn\ with\ an\ internal\ precision\ of\ \
*) \[IndentingNewLine] (*\ \ \ \ minimumPrecision\ is\ found\ and\ \
\(\(printed\)\(.\)\)\ *) \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]desiredPrecision\  = \ 
          Floor[desiredPrecisionIn]; \
\[IndentingNewLine]testStatisticDesiredPrecision\  = \ 
          Floor[testStatisticDesiredPrecisionIn]; \[IndentingNewLine]d\  = \ 
          KS1SidedOneSampleTestStatisticByMaagDicaire[alpha, sampleSize, \ 
            
            testStatisticDesiredPrecision]; \[IndentingNewLine]functionOutput\
\  = MinPrecisionMinusDesiredPrecisionDwassI[d, \ sampleSize, \ 
            desiredPrecision, \ 0]; \[IndentingNewLine]minimumPrecision\  = \ 
          functionOutput[\([2]\)]; \[IndentingNewLine]minimumPrecision\  = \ 
          minimumPrecision\  + \ 
            desiredPrecision; \[IndentingNewLine]functionOutput\  = \ 
          Timing[DwassIKS1SidedOneSampleRTArbPrecision[d, \ sampleSize, \ 
              minimumPrecision]]; \[IndentingNewLine]rightTailProbability\  = \
\ functionOutput[\([2]\)]; \[IndentingNewLine]rightTailProbabilityPrecision\  \
= \ Floor[Precision[
              rightTailProbability]]; \[IndentingNewLine]functionTimeString\  \
= \ functionOutput[\([1]\)]; \[IndentingNewLine]timeString\  = \ 
          functionTimeString\  /. \ 
            Second \[Rule] 
              1; \[IndentingNewLine]Print["\<\
TimingDwassIKS1SidedOneSampleRTArbPrecision: sampleSize = \>", \ 
          sampleSize, \ "\<   alpha = \>", \ 
          alpha, \ "\<  desiredPrecision = \>", \ 
          desiredPrecision, \ "\<   testStatisticDesiredPrecision = \>", \ 
          testStatisticDesiredPrecision, \ "\<   d = \>", \ 
          d, \ "\<   minimumPrecision = \>", \ 
          minimumPrecision, \ \ \ "\<   rightTailProbability = \>", \ 
          rightTailProbability, \ "\<  rightTailProbabilityPrecision = \>", \ 
          rightTailProbabilityPrecision, \ "\<   time in seconds = \>", \ 
          timeString\ ]; \
\[IndentingNewLine]sampleSize\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(KS1SidedOneSampleTestStatisticByMaagDicaire[alphaIn_, sampleSizeIn_, \ 
        rho_]\  := \[IndentingNewLine]Module[{d, \ alpha, \ 
          sampleSize}, \[IndentingNewLine] (*\ 
          For\ the\ KS\ 1\ sided\ one\ sample\ test, \ 
          the\ Maag\ and\ Dicaire\ formula\ is\ used\ *) \[IndentingNewLine] \
(*\ \ \ \ to\ approximate\ the\ test\ statistic\ corresponding\ to\ a\ right\ \
tail\ *) \[IndentingNewLine] (*\ \ \ \ probability\ of\ alphaIn . \ \ The\ \
test\ statistic\ d\ is\ calculated\ to\ *) \[IndentingNewLine] (*\ \ \ \ rho\ \
number\ of\ decimal\ \(\(digits\)\(.\)\)\ *) \[IndentingNewLine]alpha\  = 
          Rationalize[alphaIn, \ 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine] (*\ 
          Use\ Maag\ and\ Dicaire\ \(\(MD\)\(.\)\)\ *) \[IndentingNewLine]d\  \
= \ N[Sqrt[Log[alpha]/\((\(-2\)*sampleSize)\)] - \ \((1/\((6*
                      sampleSize)\))\), 
            rho\ \  + \ 17]; \[IndentingNewLine]d\  = \ 
          N[d, rho]; \[IndentingNewLine]d\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionDwassI[testStatistic_, \ 
        sampleSize_, \ desiredPrecision_, \ intermediateOutput_]\  := \ 
      Module[{internalPrecisionLowLimit, \ internalPrecisionHighLimit, \ 
          setInternalPrecision, \ currentPrecision, \ SquareRootN, \ 
          numberTries, \ rightTailProbability, \ 
          rightTailProbabilityToDesiredPrecision, \ 
          minPrecisionMinusDesiredPrecision, \ mantissaExp, \ numExp, \ 
          prop}, \[IndentingNewLine]SquareRootN\  = \ 
          Ceiling[Sqrt[sampleSize]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 1, \ 
          Print["\<MinPrecisionMinusDesiredPrecisionDwassI:\>", \ "\< \
sampleSize = \>", \ sampleSize, \ "\<   testStatistic = \>", \ 
            testStatistic, "\< = \>", \ 
            N[testStatistic, 6], \ \ "\<    desiredPrecision = \>", \ 
            desiredPrecision]]; \[IndentingNewLine]numberTries\  = \ 
          0; \[IndentingNewLine]internalPrecisionLowLimit\  = \ 
          desiredPrecision; \[IndentingNewLine]internalPrecisionHighLimit\  = \
\ SquareRootN\  + \ \ desiredPrecision; \
\[IndentingNewLine]setInternalPrecision\  = \ 
          internalPrecisionHighLimit; \[IndentingNewLine] (*\ 
          Determine\ a\ high\ limit\ for\ minimumPrecision\ \
*) \[IndentingNewLine]Label[
          DetermineInternalPrecisionHighLimit]; \
\[IndentingNewLine]numberTries\  = \ 
          numberTries\ \  + \ 
            1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassIKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   FindHighLimit: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision = \>", \ \ \
currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  \[GreaterEqual] \ desiredPrecision, \ 
          Goto[HighLimitFound], \ 
          Goto[HighLimitTooSmall]]; \[IndentingNewLine] (*\ 
          Current\ high\ limit\ too\ small\ *) \[IndentingNewLine]Label[
          HighLimitTooSmall]; \[IndentingNewLine]internalPrecisionLowLimit\  \
= \ internalPrecisionHighLimit; \[IndentingNewLine]internalPrecisionHighLimit\
\  = \ internalPrecisionHighLimit\  + \ desiredPrecision\  - \ 
            currentPrecision; \[IndentingNewLine]setInternalPrecision\  = \ 
          internalPrecisionHighLimit; \[IndentingNewLine]Goto[
          DetermineInternalPrecisionHighLimit]; \[IndentingNewLine] (*\ 
          High\ limit\ found\ *) \[IndentingNewLine]Label[
          HighLimitFound]; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Bisection\ search\ to\ find\ minimumPrecision\ between\ \
internalPrecisionLowLimit\ and\ internalPrecisionHighLimit\ \
*) \[IndentingNewLine]Label[
          BisectionIteration]; \[IndentingNewLine]setInternalPrecision\  = \ 
          Floor[\((internalPrecisionLowLimit\  + \ 
                  internalPrecisionHighLimit)\)/2]; \[IndentingNewLine]If[
          setInternalPrecision\ \  \[LessEqual] \ 
            internalPrecisionLowLimit, \ 
          setInternalPrecision\ \  = \ 
            internalPrecisionLowLimit\  + \ 1, \[IndentingNewLine]\(If[
              setInternalPrecision\ \  \[GreaterEqual] \ \ \
internalPrecisionHighLimit, \ 
              setInternalPrecision\ \  = \ 
                internalPrecisionHighLimit\  - \ 
                  1];\)\[IndentingNewLine]]; \[IndentingNewLine]numberTries\  \
= \ numberTries\ \  + \ 1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassIKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   Bisection Search: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision = \>", \ \ \
currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  \[GreaterEqual] \ desiredPrecision, \ 
          Goto[ResetHighLimit], \ 
          Goto[ResetLowLimit]]; \[IndentingNewLine] (*\ 
          Reset\ internalPrecisionHighLimit\ to\ currentPrecision\ \
*) \[IndentingNewLine]Label[
          ResetHighLimit]; \[IndentingNewLine]internalPrecisionHighLimit\  = \
\ setInternalPrecision; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Reset\ internalPrecisionLowLimit\ to\ currentPrecision\ \
*) \[IndentingNewLine]Label[
          ResetLowLimit]; \[IndentingNewLine]internalPrecisionLowLimit\  = \ 
          setInternalPrecision; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Minimum\ internal\ precision\ found\ *) \[IndentingNewLine]Label[
          MinInternalPrecisionFound]; \[IndentingNewLine]setInternalPrecision\
\  = \ internalPrecisionLowLimit; \[IndentingNewLine]numberTries\  = \ 
          numberTries\ \  + \ 
            1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassIKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          
          Print["\<   Determine whether low or high limit is minimum \
precision: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision for low limit = \>", \ \
\ currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  < \ desiredPrecision, \ 
          setInternalPrecision\  = \ internalPrecisionHighLimit, \ 
          setInternalPrecision\  = \ 
            internalPrecisionLowLimit]; \
\[IndentingNewLine]minPrecisionMinusDesiredPrecision\  = \ 
          setInternalPrecision\  - \ \ desiredPrecision; \
\[IndentingNewLine]If[\ intermediateOutput \[GreaterEqual] \ 1, \ 
          Print["\<   Minimum Internal Precision Found: \>", \ "\< sampleSize \
= \>", \ sampleSize, \ "\<   testStatistic = \>", \ 
            testStatistic, "\< = \>", \ 
            N[testStatistic, 6], \ \ "\<    desiredPrecision = \>", \ 
            desiredPrecision, \ "\<   numberTries = \>", \ 
            numberTries, \ "\<   minimumInternalPrecision = \>", \ 
            setInternalPrecision, \ "\<   minPrecisionMinusDesiredPrecision = \
\>", \ minPrecisionMinusDesiredPrecision\ ]]; \
\[IndentingNewLine]{numberTries, \ 
          minPrecisionMinusDesiredPrecision}\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassIKS1SidedOneSampleRTArbPrecision[dIn_, sampleSizeIn_, \ 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ term, \ 
          leftTailProbability, \ rightTailProbability, \ sumTerms, \ 
          NminusjMinusOne, \ NminusjPlusOne, \ dN, \ jMinusdN, \ 
          nMINUSjPlusOnePLUSdn, \ jMINUSdnMinusOne}, \[IndentingNewLine] (*\ 
          Dwass\ Iterative\ formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ \
sample\ *) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ d]; \[IndentingNewLine]sumTerms\  = \ 
          N[\ d\ *\ \((1\  + \ d)\)^\((sampleSize - 1)\), \ 
            internalPrecision]; \[IndentingNewLine]term\  = \ 
          sumTerms; \[IndentingNewLine]NminusjMinusOne\  = \ 
          N[sampleSize\  - \ 1, \ 
            internalPrecision]; \[IndentingNewLine]NminusjPlusOne\  = \ 
          N[sampleSize\  + \ 1, \ 
            internalPrecision]; \[IndentingNewLine]dN\  = \ 
          N[d\ *\ sampleSize, \ 
            internalPrecision]; \[IndentingNewLine]jHighLimit\  = \ 
          Floor[dN]; \[IndentingNewLine]jMinusdN\  = \ \(-\ 
            dN\); \[IndentingNewLine]nMINUSjPlusOnePLUSdn\  = \ 
          N[\ sampleSize\  + \ 1\  + \ dN, \ 
            internalPrecision]; \[IndentingNewLine]jMINUSdnMinusOne\  = \ 
          N[\(-\ dN\)\  - \ 1, \ internalPrecision]; \[IndentingNewLine]If[
          jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]NminusjMinusOne\  = \ 
            N[NminusjMinusOne\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]NminusjPlusOne\  = \ 
            N[NminusjPlusOne\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]jMinusdN\  = \ 
            N[jMinusdN\  + \ 1\ , \ 
              internalPrecision]; \[IndentingNewLine]nMINUSjPlusOnePLUSdn\  = \
\ N[\ nMINUSjPlusOnePLUSdn\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]jMINUSdnMinusOne\  = \ 
            N[jMINUSdnMinusOne\  + \ 1, \ 
              internalPrecision]; \[IndentingNewLine]term\  = \ 
            N[\ \((\((NminusjPlusOne\ *\ jMinusdN)\)/\((j\ *\ 
                        nMINUSjPlusOnePLUSdn)\))\)*\ \((1\  - \ \((1/
                          nMINUSjPlusOnePLUSdn)\))\)^
                  NminusjMinusOne\ *\ \((1\  + \ \((1/
                          jMINUSdnMinusOne)\))\)^\((j - 1)\)*term, \ 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + term, \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1 - sumTerms, \ internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
14.1  Calculation Time for DwassI Sample Output on a 3.4 GHz Pentium IV\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassIKS1SidedOneSampleRTArbPrecision[0.001, \ 1000000, \ 20, \ 
      6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassIKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]1000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.001`\[InvisibleSpace]"  desiredPrecision = "\
\[InvisibleSpace]20\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0018582944277582526`6. \[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]1055\[InvisibleSpace]"   \
rightTailProbability = \
"\[InvisibleSpace]0.00100000519945517771720304317323965854`20.477495124372922\
\[InvisibleSpace]"  rightTailProbabilityPrecision = "\[InvisibleSpace]20\
\[InvisibleSpace]"   time in seconds = "\[InvisibleSpace]19.28099999999904`\),
        
        SequenceForm[ 
        "TimingDwassIKS1SidedOneSampleRTArbPrecision: sampleSize = ", 1000000,
           "   alpha = ", .001, "  desiredPrecision = ", 20, 
          "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0018582944277582526`6., "   minimumPrecision = ", 1055, 
          "   rightTailProbability = ", 
          0.00100000519945517771720304317323965854`20.477495124372922, 
          "  rightTailProbabilityPrecision = ", 20, "   time in seconds = ", 
          19.28099999999904],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`1000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassIKS1SidedOneSampleRTArbPrecision[0.001, \ 1000000, \ 100, \ 
      6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassIKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]1000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.001`\[InvisibleSpace]"  desiredPrecision = "\
\[InvisibleSpace]100\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0018582944277582526`6. \[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]1135\[InvisibleSpace]"   \
rightTailProbability = \
"\[InvisibleSpace]0.\
001000005199455177717203043173239657016576905944280063055591650077084956245924\
2870800970192444170276407025055827565`100.47749512437272\[InvisibleSpace]"  \
rightTailProbabilityPrecision = "\[InvisibleSpace]100\[InvisibleSpace]"   \
time in seconds = "\[InvisibleSpace]19.82799999999952`\),
        SequenceForm[ 
        "TimingDwassIKS1SidedOneSampleRTArbPrecision: sampleSize = ", 1000000,
           "   alpha = ", .001, "  desiredPrecision = ", 100, 
          "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0018582944277582526`6., "   minimumPrecision = ", 1135, 
          "   rightTailProbability = ", 
          0.001000005199455177717203043173239657016576905944280063055591650077\
0849562459242870800970192444170276407025055827565`100.47749512437272, 
          "  rightTailProbabilityPrecision = ", 100, "   time in seconds = ", 
          19.82799999999952],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`1000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassIKS1SidedOneSampleRTArbPrecision[0.9, \ 1000000, \ 20, \ 
      6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassIKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]1000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.9`\[InvisibleSpace]"  desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0002293551358465437218400548`6.000000000000002\
\[InvisibleSpace]"   minimumPrecision = \
"\[InvisibleSpace]147\[InvisibleSpace]"   rightTailProbability = "\
\[InvisibleSpace]0.90000015781059704546078396689199627583`20.945450455040806\
\[InvisibleSpace]"  rightTailProbabilityPrecision = "\[InvisibleSpace]20\
\[InvisibleSpace]"   time in seconds = "\[InvisibleSpace]4.563000000000102`\),
        
        SequenceForm[ 
        "TimingDwassIKS1SidedOneSampleRTArbPrecision: sampleSize = ", 1000000,
           "   alpha = ", .90000000000000002, "  desiredPrecision = ", 20, 
          "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0002293551358465437218400548`6.000000000000002, 
          "   minimumPrecision = ", 147, "   rightTailProbability = ", 
          0.90000015781059704546078396689199627583`20.945450455040806, 
          "  rightTailProbabilityPrecision = ", 20, "   time in seconds = ", 
          4.5630000000001019],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`1000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassIKS1SidedOneSampleRTArbPrecision[0.001, \ 5000000, \ 20, \ 
      6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassIKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]5000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.001`\[InvisibleSpace]"  desiredPrecision = "\
\[InvisibleSpace]20\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0008310957348012216`5.999999999999999\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]2330\[InvisibleSpace]"   \
rightTailProbability = \
"\[InvisibleSpace]0.00099999870917696091267298145583196882`20.010889624769934\
\[InvisibleSpace]"  rightTailProbabilityPrecision = "\[InvisibleSpace]20\
\[InvisibleSpace]"   time in seconds = \
"\[InvisibleSpace]108.48400000000038`\),
        SequenceForm[ 
        "TimingDwassIKS1SidedOneSampleRTArbPrecision: sampleSize = ", 5000000,
           "   alpha = ", .001, "  desiredPrecision = ", 20, 
          "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0008310957348012216`5.999999999999999, "   minimumPrecision = ", 
          2330, "   rightTailProbability = ", 
          0.00099999870917696091267298145583196882`20.010889624769934, 
          "  rightTailProbabilityPrecision = ", 20, "   time in seconds = ", 
          108.48400000000038],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`5000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassIKS1SidedOneSampleRTArbPrecision[0.001, \ 5000000, \ 100, \ 
      6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassIKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]5000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.001`\[InvisibleSpace]"  desiredPrecision = "\
\[InvisibleSpace]100\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0008310957348012216`5.999999999999999\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]2410\[InvisibleSpace]"   \
rightTailProbability = \
"\[InvisibleSpace]0.\
000999998709176960912672981455831968819987827596090744225002676475244134381205\
6948730480676837976559845189726002167`100.01088962477004\[InvisibleSpace]"  \
rightTailProbabilityPrecision = "\[InvisibleSpace]100\[InvisibleSpace]"   \
time in seconds = "\[InvisibleSpace]111.67199999999866`\),
        SequenceForm[ 
        "TimingDwassIKS1SidedOneSampleRTArbPrecision: sampleSize = ", 5000000,
           "   alpha = ", .001, "  desiredPrecision = ", 100, 
          "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0008310957348012216`5.999999999999999, "   minimumPrecision = ", 
          2410, "   rightTailProbability = ", 
          0.000999998709176960912672981455831968819987827596090744225002676475\
2441343812056948730480676837976559845189726002167`100.01088962477004, 
          "  rightTailProbabilityPrecision = ", 100, "   time in seconds = ", 
          111.67199999999866],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`5000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassIKS1SidedOneSampleRTArbPrecision[0.9, \ 5000000, \ 20, \ 
      6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassIKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]5000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.9`\[InvisibleSpace]"  desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0001026119372142307669068612`6.000000000000002\
\[InvisibleSpace]"   minimumPrecision = \
"\[InvisibleSpace]304\[InvisibleSpace]"   rightTailProbability = "\
\[InvisibleSpace]0.90000000829283041495172335763255607517`20.424005127998097\
\[InvisibleSpace]"  rightTailProbabilityPrecision = "\[InvisibleSpace]20\
\[InvisibleSpace]"   time in seconds = "\[InvisibleSpace]24.21900000000096`\),
        
        SequenceForm[ 
        "TimingDwassIKS1SidedOneSampleRTArbPrecision: sampleSize = ", 5000000,
           "   alpha = ", .90000000000000002, "  desiredPrecision = ", 20, 
          "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0001026119372142307669068612`6.000000000000002, 
          "   minimumPrecision = ", 304, "   rightTailProbability = ", 
          0.90000000829283041495172335763255607517`20.424005127998097, 
          "  rightTailProbabilityPrecision = ", 20, "   time in seconds = ", 
          24.21900000000096],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`5000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassIKS1SidedOneSampleRTArbPrecision[0.001, \ 10000000, \ 20, \ 
      6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassIKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]10000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.001`\[InvisibleSpace]"  desiredPrecision = "\
\[InvisibleSpace]20\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0005876803334525333`6.000000000000002\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]3286\[InvisibleSpace]"   \
rightTailProbability = \
"\[InvisibleSpace]0.00100000539120678945192816085831260261`20.28108417411803\
\[InvisibleSpace]"  rightTailProbabilityPrecision = "\[InvisibleSpace]20\
\[InvisibleSpace]"   time in seconds = \
"\[InvisibleSpace]264.28199999999924`\),
        SequenceForm[ 
        "TimingDwassIKS1SidedOneSampleRTArbPrecision: sampleSize = ", 
          10000000, "   alpha = ", .001, "  desiredPrecision = ", 20, 
          "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0005876803334525333`6.000000000000002, "   minimumPrecision = ", 
          3286, "   rightTailProbability = ", 
          0.00100000539120678945192816085831260261`20.28108417411803, 
          "  rightTailProbabilityPrecision = ", 20, "   time in seconds = ", 
          264.28199999999924],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`10000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassIKS1SidedOneSampleRTArbPrecision[0.001, \ 10000000, \ 100, \ 
      6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassIKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]10000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.001`\[InvisibleSpace]"  desiredPrecision = "\
\[InvisibleSpace]100\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0005876803334525333`6.000000000000002\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]3366\[InvisibleSpace]"   \
rightTailProbability = \
"\[InvisibleSpace]0.\
001000005391206789451928160858312602629537126695141170964778858883896442362026\
2012939158261205589577311062122224052`100.28108417411859\[InvisibleSpace]"  \
rightTailProbabilityPrecision = "\[InvisibleSpace]100\[InvisibleSpace]"   \
time in seconds = "\[InvisibleSpace]269.625`\),
        SequenceForm[ 
        "TimingDwassIKS1SidedOneSampleRTArbPrecision: sampleSize = ", 
          10000000, "   alpha = ", .001, "  desiredPrecision = ", 100, 
          "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0005876803334525333`6.000000000000002, "   minimumPrecision = ", 
          3366, "   rightTailProbability = ", 
          0.001000005391206789451928160858312602629537126695141170964778858883\
8964423620262012939158261205589577311062122224052`100.28108417411859, 
          "  rightTailProbabilityPrecision = ", 100, "   time in seconds = ", 
          269.625],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`10000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassIKS1SidedOneSampleRTArbPrecision[0.9, \ 10000000, \ 20, \ 
      6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassIKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]10000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.9`\[InvisibleSpace]"  desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0000725645001942437127574416`6.000000000000002\
\[InvisibleSpace]"   minimumPrecision = \
"\[InvisibleSpace]422\[InvisibleSpace]"   rightTailProbability = "\
\[InvisibleSpace]0.89999987106638007733105785714793785198`20.389941618264835\
\[InvisibleSpace]"  rightTailProbabilityPrecision = "\[InvisibleSpace]20\
\[InvisibleSpace]"   time in seconds = "\[InvisibleSpace]57.48400000000038`\),
        
        SequenceForm[ 
        "TimingDwassIKS1SidedOneSampleRTArbPrecision: sampleSize = ", 
          10000000, "   alpha = ", .90000000000000002, 
          "  desiredPrecision = ", 20, "   testStatisticDesiredPrecision = ", 
          6, "   d = ", 0.0000725645001942437127574416`6.000000000000002, 
          "   minimumPrecision = ", 422, "   rightTailProbability = ", 
          0.89999987106638007733105785714793785198`20.389941618264835, 
          "  rightTailProbabilityPrecision = ", 20, "   time in seconds = ", 
          57.484000000000378],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`10000000\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["15. DwassI Minimum Precision Minus Desired Precision To File", "Section"],

Cell["\<\
The following is the code of the Mathematica function \
MinPrecisionMinusDesiredPrecisionToFileDwassI that calculates the minimum \
precision minus desired precision needed for the arbitrary precision DwassI \
formula and the sample sizes in the vector sampleSizeVectorIn, the desired \
precisions in the vector desiredPrecisionVectorIn, and the Maag and Dicaire \
test statistic to six digits of precision for the p-values in the vector \
alphaVectorIn.  The results are written to file outputFileName which can be \
read by Execel if separatorString is a comma.  Sample intermediate output is \
given in subsection 15.1.  The sample output file generated by the example in \
subsection 15.1 is given in subsection 15.2.\
\>", "Text"],

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionToFileDwassI[sampleSizeVectorIn_, \ 
        desiredPrecisionVectorIn_, \ alphaVectorIn_, \ intermediateOutput_, \ 
        outputFileName_, \ howToOpenFile_, \ separatorString_]\  := \ 
      Module[{numberSampleSizes, \ numberDesiredPrecisions, \ numberAlphas, \ 
          VectorDimensions, \ sampleSize, \ desiredPrecision, \ alpha, \ 
          numberDesiredPrecisionsAndAlphas, \ minimumPrecision, \ 
          sampleSizeIndex, \ desiredPrecisionIndex, \ alphaIndex, \ 
          outputFileNumber, \ minimumPrecisionArray, \ d, \ numExp, \ 
          nOutputString, \ numberTermsOutputString, \ 
          desiredPrecisionOutputString, \ minimumPrecisionOutputString, \ 
          stringIndex, \ functionOutput}, \[IndentingNewLine] (*\ 
          Generate\ minimumPrecision - 
            desiredPrecision\ for\ arbitrary\ precision\ \[IndentingNewLine]\ \
\ \ \ \ \ \ DwassI\ and\ put\ into\ file, \ 
          outputFileName\ *) \[IndentingNewLine] (*\ 
          Open\ \(file : \ howToOpenFile\) = 0, \ 
          use\ OpenWrite\ which\ creates\ a\ new\ file\[IndentingNewLine]\ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ and\ destroys\ an\ old\ \
file\ *) \ \[IndentingNewLine] (*\ \ \ \ \ \ \ \ \ \ \ \ howToOpenFile = 1, \ 
          use\ OpenAppend\ which\ opens\ file\ and\[IndentingNewLine]\ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ appends\ output\ to\ end\ \
of\ that\ \(\(file\)\(.\)\)\ \ *) \[IndentingNewLine]VectorDimensions\  = \ 
          Dimensions[
            sampleSizeVectorIn]; \[IndentingNewLine]numberSampleSizes\  = \ \ \
VectorDimensions[\([1]\)]; \[IndentingNewLine]VectorDimensions\  = \ 
          Dimensions[
            desiredPrecisionVectorIn]; \
\[IndentingNewLine]numberDesiredPrecisions\  = \ \ VectorDimensions[\([1]\)]; \
\[IndentingNewLine]VectorDimensions\  = \ 
          Dimensions[
            alphaVectorIn]; \[IndentingNewLine]numberAlphas\  = \ \ \
VectorDimensions[\([1]\)]; \
\[IndentingNewLine]numberDesiredPrecisionsAndAlphas\  = \ 
          numberDesiredPrecisions\ *\ 
            numberAlphas; \[IndentingNewLine]minimumPrecisionArray\  = \ 
          Array[
            0, \ {numberSampleSizes, \ numberDesiredPrecisions, \ 
              numberAlphas}]; \[IndentingNewLine]If[
          howToOpenFile\  \[LessEqual] \ 0, \ 
          outputFileNumber\  = \ OpenWrite[outputFileName], \ 
          outputFileNumber\  = \ 
            OpenAppend[outputFileName]]; \[IndentingNewLine]If[
          howToOpenFile\  \[LessEqual] \ 0, \ \[IndentingNewLine] (*\ 
            Output\ all\ the\ minimum\ precisions\ in\ a\ vector\ \
*) \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<DwassI:\n\>"]; \
\[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<Desired\>", \ \ separatorString, \ 
            separatorString, \ "\<Sample\>", \ 
            separatorString, \ \ "\<Minimum\>", 
            separatorString, "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<Precision\>", \ \ separatorString, \ 
            separatorString, \ "\<Size\>", \ 
            separatorString, \ "\<Precision\>", \ 
            separatorString, "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<dp\>", \ \ separatorString, \ "\<alpha\>", \
\ separatorString, \ "\<n\>", \ separatorString, \ "\<mp\>", \ 
            separatorString, \ "\<mp - dp\>", "\<\n\>"\ \
];\[IndentingNewLine]]; \[IndentingNewLine]If[
          intermediateOutput\  \[GreaterEqual] \ 
            1, \[IndentingNewLine]\(Print["\<\
MinPrecisionMinusDesiredPrecisionToFileDwassI:  For \>", \ 
              numberSampleSizes, "\< sampleSizes \>", \ \ sampleSizeVectorIn, \
\ "\<; \>", \ numberDesiredPrecisions, "\< desiredPrecisions \>", 
              desiredPrecisionVectorIn, \ \ "\<; and \>", \ 
              numberAlphas, "\< alphas \>", 
              alphaVectorIn, \ "\<, outputFileName = \>", \ 
              outputFileName, \ "\<, howToOpenFile = \>", \ 
              howToOpenFile, \ "\<, and separatorString = '\>", \ 
              separatorString, \ "\<'\>", \ "\<   intermediateOutput = \>", \ 
              intermediateOutput];\)\[IndentingNewLine]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]sampleSize\  = \ 
            sampleSizeVectorIn[\([sampleSizeIndex]\)]; \[IndentingNewLine]Do[\
\[IndentingNewLine]desiredPrecision\  = \ 
              desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)]; \
\[IndentingNewLine]Do[\[IndentingNewLine]alpha\  = \ \ \
alphaVectorIn[\([alphaIndex]\)]; \[IndentingNewLine]d\  = \ 
                Rationalize[
                  KS1SidedOneSampleTestStatisticByMaagDicaire[alpha, 
                    sampleSize, \ 6], 
                  0]; \[IndentingNewLine]functionOutput\  = 
                MinPrecisionMinusDesiredPrecisionDwassI[d, \ sampleSize, \ 
                  desiredPrecision, \ 
                  0]; \[IndentingNewLine]minimumPrecision\  = \ 
                functionOutput[\([2]\)]; \[IndentingNewLine]minimumPrecision\ \
 = \ minimumPrecision\  + \ 
                  desiredPrecision; \[IndentingNewLine]minimumPrecisionArray[\
\([sampleSizeIndex, \ desiredPrecisionIndex, \ alphaIndex]\)]\  = \ 
                minimumPrecision; \[IndentingNewLine]WriteString[
                outputFileNumber, \ 
                ToString[\ desiredPrecision, \ 
                  FortranForm], \ \ separatorString, \ 
                ToString[\ alpha, \ FortranForm], \ \ separatorString, \ 
                ToString[\ sampleSize, \ FortranForm], \ \ separatorString, \ 
                ToString[\ 
                  minimumPrecisionArray[\([sampleSizeIndex, \ 
                      desiredPrecisionIndex, \ alphaIndex]\)], \ 
                  FortranForm], \ \ separatorString, \ \ ToString[\ 
                  minimumPrecisionArray[\([sampleSizeIndex, \ 
                        desiredPrecisionIndex, \ alphaIndex]\)]\  - \ 
                    desiredPrecision\ , \ 
                  FortranForm], \ "\<\n\>"]; \[IndentingNewLine]If[
                intermediateOutput\  \[GreaterEqual] \ 
                  2, \[IndentingNewLine]\(Print["\<    sampleSize = \>", \ \ \
sampleSize, \ "\<   desiredPrecision = \>", \ 
                    desiredPrecision, \ "\<   alpha = \>", \ 
                    alpha, \ "\<   d = \>", \ d, \ "\< = \>", \ 
                    N[d, \ 6], \ "\<   minimumPrecision = \>", \ 
                    minimumPrecision];\)\[IndentingNewLine]];\
\[IndentingNewLine], {alphaIndex, \ 1, \ \ numberAlphas, \ 
                1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 1, \ 
              numberDesiredPrecisions, \ 
              1}];\[IndentingNewLine], {sampleSizeIndex, \ 1, \ 
            numberSampleSizes, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\n\n\>"\ ]; \[IndentingNewLine] (*\ 
          Minimum\ precision\ by\ desiredPrecision\ by\ alpha\ \
*) \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<DwassI:\>", \ \ separatorString, \ \
"\<Minimum Precision mp\>"]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
              outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{stringIndex, \ 1, \ numberDesiredPrecisionsAndAlphas\  - \ 1\ , \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Sample\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ separatorString, \ "\<Desired Precision dp \
= \>", \ ToString[\ desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)], \ 
              FortranForm]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{\ alphaIndex, \ 1\ , \ numberAlphas\  - \ 1, \ 
              1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 
            1, \ \ numberDesiredPrecisions, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Size\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ \ separatorString, \ "\<alpha\>"]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{\ alphaIndex, \ 1\ , \ numberAlphas\  - \ 1, \ 
              1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 
            1, \ \ numberDesiredPrecisions, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<n\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]\(WriteString[
                  outputFileNumber, \ \ separatorString, \ 
                  ToString[\ alphaVectorIn[\([alphaIndex]\)], \ 
                    FortranForm]];\)\[IndentingNewLine], {\ alphaIndex, \ 
                1\ , \ numberAlphas, \ 
                1}];\)\[IndentingNewLine], {desiredPrecisionIndex, \ 
            1, \ \ numberDesiredPrecisions, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]Do[\
\[IndentingNewLine]sampleSize\  = \ 
            sampleSizeVectorIn[\([sampleSizeIndex]\)]; \
\[IndentingNewLine]WriteString[outputFileNumber, \ 
            ToString[\ sampleSize, \ 
              FortranForm]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]desiredPrecision\  = \ 
              desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)]; \
\[IndentingNewLine]Do[\[IndentingNewLine]alpha\  = \ \ \
alphaVectorIn[\([alphaIndex]\)]; \[IndentingNewLine]WriteString[
                outputFileNumber, \ \ separatorString, \ 
                ToString[\ 
                  minimumPrecisionArray[\([sampleSizeIndex, \ 
                      desiredPrecisionIndex, \ alphaIndex]\)], \ 
                  FortranForm]];\[IndentingNewLine], {alphaIndex, \ 
                1, \ \ numberAlphas, \ 
                1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 1, \ 
              numberDesiredPrecisions, \ 1}]; \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<\n\>"\ ];\[IndentingNewLine], \
{sampleSizeIndex, \ 1, \ numberSampleSizes, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\n\n\>"\ ]; \[IndentingNewLine] (*\ 
          Minimum\ precision\ by\ alpha\ by\ desiredPrecision\ \
*) \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<DwassI:\>", \ \ separatorString, \ \
"\<Minimum Precision mp\>"]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
              outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{stringIndex, \ 1, \ numberDesiredPrecisionsAndAlphas\  - \ 1\ , \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Sample\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ separatorString, \ "\<alpha = \>", \ 
            ToString[\ alphaVectorIn[\([alphaIndex]\)], \ 
              FortranForm]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ \ numberDesiredPrecisions\  - \ 1, \ 
              1}];\[IndentingNewLine], {\ alphaIndex, \ 1\ , \ 
            numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Size\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]\(WriteString[
                  outputFileNumber, \ \ separatorString, \ "\<dp\>"];\)\
\[IndentingNewLine], {desiredPrecisionIndex, \ 
                1, \ \ numberDesiredPrecisions, \ 
                1}];\)\[IndentingNewLine], {\ alphaIndex, \ 1\ , \ 
            numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<n\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]\(WriteString[
                  outputFileNumber, \ \ separatorString, \ 
                  ToString[\ 
                    desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)], \ 
                    FortranForm]];\)\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ \ numberDesiredPrecisions, \ 
                1}];\)\[IndentingNewLine], {\ alphaIndex, \ 1\ , \ 
            numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]Do[\
\[IndentingNewLine]sampleSize\  = \ 
            sampleSizeVectorIn[\([sampleSizeIndex]\)]; \
\[IndentingNewLine]WriteString[outputFileNumber, \ 
            ToString[\ sampleSize, \ 
              FortranForm]]; \[IndentingNewLine]Do[\[IndentingNewLine]\(Do[\
\[IndentingNewLine]\(WriteString[outputFileNumber, \ \ separatorString, \ 
                    ToString[\ 
                      minimumPrecisionArray[\([sampleSizeIndex, \ 
                          desiredPrecisionIndex, \ alphaIndex]\)], \ 
                      FortranForm]];\)\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ numberDesiredPrecisions, \ 
                  1}];\)\[IndentingNewLine], {alphaIndex, \ 
              1, \ \ numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<\n\>"\ ];\[IndentingNewLine], \
{sampleSizeIndex, \ 1, \ numberSampleSizes, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\n\n\>"\ ]; \[IndentingNewLine] (*\ 
          Minimum\ precision\ minus\ desired\ precision\ by\ desiredPrecision\
\ by\ alpha\ *) \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<DwassI:\>", \ \ separatorString, \ \
"\<Minimum Precision Minus Desired Precision mp - dp\>"]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
              outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{stringIndex, \ 1, \ numberDesiredPrecisionsAndAlphas\  - \ 1\ , \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Sample\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ separatorString, \ "\<Desired Precision dp \
= \>", \ ToString[\ desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)], \ 
              FortranForm]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{\ alphaIndex, \ 1\ , \ numberAlphas\  - \ 1, \ 
              1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 
            1, \ \ numberDesiredPrecisions, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Size\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ \ separatorString, \ "\<alpha\>"]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{\ alphaIndex, \ 1\ , \ numberAlphas\  - \ 1, \ 
              1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 
            1, \ \ numberDesiredPrecisions, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<n\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]\(WriteString[
                  outputFileNumber, \ \ separatorString, \ 
                  ToString[\ alphaVectorIn[\([alphaIndex]\)], \ 
                    FortranForm]];\)\[IndentingNewLine], {\ alphaIndex, \ 
                1\ , \ numberAlphas, \ 
                1}];\)\[IndentingNewLine], {desiredPrecisionIndex, \ 
            1, \ \ numberDesiredPrecisions, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]Do[\
\[IndentingNewLine]sampleSize\  = \ 
            sampleSizeVectorIn[\([sampleSizeIndex]\)]; \
\[IndentingNewLine]WriteString[outputFileNumber, \ 
            ToString[\ sampleSize, \ 
              FortranForm]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]desiredPrecision\  = \ 
              desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)]; \
\[IndentingNewLine]Do[\[IndentingNewLine]alpha\  = \ \ \
alphaVectorIn[\([alphaIndex]\)]; \[IndentingNewLine]WriteString[
                outputFileNumber, \ \ separatorString, \ 
                ToString[\ 
                  minimumPrecisionArray[\([sampleSizeIndex, \ 
                        desiredPrecisionIndex, \ alphaIndex]\)]\  - \ 
                    desiredPrecision, \ 
                  FortranForm]];\[IndentingNewLine], {alphaIndex, \ 
                1, \ \ numberAlphas, \ 
                1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 1, \ 
              numberDesiredPrecisions, \ 1}]; \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<\n\>"\ ];\[IndentingNewLine], \
{sampleSizeIndex, \ 1, \ numberSampleSizes, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\n\n\>"\ ]; \[IndentingNewLine] (*\ 
          Minimum\ precision\ minus\ desired\ precision\ by\ alpha\ by\ \
desiredPrecision\ *) \[IndentingNewLine]WriteString[
          outputFileNumber, \ \ "\<DwassI:\>", \ \ separatorString, \ \
"\<Minimum Precision Minus Desired Precision mp - dp\>"]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
              outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{stringIndex, \ 1, \ numberDesiredPrecisionsAndAlphas\  - \ 1\ , \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Sample\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ separatorString, \ "\<alpha = \>", \ 
            ToString[\ alphaVectorIn[\([alphaIndex]\)], \ 
              FortranForm]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ \ numberDesiredPrecisions\  - \ 1, \ 
              1}];\[IndentingNewLine], {\ alphaIndex, \ 1\ , \ 
            numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Size\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]\(WriteString[
                  outputFileNumber, \ \ separatorString, \ "\<dp\>"];\)\
\[IndentingNewLine], {desiredPrecisionIndex, \ 
                1, \ \ numberDesiredPrecisions, \ 
                1}];\)\[IndentingNewLine], {\ alphaIndex, \ 1\ , \ 
            numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<n\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]\(WriteString[
                  outputFileNumber, \ \ separatorString, \ 
                  ToString[\ 
                    desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)], \ 
                    FortranForm]];\)\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ \ numberDesiredPrecisions, \ 
                1}];\)\[IndentingNewLine], {\ alphaIndex, \ 1\ , \ 
            numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]Do[\
\[IndentingNewLine]sampleSize\  = \ 
            sampleSizeVectorIn[\([sampleSizeIndex]\)]; \
\[IndentingNewLine]WriteString[outputFileNumber, \ 
            ToString[\ sampleSize, \ 
              FortranForm]]; \[IndentingNewLine]Do[\[IndentingNewLine]\(Do[\
\[IndentingNewLine]desiredPrecision\  = \ 
                  desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)]; \
\[IndentingNewLine]WriteString[outputFileNumber, \ \ separatorString, \ 
                  ToString[\ 
                    minimumPrecisionArray[\([sampleSizeIndex, \ 
                          desiredPrecisionIndex, \ alphaIndex]\)]\  - \ 
                      desiredPrecision\ , \ 
                    FortranForm]];\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ numberDesiredPrecisions, \ 
                  1}];\)\[IndentingNewLine], {alphaIndex, \ 
              1, \ \ numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<\n\>"\ ];\[IndentingNewLine], \
{sampleSizeIndex, \ 1, \ numberSampleSizes, \ 1}]; \[IndentingNewLine]Close[
          
          outputFileNumber]; \[IndentingNewLine]minimumPrecisionArray\
\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(KS1SidedOneSampleTestStatisticByMaagDicaire[alphaIn_, sampleSizeIn_, \ 
        rho_]\  := \[IndentingNewLine]Module[{d, \ alpha, \ 
          sampleSize}, \[IndentingNewLine] (*\ 
          For\ the\ KS\ 1\ sided\ one\ sample\ test, \ 
          the\ Maag\ and\ Dicaire\ formula\ is\ used\ *) \[IndentingNewLine] \
(*\ \ \ \ to\ approximate\ the\ test\ statistic\ corresponding\ to\ a\ right\ \
tail\ *) \[IndentingNewLine] (*\ \ \ \ probability\ of\ alphaIn . \ \ The\ \
test\ statistic\ d\ is\ calculated\ to\ *) \[IndentingNewLine] (*\ \ \ \ rho\ \
number\ of\ decimal\ \(\(digits\)\(.\)\)\ *) \[IndentingNewLine]alpha\  = 
          Rationalize[alphaIn, \ 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine] (*\ 
          Use\ Maag\ and\ Dicaire\ \(\(MD\)\(.\)\)\ *) \[IndentingNewLine]d\  \
= \ N[Sqrt[Log[alpha]/\((\(-2\)*sampleSize)\)] - \ \((1/\((6*
                      sampleSize)\))\), 
            rho\ \  + \ 17]; \[IndentingNewLine]d\  = \ 
          N[d, rho]; \[IndentingNewLine]d\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionDwassI[testStatistic_, \ 
        sampleSize_, \ desiredPrecision_, \ intermediateOutput_]\  := \ 
      Module[{internalPrecisionLowLimit, \ internalPrecisionHighLimit, \ 
          setInternalPrecision, \ currentPrecision, \ SquareRootN, \ 
          numberTries, \ rightTailProbability, \ 
          rightTailProbabilityToDesiredPrecision, \ 
          minPrecisionMinusDesiredPrecision, \ mantissaExp, \ numExp, \ 
          prop}, \[IndentingNewLine]SquareRootN\  = \ 
          Ceiling[Sqrt[sampleSize]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 1, \ 
          Print["\<MinPrecisionMinusDesiredPrecisionDwassI:\>", \ "\< \
sampleSize = \>", \ sampleSize, \ "\<   testStatistic = \>", \ 
            testStatistic, "\< = \>", \ 
            N[testStatistic, 6], \ \ "\<    desiredPrecision = \>", \ 
            desiredPrecision]]; \[IndentingNewLine]numberTries\  = \ 
          0; \[IndentingNewLine]internalPrecisionLowLimit\  = \ 
          desiredPrecision; \[IndentingNewLine]internalPrecisionHighLimit\  = \
\ SquareRootN\  + \ \ desiredPrecision; \
\[IndentingNewLine]setInternalPrecision\  = \ 
          internalPrecisionHighLimit; \[IndentingNewLine] (*\ 
          Determine\ a\ high\ limit\ for\ minimumPrecision\ \
*) \[IndentingNewLine]Label[
          DetermineInternalPrecisionHighLimit]; \
\[IndentingNewLine]numberTries\  = \ 
          numberTries\ \  + \ 
            1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassIKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   FindHighLimit: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision = \>", \ \ \
currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  \[GreaterEqual] \ desiredPrecision, \ 
          Goto[HighLimitFound], \ 
          Goto[HighLimitTooSmall]]; \[IndentingNewLine] (*\ 
          Current\ high\ limit\ too\ small\ *) \[IndentingNewLine]Label[
          HighLimitTooSmall]; \[IndentingNewLine]internalPrecisionLowLimit\  \
= \ internalPrecisionHighLimit; \[IndentingNewLine]internalPrecisionHighLimit\
\  = \ internalPrecisionHighLimit\  + \ desiredPrecision\  - \ 
            currentPrecision; \[IndentingNewLine]setInternalPrecision\  = \ 
          internalPrecisionHighLimit; \[IndentingNewLine]Goto[
          DetermineInternalPrecisionHighLimit]; \[IndentingNewLine] (*\ 
          High\ limit\ found\ *) \[IndentingNewLine]Label[
          HighLimitFound]; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Bisection\ search\ to\ find\ minimumPrecision\ between\ \
internalPrecisionLowLimit\ and\ internalPrecisionHighLimit\ \
*) \[IndentingNewLine]Label[
          BisectionIteration]; \[IndentingNewLine]setInternalPrecision\  = \ 
          Floor[\((internalPrecisionLowLimit\  + \ 
                  internalPrecisionHighLimit)\)/2]; \[IndentingNewLine]If[
          setInternalPrecision\ \  \[LessEqual] \ 
            internalPrecisionLowLimit, \ 
          setInternalPrecision\ \  = \ 
            internalPrecisionLowLimit\  + \ 1, \[IndentingNewLine]\(If[
              setInternalPrecision\ \  \[GreaterEqual] \ \ \
internalPrecisionHighLimit, \ 
              setInternalPrecision\ \  = \ 
                internalPrecisionHighLimit\  - \ 
                  1];\)\[IndentingNewLine]]; \[IndentingNewLine]numberTries\  \
= \ numberTries\ \  + \ 1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassIKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   Bisection Search: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision = \>", \ \ \
currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  \[GreaterEqual] \ desiredPrecision, \ 
          Goto[ResetHighLimit], \ 
          Goto[ResetLowLimit]]; \[IndentingNewLine] (*\ 
          Reset\ internalPrecisionHighLimit\ to\ currentPrecision\ \
*) \[IndentingNewLine]Label[
          ResetHighLimit]; \[IndentingNewLine]internalPrecisionHighLimit\  = \
\ setInternalPrecision; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Reset\ internalPrecisionLowLimit\ to\ currentPrecision\ \
*) \[IndentingNewLine]Label[
          ResetLowLimit]; \[IndentingNewLine]internalPrecisionLowLimit\  = \ 
          setInternalPrecision; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Minimum\ internal\ precision\ found\ *) \[IndentingNewLine]Label[
          MinInternalPrecisionFound]; \[IndentingNewLine]setInternalPrecision\
\  = \ internalPrecisionLowLimit; \[IndentingNewLine]numberTries\  = \ 
          numberTries\ \  + \ 
            1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassIKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          
          Print["\<   Determine whether low or high limit is minimum \
precision: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision for low limit = \>", \ \
\ currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  < \ desiredPrecision, \ 
          setInternalPrecision\  = \ internalPrecisionHighLimit, \ 
          setInternalPrecision\  = \ 
            internalPrecisionLowLimit]; \
\[IndentingNewLine]minPrecisionMinusDesiredPrecision\  = \ 
          setInternalPrecision\  - \ \ desiredPrecision; \
\[IndentingNewLine]If[\ intermediateOutput \[GreaterEqual] \ 1, \ 
          Print["\<   Minimum Internal Precision Found: \>", \ "\< sampleSize \
= \>", \ sampleSize, \ "\<   testStatistic = \>", \ 
            testStatistic, "\< = \>", \ 
            N[testStatistic, 6], \ \ "\<    desiredPrecision = \>", \ 
            desiredPrecision, \ "\<   numberTries = \>", \ 
            numberTries, \ "\<   minimumInternalPrecision = \>", \ 
            setInternalPrecision, \ "\<   minPrecisionMinusDesiredPrecision = \
\>", \ minPrecisionMinusDesiredPrecision\ ]]; \
\[IndentingNewLine]{numberTries, \ 
          minPrecisionMinusDesiredPrecision}\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassIKS1SidedOneSampleRTArbPrecision[dIn_, sampleSizeIn_, \ 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ term, \ 
          leftTailProbability, \ rightTailProbability, \ sumTerms, \ 
          NminusjMinusOne, \ NminusjPlusOne, \ dN, \ jMinusdN, \ 
          nMINUSjPlusOnePLUSdn, \ jMINUSdnMinusOne}, \[IndentingNewLine] (*\ 
          Dwass\ Iterative\ formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ \
sample\ *) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ d]; \[IndentingNewLine]sumTerms\  = \ 
          N[\ d\ *\ \((1\  + \ d)\)^\((sampleSize - 1)\), \ 
            internalPrecision]; \[IndentingNewLine]term\  = \ 
          sumTerms; \[IndentingNewLine]NminusjMinusOne\  = \ 
          N[sampleSize\  - \ 1, \ 
            internalPrecision]; \[IndentingNewLine]NminusjPlusOne\  = \ 
          N[sampleSize\  + \ 1, \ 
            internalPrecision]; \[IndentingNewLine]dN\  = \ 
          N[d\ *\ sampleSize, \ 
            internalPrecision]; \[IndentingNewLine]jHighLimit\  = \ 
          Floor[dN]; \[IndentingNewLine]jMinusdN\  = \ \(-\ 
            dN\); \[IndentingNewLine]nMINUSjPlusOnePLUSdn\  = \ 
          N[\ sampleSize\  + \ 1\  + \ dN, \ 
            internalPrecision]; \[IndentingNewLine]jMINUSdnMinusOne\  = \ 
          N[\(-\ dN\)\  - \ 1, \ internalPrecision]; \[IndentingNewLine]If[
          jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]NminusjMinusOne\  = \ 
            N[NminusjMinusOne\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]NminusjPlusOne\  = \ 
            N[NminusjPlusOne\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]jMinusdN\  = \ 
            N[jMinusdN\  + \ 1\ , \ 
              internalPrecision]; \[IndentingNewLine]nMINUSjPlusOnePLUSdn\  = \
\ N[\ nMINUSjPlusOnePLUSdn\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]jMINUSdnMinusOne\  = \ 
            N[jMINUSdnMinusOne\  + \ 1, \ 
              internalPrecision]; \[IndentingNewLine]term\  = \ 
            N[\ \((\((NminusjPlusOne\ *\ jMinusdN)\)/\((j\ *\ 
                        nMINUSjPlusOnePLUSdn)\))\)*\ \((1\  - \ \((1/
                          nMINUSjPlusOnePLUSdn)\))\)^
                  NminusjMinusOne\ *\ \((1\  + \ \((1/
                          jMINUSdnMinusOne)\))\)^\((j - 1)\)*term, \ 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + term, \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1 - sumTerms, \ internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
15.1  DwassI Minimum Precision Minus Desired Precision To File Sample \
Intermediate Output\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionToFileDwassI[{100, \ 500}, \ {20, \ 
        100}, \ {0.001, \ 0.9}, \ 
      2, \ "\<C:/KSoutput/KS1SidedOneSampleDwassImpMINUSdpN100and500.csv\>", \
\ 0, \ "\<,\>"]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("MinPrecisionMinusDesiredPrecisionToFileDwassI:  \
For "\[InvisibleSpace]2\[InvisibleSpace]" sampleSizes "\[InvisibleSpace]{100, 
            500}\[InvisibleSpace]"; "\[InvisibleSpace]2\[InvisibleSpace]" \
desiredPrecisions "\[InvisibleSpace]{20, 
            100}\[InvisibleSpace]"; and "\[InvisibleSpace]2\[InvisibleSpace]" \
alphas "\[InvisibleSpace]{0.001`, 
            0.9`}\[InvisibleSpace]", outputFileName = \
"\[InvisibleSpace]"C:/KSoutput/KS1SidedOneSampleDwassImpMINUSdpN100and500.\
csv"\[InvisibleSpace]", howToOpenFile = \
"\[InvisibleSpace]0\[InvisibleSpace]", and separatorString = '"\
\[InvisibleSpace]","\[InvisibleSpace]"'"\[InvisibleSpace]"   \
intermediateOutput = "\[InvisibleSpace]2\),
        SequenceForm[ 
        "MinPrecisionMinusDesiredPrecisionToFileDwassI:  For ", 2, 
          " sampleSizes ", {100, 500}, "; ", 2, " desiredPrecisions ", {20, 
          100}, "; and ", 2, " alphas ", {.001, .90000000000000002}, 
          ", outputFileName = ", 
          "C:/KSoutput/KS1SidedOneSampleDwassImpMINUSdpN100and500.csv", 
          ", howToOpenFile = ", 0, ", and separatorString = '", ",", "'", 
          "   intermediateOutput = ", 2],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]100\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.001`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]156\/847\[InvisibleSpace]" = "\
\[InvisibleSpace]0.184179456906729634`6. \[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]33\),
        SequenceForm[ 
        "    sampleSize = ", 100, "   desiredPrecision = ", 20, 
          "   alpha = ", .001, "   d = ", 
          Rational[ 156, 847], " = ", 0.184179456906729634`6., 
          "   minimumPrecision = ", 33],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]100\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.9`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]203\/9537\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0212855195554157492`5.999999999999999\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]20\),
        SequenceForm[ 
        "    sampleSize = ", 100, "   desiredPrecision = ", 20, 
          "   alpha = ", .90000000000000002, "   d = ", 
          Rational[ 203, 9537], " = ", 
          0.0212855195554157492`5.999999999999999, "   minimumPrecision = ", 
          20],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]100\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.001`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]156\/847\[InvisibleSpace]" = "\
\[InvisibleSpace]0.184179456906729634`6. \[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]113\),
        SequenceForm[ 
        "    sampleSize = ", 100, "   desiredPrecision = ", 100, 
          "   alpha = ", .001, "   d = ", 
          Rational[ 156, 847], " = ", 0.184179456906729634`6., 
          "   minimumPrecision = ", 113],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]100\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.9`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]203\/9537\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0212855195554157492`5.999999999999999\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]101\),
        SequenceForm[ 
        "    sampleSize = ", 100, "   desiredPrecision = ", 100, 
          "   alpha = ", .90000000000000002, "   d = ", 
          Rational[ 203, 9537], " = ", 
          0.0212855195554157492`5.999999999999999, "   minimumPrecision = ", 
          101],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]500\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.001`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]299\/3612\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0827796234772978959`6. \[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]46\),
        SequenceForm[ 
        "    sampleSize = ", 500, "   desiredPrecision = ", 20, 
          "   alpha = ", .001, "   d = ", 
          Rational[ 299, 3612], " = ", 0.0827796234772978959`6., 
          "   minimumPrecision = ", 46],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]500\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.9`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]140\/14097\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0099311910335532383`5.999999999999999\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]22\),
        SequenceForm[ 
        "    sampleSize = ", 500, "   desiredPrecision = ", 20, 
          "   alpha = ", .90000000000000002, "   d = ", 
          Rational[ 140, 14097], " = ", 
          0.0099311910335532383`5.999999999999999, "   minimumPrecision = ", 
          22],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]500\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.001`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]299\/3612\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0827796234772978959`6. \[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]126\),
        SequenceForm[ 
        "    sampleSize = ", 500, "   desiredPrecision = ", 100, 
          "   alpha = ", .001, "   d = ", 
          Rational[ 299, 3612], " = ", 0.0827796234772978959`6., 
          "   minimumPrecision = ", 126],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]500\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.9`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]140\/14097\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0099311910335532383`5.999999999999999\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]102\),
        SequenceForm[ 
        "    sampleSize = ", 500, "   desiredPrecision = ", 100, 
          "   alpha = ", .90000000000000002, "   d = ", 
          Rational[ 140, 14097], " = ", 
          0.0099311910335532383`5.999999999999999, "   minimumPrecision = ", 
          102],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({33, 20}\), \({113, 101}\)},
            {\({46, 22}\), \({126, 102}\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
15.2  DwassI Minimum Precision Minus Desired Precision Sample Output File, \
C:/KSoutput/KS1SidedOneSampleDwassImpMINUSdpN100and500.csv\
\>", "Subsection"],

Cell[BoxData[{
    \(DwassI : Desired, , Sample, Minimum, Precision, , Size, Precision, dp, 
    alpha, n, mp, mp - dp\), "\n", 
    \(20, 0.001, 100, 33, 13\), "\n", 
    \(20, 0.9, 100, 20, 0\), "\n", 
    \(100, 0.001, 100, 113, 13\), "\n", 
    \(100, 0.9, 100, 101, 1\), "\n", 
    \(20, 0.001, 500, 46, 26\), "\n", 
    \(20, 0.9, 500, 22, 2\), "\n", 
    \(100, 0.001, 500, 126, 26\), "\n", 
    \(\(\(100, 0.9, 500, 102, 
    2\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(DwassI\)\(:\)\), Minimum\ Precision\ mp, , , Sample, 
    Desired\ Precision\ dp = 20, , Desired\ Precision\ dp = 100, Size, 
    alpha, , alpha, n, 0.001, 0.9, 0.001, 0.9\), "\n", 
    \(100, 33, 20, 113, 101\), "\n", 
    \(\(\(500, 46, 22, 126, 
    102\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(DwassI\)\(:\)\), Minimum\ Precision\ mp, , , Sample, 
    alpha = 0.001, , alpha = 0.9, Size, dp, dp, dp, dp\), "\n", 
    \(n, 20, 100, 20, 100\), "\n", 
    \(100, 33, 113, 20, 101\), "\n", 
    \(\(\(500, 46, 126, 22, 
    102\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(DwassI\)\(:\)\), 
    Minimum\ Precision\ Minus\ Desired\ Precision\ mp - dp, , , Sample, 
    Desired\ Precision\ dp = 20, , Desired\ Precision\ dp = 100, Size, 
    alpha, , alpha, n, 0.001, 0.9, 0.001, 0.9\), "\n", 
    \(100, 13, 0, 13, 1\), "\n", 
    \(\(\(500, 26, 2, 26, 
    2\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(DwassI\)\(:\)\), 
    Minimum\ Precision\ Minus\ Desired\ Precision\ mp - dp, , , Sample, 
    alpha = 0.001, , alpha = 0.9, Size, dp, dp, dp, dp\), "\n", 
    \(n, 20, 100, 20, 100\), "\n", 
    \(100, 13, 13, 0, 1\), "\n", 
    \(500, 26, 26, 2, 2\), "\n", 
    \(\)}], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["16. DwassI Desired Precision", "Section"],

Cell["\<\
The following is the code of the Mathematica function \
DwassIKS1SidedOneSampleRTdesiredPrecision that calculates the right tail \
p-value to desiredPrecisionIn digits of precision.  Sample output is given in \
subsection 167.1.\
\>", "Text"],

Cell[BoxData[
    \(DwassIKS1SidedOneSampleRTdesiredPrecision[dIn_, sampleSizeIn_, \ 
        desiredPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ desiredPrecision, \ internalPrecision, \ j, \ 
          jLowLimit, \ term, \ leftTailProbability, \ rightTailProbability, \ 
          binomialCoefficient, \ secondTerm, \ thirdTerm, \ sumTerms, \ 
          numberIterations, \ alphaPredict, \ 
          resultPrecision}, \[IndentingNewLine] (*\ 
          DwassI\ formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ sample\ \
*) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ to\ desiredPrecisionIn\ digits\ of\ *) \[IndentingNewLine] \
(*\ \ \ \ precision\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine]d = 
          Rationalize[dIn, \ 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]desiredPrecision\  = \ 
          Ceiling[desiredPrecisionIn]; \[IndentingNewLine] (*\ 
          Maag\ and\ Dicaire\ approximation\ \
*) \[IndentingNewLine]alphaPredict\  = \ 
          Exp[\(-2\)\ *\ d^2\ *\ 
                sampleSize\  - \ \((2\ *
                  d\ /\ 3)\)\  - \ \((1/\((18\ *\ 
                      sampleSize)\))\)]; \[IndentingNewLine]internalPrecision\
\  = \ Ceiling[
              5\  + \ \((2.986\  + \ 1.032\ *\ Sqrt[sampleSize])\)\ *\ \((\ 
                    0.6875\  - \ 0.1433*\ alphaPredict\  - \ 
                      0.399\ *\ alphaPredict^\((1/4)\)\  + \ 
                      0.04703\ *\ alphaPredict^3\  - \ 
                      0.1323\ *\ alphaPredict^4\  - \ 
                      0.0556\ *\ Log[alphaPredict])\)]\  + \ 
            desiredPrecision; \[IndentingNewLine]numberIterations\  = \ 
          0; \[IndentingNewLine]Label[
          AnotherIteration]; \[IndentingNewLine]numberIterations\  = \ 
          numberIterations\  + \ 
            1; \[IndentingNewLine]rightTailProbability\ \  = \ 
          DwassIKS1SidedOneSampleRTArbPrecision[d, sampleSize, 
            internalPrecision]; \[IndentingNewLine]resultPrecision\  = \ 
          Precision[rightTailProbability]; \[IndentingNewLine]If[
          resultPrecision\  < \ 
            desiredPrecision, \[IndentingNewLine]internalPrecision\  = \ 
            internalPrecision\  + \ desiredPrecision; \[IndentingNewLine]Goto[
            AnotherIteration];\[IndentingNewLine]]; \
\[IndentingNewLine]rightTailProbability\ \[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassIKS1SidedOneSampleRTArbPrecision[dIn_, sampleSizeIn_, \ 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ term, \ 
          leftTailProbability, \ rightTailProbability, \ sumTerms, \ 
          NminusjMinusOne, \ NminusjPlusOne, \ dN, \ jMinusdN, \ 
          nMINUSjPlusOnePLUSdn, \ jMINUSdnMinusOne}, \[IndentingNewLine] (*\ 
          Dwass\ Iterative\ formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ \
sample\ *) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ d]; \[IndentingNewLine]sumTerms\  = \ 
          N[\ d\ *\ \((1\  + \ d)\)^\((sampleSize - 1)\), \ 
            internalPrecision]; \[IndentingNewLine]term\  = \ 
          sumTerms; \[IndentingNewLine]NminusjMinusOne\  = \ 
          N[sampleSize\  - \ 1, \ 
            internalPrecision]; \[IndentingNewLine]NminusjPlusOne\  = \ 
          N[sampleSize\  + \ 1, \ 
            internalPrecision]; \[IndentingNewLine]dN\  = \ 
          N[d\ *\ sampleSize, \ 
            internalPrecision]; \[IndentingNewLine]jHighLimit\  = \ 
          Floor[dN]; \[IndentingNewLine]jMinusdN\  = \ \(-\ 
            dN\); \[IndentingNewLine]nMINUSjPlusOnePLUSdn\  = \ 
          N[\ sampleSize\  + \ 1\  + \ dN, \ 
            internalPrecision]; \[IndentingNewLine]jMINUSdnMinusOne\  = \ 
          N[\(-\ dN\)\  - \ 1, \ internalPrecision]; \[IndentingNewLine]If[
          jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]NminusjMinusOne\  = \ 
            N[NminusjMinusOne\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]NminusjPlusOne\  = \ 
            N[NminusjPlusOne\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]jMinusdN\  = \ 
            N[jMinusdN\  + \ 1\ , \ 
              internalPrecision]; \[IndentingNewLine]nMINUSjPlusOnePLUSdn\  = \
\ N[\ nMINUSjPlusOnePLUSdn\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]jMINUSdnMinusOne\  = \ 
            N[jMINUSdnMinusOne\  + \ 1, \ 
              internalPrecision]; \[IndentingNewLine]term\  = \ 
            N[\ \((\((NminusjPlusOne\ *\ jMinusdN)\)/\((j\ *\ 
                        nMINUSjPlusOnePLUSdn)\))\)*\ \((1\  - \ \((1/
                          nMINUSjPlusOnePLUSdn)\))\)^
                  NminusjMinusOne\ *\ \((1\  + \ \((1/
                          jMINUSdnMinusOne)\))\)^\((j - 1)\)*term, \ 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + term, \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1 - sumTerms, \ internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[CellGroupData[{

Cell["16.1  DwassI Desired Precision Sample Output", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DwassIKS1SidedOneSampleRTdesiredPrecision[0.000831096, 5000000, \ 
      30]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.\
00099999484950123212764686094951028587839739853026501132`37.01024351548722\)],\
 "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DwassIKS1SidedOneSampleRTdesiredPrecision[0.000339290, 10000000, \ 
      40]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.\
100000480993207370350317616589677055270014407449947732646`45.39480689486456\)]\
, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["17. DwassAltI Arbitrary Precision", "Section"],

Cell["\<\
The following is the code of the Mathematica function \
DwassAltIKS1SidedOneSampleRTArbPrecision that calculates the right tail \
p-value using the DwassAltI formula with test statistic dIn and sample size \
sampleSizeIn.  Internally the function uses arbitrary precision arithmetic \
with internalPrecisionIn digits of precision.   Sample output is given in \
subsection 17.1.\
\>", "Text"],

Cell[BoxData[
    \(DwassAltIKS1SidedOneSampleRTArbPrecision[dIn_, sampleSizeIn_, \ 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ term, \ 
          leftTailProbability, \ rightTailProbability, \ sumTerms, \ 
          NminusjMinusOne, \ NminusjPlusOne, \ dN, \ jMinusdN, \ 
          nMINUSjPlusOnePLUSdn, \ jMINUSdnMinusOne}, \[IndentingNewLine] (*\ 
          Dwass\ Alternate\ Iterative\ formula\ to\ calculate\ the\ KS\ 1\ \
Sided\ one\ *) \[IndentingNewLine] (*\ \ \ \ sample\ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ d]; \[IndentingNewLine]sumTerms\  = \ 
          N[\ d\ *\ \((sampleSize\  + \ d*sampleSize)\)^\((sampleSize - 
                    1)\), \ internalPrecision]; \[IndentingNewLine]term\  = \ 
          sumTerms; \[IndentingNewLine]NminusjMinusOne\  = \ 
          N[sampleSize\  - \ 1, \ 
            internalPrecision]; \[IndentingNewLine]NminusjPlusOne\  = \ 
          N[sampleSize\  + \ 1, \ 
            internalPrecision]; \[IndentingNewLine]dN\  = \ 
          N[d\ *\ sampleSize, \ 
            internalPrecision]; \[IndentingNewLine]jHighLimit\  = \ 
          Floor[dN]; \[IndentingNewLine]jMinusdN\  = \ \(-\ 
            dN\); \[IndentingNewLine]nMINUSjPlusOnePLUSdn\  = \ 
          N[\ sampleSize\  + \ 1\  + \ dN, \ 
            internalPrecision]; \[IndentingNewLine]jMINUSdnMinusOne\  = \ 
          N[\(-\ dN\)\  - \ 1, \ internalPrecision]; \[IndentingNewLine]If[
          jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]NminusjMinusOne\  = \ 
            N[NminusjMinusOne\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]NminusjPlusOne\  = \ 
            N[NminusjPlusOne\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]jMinusdN\  = \ 
            N[jMinusdN\  + \ 1\ , \ 
              internalPrecision]; \[IndentingNewLine]nMINUSjPlusOnePLUSdn\  = \
\ N[\ nMINUSjPlusOnePLUSdn\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]jMINUSdnMinusOne\  = \ 
            N[jMINUSdnMinusOne\  + \ 1, \ 
              internalPrecision]; \[IndentingNewLine]term\  = \ 
            N[\ \((\((NminusjPlusOne\ *\ jMinusdN)\)/\((j\ *\ 
                        nMINUSjPlusOnePLUSdn)\))\)*\ \((1\  - \ \((1/
                          nMINUSjPlusOnePLUSdn)\))\)^
                  NminusjMinusOne\ *\ \((1\  + \ \((1/
                          jMINUSdnMinusOne)\))\)^\((j - 1)\)*term, \ 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + term, \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1 - \((sumTerms/sampleSize^\((sampleSize\  - \ 1)\))\), \ 
            internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[CellGroupData[{

Cell["17.1  DwassAltI Arbitrary Precision Sample Output", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(DwassAltIKS1SidedOneSampleRTArbPrecision[0.105632, 100, \ 
      30]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.09997990380077079963347414081954319602`23.\
391302012069712\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Precision[
      DwassAltIKS1SidedOneSampleRTArbPrecision[0.105632, 100, \ 
        30]\ ]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`23.391302012069712`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(DwassAltIKS1SidedOneSampleRTArbPrecision[0.0199760, 2000, \ 
      60]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.199998648779404946563706459535437273240059330285`37.\
43911329145231\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Precision[
      DwassAltIKS1SidedOneSampleRTArbPrecision[0.0199760, 2000, \ 
        60]\ ]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`37.43911329145231`\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["18. DwassAltI Minimum Precision Minus Desired Precision", "Section"],

Cell["\<\
The following is the code of the Mathematica function \
MinPrecisionMinusDesiredPrecisionDwassAltI that calculates the minimum \
precision minus desired precision needed for the arbitrary precision \
DwassAltI formula with test statistic testStatistic and sample size \
sampleSize to calculate the right tail p-value to a precision of desired \
precision desiredPrecision.  Sample intermediate output is given in \
subsection 18.1.\
\>", "Text"],

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionDwassAltI[testStatistic_, \ 
        sampleSize_, \ desiredPrecision_, \ intermediateOutput_]\  := \ 
      Module[{internalPrecisionLowLimit, \ internalPrecisionHighLimit, \ 
          setInternalPrecision, \ currentPrecision, \ SquareRootN, \ 
          numberTries, \ rightTailProbability, \ 
          rightTailProbabilityToDesiredPrecision, \ 
          minPrecisionMinusDesiredPrecision, \ mantissaExp, \ numExp, \ 
          prop}, \[IndentingNewLine]SquareRootN\  = \ 
          Ceiling[Sqrt[sampleSize]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 1, \ 
          Print["\<MinPrecisionMinusDesiredPrecisionDwassAltI:\>", \ "\< \
sampleSize = \>", \ sampleSize, \ "\<   testStatistic = \>", \ 
            testStatistic, "\< = \>", \ 
            N[testStatistic, 6], \ \ "\<    desiredPrecision = \>", \ 
            desiredPrecision]]; \[IndentingNewLine]numberTries\  = \ 
          0; \[IndentingNewLine]internalPrecisionLowLimit\  = \ 
          desiredPrecision; \[IndentingNewLine]internalPrecisionHighLimit\  = \
\ SquareRootN\  + \ \ desiredPrecision; \
\[IndentingNewLine]setInternalPrecision\  = \ 
          internalPrecisionHighLimit; \[IndentingNewLine] (*\ 
          Determine\ a\ high\ limit\ for\ minimumPrecision\ \
*) \[IndentingNewLine]Label[
          DetermineInternalPrecisionHighLimit]; \
\[IndentingNewLine]numberTries\  = \ 
          numberTries\ \  + \ 
            1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassAltIKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   FindHighLimit: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision = \>", \ \ \
currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  \[GreaterEqual] \ desiredPrecision, \ 
          Goto[HighLimitFound], \ 
          Goto[HighLimitTooSmall]]; \[IndentingNewLine] (*\ 
          Current\ high\ limit\ too\ small\ *) \[IndentingNewLine]Label[
          HighLimitTooSmall]; \[IndentingNewLine]internalPrecisionLowLimit\  \
= \ internalPrecisionHighLimit; \[IndentingNewLine]internalPrecisionHighLimit\
\  = \ internalPrecisionHighLimit\  + \ desiredPrecision\  - \ 
            currentPrecision; \[IndentingNewLine]setInternalPrecision\  = \ 
          internalPrecisionHighLimit; \[IndentingNewLine]Goto[
          DetermineInternalPrecisionHighLimit]; \[IndentingNewLine] (*\ 
          High\ limit\ found\ *) \[IndentingNewLine]Label[
          HighLimitFound]; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Bisection\ search\ to\ find\ minimumPrecision\ between\ \
internalPrecisionLowLimit\ and\ internalPrecisionHighLimit\ \
*) \[IndentingNewLine]Label[
          BisectionIteration]; \[IndentingNewLine]setInternalPrecision\  = \ 
          Floor[\((internalPrecisionLowLimit\  + \ 
                  internalPrecisionHighLimit)\)/2]; \[IndentingNewLine]If[
          setInternalPrecision\ \  \[LessEqual] \ 
            internalPrecisionLowLimit, \ 
          setInternalPrecision\ \  = \ 
            internalPrecisionLowLimit\  + \ 1, \[IndentingNewLine]\(If[
              setInternalPrecision\ \  \[GreaterEqual] \ \ \
internalPrecisionHighLimit, \ 
              setInternalPrecision\ \  = \ 
                internalPrecisionHighLimit\  - \ 
                  1];\)\[IndentingNewLine]]; \[IndentingNewLine]numberTries\  \
= \ numberTries\ \  + \ 1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassAltIKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   Bisection Search: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision = \>", \ \ \
currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  \[GreaterEqual] \ desiredPrecision, \ 
          Goto[ResetHighLimit], \ 
          Goto[ResetLowLimit]]; \[IndentingNewLine] (*\ 
          Reset\ internalPrecisionHighLimit\ to\ currentPrecision\ \
*) \[IndentingNewLine]Label[
          ResetHighLimit]; \[IndentingNewLine]internalPrecisionHighLimit\  = \
\ setInternalPrecision; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Reset\ internalPrecisionLowLimit\ to\ currentPrecision\ \
*) \[IndentingNewLine]Label[
          ResetLowLimit]; \[IndentingNewLine]internalPrecisionLowLimit\  = \ 
          setInternalPrecision; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Minimum\ internal\ precision\ found\ *) \[IndentingNewLine]Label[
          MinInternalPrecisionFound]; \[IndentingNewLine]setInternalPrecision\
\  = \ internalPrecisionLowLimit; \[IndentingNewLine]numberTries\  = \ 
          numberTries\ \  + \ 
            1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassAltIKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          
          Print["\<   Determine whether low or high limit is minimum \
precision: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision for low limit = \>", \ \
\ currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  < \ desiredPrecision, \ 
          setInternalPrecision\  = \ internalPrecisionHighLimit, \ 
          setInternalPrecision\  = \ 
            internalPrecisionLowLimit]; \
\[IndentingNewLine]minPrecisionMinusDesiredPrecision\  = \ 
          setInternalPrecision\  - \ \ desiredPrecision; \
\[IndentingNewLine]If[\ intermediateOutput \[GreaterEqual] \ 1, \ 
          Print["\<   Minimum Internal Precision Found: \>", \ "\< sampleSize \
= \>", \ sampleSize, \ "\<   testStatistic = \>", \ 
            testStatistic, "\< = \>", \ 
            N[testStatistic, 6], \ \ "\<    desiredPrecision = \>", \ 
            desiredPrecision, \ "\<   numberTries = \>", \ 
            numberTries, \ "\<   minimumInternalPrecision = \>", \ 
            setInternalPrecision, \ "\<   minPrecisionMinusDesiredPrecision = \
\>", \ minPrecisionMinusDesiredPrecision\ ]]; \
\[IndentingNewLine]{numberTries, \ 
          minPrecisionMinusDesiredPrecision}\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassAltIKS1SidedOneSampleRTArbPrecision[dIn_, sampleSizeIn_, \ 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ term, \ 
          leftTailProbability, \ rightTailProbability, \ sumTerms, \ 
          NminusjMinusOne, \ NminusjPlusOne, \ dN, \ jMinusdN, \ 
          nMINUSjPlusOnePLUSdn, \ jMINUSdnMinusOne}, \[IndentingNewLine] (*\ 
          Dwass\ Alternate\ Iterative\ formula\ to\ calculate\ the\ KS\ 1\ \
Sided\ one\ *) \[IndentingNewLine] (*\ \ \ \ sample\ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ d]; \[IndentingNewLine]sumTerms\  = \ 
          N[\ d\ *\ \((sampleSize\  + \ d*sampleSize)\)^\((sampleSize - 
                    1)\), \ internalPrecision]; \[IndentingNewLine]term\  = \ 
          sumTerms; \[IndentingNewLine]NminusjMinusOne\  = \ 
          N[sampleSize\  - \ 1, \ 
            internalPrecision]; \[IndentingNewLine]NminusjPlusOne\  = \ 
          N[sampleSize\  + \ 1, \ 
            internalPrecision]; \[IndentingNewLine]dN\  = \ 
          N[d\ *\ sampleSize, \ 
            internalPrecision]; \[IndentingNewLine]jHighLimit\  = \ 
          Floor[dN]; \[IndentingNewLine]jMinusdN\  = \ \(-\ 
            dN\); \[IndentingNewLine]nMINUSjPlusOnePLUSdn\  = \ 
          N[\ sampleSize\  + \ 1\  + \ dN, \ 
            internalPrecision]; \[IndentingNewLine]jMINUSdnMinusOne\  = \ 
          N[\(-\ dN\)\  - \ 1, \ internalPrecision]; \[IndentingNewLine]If[
          jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]NminusjMinusOne\  = \ 
            N[NminusjMinusOne\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]NminusjPlusOne\  = \ 
            N[NminusjPlusOne\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]jMinusdN\  = \ 
            N[jMinusdN\  + \ 1\ , \ 
              internalPrecision]; \[IndentingNewLine]nMINUSjPlusOnePLUSdn\  = \
\ N[\ nMINUSjPlusOnePLUSdn\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]jMINUSdnMinusOne\  = \ 
            N[jMINUSdnMinusOne\  + \ 1, \ 
              internalPrecision]; \[IndentingNewLine]term\  = \ 
            N[\ \((\((NminusjPlusOne\ *\ jMinusdN)\)/\((j\ *\ 
                        nMINUSjPlusOnePLUSdn)\))\)*\ \((1\  - \ \((1/
                          nMINUSjPlusOnePLUSdn)\))\)^
                  NminusjMinusOne\ *\ \((1\  + \ \((1/
                          jMINUSdnMinusOne)\))\)^\((j - 1)\)*term, \ 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + term, \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1 - \((sumTerms/sampleSize^\((sampleSize\  - \ 1)\))\), \ 
            internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
18.1  DwassAltI Minimum Precision Minus Desired Precision Sample Intermediate \
Output\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionDwassAltI[\[InvisibleSpace]0.0185679, \
\ 10000\[InvisibleSpace], \ 20, \ 2]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("MinPrecisionMinusDesiredPrecisionDwassAltI:"\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.0185679`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0185679`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]20\),
        SequenceForm[ 
        "MinPrecisionMinusDesiredPrecisionDwassAltI:", " sampleSize = ", 
          10000, "   testStatistic = ", .018567899999999998, 
          " = ", .018567899999999998, "    desiredPrecision = ", 20],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   FindHighLimit: numberTries = \
"\[InvisibleSpace]1\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]20\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]120\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]120\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]14\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.0009996621833282029441213373`14.163349370430577\),
        SequenceForm[ 
        "   FindHighLimit: numberTries = ", 1, 
          ", internalPrecisionLowLimit = ", 20, ", setInternalPrecision = ", 
          120, ", internalPrecisionHighLimit = ", 120, 
          ", desiredPrecision = ", 20, ", currentPrecision = ", 14, 
          ", rightTailProbability = ", 
          0.0009996621833282029441213373`14.163349370430577],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   FindHighLimit: numberTries = \
"\[InvisibleSpace]2\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]120\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]126\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]126\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.00099966218332820294412562226362553164`20.1633493704233\),
        SequenceForm[ 
        "   FindHighLimit: numberTries = ", 2, 
          ", internalPrecisionLowLimit = ", 120, ", setInternalPrecision = ", 
          126, ", internalPrecisionHighLimit = ", 126, 
          ", desiredPrecision = ", 20, ", currentPrecision = ", 20, 
          ", rightTailProbability = ", 
          0.00099966218332820294412562226362553164`20.1633493704233],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]3\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]120\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]123\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]126\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]17\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.00099966218332820294412551680603830336`17.16334937042256\),
        
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 3, 
          ", internalPrecisionLowLimit = ", 120, ", setInternalPrecision = ", 
          123, ", internalPrecisionHighLimit = ", 126, 
          ", desiredPrecision = ", 20, ", currentPrecision = ", 17, 
          ", rightTailProbability = ", 
          0.00099966218332820294412551680603830336`17.16334937042256],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]4\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]123\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]124\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]126\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]18\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.00099966218332820294412562226362553157`18.163349370425728\)\
,
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 4, 
          ", internalPrecisionLowLimit = ", 123, ", setInternalPrecision = ", 
          124, ", internalPrecisionHighLimit = ", 126, 
          ", desiredPrecision = ", 20, ", currentPrecision = ", 18, 
          ", rightTailProbability = ", 
          0.00099966218332820294412562226362553157`18.163349370425728],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]5\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]124\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]125\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]126\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]19\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.00099966218332820294412562226362553763`19.163349370428893\)\
,
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 5, 
          ", internalPrecisionLowLimit = ", 124, ", setInternalPrecision = ", 
          125, ", internalPrecisionHighLimit = ", 126, 
          ", desiredPrecision = ", 20, ", currentPrecision = ", 19, 
          ", rightTailProbability = ", 
          0.00099966218332820294412562226362553763`19.163349370428893],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Determine whether low or high limit is minimum \
precision: numberTries = "\[InvisibleSpace]6\[InvisibleSpace]", \
internalPrecisionLowLimit = "\[InvisibleSpace]125\[InvisibleSpace]", \
setInternalPrecision = "\[InvisibleSpace]125\[InvisibleSpace]", \
internalPrecisionHighLimit = "\[InvisibleSpace]126\[InvisibleSpace]", \
desiredPrecision = "\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision \
for low limit = "\[InvisibleSpace]19\[InvisibleSpace]", rightTailProbability \
= "\[InvisibleSpace]0.00099966218332820294412562226362553763`19.\
163349370428893\),
        SequenceForm[ 
        "   Determine whether low or high limit is minimum precision: \
numberTries = ", 6, ", internalPrecisionLowLimit = ", 125, 
          ", setInternalPrecision = ", 125, ", internalPrecisionHighLimit = ",
           126, ", desiredPrecision = ", 20, 
          ", currentPrecision for low limit = ", 19, 
          ", rightTailProbability = ", 
          0.00099966218332820294412562226362553763`19.163349370428893],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Minimum Internal Precision Found: "\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.0185679`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0185679`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]20\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]6\
\[InvisibleSpace]"   minimumInternalPrecision = "\[InvisibleSpace]126\
\[InvisibleSpace]"   minPrecisionMinusDesiredPrecision = \
"\[InvisibleSpace]106\),
        SequenceForm[ 
        "   Minimum Internal Precision Found: ", " sampleSize = ", 10000, 
          "   testStatistic = ", .018567899999999998, 
          " = ", .018567899999999998, "    desiredPrecision = ", 20, 
          "   numberTries = ", 6, "   minimumInternalPrecision = ", 126, 
          "   minPrecisionMinusDesiredPrecision = ", 106],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`{6, 106}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionDwassAltI[\[InvisibleSpace]0.0185679, \
\ 10000\[InvisibleSpace], \ 100, \ 2]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("MinPrecisionMinusDesiredPrecisionDwassAltI:"\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.0185679`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0185679`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]100\),
        SequenceForm[ 
        "MinPrecisionMinusDesiredPrecisionDwassAltI:", " sampleSize = ", 
          10000, "   testStatistic = ", .018567899999999998, 
          " = ", .018567899999999998, "    desiredPrecision = ", 100],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   FindHighLimit: numberTries = \
"\[InvisibleSpace]1\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]100\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]200\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]200\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]94\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
000999662183328202944125621550457714894310537494670134398443417283814375958241\
3911487057462674970473919129189317997`94.16334937042991\),
        SequenceForm[ 
        "   FindHighLimit: numberTries = ", 1, 
          ", internalPrecisionLowLimit = ", 100, ", setInternalPrecision = ", 
          200, ", internalPrecisionHighLimit = ", 200, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 94, 
          ", rightTailProbability = ", 
          0.000999662183328202944125621550457714894310537494670134398443417283\
8143759582413911487057462674970473919129189317997`94.16334937042991],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   FindHighLimit: numberTries = \
"\[InvisibleSpace]2\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]200\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]206\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]206\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
000999662183328202944125621550457714894310537494670134398443417283814375958241\
3911487057462674970473919133896126884`100.16334937042264\),
        SequenceForm[ 
        "   FindHighLimit: numberTries = ", 2, 
          ", internalPrecisionLowLimit = ", 200, ", setInternalPrecision = ", 
          206, ", internalPrecisionHighLimit = ", 206, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 100, 
          ", rightTailProbability = ", 
          0.000999662183328202944125621550457714894310537494670134398443417283\
8143759582413911487057462674970473919133896126884`100.16334937042264],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]3\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]200\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]203\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]206\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]97\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
000999662183328202944125621550457714894310537494670134398443417283814375958241\
3911487057462674970473919129189319721`97.16334937043065\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 3, 
          ", internalPrecisionLowLimit = ", 200, ", setInternalPrecision = ", 
          203, ", internalPrecisionHighLimit = ", 206, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 97, 
          ", rightTailProbability = ", 
          0.000999662183328202944125621550457714894310537494670134398443417283\
8143759582413911487057462674970473919129189319721`97.16334937043065],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]4\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]203\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]204\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]206\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]98\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
000999662183328202944125621550457714894310537494670134398443417283814375958241\
3911487057462674970473919133896126884`98.16334937042507\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 4, 
          ", internalPrecisionLowLimit = ", 203, ", setInternalPrecision = ", 
          204, ", internalPrecisionHighLimit = ", 206, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 98, 
          ", rightTailProbability = ", 
          0.000999662183328202944125621550457714894310537494670134398443417283\
8143759582413911487057462674970473919133896126884`98.16334937042507],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]5\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]204\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]205\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]206\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]99\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
000999662183328202944125621550457714894310537494670134398443417283814375958241\
3911487057462674970473919133896126885`99.16334937042824\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 5, 
          ", internalPrecisionLowLimit = ", 204, ", setInternalPrecision = ", 
          205, ", internalPrecisionHighLimit = ", 206, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 99, 
          ", rightTailProbability = ", 
          0.000999662183328202944125621550457714894310537494670134398443417283\
8143759582413911487057462674970473919133896126885`99.16334937042824],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Determine whether low or high limit is minimum \
precision: numberTries = "\[InvisibleSpace]6\[InvisibleSpace]", \
internalPrecisionLowLimit = "\[InvisibleSpace]205\[InvisibleSpace]", \
setInternalPrecision = "\[InvisibleSpace]205\[InvisibleSpace]", \
internalPrecisionHighLimit = "\[InvisibleSpace]206\[InvisibleSpace]", \
desiredPrecision = "\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision \
for low limit = "\[InvisibleSpace]99\[InvisibleSpace]", rightTailProbability \
= "\[InvisibleSpace]0.\
000999662183328202944125621550457714894310537494670134398443417283814375958241\
3911487057462674970473919133896126885`99.16334937042824\),
        SequenceForm[ 
        "   Determine whether low or high limit is minimum precision: \
numberTries = ", 6, ", internalPrecisionLowLimit = ", 205, 
          ", setInternalPrecision = ", 205, ", internalPrecisionHighLimit = ",
           206, ", desiredPrecision = ", 100, 
          ", currentPrecision for low limit = ", 99, 
          ", rightTailProbability = ", 
          0.000999662183328202944125621550457714894310537494670134398443417283\
8143759582413911487057462674970473919133896126885`99.16334937042824],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Minimum Internal Precision Found: "\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.0185679`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0185679`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]100\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]6\
\[InvisibleSpace]"   minimumInternalPrecision = "\[InvisibleSpace]206\
\[InvisibleSpace]"   minPrecisionMinusDesiredPrecision = \
"\[InvisibleSpace]106\),
        SequenceForm[ 
        "   Minimum Internal Precision Found: ", " sampleSize = ", 10000, 
          "   testStatistic = ", .018567899999999998, 
          " = ", .018567899999999998, "    desiredPrecision = ", 100, 
          "   numberTries = ", 6, "   minimumInternalPrecision = ", 206, 
          "   minPrecisionMinusDesiredPrecision = ", 106],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`{6, 106}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionDwassAltI[\[InvisibleSpace]0.00227855, \
\ 10000\[InvisibleSpace], \ 20, \ 2]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("MinPrecisionMinusDesiredPrecisionDwassAltI:"\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.00227855`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.00227855`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]20\),
        SequenceForm[ 
        "MinPrecisionMinusDesiredPrecisionDwassAltI:", " sampleSize = ", 
          10000, "   testStatistic = ", .0022785499999999998, 
          " = ", .0022785499999999998, "    desiredPrecision = ", 20],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   FindHighLimit: numberTries = \
"\[InvisibleSpace]1\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]20\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]120\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]120\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]108\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
57423203977333122521487532944587444071511818591`108.64024442254028\),
        SequenceForm[ 
        "   FindHighLimit: numberTries = ", 1, 
          ", internalPrecisionLowLimit = ", 20, ", setInternalPrecision = ", 
          120, ", internalPrecisionHighLimit = ", 120, 
          ", desiredPrecision = ", 20, ", currentPrecision = ", 108, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
43202665708657423203977333122521487532944587444071511818591`108.\
64024442254028],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]2\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]20\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]70\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]120\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]58\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
90000709705339186224768503926219924843185404002007483123589475715261223695035`\
58.640244422539595\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 2, 
          ", internalPrecisionLowLimit = ", 20, ", setInternalPrecision = ", 
          70, ", internalPrecisionHighLimit = ", 120, ", desiredPrecision = ",
           20, ", currentPrecision = ", 58, ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894757152\
61223695035`58.640244422539595],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]3\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]20\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]45\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]70\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]33\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.900007097053391862247685039262199248460649358606`33.\
640244422539254\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 3, 
          ", internalPrecisionLowLimit = ", 20, ", setInternalPrecision = ", 
          45, ", internalPrecisionHighLimit = ", 70, ", desiredPrecision = ", 
          20, ", currentPrecision = ", 33, ", rightTailProbability = ", 
          0.900007097053391862247685039262199248460649358606`33.\
640244422539254],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]4\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]20\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]32\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]45\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.900007097053391862247685038945893989`20.640244422541876\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 4, 
          ", internalPrecisionLowLimit = ", 20, ", setInternalPrecision = ", 
          32, ", internalPrecisionHighLimit = ", 45, ", desiredPrecision = ", 
          20, ", currentPrecision = ", 20, ", rightTailProbability = ", 
          0.900007097053391862247685038945893989`20.640244422541876],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]5\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]20\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]26\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]32\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]14\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.9000070970533918622476850389`14.640244422540395\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 5, 
          ", internalPrecisionLowLimit = ", 20, ", setInternalPrecision = ", 
          26, ", internalPrecisionHighLimit = ", 32, ", desiredPrecision = ", 
          20, ", currentPrecision = ", 14, ", rightTailProbability = ", 
          0.9000070970533918622476850389`14.640244422540395],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]6\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]26\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]29\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]32\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]17\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.9000070970533918622476850389`17.640244422541137\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 6, 
          ", internalPrecisionLowLimit = ", 26, ", setInternalPrecision = ", 
          29, ", internalPrecisionHighLimit = ", 32, ", desiredPrecision = ", 
          20, ", currentPrecision = ", 17, ", rightTailProbability = ", 
          0.9000070970533918622476850389`17.640244422541137],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]7\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]29\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]30\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]32\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]18\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.9000070970533918622476850389`18.640244422544303\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 7, 
          ", internalPrecisionLowLimit = ", 29, ", setInternalPrecision = ", 
          30, ", internalPrecisionHighLimit = ", 32, ", desiredPrecision = ", 
          20, ", currentPrecision = ", 18, ", rightTailProbability = ", 
          0.9000070970533918622476850389`18.640244422544303],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]8\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]30\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]31\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]32\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]19\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.900007097053391862247685038945893989`19.64024442253871\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 8, 
          ", internalPrecisionLowLimit = ", 30, ", setInternalPrecision = ", 
          31, ", internalPrecisionHighLimit = ", 32, ", desiredPrecision = ", 
          20, ", currentPrecision = ", 19, ", rightTailProbability = ", 
          0.900007097053391862247685038945893989`19.64024442253871],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Determine whether low or high limit is minimum \
precision: numberTries = "\[InvisibleSpace]9\[InvisibleSpace]", \
internalPrecisionLowLimit = "\[InvisibleSpace]31\[InvisibleSpace]", \
setInternalPrecision = "\[InvisibleSpace]31\[InvisibleSpace]", \
internalPrecisionHighLimit = "\[InvisibleSpace]32\[InvisibleSpace]", \
desiredPrecision = "\[InvisibleSpace]20\[InvisibleSpace]", currentPrecision \
for low limit = "\[InvisibleSpace]19\[InvisibleSpace]", rightTailProbability \
= "\[InvisibleSpace]0.900007097053391862247685038945893989`19.64024442253871\)\
,
        SequenceForm[ 
        "   Determine whether low or high limit is minimum precision: \
numberTries = ", 9, ", internalPrecisionLowLimit = ", 31, 
          ", setInternalPrecision = ", 31, ", internalPrecisionHighLimit = ", 
          32, ", desiredPrecision = ", 20, 
          ", currentPrecision for low limit = ", 19, 
          ", rightTailProbability = ", 
          0.900007097053391862247685038945893989`19.64024442253871],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Minimum Internal Precision Found: "\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.00227855`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.00227855`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]20\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]9\
\[InvisibleSpace]"   minimumInternalPrecision = "\[InvisibleSpace]32\
\[InvisibleSpace]"   minPrecisionMinusDesiredPrecision = "\[InvisibleSpace]12\
\),
        SequenceForm[ 
        "   Minimum Internal Precision Found: ", " sampleSize = ", 10000, 
          "   testStatistic = ", .0022785499999999998, 
          " = ", .0022785499999999998, "    desiredPrecision = ", 20, 
          "   numberTries = ", 9, "   minimumInternalPrecision = ", 32, 
          "   minPrecisionMinusDesiredPrecision = ", 12],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`{9, 12}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionDwassAltI[\[InvisibleSpace]0.00227855, \
\ 10000\[InvisibleSpace], \ 100, \ 2]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("MinPrecisionMinusDesiredPrecisionDwassAltI:"\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.00227855`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.00227855`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]100\),
        SequenceForm[ 
        "MinPrecisionMinusDesiredPrecisionDwassAltI:", " sampleSize = ", 
          10000, "   testStatistic = ", .0022785499999999998, 
          " = ", .0022785499999999998, "    desiredPrecision = ", 100],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   FindHighLimit: numberTries = \
"\[InvisibleSpace]1\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]100\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]200\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]200\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]188\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
574232039773331225214875329445874436559343337822145489039989694596584351287545\
7268527068422767664995488423420968570806140389`188.6402444225396\),
        SequenceForm[ 
        "   FindHighLimit: numberTries = ", 1, 
          ", internalPrecisionLowLimit = ", 100, ", setInternalPrecision = ", 
          200, ", internalPrecisionHighLimit = ", 200, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 188, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
432026657086574232039773331225214875329445874436559343337822145489039989694596\
5843512875457268527068422767664995488423420968570806140389`188.6402444225396],
        
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]2\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]100\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]150\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]200\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]138\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
5742320397733312252148753294458744365593433378221454890399896946178684541268`\
138.64024442253893\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 2, 
          ", internalPrecisionLowLimit = ", 100, ", setInternalPrecision = ", 
          150, ", internalPrecisionHighLimit = ", 200, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 138, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
432026657086574232039773331225214875329445874436559343337822145489039989694617\
8684541268`138.64024442253893],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]3\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]100\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]125\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]150\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]113\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
57423203977333122521487532944587443655929757625`113.6402444225386\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 3, 
          ", internalPrecisionLowLimit = ", 100, ", setInternalPrecision = ", 
          125, ", internalPrecisionHighLimit = ", 150, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 113, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
43202665708657423203977333122521487532944587443655929757625`113.6402444225386]\
,
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]4\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]100\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]112\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]125\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
5742320397733312252148753292201826877`100.64024442254123\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 4, 
          ", internalPrecisionLowLimit = ", 100, ", setInternalPrecision = ", 
          112, ", internalPrecisionHighLimit = ", 125, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 100, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
4320266570865742320397733312252148753292201826877`100.64024442254123],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]5\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]100\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]106\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]112\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]94\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
574232039773331225214276952`94.64024442253974\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 5, 
          ", internalPrecisionLowLimit = ", 100, ", setInternalPrecision = ", 
          106, ", internalPrecisionHighLimit = ", 112, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 94, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
432026657086574232039773331225214276952`94.64024442253974],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]6\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]106\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]109\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]112\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]97\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
5742320397733312252148751474842358357`97.64024442254049\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 6, 
          ", internalPrecisionLowLimit = ", 106, ", setInternalPrecision = ", 
          109, ", internalPrecisionHighLimit = ", 112, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 97, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
4320266570865742320397733312252148751474842358357`97.64024442254049],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]7\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]109\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]110\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]112\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]98\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
5742320397733312252148753707694570417`98.64024442254365\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 7, 
          ", internalPrecisionLowLimit = ", 109, ", setInternalPrecision = ", 
          110, ", internalPrecisionHighLimit = ", 112, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 98, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
4320266570865742320397733312252148753707694570417`98.64024442254365],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Bisection Search: numberTries = "\
\[InvisibleSpace]8\[InvisibleSpace]", internalPrecisionLowLimit = "\
\[InvisibleSpace]110\[InvisibleSpace]", setInternalPrecision = "\
\[InvisibleSpace]111\[InvisibleSpace]", internalPrecisionHighLimit = "\
\[InvisibleSpace]112\[InvisibleSpace]", desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision = \
"\[InvisibleSpace]99\[InvisibleSpace]", rightTailProbability = "\
\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
5742320397733312252148753707694571555`99.64024442253806\),
        SequenceForm[ 
        "   Bisection Search: numberTries = ", 8, 
          ", internalPrecisionLowLimit = ", 110, ", setInternalPrecision = ", 
          111, ", internalPrecisionHighLimit = ", 112, 
          ", desiredPrecision = ", 100, ", currentPrecision = ", 99, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
4320266570865742320397733312252148753707694571555`99.64024442253806],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Determine whether low or high limit is minimum \
precision: numberTries = "\[InvisibleSpace]9\[InvisibleSpace]", \
internalPrecisionLowLimit = "\[InvisibleSpace]111\[InvisibleSpace]", \
setInternalPrecision = "\[InvisibleSpace]111\[InvisibleSpace]", \
internalPrecisionHighLimit = "\[InvisibleSpace]112\[InvisibleSpace]", \
desiredPrecision = "\[InvisibleSpace]100\[InvisibleSpace]", currentPrecision \
for low limit = "\[InvisibleSpace]99\[InvisibleSpace]", rightTailProbability \
= "\[InvisibleSpace]0.\
900007097053391862247685039262199248431854040020074831235894751853432026657086\
5742320397733312252148753707694571555`99.64024442253806\),
        SequenceForm[ 
        "   Determine whether low or high limit is minimum precision: \
numberTries = ", 9, ", internalPrecisionLowLimit = ", 111, 
          ", setInternalPrecision = ", 111, ", internalPrecisionHighLimit = ",
           112, ", desiredPrecision = ", 100, 
          ", currentPrecision for low limit = ", 99, 
          ", rightTailProbability = ", 
          0.900007097053391862247685039262199248431854040020074831235894751853\
4320266570865742320397733312252148753707694571555`99.64024442253806],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Minimum Internal Precision Found: "\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000\[InvisibleSpace]"   \
testStatistic = "\[InvisibleSpace]0.00227855`\[InvisibleSpace]" = "\
\[InvisibleSpace]0.00227855`\[InvisibleSpace]"    desiredPrecision = "\
\[InvisibleSpace]100\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]9\
\[InvisibleSpace]"   minimumInternalPrecision = "\[InvisibleSpace]112\
\[InvisibleSpace]"   minPrecisionMinusDesiredPrecision = "\[InvisibleSpace]12\
\),
        SequenceForm[ 
        "   Minimum Internal Precision Found: ", " sampleSize = ", 10000, 
          "   testStatistic = ", .0022785499999999998, 
          " = ", .0022785499999999998, "    desiredPrecision = ", 100, 
          "   numberTries = ", 9, "   minimumInternalPrecision = ", 112, 
          "   minPrecisionMinusDesiredPrecision = ", 12],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`{9, 12}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["19. Calculation Time for DwassAltI", "Section"],

Cell["\<\
The following is the code of the Mathematica function \
TimingDwassAltIKS1SidedOneSampleRTArbPrecision.  Sample output is given in \
subsection 19.1.\
\>", "Text"],

Cell[BoxData[
    \(TimingDwassAltIKS1SidedOneSampleRTArbPrecision[alpha_, \ 
        sampleSizeIn_, \ desiredPrecisionIn_, \ 
        testStatisticDesiredPrecisionIn_]\ \  := 
      Module[{d, \ \ sampleSize, \ minimumPrecision, \ desiredPrecision, \ 
          testStatisticDesiredPrecision, \ functionOutput, \ 
          rightTailProbability, rightTailProbabilityPrecision, \ 
          functionTimeString, \ timeString}, \[IndentingNewLine] (*\ 
          For\ the\ KS\ 1\ sided\ one\ sample\ test, \ 
          the\ Maag\ and\ Dicaire\ formula\ is\ used\ *) \[IndentingNewLine] \
(*\ \ \ \ for\ sample\ size\ sampleSizeIn\ and\ right\ tail\ p - 
            value\ alpha\ to\ produce\ a\ *) \[IndentingNewLine] (*\ \ \ \ \
test\ statistic\ d\ with\ testStatisticDesiredPrecisionIn\ decimal\ digits\ \
of\ *) \[IndentingNewLine] (*\ \ \ \ accuracy . \ \ Then\ the\ minimum\ \
precision\ minimumPrecision\ needed\ for\ the\ *) \[IndentingNewLine] (*\ \ \ \
\ arbitrary\ precision\ DwassAltI\ formula\ to\ calculate\ a\ right\ tail\ \
*) \[IndentingNewLine] (*\ \ \ \ probability\ with\ desiredPrecisionIn\ \
digits\ of\ precision\ for\ test\ *) \[IndentingNewLine] (*\ \ \ \ statistic\ \
d\ and\ sample\ size\ sampleSizeIn\ is\ \(\(calculated\)\(.\)\)\ \
*) \[IndentingNewLine] (*\ \ \ \ Finally, \ 
          the\ time\ in\ seconds\ for\ the\ arbitrary\ precision\ DwassAltI\ \
*) \[IndentingNewLine] (*\ \ \ \ formula\ to\ calculate\ the\ right\ tail\ \
probability\ for\ test\ statistic\ d\ *) \[IndentingNewLine] (*\ \ \ \ and\ \
sample\ size\ sampleSizeIn\ with\ an\ internal\ precision\ of\ \
*) \[IndentingNewLine] (*\ \ \ \ minimumPrecision\ is\ found\ and\ \
\(\(printed\)\(.\)\)\ *) \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]desiredPrecision\  = \ 
          Floor[desiredPrecisionIn]; \
\[IndentingNewLine]testStatisticDesiredPrecision\  = \ 
          Floor[testStatisticDesiredPrecisionIn]; \[IndentingNewLine]d\  = \ 
          KS1SidedOneSampleTestStatisticByMaagDicaire[alpha, sampleSize, \ 
            
            testStatisticDesiredPrecision]; \[IndentingNewLine]functionOutput\
\  = MinPrecisionMinusDesiredPrecisionDwassAltI[d, \ sampleSize, \ 
            desiredPrecision, \ 0]; \[IndentingNewLine]minimumPrecision\  = \ 
          functionOutput[\([2]\)]; \[IndentingNewLine]minimumPrecision\  = \ 
          minimumPrecision\  + \ 
            desiredPrecision; \[IndentingNewLine]functionOutput\  = \ 
          Timing[DwassAltIKS1SidedOneSampleRTArbPrecision[d, \ sampleSize, \ 
              minimumPrecision]]; \[IndentingNewLine]rightTailProbability\  = \
\ functionOutput[\([2]\)]; \[IndentingNewLine]rightTailProbabilityPrecision\  \
= \ Floor[Precision[
              rightTailProbability]]; \[IndentingNewLine]functionTimeString\  \
= \ functionOutput[\([1]\)]; \[IndentingNewLine]timeString\  = \ 
          functionTimeString\  /. \ 
            Second \[Rule] 
              1; \[IndentingNewLine]Print["\<\
TimingDwassAltIKS1SidedOneSampleRTArbPrecision: sampleSize = \>", \ 
          sampleSize, \ "\<   alpha = \>", \ 
          alpha, \ "\<  desiredPrecision = \>", \ 
          desiredPrecision, \ "\<   testStatisticDesiredPrecision = \>", \ 
          testStatisticDesiredPrecision, \ "\<   d = \>", \ 
          d, \ "\<   minimumPrecision = \>", \ 
          minimumPrecision, \ \ \ "\<   rightTailProbability = \>", \ 
          rightTailProbability, \ "\<  rightTailProbabilityPrecision = \>", \ 
          rightTailProbabilityPrecision, \ "\<   time in seconds = \>", \ 
          timeString\ ]; \
\[IndentingNewLine]sampleSize\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(KS1SidedOneSampleTestStatisticByMaagDicaire[alphaIn_, sampleSizeIn_, \ 
        rho_]\  := \[IndentingNewLine]Module[{d, \ alpha, \ 
          sampleSize}, \[IndentingNewLine] (*\ 
          For\ the\ KS\ 1\ sided\ one\ sample\ test, \ 
          the\ Maag\ and\ Dicaire\ formula\ is\ used\ *) \[IndentingNewLine] \
(*\ \ \ \ to\ approximate\ the\ test\ statistic\ corresponding\ to\ a\ right\ \
tail\ *) \[IndentingNewLine] (*\ \ \ \ probability\ of\ alphaIn . \ \ The\ \
test\ statistic\ d\ is\ calculated\ to\ *) \[IndentingNewLine] (*\ \ \ \ rho\ \
number\ of\ decimal\ \(\(digits\)\(.\)\)\ *) \[IndentingNewLine]alpha\  = 
          Rationalize[alphaIn, \ 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine] (*\ 
          Use\ Maag\ and\ Dicaire\ \(\(MD\)\(.\)\)\ *) \[IndentingNewLine]d\  \
= \ N[Sqrt[Log[alpha]/\((\(-2\)*sampleSize)\)] - \ \((1/\((6*
                      sampleSize)\))\), 
            rho\ \  + \ 17]; \[IndentingNewLine]d\  = \ 
          N[d, rho]; \[IndentingNewLine]d\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionDwassAltI[testStatistic_, \ 
        sampleSize_, \ desiredPrecision_, \ intermediateOutput_]\  := \ 
      Module[{internalPrecisionLowLimit, \ internalPrecisionHighLimit, \ 
          setInternalPrecision, \ currentPrecision, \ SquareRootN, \ 
          numberTries, \ rightTailProbability, \ 
          rightTailProbabilityToDesiredPrecision, \ 
          minPrecisionMinusDesiredPrecision, \ mantissaExp, \ numExp, \ 
          prop}, \[IndentingNewLine]SquareRootN\  = \ 
          Ceiling[Sqrt[sampleSize]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 1, \ 
          Print["\<MinPrecisionMinusDesiredPrecisionDwassAltI:\>", \ "\< \
sampleSize = \>", \ sampleSize, \ "\<   testStatistic = \>", \ 
            testStatistic, "\< = \>", \ 
            N[testStatistic, 6], \ \ "\<    desiredPrecision = \>", \ 
            desiredPrecision]]; \[IndentingNewLine]numberTries\  = \ 
          0; \[IndentingNewLine]internalPrecisionLowLimit\  = \ 
          desiredPrecision; \[IndentingNewLine]internalPrecisionHighLimit\  = \
\ SquareRootN\  + \ \ desiredPrecision; \
\[IndentingNewLine]setInternalPrecision\  = \ 
          internalPrecisionHighLimit; \[IndentingNewLine] (*\ 
          Determine\ a\ high\ limit\ for\ minimumPrecision\ \
*) \[IndentingNewLine]Label[
          DetermineInternalPrecisionHighLimit]; \
\[IndentingNewLine]numberTries\  = \ 
          numberTries\ \  + \ 
            1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassAltIKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   FindHighLimit: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision = \>", \ \ \
currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  \[GreaterEqual] \ desiredPrecision, \ 
          Goto[HighLimitFound], \ 
          Goto[HighLimitTooSmall]]; \[IndentingNewLine] (*\ 
          Current\ high\ limit\ too\ small\ *) \[IndentingNewLine]Label[
          HighLimitTooSmall]; \[IndentingNewLine]internalPrecisionLowLimit\  \
= \ internalPrecisionHighLimit; \[IndentingNewLine]internalPrecisionHighLimit\
\  = \ internalPrecisionHighLimit\  + \ desiredPrecision\  - \ 
            currentPrecision; \[IndentingNewLine]setInternalPrecision\  = \ 
          internalPrecisionHighLimit; \[IndentingNewLine]Goto[
          DetermineInternalPrecisionHighLimit]; \[IndentingNewLine] (*\ 
          High\ limit\ found\ *) \[IndentingNewLine]Label[
          HighLimitFound]; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Bisection\ search\ to\ find\ minimumPrecision\ between\ \
internalPrecisionLowLimit\ and\ internalPrecisionHighLimit\ \
*) \[IndentingNewLine]Label[
          BisectionIteration]; \[IndentingNewLine]setInternalPrecision\  = \ 
          Floor[\((internalPrecisionLowLimit\  + \ 
                  internalPrecisionHighLimit)\)/2]; \[IndentingNewLine]If[
          setInternalPrecision\ \  \[LessEqual] \ 
            internalPrecisionLowLimit, \ 
          setInternalPrecision\ \  = \ 
            internalPrecisionLowLimit\  + \ 1, \[IndentingNewLine]\(If[
              setInternalPrecision\ \  \[GreaterEqual] \ \ \
internalPrecisionHighLimit, \ 
              setInternalPrecision\ \  = \ 
                internalPrecisionHighLimit\  - \ 
                  1];\)\[IndentingNewLine]]; \[IndentingNewLine]numberTries\  \
= \ numberTries\ \  + \ 1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassAltIKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   Bisection Search: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision = \>", \ \ \
currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  \[GreaterEqual] \ desiredPrecision, \ 
          Goto[ResetHighLimit], \ 
          Goto[ResetLowLimit]]; \[IndentingNewLine] (*\ 
          Reset\ internalPrecisionHighLimit\ to\ currentPrecision\ \
*) \[IndentingNewLine]Label[
          ResetHighLimit]; \[IndentingNewLine]internalPrecisionHighLimit\  = \
\ setInternalPrecision; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Reset\ internalPrecisionLowLimit\ to\ currentPrecision\ \
*) \[IndentingNewLine]Label[
          ResetLowLimit]; \[IndentingNewLine]internalPrecisionLowLimit\  = \ 
          setInternalPrecision; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Minimum\ internal\ precision\ found\ *) \[IndentingNewLine]Label[
          MinInternalPrecisionFound]; \[IndentingNewLine]setInternalPrecision\
\  = \ internalPrecisionLowLimit; \[IndentingNewLine]numberTries\  = \ 
          numberTries\ \  + \ 
            1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassAltIKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          
          Print["\<   Determine whether low or high limit is minimum \
precision: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision for low limit = \>", \ \
\ currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  < \ desiredPrecision, \ 
          setInternalPrecision\  = \ internalPrecisionHighLimit, \ 
          setInternalPrecision\  = \ 
            internalPrecisionLowLimit]; \
\[IndentingNewLine]minPrecisionMinusDesiredPrecision\  = \ 
          setInternalPrecision\  - \ \ desiredPrecision; \
\[IndentingNewLine]If[\ intermediateOutput \[GreaterEqual] \ 1, \ 
          Print["\<   Minimum Internal Precision Found: \>", \ "\< sampleSize \
= \>", \ sampleSize, \ "\<   testStatistic = \>", \ 
            testStatistic, "\< = \>", \ 
            N[testStatistic, 6], \ \ "\<    desiredPrecision = \>", \ 
            desiredPrecision, \ "\<   numberTries = \>", \ 
            numberTries, \ "\<   minimumInternalPrecision = \>", \ 
            setInternalPrecision, \ "\<   minPrecisionMinusDesiredPrecision = \
\>", \ minPrecisionMinusDesiredPrecision\ ]]; \
\[IndentingNewLine]{numberTries, \ 
          minPrecisionMinusDesiredPrecision}\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassAltIKS1SidedOneSampleRTArbPrecision[dIn_, sampleSizeIn_, \ 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ term, \ 
          leftTailProbability, \ rightTailProbability, \ sumTerms, \ 
          NminusjMinusOne, \ NminusjPlusOne, \ dN, \ jMinusdN, \ 
          nMINUSjPlusOnePLUSdn, \ jMINUSdnMinusOne}, \[IndentingNewLine] (*\ 
          Dwass\ Alternate\ Iterative\ formula\ to\ calculate\ the\ KS\ 1\ \
Sided\ one\ *) \[IndentingNewLine] (*\ \ \ \ sample\ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ d]; \[IndentingNewLine]sumTerms\  = \ 
          N[\ d\ *\ \((sampleSize\  + \ d*sampleSize)\)^\((sampleSize - 
                    1)\), \ internalPrecision]; \[IndentingNewLine]term\  = \ 
          sumTerms; \[IndentingNewLine]NminusjMinusOne\  = \ 
          N[sampleSize\  - \ 1, \ 
            internalPrecision]; \[IndentingNewLine]NminusjPlusOne\  = \ 
          N[sampleSize\  + \ 1, \ 
            internalPrecision]; \[IndentingNewLine]dN\  = \ 
          N[d\ *\ sampleSize, \ 
            internalPrecision]; \[IndentingNewLine]jHighLimit\  = \ 
          Floor[dN]; \[IndentingNewLine]jMinusdN\  = \ \(-\ 
            dN\); \[IndentingNewLine]nMINUSjPlusOnePLUSdn\  = \ 
          N[\ sampleSize\  + \ 1\  + \ dN, \ 
            internalPrecision]; \[IndentingNewLine]jMINUSdnMinusOne\  = \ 
          N[\(-\ dN\)\  - \ 1, \ internalPrecision]; \[IndentingNewLine]If[
          jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]NminusjMinusOne\  = \ 
            N[NminusjMinusOne\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]NminusjPlusOne\  = \ 
            N[NminusjPlusOne\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]jMinusdN\  = \ 
            N[jMinusdN\  + \ 1\ , \ 
              internalPrecision]; \[IndentingNewLine]nMINUSjPlusOnePLUSdn\  = \
\ N[\ nMINUSjPlusOnePLUSdn\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]jMINUSdnMinusOne\  = \ 
            N[jMINUSdnMinusOne\  + \ 1, \ 
              internalPrecision]; \[IndentingNewLine]term\  = \ 
            N[\ \((\((NminusjPlusOne\ *\ jMinusdN)\)/\((j\ *\ 
                        nMINUSjPlusOnePLUSdn)\))\)*\ \((1\  - \ \((1/
                          nMINUSjPlusOnePLUSdn)\))\)^
                  NminusjMinusOne\ *\ \((1\  + \ \((1/
                          jMINUSdnMinusOne)\))\)^\((j - 1)\)*term, \ 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + term, \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1 - \((sumTerms/sampleSize^\((sampleSize\  - \ 1)\))\), \ 
            internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
19.1  Calculation Time for DwassAltI Sample Output on a 3.4 GHz Pentium IV\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassAltIKS1SidedOneSampleRTArbPrecision[0.001, \ 1000000, \ 
      20, \ 6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassAltIKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]1000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.001`\[InvisibleSpace]"  desiredPrecision = "\
\[InvisibleSpace]20\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0018582944277582526`6. \[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]1055\[InvisibleSpace]"   \
rightTailProbability = \
"\[InvisibleSpace]0.00100000519945517771720304317323965855`20.477495122596483\
\[InvisibleSpace]"  rightTailProbabilityPrecision = "\[InvisibleSpace]20\
\[InvisibleSpace]"   time in seconds = \
"\[InvisibleSpace]24.422000000000025`\),
        SequenceForm[ 
        "TimingDwassAltIKS1SidedOneSampleRTArbPrecision: sampleSize = ", 
          1000000, "   alpha = ", .001, "  desiredPrecision = ", 20, 
          "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0018582944277582526`6., "   minimumPrecision = ", 1055, 
          "   rightTailProbability = ", 
          0.00100000519945517771720304317323965855`20.477495122596483, 
          "  rightTailProbabilityPrecision = ", 20, "   time in seconds = ", 
          24.422000000000025],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`1000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassAltIKS1SidedOneSampleRTArbPrecision[0.001, \ 1000000, \ 
      100, \ 6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassAltIKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]1000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.001`\[InvisibleSpace]"  desiredPrecision = "\
\[InvisibleSpace]100\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0018582944277582526`6. \[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]1135\[InvisibleSpace]"   \
rightTailProbability = \
"\[InvisibleSpace]0.\
001000005199455177717203043173239657016576905944280063055591650077084956245924\
2870800970192444170276407025055827575`100.47749512256954\[InvisibleSpace]"  \
rightTailProbabilityPrecision = "\[InvisibleSpace]100\[InvisibleSpace]"   \
time in seconds = "\[InvisibleSpace]25.782000000000153`\),
        SequenceForm[ 
        "TimingDwassAltIKS1SidedOneSampleRTArbPrecision: sampleSize = ", 
          1000000, "   alpha = ", .001, "  desiredPrecision = ", 100, 
          "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0018582944277582526`6., "   minimumPrecision = ", 1135, 
          "   rightTailProbability = ", 
          0.001000005199455177717203043173239657016576905944280063055591650077\
0849562459242870800970192444170276407025055827575`100.47749512256954, 
          "  rightTailProbabilityPrecision = ", 100, "   time in seconds = ", 
          25.782000000000153],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`1000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassAltIKS1SidedOneSampleRTArbPrecision[0.9, \ 1000000, \ 20, \ 
      6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassAltIKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]1000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.9`\[InvisibleSpace]"  desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0002293551358465437218400548`6.000000000000002\
\[InvisibleSpace]"   minimumPrecision = \
"\[InvisibleSpace]147\[InvisibleSpace]"   rightTailProbability = "\
\[InvisibleSpace]0.90000015781059704546078396689199627585`20.94545045520121\
\[InvisibleSpace]"  rightTailProbabilityPrecision = "\[InvisibleSpace]20\
\[InvisibleSpace]"   time in seconds = "\[InvisibleSpace]8.985000000000127`\),
        
        SequenceForm[ 
        "TimingDwassAltIKS1SidedOneSampleRTArbPrecision: sampleSize = ", 
          1000000, "   alpha = ", .90000000000000002, "  desiredPrecision = ",
           20, "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0002293551358465437218400548`6.000000000000002, 
          "   minimumPrecision = ", 147, "   rightTailProbability = ", 
          0.90000015781059704546078396689199627585`20.94545045520121, 
          "  rightTailProbabilityPrecision = ", 20, "   time in seconds = ", 
          8.9850000000001273],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`1000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassAltIKS1SidedOneSampleRTArbPrecision[0.001, \ 5000000, \ 
      20, \ 6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassAltIKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]5000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.001`\[InvisibleSpace]"  desiredPrecision = "\
\[InvisibleSpace]20\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0008310957348012216`5.999999999999999\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]2330\[InvisibleSpace]"   \
rightTailProbability = \
"\[InvisibleSpace]0.00099999870917696091267298145583196882`20.010889621361635\
\[InvisibleSpace]"  rightTailProbabilityPrecision = "\[InvisibleSpace]20\
\[InvisibleSpace]"   time in seconds = \
"\[InvisibleSpace]133.10899999999947`\),
        SequenceForm[ 
        "TimingDwassAltIKS1SidedOneSampleRTArbPrecision: sampleSize = ", 
          5000000, "   alpha = ", .001, "  desiredPrecision = ", 20, 
          "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0008310957348012216`5.999999999999999, "   minimumPrecision = ", 
          2330, "   rightTailProbability = ", 
          0.00099999870917696091267298145583196882`20.010889621361635, 
          "  rightTailProbabilityPrecision = ", 20, "   time in seconds = ", 
          133.10899999999947],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`5000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassAltIKS1SidedOneSampleRTArbPrecision[0.001, \ 5000000, \ 
      100, \ 6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassAltIKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]5000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.001`\[InvisibleSpace]"  desiredPrecision = "\
\[InvisibleSpace]100\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0008310957348012216`5.999999999999999\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]2410\[InvisibleSpace]"   \
rightTailProbability = \
"\[InvisibleSpace]0.\
000999998709176960912672981455831968819987827596090744225002676475244134381205\
6948730480676837976559845189726002164`100.01088962133468\[InvisibleSpace]"  \
rightTailProbabilityPrecision = "\[InvisibleSpace]100\[InvisibleSpace]"   \
time in seconds = "\[InvisibleSpace]131.48400000000038`\),
        SequenceForm[ 
        "TimingDwassAltIKS1SidedOneSampleRTArbPrecision: sampleSize = ", 
          5000000, "   alpha = ", .001, "  desiredPrecision = ", 100, 
          "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0008310957348012216`5.999999999999999, "   minimumPrecision = ", 
          2410, "   rightTailProbability = ", 
          0.000999998709176960912672981455831968819987827596090744225002676475\
2441343812056948730480676837976559845189726002164`100.01088962133468, 
          "  rightTailProbabilityPrecision = ", 100, "   time in seconds = ", 
          131.48400000000038],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`5000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassAltIKS1SidedOneSampleRTArbPrecision[0.9, \ 5000000, \ 20, \ 
      6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassAltIKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]5000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.9`\[InvisibleSpace]"  desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0001026119372142307669068612`6.000000000000002\
\[InvisibleSpace]"   minimumPrecision = \
"\[InvisibleSpace]304\[InvisibleSpace]"   rightTailProbability = "\
\[InvisibleSpace]0.90000000829283041495172335763200479083`20.424005097494735\
\[InvisibleSpace]"  rightTailProbabilityPrecision = "\[InvisibleSpace]20\
\[InvisibleSpace]"   time in seconds = "\[InvisibleSpace]40.34400000000005`\),
        
        SequenceForm[ 
        "TimingDwassAltIKS1SidedOneSampleRTArbPrecision: sampleSize = ", 
          5000000, "   alpha = ", .90000000000000002, "  desiredPrecision = ",
           20, "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0001026119372142307669068612`6.000000000000002, 
          "   minimumPrecision = ", 304, "   rightTailProbability = ", 
          0.90000000829283041495172335763200479083`20.424005097494735, 
          "  rightTailProbabilityPrecision = ", 20, "   time in seconds = ", 
          40.344000000000051],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`5000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassAltIKS1SidedOneSampleRTArbPrecision[0.001, \ 10000000, \ 
      20, \ 6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassAltIKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]10000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.001`\[InvisibleSpace]"  desiredPrecision = "\
\[InvisibleSpace]20\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0005876803334525333`6.000000000000002\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]3286\[InvisibleSpace]"   \
rightTailProbability = \
"\[InvisibleSpace]0.00100000539120678945192816085831260266`20.281084169008224\
\[InvisibleSpace]"  rightTailProbabilityPrecision = "\[InvisibleSpace]20\
\[InvisibleSpace]"   time in seconds = "\[InvisibleSpace]302.2350000000006`\),
        
        SequenceForm[ 
        "TimingDwassAltIKS1SidedOneSampleRTArbPrecision: sampleSize = ", 
          10000000, "   alpha = ", .001, "  desiredPrecision = ", 20, 
          "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0005876803334525333`6.000000000000002, "   minimumPrecision = ", 
          3286, "   rightTailProbability = ", 
          0.00100000539120678945192816085831260266`20.281084169008224, 
          "  rightTailProbabilityPrecision = ", 20, "   time in seconds = ", 
          302.23500000000058],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`10000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassAltIKS1SidedOneSampleRTArbPrecision[0.001, \ 10000000, \ 
      100, \ 6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassAltIKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]10000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.001`\[InvisibleSpace]"  desiredPrecision = "\
\[InvisibleSpace]100\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0005876803334525333`6.000000000000002\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]3366\[InvisibleSpace]"   \
rightTailProbability = \
"\[InvisibleSpace]0.\
001000005391206789451928160858312602629537126695141170964778858883896442362026\
2012939158261205589577311062122224045`100.2810841644956\[InvisibleSpace]"  \
rightTailProbabilityPrecision = "\[InvisibleSpace]100\[InvisibleSpace]"   \
time in seconds = "\[InvisibleSpace]303.34400000000096`\),
        SequenceForm[ 
        "TimingDwassAltIKS1SidedOneSampleRTArbPrecision: sampleSize = ", 
          10000000, "   alpha = ", .001, "  desiredPrecision = ", 100, 
          "   testStatisticDesiredPrecision = ", 6, "   d = ", 
          0.0005876803334525333`6.000000000000002, "   minimumPrecision = ", 
          3366, "   rightTailProbability = ", 
          0.001000005391206789451928160858312602629537126695141170964778858883\
8964423620262012939158261205589577311062122224045`100.2810841644956, 
          "  rightTailProbabilityPrecision = ", 100, "   time in seconds = ", 
          303.34400000000096],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`10000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimingDwassAltIKS1SidedOneSampleRTArbPrecision[0.9, \ 10000000, \ 20, \ 
      6]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("TimingDwassAltIKS1SidedOneSampleRTArbPrecision: \
sampleSize = "\[InvisibleSpace]10000000\[InvisibleSpace]"   alpha = "\
\[InvisibleSpace]0.9`\[InvisibleSpace]"  desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   testStatisticDesiredPrecision = "\
\[InvisibleSpace]6\[InvisibleSpace]"   d = \
"\[InvisibleSpace]0.0000725645001942437127574416`6.000000000000002\
\[InvisibleSpace]"   minimumPrecision = \
"\[InvisibleSpace]422\[InvisibleSpace]"   rightTailProbability = "\
\[InvisibleSpace]0.89999987106638007733105785714793785199`20.389941640461952\
\[InvisibleSpace]"  rightTailProbabilityPrecision = "\[InvisibleSpace]20\
\[InvisibleSpace]"   time in seconds = "\[InvisibleSpace]98.09400000000096`\),
        
        SequenceForm[ 
        "TimingDwassAltIKS1SidedOneSampleRTArbPrecision: sampleSize = ", 
          10000000, "   alpha = ", .90000000000000002, 
          "  desiredPrecision = ", 20, "   testStatisticDesiredPrecision = ", 
          6, "   d = ", 0.0000725645001942437127574416`6.000000000000002, 
          "   minimumPrecision = ", 422, "   rightTailProbability = ", 
          0.89999987106638007733105785714793785199`20.389941640461952, 
          "  rightTailProbabilityPrecision = ", 20, "   time in seconds = ", 
          98.09400000000096],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`10000000\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
20. DwassAltI Minimum Precision Minus Desired Precision To File\
\>", "Section"],

Cell["\<\
The following is the code of the Mathematica function \
MinPrecisionMinusDesiredPrecisionToFileDwassAltI that calculates the minimum \
precision minus desired precision needed for the arbitrary precision \
DwassAltI formula and the sample sizes in the vector sampleSizeVectorIn, the \
desired precisions in the vector desiredPrecisionVectorIn, and the Maag and \
Dicaire test statistic to six digits of precision for the p-values in the \
vector alphaVectorIn.  The results are written to file outputFileName which \
can be read by Execel if separatorString is a comma.  Sample intermediate \
output is given in subsection 20.1.  The sample output file generated by the \
example in subsection 20.1 is given in subsection 20.2.\
\>", "Text"],

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionToFileDwassAltI[sampleSizeVectorIn_, \ 
        desiredPrecisionVectorIn_, \ alphaVectorIn_, \ intermediateOutput_, \ 
        outputFileName_, \ howToOpenFile_, \ separatorString_]\  := \ 
      Module[{numberSampleSizes, \ numberDesiredPrecisions, \ numberAlphas, \ 
          VectorDimensions, \ sampleSize, \ desiredPrecision, \ alpha, \ 
          numberDesiredPrecisionsAndAlphas, \ minimumPrecision, \ 
          sampleSizeIndex, \ desiredPrecisionIndex, \ alphaIndex, \ 
          outputFileNumber, \ minimumPrecisionArray, \ d, \ numExp, \ 
          nOutputString, \ numberTermsOutputString, \ 
          desiredPrecisionOutputString, \ minimumPrecisionOutputString, \ 
          stringIndex, \ functionOutput}, \[IndentingNewLine] (*\ 
          Generate\ minimumPrecision - 
            desiredPrecision\ for\ arbitrary\ precision\ \[IndentingNewLine]\ \
\ \ \ \ \ \ DwassAltI\ and\ put\ into\ file, \ 
          outputFileName\ *) \[IndentingNewLine] (*\ 
          Open\ \(file : \ howToOpenFile\) = 0, \ 
          use\ OpenWrite\ which\ creates\ a\ new\ file\[IndentingNewLine]\ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ and\ destroys\ an\ old\ \
file\ *) \ \[IndentingNewLine] (*\ \ \ \ \ \ \ \ \ \ \ \ howToOpenFile = 1, \ 
          use\ OpenAppend\ which\ opens\ file\ and\[IndentingNewLine]\ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ appends\ output\ to\ end\ \
of\ that\ \(\(file\)\(.\)\)\ \ *) \[IndentingNewLine]VectorDimensions\  = \ 
          Dimensions[
            sampleSizeVectorIn]; \[IndentingNewLine]numberSampleSizes\  = \ \ \
VectorDimensions[\([1]\)]; \[IndentingNewLine]VectorDimensions\  = \ 
          Dimensions[
            desiredPrecisionVectorIn]; \
\[IndentingNewLine]numberDesiredPrecisions\  = \ \ VectorDimensions[\([1]\)]; \
\[IndentingNewLine]VectorDimensions\  = \ 
          Dimensions[
            alphaVectorIn]; \[IndentingNewLine]numberAlphas\  = \ \ \
VectorDimensions[\([1]\)]; \
\[IndentingNewLine]numberDesiredPrecisionsAndAlphas\  = \ 
          numberDesiredPrecisions\ *\ 
            numberAlphas; \[IndentingNewLine]minimumPrecisionArray\  = \ 
          Array[
            0, \ {numberSampleSizes, \ numberDesiredPrecisions, \ 
              numberAlphas}]; \[IndentingNewLine]If[
          howToOpenFile\  \[LessEqual] \ 0, \ 
          outputFileNumber\  = \ OpenWrite[outputFileName], \ 
          outputFileNumber\  = \ 
            OpenAppend[outputFileName]]; \[IndentingNewLine]If[
          howToOpenFile\  \[LessEqual] \ 0, \ \[IndentingNewLine] (*\ 
            Output\ all\ the\ minimum\ precisions\ in\ a\ vector\ \
*) \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<DwassAltI:\n\>"]; \
\[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<Desired\>", \ \ separatorString, \ 
            separatorString, \ "\<Sample\>", \ 
            separatorString, \ \ "\<Minimum\>", 
            separatorString, "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<Precision\>", \ \ separatorString, \ 
            separatorString, \ "\<Size\>", \ 
            separatorString, \ "\<Precision\>", \ 
            separatorString, "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<dp\>", \ \ separatorString, \ "\<alpha\>", \
\ separatorString, \ "\<n\>", \ separatorString, \ "\<mp\>", \ 
            separatorString, \ "\<mp - dp\>", "\<\n\>"\ \
];\[IndentingNewLine]]; \[IndentingNewLine]If[
          intermediateOutput\  \[GreaterEqual] \ 
            1, \[IndentingNewLine]\(Print["\<\
MinPrecisionMinusDesiredPrecisionToFileDwassAltI:  For \>", \ 
              numberSampleSizes, "\< sampleSizes \>", \ \ sampleSizeVectorIn, \
\ "\<; \>", \ numberDesiredPrecisions, "\< desiredPrecisions \>", 
              desiredPrecisionVectorIn, \ \ "\<; and \>", \ 
              numberAlphas, "\< alphas \>", 
              alphaVectorIn, \ "\<, outputFileName = \>", \ 
              outputFileName, \ "\<, howToOpenFile = \>", \ 
              howToOpenFile, \ "\<, and separatorString = '\>", \ 
              separatorString, \ "\<'\>", \ "\<   intermediateOutput = \>", \ 
              intermediateOutput];\)\[IndentingNewLine]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]sampleSize\  = \ 
            sampleSizeVectorIn[\([sampleSizeIndex]\)]; \[IndentingNewLine]Do[\
\[IndentingNewLine]desiredPrecision\  = \ 
              desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)]; \
\[IndentingNewLine]Do[\[IndentingNewLine]alpha\  = \ \ \
alphaVectorIn[\([alphaIndex]\)]; \[IndentingNewLine]d\  = \ 
                Rationalize[
                  KS1SidedOneSampleTestStatisticByMaagDicaire[alpha, 
                    sampleSize, \ 6], 
                  0]; \[IndentingNewLine]functionOutput\  = 
                MinPrecisionMinusDesiredPrecisionDwassAltI[d, \ sampleSize, \ 
                  desiredPrecision, \ 
                  0]; \[IndentingNewLine]minimumPrecision\  = \ 
                functionOutput[\([2]\)]; \[IndentingNewLine]minimumPrecision\ \
 = \ minimumPrecision\  + \ 
                  desiredPrecision; \[IndentingNewLine]minimumPrecisionArray[\
\([sampleSizeIndex, \ desiredPrecisionIndex, \ alphaIndex]\)]\  = \ 
                minimumPrecision; \[IndentingNewLine]WriteString[
                outputFileNumber, \ 
                ToString[\ desiredPrecision, \ 
                  FortranForm], \ \ separatorString, \ 
                ToString[\ alpha, \ FortranForm], \ \ separatorString, \ 
                ToString[\ sampleSize, \ FortranForm], \ \ separatorString, \ 
                ToString[\ 
                  minimumPrecisionArray[\([sampleSizeIndex, \ 
                      desiredPrecisionIndex, \ alphaIndex]\)], \ 
                  FortranForm], \ \ separatorString, \ \ ToString[\ 
                  minimumPrecisionArray[\([sampleSizeIndex, \ 
                        desiredPrecisionIndex, \ alphaIndex]\)]\  - \ 
                    desiredPrecision\ , \ 
                  FortranForm], \ "\<\n\>"]; \[IndentingNewLine]If[
                intermediateOutput\  \[GreaterEqual] \ 
                  2, \[IndentingNewLine]\(Print["\<    sampleSize = \>", \ \ \
sampleSize, \ "\<   desiredPrecision = \>", \ 
                    desiredPrecision, \ "\<   alpha = \>", \ 
                    alpha, \ "\<   d = \>", \ d, \ "\< = \>", \ 
                    N[d, \ 6], \ "\<   minimumPrecision = \>", \ 
                    minimumPrecision];\)\[IndentingNewLine]];\
\[IndentingNewLine], {alphaIndex, \ 1, \ \ numberAlphas, \ 
                1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 1, \ 
              numberDesiredPrecisions, \ 
              1}];\[IndentingNewLine], {sampleSizeIndex, \ 1, \ 
            numberSampleSizes, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\n\n\>"\ ]; \[IndentingNewLine] (*\ 
          Minimum\ precision\ by\ desiredPrecision\ by\ alpha\ \
*) \[IndentingNewLine]WriteString[
          
          outputFileNumber, \ "\<DwassAltI:\>", \ \ separatorString, \ \
"\<Minimum Precision mp\>"]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
              outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{stringIndex, \ 1, \ numberDesiredPrecisionsAndAlphas\  - \ 1\ , \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Sample\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ separatorString, \ "\<Desired Precision dp \
= \>", \ ToString[\ desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)], \ 
              FortranForm]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{\ alphaIndex, \ 1\ , \ numberAlphas\  - \ 1, \ 
              1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 
            1, \ \ numberDesiredPrecisions, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Size\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ \ separatorString, \ "\<alpha\>"]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{\ alphaIndex, \ 1\ , \ numberAlphas\  - \ 1, \ 
              1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 
            1, \ \ numberDesiredPrecisions, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<n\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]\(WriteString[
                  outputFileNumber, \ \ separatorString, \ 
                  ToString[\ alphaVectorIn[\([alphaIndex]\)], \ 
                    FortranForm]];\)\[IndentingNewLine], {\ alphaIndex, \ 
                1\ , \ numberAlphas, \ 
                1}];\)\[IndentingNewLine], {desiredPrecisionIndex, \ 
            1, \ \ numberDesiredPrecisions, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]Do[\
\[IndentingNewLine]sampleSize\  = \ 
            sampleSizeVectorIn[\([sampleSizeIndex]\)]; \
\[IndentingNewLine]WriteString[outputFileNumber, \ 
            ToString[\ sampleSize, \ 
              FortranForm]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]desiredPrecision\  = \ 
              desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)]; \
\[IndentingNewLine]Do[\[IndentingNewLine]alpha\  = \ \ \
alphaVectorIn[\([alphaIndex]\)]; \[IndentingNewLine]WriteString[
                outputFileNumber, \ \ separatorString, \ 
                ToString[\ 
                  minimumPrecisionArray[\([sampleSizeIndex, \ 
                      desiredPrecisionIndex, \ alphaIndex]\)], \ 
                  FortranForm]];\[IndentingNewLine], {alphaIndex, \ 
                1, \ \ numberAlphas, \ 
                1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 1, \ 
              numberDesiredPrecisions, \ 1}]; \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<\n\>"\ ];\[IndentingNewLine], \
{sampleSizeIndex, \ 1, \ numberSampleSizes, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\n\n\>"\ ]; \[IndentingNewLine] (*\ 
          Minimum\ precision\ by\ alpha\ by\ desiredPrecision\ \
*) \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<DwassAltI:\>", \ \ separatorString, \ \
"\<Minimum Precision mp\>"]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
              outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{stringIndex, \ 1, \ numberDesiredPrecisionsAndAlphas\  - \ 1\ , \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Sample\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ separatorString, \ "\<alpha = \>", \ 
            ToString[\ alphaVectorIn[\([alphaIndex]\)], \ 
              FortranForm]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ \ numberDesiredPrecisions\  - \ 1, \ 
              1}];\[IndentingNewLine], {\ alphaIndex, \ 1\ , \ 
            numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Size\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]\(WriteString[
                  outputFileNumber, \ \ separatorString, \ "\<dp\>"];\)\
\[IndentingNewLine], {desiredPrecisionIndex, \ 
                1, \ \ numberDesiredPrecisions, \ 
                1}];\)\[IndentingNewLine], {\ alphaIndex, \ 1\ , \ 
            numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<n\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]\(WriteString[
                  outputFileNumber, \ \ separatorString, \ 
                  ToString[\ 
                    desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)], \ 
                    FortranForm]];\)\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ \ numberDesiredPrecisions, \ 
                1}];\)\[IndentingNewLine], {\ alphaIndex, \ 1\ , \ 
            numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]Do[\
\[IndentingNewLine]sampleSize\  = \ 
            sampleSizeVectorIn[\([sampleSizeIndex]\)]; \
\[IndentingNewLine]WriteString[outputFileNumber, \ 
            ToString[\ sampleSize, \ 
              FortranForm]]; \[IndentingNewLine]Do[\[IndentingNewLine]\(Do[\
\[IndentingNewLine]\(WriteString[outputFileNumber, \ \ separatorString, \ 
                    ToString[\ 
                      minimumPrecisionArray[\([sampleSizeIndex, \ 
                          desiredPrecisionIndex, \ alphaIndex]\)], \ 
                      FortranForm]];\)\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ numberDesiredPrecisions, \ 
                  1}];\)\[IndentingNewLine], {alphaIndex, \ 
              1, \ \ numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<\n\>"\ ];\[IndentingNewLine], \
{sampleSizeIndex, \ 1, \ numberSampleSizes, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\n\n\>"\ ]; \[IndentingNewLine] (*\ 
          Minimum\ precision\ minus\ desired\ precision\ by\ desiredPrecision\
\ by\ alpha\ *) \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<DwassAltI:\>", \ \ separatorString, \ \
"\<Minimum Precision Minus Desired Precision mp - dp\>"]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
              outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{stringIndex, \ 1, \ numberDesiredPrecisionsAndAlphas\  - \ 1\ , \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Sample\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ separatorString, \ "\<Desired Precision dp \
= \>", \ ToString[\ desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)], \ 
              FortranForm]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{\ alphaIndex, \ 1\ , \ numberAlphas\  - \ 1, \ 
              1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 
            1, \ \ numberDesiredPrecisions, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Size\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ \ separatorString, \ "\<alpha\>"]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{\ alphaIndex, \ 1\ , \ numberAlphas\  - \ 1, \ 
              1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 
            1, \ \ numberDesiredPrecisions, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<n\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]\(WriteString[
                  outputFileNumber, \ \ separatorString, \ 
                  ToString[\ alphaVectorIn[\([alphaIndex]\)], \ 
                    FortranForm]];\)\[IndentingNewLine], {\ alphaIndex, \ 
                1\ , \ numberAlphas, \ 
                1}];\)\[IndentingNewLine], {desiredPrecisionIndex, \ 
            1, \ \ numberDesiredPrecisions, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]Do[\
\[IndentingNewLine]sampleSize\  = \ 
            sampleSizeVectorIn[\([sampleSizeIndex]\)]; \
\[IndentingNewLine]WriteString[outputFileNumber, \ 
            ToString[\ sampleSize, \ 
              FortranForm]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]desiredPrecision\  = \ 
              desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)]; \
\[IndentingNewLine]Do[\[IndentingNewLine]alpha\  = \ \ \
alphaVectorIn[\([alphaIndex]\)]; \[IndentingNewLine]WriteString[
                outputFileNumber, \ \ separatorString, \ 
                ToString[\ 
                  minimumPrecisionArray[\([sampleSizeIndex, \ 
                        desiredPrecisionIndex, \ alphaIndex]\)]\  - \ 
                    desiredPrecision, \ 
                  FortranForm]];\[IndentingNewLine], {alphaIndex, \ 
                1, \ \ numberAlphas, \ 
                1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 1, \ 
              numberDesiredPrecisions, \ 1}]; \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<\n\>"\ ];\[IndentingNewLine], \
{sampleSizeIndex, \ 1, \ numberSampleSizes, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\n\n\>"\ ]; \[IndentingNewLine] (*\ 
          Minimum\ precision\ minus\ desired\ precision\ by\ alpha\ by\ \
desiredPrecision\ *) \[IndentingNewLine]WriteString[
          outputFileNumber, \ \ "\<DwassAltI:\>", \ \ separatorString, \ \
"\<Minimum Precision Minus Desired Precision mp - dp\>"]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
              outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{stringIndex, \ 1, \ numberDesiredPrecisionsAndAlphas\  - \ 1\ , \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Sample\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ separatorString, \ "\<alpha = \>", \ 
            ToString[\ alphaVectorIn[\([alphaIndex]\)], \ 
              FortranForm]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ \ numberDesiredPrecisions\  - \ 1, \ 
              1}];\[IndentingNewLine], {\ alphaIndex, \ 1\ , \ 
            numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Size\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]\(WriteString[
                  outputFileNumber, \ \ separatorString, \ "\<dp\>"];\)\
\[IndentingNewLine], {desiredPrecisionIndex, \ 
                1, \ \ numberDesiredPrecisions, \ 
                1}];\)\[IndentingNewLine], {\ alphaIndex, \ 1\ , \ 
            numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<n\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]\(WriteString[
                  outputFileNumber, \ \ separatorString, \ 
                  ToString[\ 
                    desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)], \ 
                    FortranForm]];\)\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ \ numberDesiredPrecisions, \ 
                1}];\)\[IndentingNewLine], {\ alphaIndex, \ 1\ , \ 
            numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]Do[\
\[IndentingNewLine]sampleSize\  = \ 
            sampleSizeVectorIn[\([sampleSizeIndex]\)]; \
\[IndentingNewLine]WriteString[outputFileNumber, \ 
            ToString[\ sampleSize, \ 
              FortranForm]]; \[IndentingNewLine]Do[\[IndentingNewLine]\(Do[\
\[IndentingNewLine]desiredPrecision\  = \ 
                  desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)]; \
\[IndentingNewLine]WriteString[outputFileNumber, \ \ separatorString, \ 
                  ToString[\ 
                    minimumPrecisionArray[\([sampleSizeIndex, \ 
                          desiredPrecisionIndex, \ alphaIndex]\)]\  - \ 
                      desiredPrecision\ , \ 
                    FortranForm]];\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ numberDesiredPrecisions, \ 
                  1}];\)\[IndentingNewLine], {alphaIndex, \ 
              1, \ \ numberAlphas, \ 1}]; \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<\n\>"\ ];\[IndentingNewLine], \
{sampleSizeIndex, \ 1, \ numberSampleSizes, \ 1}]; \[IndentingNewLine]Close[
          
          outputFileNumber]; \[IndentingNewLine]minimumPrecisionArray\
\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(KS1SidedOneSampleTestStatisticByMaagDicaire[alphaIn_, sampleSizeIn_, \ 
        rho_]\  := \[IndentingNewLine]Module[{d, \ alpha, \ 
          sampleSize}, \[IndentingNewLine] (*\ 
          For\ the\ KS\ 1\ sided\ one\ sample\ test, \ 
          the\ Maag\ and\ Dicaire\ formula\ is\ used\ *) \[IndentingNewLine] \
(*\ \ \ \ to\ approximate\ the\ test\ statistic\ corresponding\ to\ a\ right\ \
tail\ *) \[IndentingNewLine] (*\ \ \ \ probability\ of\ alphaIn . \ \ The\ \
test\ statistic\ d\ is\ calculated\ to\ *) \[IndentingNewLine] (*\ \ \ \ rho\ \
number\ of\ decimal\ \(\(digits\)\(.\)\)\ *) \[IndentingNewLine]alpha\  = 
          Rationalize[alphaIn, \ 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine] (*\ 
          Use\ Maag\ and\ Dicaire\ \(\(MD\)\(.\)\)\ *) \[IndentingNewLine]d\  \
= \ N[Sqrt[Log[alpha]/\((\(-2\)*sampleSize)\)] - \ \((1/\((6*
                      sampleSize)\))\), 
            rho\ \  + \ 17]; \[IndentingNewLine]d\  = \ 
          N[d, rho]; \[IndentingNewLine]d\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionDwassAltI[testStatistic_, \ 
        sampleSize_, \ desiredPrecision_, \ intermediateOutput_]\  := \ 
      Module[{internalPrecisionLowLimit, \ internalPrecisionHighLimit, \ 
          setInternalPrecision, \ currentPrecision, \ SquareRootN, \ 
          numberTries, \ rightTailProbability, \ 
          rightTailProbabilityToDesiredPrecision, \ 
          minPrecisionMinusDesiredPrecision, \ mantissaExp, \ numExp, \ 
          prop}, \[IndentingNewLine]SquareRootN\  = \ 
          Ceiling[Sqrt[sampleSize]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 1, \ 
          Print["\<MinPrecisionMinusDesiredPrecisionDwassAltI:\>", \ "\< \
sampleSize = \>", \ sampleSize, \ "\<   testStatistic = \>", \ 
            testStatistic, "\< = \>", \ 
            N[testStatistic, 6], \ \ "\<    desiredPrecision = \>", \ 
            desiredPrecision]]; \[IndentingNewLine]numberTries\  = \ 
          0; \[IndentingNewLine]internalPrecisionLowLimit\  = \ 
          desiredPrecision; \[IndentingNewLine]internalPrecisionHighLimit\  = \
\ SquareRootN\  + \ \ desiredPrecision; \
\[IndentingNewLine]setInternalPrecision\  = \ 
          internalPrecisionHighLimit; \[IndentingNewLine] (*\ 
          Determine\ a\ high\ limit\ for\ minimumPrecision\ \
*) \[IndentingNewLine]Label[
          DetermineInternalPrecisionHighLimit]; \
\[IndentingNewLine]numberTries\  = \ 
          numberTries\ \  + \ 
            1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassAltIKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   FindHighLimit: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision = \>", \ \ \
currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  \[GreaterEqual] \ desiredPrecision, \ 
          Goto[HighLimitFound], \ 
          Goto[HighLimitTooSmall]]; \[IndentingNewLine] (*\ 
          Current\ high\ limit\ too\ small\ *) \[IndentingNewLine]Label[
          HighLimitTooSmall]; \[IndentingNewLine]internalPrecisionLowLimit\  \
= \ internalPrecisionHighLimit; \[IndentingNewLine]internalPrecisionHighLimit\
\  = \ internalPrecisionHighLimit\  + \ desiredPrecision\  - \ 
            currentPrecision; \[IndentingNewLine]setInternalPrecision\  = \ 
          internalPrecisionHighLimit; \[IndentingNewLine]Goto[
          DetermineInternalPrecisionHighLimit]; \[IndentingNewLine] (*\ 
          High\ limit\ found\ *) \[IndentingNewLine]Label[
          HighLimitFound]; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Bisection\ search\ to\ find\ minimumPrecision\ between\ \
internalPrecisionLowLimit\ and\ internalPrecisionHighLimit\ \
*) \[IndentingNewLine]Label[
          BisectionIteration]; \[IndentingNewLine]setInternalPrecision\  = \ 
          Floor[\((internalPrecisionLowLimit\  + \ 
                  internalPrecisionHighLimit)\)/2]; \[IndentingNewLine]If[
          setInternalPrecision\ \  \[LessEqual] \ 
            internalPrecisionLowLimit, \ 
          setInternalPrecision\ \  = \ 
            internalPrecisionLowLimit\  + \ 1, \[IndentingNewLine]\(If[
              setInternalPrecision\ \  \[GreaterEqual] \ \ \
internalPrecisionHighLimit, \ 
              setInternalPrecision\ \  = \ 
                internalPrecisionHighLimit\  - \ 
                  1];\)\[IndentingNewLine]]; \[IndentingNewLine]numberTries\  \
= \ numberTries\ \  + \ 1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassAltIKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   Bisection Search: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision = \>", \ \ \
currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  \[GreaterEqual] \ desiredPrecision, \ 
          Goto[ResetHighLimit], \ 
          Goto[ResetLowLimit]]; \[IndentingNewLine] (*\ 
          Reset\ internalPrecisionHighLimit\ to\ currentPrecision\ \
*) \[IndentingNewLine]Label[
          ResetHighLimit]; \[IndentingNewLine]internalPrecisionHighLimit\  = \
\ setInternalPrecision; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Reset\ internalPrecisionLowLimit\ to\ currentPrecision\ \
*) \[IndentingNewLine]Label[
          ResetLowLimit]; \[IndentingNewLine]internalPrecisionLowLimit\  = \ 
          setInternalPrecision; \[IndentingNewLine]If[
          internalPrecisionLowLimit\  \[GreaterEqual] \ 
            internalPrecisionHighLimit\  - \ 1, \ 
          Goto[MinInternalPrecisionFound], \ 
          Goto[BisectionIteration]]; \[IndentingNewLine] (*\ 
          Minimum\ internal\ precision\ found\ *) \[IndentingNewLine]Label[
          MinInternalPrecisionFound]; \[IndentingNewLine]setInternalPrecision\
\  = \ internalPrecisionLowLimit; \[IndentingNewLine]numberTries\  = \ 
          numberTries\ \  + \ 
            1; \[IndentingNewLine]rightTailProbability\  = \ 
          DwassAltIKS1SidedOneSampleRTArbPrecision[testStatistic, \ 
            sampleSize, \ 
            setInternalPrecision]; \[IndentingNewLine]currentPrecision\  = \ 
          Floor[Precision[rightTailProbability]]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          
          Print["\<   Determine whether low or high limit is minimum \
precision: numberTries = \>", \ 
            numberTries, \ \ "\<, internalPrecisionLowLimit = \>", \ 
            internalPrecisionLowLimit, \ "\<, setInternalPrecision = \>", \ 
            setInternalPrecision, "\<, internalPrecisionHighLimit = \>", \ 
            internalPrecisionHighLimit, \ \ "\<, desiredPrecision = \>", \ 
            desiredPrecision, \ "\<, currentPrecision for low limit = \>", \ \
\ currentPrecision, "\<, rightTailProbability = \>", \ 
            rightTailProbability]]; \[IndentingNewLine]If[
          currentPrecision\  < \ desiredPrecision, \ 
          setInternalPrecision\  = \ internalPrecisionHighLimit, \ 
          setInternalPrecision\  = \ 
            internalPrecisionLowLimit]; \
\[IndentingNewLine]minPrecisionMinusDesiredPrecision\  = \ 
          setInternalPrecision\  - \ \ desiredPrecision; \
\[IndentingNewLine]If[\ intermediateOutput \[GreaterEqual] \ 1, \ 
          Print["\<   Minimum Internal Precision Found: \>", \ "\< sampleSize \
= \>", \ sampleSize, \ "\<   testStatistic = \>", \ 
            testStatistic, "\< = \>", \ 
            N[testStatistic, 6], \ \ "\<    desiredPrecision = \>", \ 
            desiredPrecision, \ "\<   numberTries = \>", \ 
            numberTries, \ "\<   minimumInternalPrecision = \>", \ 
            setInternalPrecision, \ "\<   minPrecisionMinusDesiredPrecision = \
\>", \ minPrecisionMinusDesiredPrecision\ ]]; \
\[IndentingNewLine]{numberTries, \ 
          minPrecisionMinusDesiredPrecision}\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassAltIKS1SidedOneSampleRTArbPrecision[dIn_, sampleSizeIn_, \ 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ term, \ 
          leftTailProbability, \ rightTailProbability, \ sumTerms, \ 
          NminusjMinusOne, \ NminusjPlusOne, \ dN, \ jMinusdN, \ 
          nMINUSjPlusOnePLUSdn, \ jMINUSdnMinusOne}, \[IndentingNewLine] (*\ 
          Dwass\ Alternate\ Iterative\ formula\ to\ calculate\ the\ KS\ 1\ \
Sided\ one\ *) \[IndentingNewLine] (*\ \ \ \ sample\ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ d]; \[IndentingNewLine]sumTerms\  = \ 
          N[\ d\ *\ \((sampleSize\  + \ d*sampleSize)\)^\((sampleSize - 
                    1)\), \ internalPrecision]; \[IndentingNewLine]term\  = \ 
          sumTerms; \[IndentingNewLine]NminusjMinusOne\  = \ 
          N[sampleSize\  - \ 1, \ 
            internalPrecision]; \[IndentingNewLine]NminusjPlusOne\  = \ 
          N[sampleSize\  + \ 1, \ 
            internalPrecision]; \[IndentingNewLine]dN\  = \ 
          N[d\ *\ sampleSize, \ 
            internalPrecision]; \[IndentingNewLine]jHighLimit\  = \ 
          Floor[dN]; \[IndentingNewLine]jMinusdN\  = \ \(-\ 
            dN\); \[IndentingNewLine]nMINUSjPlusOnePLUSdn\  = \ 
          N[\ sampleSize\  + \ 1\  + \ dN, \ 
            internalPrecision]; \[IndentingNewLine]jMINUSdnMinusOne\  = \ 
          N[\(-\ dN\)\  - \ 1, \ internalPrecision]; \[IndentingNewLine]If[
          jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]NminusjMinusOne\  = \ 
            N[NminusjMinusOne\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]NminusjPlusOne\  = \ 
            N[NminusjPlusOne\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]jMinusdN\  = \ 
            N[jMinusdN\  + \ 1\ , \ 
              internalPrecision]; \[IndentingNewLine]nMINUSjPlusOnePLUSdn\  = \
\ N[\ nMINUSjPlusOnePLUSdn\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]jMINUSdnMinusOne\  = \ 
            N[jMINUSdnMinusOne\  + \ 1, \ 
              internalPrecision]; \[IndentingNewLine]term\  = \ 
            N[\ \((\((NminusjPlusOne\ *\ jMinusdN)\)/\((j\ *\ 
                        nMINUSjPlusOnePLUSdn)\))\)*\ \((1\  - \ \((1/
                          nMINUSjPlusOnePLUSdn)\))\)^
                  NminusjMinusOne\ *\ \((1\  + \ \((1/
                          jMINUSdnMinusOne)\))\)^\((j - 1)\)*term, \ 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + term, \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1 - \((sumTerms/sampleSize^\((sampleSize\  - \ 1)\))\), \ 
            internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
20.1  DwassAltI Minimum Precision Minus Desired Precision To File Sample \
Intermediate Output\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MinPrecisionMinusDesiredPrecisionToFileDwassAltI[{100, \ 500}, \ {20, \ 
        100}, \ {0.001, \ 0.9}, \ 
      2, \ "\<C:/KSoutput/KS1SidedOneSampleDwassAltImpMINUSdpN100and500.csv\>\
", \ 0, \ "\<,\>"]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("MinPrecisionMinusDesiredPrecisionToFileDwassAltI:  \
For "\[InvisibleSpace]2\[InvisibleSpace]" sampleSizes "\[InvisibleSpace]{100, 
            500}\[InvisibleSpace]"; "\[InvisibleSpace]2\[InvisibleSpace]" \
desiredPrecisions "\[InvisibleSpace]{20, 
            100}\[InvisibleSpace]"; and "\[InvisibleSpace]2\[InvisibleSpace]" \
alphas "\[InvisibleSpace]{0.001`, 
            0.9`}\[InvisibleSpace]", outputFileName = \
"\[InvisibleSpace]"C:/KSoutput/KS1SidedOneSampleDwassAltImpMINUSdpN100and500.\
csv"\[InvisibleSpace]", howToOpenFile = \
"\[InvisibleSpace]0\[InvisibleSpace]", and separatorString = '"\
\[InvisibleSpace]","\[InvisibleSpace]"'"\[InvisibleSpace]"   \
intermediateOutput = "\[InvisibleSpace]2\),
        SequenceForm[ 
        "MinPrecisionMinusDesiredPrecisionToFileDwassAltI:  For ", 2, 
          " sampleSizes ", {100, 500}, "; ", 2, " desiredPrecisions ", {20, 
          100}, "; and ", 2, " alphas ", {.001, .90000000000000002}, 
          ", outputFileName = ", 
          "C:/KSoutput/KS1SidedOneSampleDwassAltImpMINUSdpN100and500.csv", 
          ", howToOpenFile = ", 0, ", and separatorString = '", ",", "'", 
          "   intermediateOutput = ", 2],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]100\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.001`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]156\/847\[InvisibleSpace]" = "\
\[InvisibleSpace]0.184179456906729634`6. \[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]33\),
        SequenceForm[ 
        "    sampleSize = ", 100, "   desiredPrecision = ", 20, 
          "   alpha = ", .001, "   d = ", 
          Rational[ 156, 847], " = ", 0.184179456906729634`6., 
          "   minimumPrecision = ", 33],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]100\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.9`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]203\/9537\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0212855195554157492`5.999999999999999\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]20\),
        SequenceForm[ 
        "    sampleSize = ", 100, "   desiredPrecision = ", 20, 
          "   alpha = ", .90000000000000002, "   d = ", 
          Rational[ 203, 9537], " = ", 
          0.0212855195554157492`5.999999999999999, "   minimumPrecision = ", 
          20],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]100\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.001`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]156\/847\[InvisibleSpace]" = "\
\[InvisibleSpace]0.184179456906729634`6. \[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]113\),
        SequenceForm[ 
        "    sampleSize = ", 100, "   desiredPrecision = ", 100, 
          "   alpha = ", .001, "   d = ", 
          Rational[ 156, 847], " = ", 0.184179456906729634`6., 
          "   minimumPrecision = ", 113],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]100\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.9`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]203\/9537\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0212855195554157492`5.999999999999999\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]101\),
        SequenceForm[ 
        "    sampleSize = ", 100, "   desiredPrecision = ", 100, 
          "   alpha = ", .90000000000000002, "   d = ", 
          Rational[ 203, 9537], " = ", 
          0.0212855195554157492`5.999999999999999, "   minimumPrecision = ", 
          101],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]500\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.001`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]299\/3612\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0827796234772978959`6. \[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]46\),
        SequenceForm[ 
        "    sampleSize = ", 500, "   desiredPrecision = ", 20, 
          "   alpha = ", .001, "   d = ", 
          Rational[ 299, 3612], " = ", 0.0827796234772978959`6., 
          "   minimumPrecision = ", 46],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]500\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.9`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]140\/14097\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0099311910335532383`5.999999999999999\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]22\),
        SequenceForm[ 
        "    sampleSize = ", 500, "   desiredPrecision = ", 20, 
          "   alpha = ", .90000000000000002, "   d = ", 
          Rational[ 140, 14097], " = ", 
          0.0099311910335532383`5.999999999999999, "   minimumPrecision = ", 
          22],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]500\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.001`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]299\/3612\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0827796234772978959`6. \[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]126\),
        SequenceForm[ 
        "    sampleSize = ", 500, "   desiredPrecision = ", 100, 
          "   alpha = ", .001, "   d = ", 
          Rational[ 299, 3612], " = ", 0.0827796234772978959`6., 
          "   minimumPrecision = ", 126],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("    sampleSize = "\[InvisibleSpace]500\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]"   alpha = "\[InvisibleSpace]0.9`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]140\/14097\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0099311910335532383`5.999999999999999\[InvisibleSpace]"   \
minimumPrecision = "\[InvisibleSpace]102\),
        SequenceForm[ 
        "    sampleSize = ", 500, "   desiredPrecision = ", 100, 
          "   alpha = ", .90000000000000002, "   d = ", 
          Rational[ 140, 14097], " = ", 
          0.0099311910335532383`5.999999999999999, "   minimumPrecision = ", 
          102],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({33, 20}\), \({113, 101}\)},
            {\({46, 22}\), \({126, 102}\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
20.2  DwassAltI Minimum Precision Minus Desired Precision Sample Output File, \
C:/KSoutput/KS1SidedOneSampleDwassAltImpMINUSdpN100and500.csv\
\>", "Subsection"],

Cell[BoxData[{
    \(DwassAltI : Desired, , Sample, Minimum, Precision, , Size, Precision, 
    dp, alpha, n, mp, mp - dp\), "\n", 
    \(20, 0.001, 100, 33, 13\), "\n", 
    \(20, 0.9, 100, 20, 0\), "\n", 
    \(100, 0.001, 100, 113, 13\), "\n", 
    \(100, 0.9, 100, 101, 1\), "\n", 
    \(20, 0.001, 500, 46, 26\), "\n", 
    \(20, 0.9, 500, 22, 2\), "\n", 
    \(100, 0.001, 500, 126, 26\), "\n", 
    \(\(\(100, 0.9, 500, 102, 
    2\)\(\n\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(DwassAltI\)\(:\)\), Minimum\ Precision\ mp, , , Sample, 
    Desired\ Precision\ dp = 20, , Desired\ Precision\ dp = 100, Size, 
    alpha, , alpha, n, 0.001, 0.9, 0.001, 0.9\), "\n", 
    \(100, 33, 20, 113, 101\), "\n", 
    \(\(\(500, 46, 22, 126, 
    102\)\(\n\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(DwassAltI\)\(:\)\), Minimum\ Precision\ mp, , , Sample, 
    alpha = 0.001, , alpha = 0.9, Size, dp, dp, dp, dp\), "\n", 
    \(n, 20, 100, 20, 100\), "\n", 
    \(100, 33, 113, 20, 101\), "\n", 
    \(\(\(500, 46, 126, 22, 
    102\)\(\n\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(DwassAltI\)\(:\)\), 
    Minimum\ Precision\ Minus\ Desired\ Precision\ mp - dp, , , Sample, 
    Desired\ Precision\ dp = 20, , Desired\ Precision\ dp = 100, Size, 
    alpha, , alpha, n, 0.001, 0.9, 0.001, 0.9\), "\n", 
    \(100, 13, 0, 13, 1\), "\n", 
    \(\(\(500, 26, 2, 26, 
    2\)\(\n\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(DwassAltI\)\(:\)\), 
    Minimum\ Precision\ Minus\ Desired\ Precision\ mp - dp, , , Sample, 
    alpha = 0.001, , alpha = 0.9, Size, dp, dp, dp, dp\), "\n", 
    \(n, 20, 100, 20, 100\), "\n", 
    \(100, 13, 13, 0, 1\), "\n", 
    \(500, 26, 26, 2, 2\), "\n", 
    \(\)}], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["21. DwassAltI Desired Precision", "Section"],

Cell["\<\
The following is the code of the Mathematica function \
DwassAltIKS1SidedOneSampleRTdesiredPrecision that calculates the right tail \
p-value to desiredPrecisionIn digits of precision.  Sample output is given in \
subsection 21.1.\
\>", "Text"],

Cell[BoxData[
    \(DwassAltIKS1SidedOneSampleRTdesiredPrecision[dIn_, sampleSizeIn_, \ 
        desiredPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ desiredPrecision, \ internalPrecision, \ j, \ 
          jLowLimit, \ term, \ leftTailProbability, \ rightTailProbability, \ 
          binomialCoefficient, \ secondTerm, \ thirdTerm, \ sumTerms, \ 
          numberIterations, \ alphaPredict, \ 
          resultPrecision}, \[IndentingNewLine] (*\ 
          DwassAltI\ formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ sample\ \
*) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ to\ desiredPrecisionIn\ digits\ of\ *) \[IndentingNewLine] \
(*\ \ \ \ precision\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine]d = 
          Rationalize[dIn, \ 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]desiredPrecision\  = \ 
          Ceiling[desiredPrecisionIn]; \[IndentingNewLine] (*\ 
          Maag\ and\ Dicaire\ approximation\ \
*) \[IndentingNewLine]alphaPredict\  = \ 
          Exp[\(-2\)\ *\ d^2\ *\ 
                sampleSize\  - \ \((2\ *
                  d\ /\ 3)\)\  - \ \((1/\((18\ *\ 
                      sampleSize)\))\)]; \[IndentingNewLine]internalPrecision\
\  = \ Ceiling[
              5\  + \ \((2.986\  + \ 1.032\ *\ Sqrt[sampleSize])\)\ *\ \((\ 
                    0.6875\  - \ 0.1433*\ alphaPredict\  - \ 
                      0.399\ *\ alphaPredict^\((1/4)\)\  + \ 
                      0.04703\ *\ alphaPredict^3\  - \ 
                      0.1323\ *\ alphaPredict^4\  - \ 
                      0.0556\ *\ Log[alphaPredict])\)]\  + \ 
            desiredPrecision; \[IndentingNewLine]numberIterations\  = \ 
          0; \[IndentingNewLine]Label[
          AnotherIteration]; \[IndentingNewLine]numberIterations\  = \ 
          numberIterations\  + \ 
            1; \[IndentingNewLine]rightTailProbability\ \  = \ 
          DwassAltIKS1SidedOneSampleRTArbPrecision[d, sampleSize, 
            internalPrecision]; \[IndentingNewLine]resultPrecision\  = \ 
          Precision[rightTailProbability]; \[IndentingNewLine]If[
          resultPrecision\  < \ 
            desiredPrecision, \[IndentingNewLine]internalPrecision\  = \ 
            internalPrecision\  + \ desiredPrecision; \[IndentingNewLine]Goto[
            AnotherIteration];\[IndentingNewLine]]; \
\[IndentingNewLine]rightTailProbability\ \[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassAltIKS1SidedOneSampleRTArbPrecision[dIn_, sampleSizeIn_, \ 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ term, \ 
          leftTailProbability, \ rightTailProbability, \ sumTerms, \ 
          NminusjMinusOne, \ NminusjPlusOne, \ dN, \ jMinusdN, \ 
          nMINUSjPlusOnePLUSdn, \ jMINUSdnMinusOne}, \[IndentingNewLine] (*\ 
          Dwass\ Alternate\ Iterative\ formula\ to\ calculate\ the\ KS\ 1\ \
Sided\ one\ *) \[IndentingNewLine] (*\ \ \ \ sample\ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ d]; \[IndentingNewLine]sumTerms\  = \ 
          N[\ d\ *\ \((sampleSize\  + \ d*sampleSize)\)^\((sampleSize - 
                    1)\), \ internalPrecision]; \[IndentingNewLine]term\  = \ 
          sumTerms; \[IndentingNewLine]NminusjMinusOne\  = \ 
          N[sampleSize\  - \ 1, \ 
            internalPrecision]; \[IndentingNewLine]NminusjPlusOne\  = \ 
          N[sampleSize\  + \ 1, \ 
            internalPrecision]; \[IndentingNewLine]dN\  = \ 
          N[d\ *\ sampleSize, \ 
            internalPrecision]; \[IndentingNewLine]jHighLimit\  = \ 
          Floor[dN]; \[IndentingNewLine]jMinusdN\  = \ \(-\ 
            dN\); \[IndentingNewLine]nMINUSjPlusOnePLUSdn\  = \ 
          N[\ sampleSize\  + \ 1\  + \ dN, \ 
            internalPrecision]; \[IndentingNewLine]jMINUSdnMinusOne\  = \ 
          N[\(-\ dN\)\  - \ 1, \ internalPrecision]; \[IndentingNewLine]If[
          jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]NminusjMinusOne\  = \ 
            N[NminusjMinusOne\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]NminusjPlusOne\  = \ 
            N[NminusjPlusOne\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]jMinusdN\  = \ 
            N[jMinusdN\  + \ 1\ , \ 
              internalPrecision]; \[IndentingNewLine]nMINUSjPlusOnePLUSdn\  = \
\ N[\ nMINUSjPlusOnePLUSdn\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]jMINUSdnMinusOne\  = \ 
            N[jMINUSdnMinusOne\  + \ 1, \ 
              internalPrecision]; \[IndentingNewLine]term\  = \ 
            N[\ \((\((NminusjPlusOne\ *\ jMinusdN)\)/\((j\ *\ 
                        nMINUSjPlusOnePLUSdn)\))\)*\ \((1\  - \ \((1/
                          nMINUSjPlusOnePLUSdn)\))\)^
                  NminusjMinusOne\ *\ \((1\  + \ \((1/
                          jMINUSdnMinusOne)\))\)^\((j - 1)\)*term, \ 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + term, \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1 - \((sumTerms/sampleSize^\((sampleSize\  - \ 1)\))\), \ 
            internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[CellGroupData[{

Cell["21.1  DwassAltI Desired Precision Sample Output", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DwassAltIKS1SidedOneSampleRTdesiredPrecision[0.000831096, 5000000, \ 
      30]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.\
000999994849501232127646860949510285878397398529743434028`37.010243527545725\)\
], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DwassAltIKS1SidedOneSampleRTdesiredPrecision[0.000339290, 10000000, \ 
      40]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.\
100000480993207370350317616589677055270014407449947732643`45.394806868611006\)\
], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["22. Dwass Arb Precision and Rational Timing To File", "Section"],

Cell["\<\
The following is the code of the Mathematica function \
DwassArbPrecisionRationalTimingsToFile that calculates the computer time in \
seconds needed for the arbitrary precision DwassAltD, DwassD, DwassI, and \
DwassAltI formulae as well as the rational arithmetic DwassAltD formula.  The \
computer times are genreated for the sample sizes in the vector \
sampleSizeVectorIn, the desired precisions in the vector \
desiredPrecisionVectorIn, and the Maag and Dicaire test statistic to rho \
digits of precision for the p-values in the vector alphaVectorIn.  For the \
same sample size, desired precision, and test statistic, the right tail \
probabilities produced by all formulae are compared to determine if there are \
any errors.  The results are written to file outputFileName which can be read \
by Execel if separatorString is a comma.  Sample intermediate output is given \
in subsection 22.1.  The sample output file generated by the example in \
subsection 22.1 is given in subsection 22.2.\
\>", "Text"],

Cell[BoxData[
    \(DwassArbPrecisionRationalTimingsToFile[sampleSizeVectorIn_, \ 
        desiredPrecisionVectorIn_, \ alphaMDVectorIn_, \ 
        intermediateOutput_, \ outputFileName_, \ howToOpenFile_, \ 
        separatorString_, \ rhoIn_]\  := \ 
      Module[{numberSampleSizes, \ numberDesiredPrecisions, \ 
          numberalphaMDs, \ VectorDimensions, \ numberFormulae, \ 
          sampleSize, \ desiredPrecision, \ alphaMD, \ 
          numberDesiredPrecisionsAndalphaMDs, \ computerTime, \ 
          sampleSizeIndex, \ desiredPrecisionIndex, \ alphaMDIndex, \ 
          formulaIndex, \ formulaName, \ outputFileNumber, \ 
          computerTimeArray, \ formulaNameArray, \ 
          rationalDwassAltDrightTailProbabilityArray, \ d, \ rho, \ numExp, \ 
          nOutputString, \ numberTermsOutputString, \ 
          desiredPrecisionOutputString, \ computerTimeOutputString, \ 
          stringIndex, \ functionOutput, \ rightTailProbability, \ 
          rightTailProbabilityPrecision, \ 
          rightTailProbabilityAbsDifference, \ functionTimeString, \ 
          timeString, \ rTPpowerTen, rTP, \ precisionUsed, \ 
          precisionDwassAltD, \ precisionDwassD, \ precisionDwassI, \ 
          precisionDwassAltI, \ rightTailProbabilityDwassAltD, \ 
          rightTailProbabilityDwassD, \ rightTailProbabilityDwassI, \ 
          rightTailProbabilityDwassAltI, \ 
          rightTailProbabilityDwassAltDrational, \ 
          rightTailProbabilityDwassAltDrationalInArbPrecision, \ 
          powerTenCompare}, \[IndentingNewLine] (*\ 
          Generate\ timings\ for\ desired\ precision\ formulae\ \((DwassAltD, \
\ DwassD, \[IndentingNewLine]\ \ \ \ \ DwassI, \ DwassAltI, \ 
              Rational\ DwassAltD)\), \ 
          check\ to\ see\ if\ all\[IndentingNewLine]\ \ \ \ \ \ formulae\ get\
\ the\ same\ right\ tail\ probability, \ 
          and\ put\[IndentingNewLine]\ \ \ \ \ \ timings\ into\ file, \ 
          outputFileName\ *) \[IndentingNewLine] (*\ 
          Open\ \(file : \ howToOpenFile\) = 0, \ 
          use\ OpenWrite\ which\ creates\ a\ new\ file\[IndentingNewLine]\ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ and\ destroys\ an\ old\ \
file\ *) \ \[IndentingNewLine] (*\ \ \ \ \ \ \ \ \ \ \ \ howToOpenFile = 1, \ 
          use\ OpenAppend\ which\ opens\ file\ and\[IndentingNewLine]\ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ appends\ output\ to\ end\ \
of\ that\ \(\(file\)\(.\)\)\ \ *) \[IndentingNewLine]VectorDimensions\  = \ 
          Dimensions[
            sampleSizeVectorIn]; \[IndentingNewLine]numberSampleSizes\  = \ \ \
VectorDimensions[\([1]\)]; \[IndentingNewLine]VectorDimensions\  = \ 
          Dimensions[
            desiredPrecisionVectorIn]; \
\[IndentingNewLine]numberDesiredPrecisions\  = \ \ VectorDimensions[\([1]\)]; \
\[IndentingNewLine]VectorDimensions\  = \ 
          Dimensions[
            alphaMDVectorIn]; \[IndentingNewLine]numberalphaMDs\  = \ \ \
VectorDimensions[\([1]\)]; \
\[IndentingNewLine]numberDesiredPrecisionsAndalphaMDs\  = \ 
          numberDesiredPrecisions\ *\ 
            numberalphaMDs; \[IndentingNewLine]rho\  = \ 
          Round[rhoIn]; \[IndentingNewLine]If[\ rho\  < \ 2, \ 
          rho\  = \ 2]; \[IndentingNewLine]numberFormulae\  = \ 
          5; \[IndentingNewLine]formulaNameArray\  = \ 
          Array["\<DeassAltD\>", \ {5}]; \[IndentingNewLine]formulaNameArray[\
\([1]\)]\  = \ "\<DwassAltD\>"; \[IndentingNewLine]formulaNameArray[\([2]\)]\ \
 = \ "\<DwassD\>"; \[IndentingNewLine]formulaNameArray[\([3]\)]\  = \ \
"\<DwassI\>"; \[IndentingNewLine]formulaNameArray[\([4]\)]\  = \ "\<DwassAltI\
\>"; \[IndentingNewLine]formulaNameArray[\([5]\)]\  = \ "\<Rational DwassAltD\
\>"; \[IndentingNewLine]computerTimeArray\  = \ 
          Array[0, \ {numberSampleSizes, \ numberFormulae, \ 
              numberDesiredPrecisions, \ 
              numberalphaMDs}]; \
\[IndentingNewLine]rationalDwassAltDrightTailProbabilityArray\  = \ 
          Array[0, \ {numberSampleSizes, \ 
              numberFormulae, \ \ numberalphaMDs}]; \[IndentingNewLine]If[
          howToOpenFile\  \[LessEqual] \ 0, \ 
          outputFileNumber\  = \ OpenWrite[outputFileName], \ 
          outputFileNumber\  = \ 
            OpenAppend[outputFileName]]; \[IndentingNewLine]If[
          howToOpenFile\  \[LessEqual] \ 0, \ \[IndentingNewLine] (*\ 
            
            Output\ all\ the\ computer\ times\ in\ a\ vector\ \
*) \[IndentingNewLine]WriteString[outputFileNumber, \ "\<rho = \>", \ 
            rho, \ \ separatorString, \ 
            separatorString, \ \ separatorString, \ 
            separatorString, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<Desired\>", \ \ separatorString, \ 
            separatorString, \ "\<Sample\>", \ \ separatorString, \ 
            separatorString, \ \ "\<Computer\>", \ "\<\n\>"\ ]; \
\[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<Precision\>", \ \ separatorString, \ 
            separatorString, \ "\<Size\>", \ separatorString, \ 
            separatorString, \ "\<Time In\>", \ "\<\n\>"\ ]; \
\[IndentingNewLine]WriteString[
            outputFileNumber, "\<dp\>", \ \ separatorString, \ "\<alphaMD\>", \
\ separatorString, \ "\<n\>", \ 
            separatorString, \ \ "\<Formula\>", \ \ separatorString, \ \
"\<Seconds\>", \ "\<\n\>"\ ];\[IndentingNewLine]]; \[IndentingNewLine]If[
          intermediateOutput\  \[GreaterEqual] \ 
            1, \[IndentingNewLine]\(Print["\<\
DwassArbPrecisionRationalTimingsToFile:  For \>", \ 
              numberSampleSizes, "\< sampleSizes \>", \ \ sampleSizeVectorIn, \
\ "\<; \>", \ numberDesiredPrecisions, "\< desiredPrecisions \>", 
              desiredPrecisionVectorIn, \ \ "\<; \>", \ 
              numberalphaMDs, "\< alphaMDs \>", 
              alphaMDVectorIn, "\<; and \>", \ 
              numberFormulae, "\< formulae \>", \ 
              formulaNameArray, \ "\<, outputFileName = \>", \ 
              outputFileName, \ "\<, howToOpenFile = \>", \ 
              howToOpenFile, \ "\<, and separatorString = '\>", \ 
              separatorString, \ "\<'\>", \ "\<   intermediateOutput = \>", \ 
              intermediateOutput, \ "\<   rho = \>", \ 
              rho];\)\[IndentingNewLine]]; \[IndentingNewLine]Do[\
\[IndentingNewLine]sampleSize\  = \ 
            sampleSizeVectorIn[\([sampleSizeIndex]\)]; \[IndentingNewLine]Do[\
\[IndentingNewLine]desiredPrecision\  = \ 
              desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)]; \
\[IndentingNewLine]Do[\[IndentingNewLine]alphaMD\  = \ \ \
alphaMDVectorIn[\([alphaMDIndex]\)]; \[IndentingNewLine]d\  = \ 
                Rationalize[
                  KS1SidedOneSampleTestStatisticByMaagDicaire[alphaMD, 
                    sampleSize, \ rho], 0]; \[IndentingNewLine]If[
                intermediateOutput\  \[GreaterEqual] \ 
                  2, \[IndentingNewLine]\(Print["\<  sampleSize = \>", \ \ \
sampleSize, \ "\<   desiredPrecision = \>", \ 
                    desiredPrecision, \ "\<   alphaMD = \>", \ 
                    alphaMD, \ "\<   d = \>", \ d, \ "\< = \>", \ 
                    N[d, \ rho]];\)\[IndentingNewLine]]; \[IndentingNewLine] \
(*\ DwassAltD\ computer\ time\ *) \[IndentingNewLine]formulaIndex\  = \ 
                1; \[IndentingNewLine]formulaName\  = \ 
                formulaNameArray[\([formulaIndex]\)]; \
\[IndentingNewLine]functionOutput\  = \ 
                Timing[DwassAltDKS1SidedOneSampleRTdesiredPrecision[d, 
                    sampleSize, \ 
                    desiredPrecision]]; \
\[IndentingNewLine]rightTailProbabilityDwassAltD\  = \ 
                functionOutput[\([2]\)]; \
\[IndentingNewLine]precisionDwassAltD\  = \ 
                Floor[Precision[
                    rightTailProbabilityDwassAltD]]; \
\[IndentingNewLine]functionTimeString\  = \ 
                functionOutput[\([1]\)]; \[IndentingNewLine]timeString\  = \ 
                functionTimeString\  /. \ 
                  Second \[Rule] 1; \[IndentingNewLine]computerTime\  = \ 
                timeString; \[IndentingNewLine]rTP\  = \ 
                rightTailProbabilityDwassAltD; \[IndentingNewLine]rTPpowerTen\
\  = \ 0; \[IndentingNewLine]Label[AnotherPower]; \[IndentingNewLine]If[
                rTP\  < \ 1, \ rTPpowerTen\  = \ rTPpowerTen\  - \ 1; \ 
                rTP\  = \ N[rTP\ *\ 10, precisionDwassAltD\ ]; \ 
                Goto[AnotherPower]\ \ \ ]; \
\[IndentingNewLine]computerTimeArray[\([sampleSizeIndex, \ formulaIndex, \ 
                    desiredPrecisionIndex, \ alphaMDIndex]\)]\  = \ 
                computerTime; \[IndentingNewLine]WriteString[
                outputFileNumber, \ 
                ToString[\ desiredPrecision, \ 
                  FortranForm], \ \ separatorString, \ 
                ToString[\ alphaMD, \ FortranForm], \ \ separatorString, \ 
                ToString[\ sampleSize, \ FortranForm], \ \ separatorString, \ 
                formulaName, \ \ separatorString, \ 
                ToString[\ 
                    computerTimeArray[\([sampleSizeIndex, \ formulaIndex, \ 
                        desiredPrecisionIndex, \ alphaMDIndex]\)], \ 
                    FortranForm]\ "\<\n\>"]; \[IndentingNewLine]If[
                intermediateOutput\  \[GreaterEqual] \ 
                  3, \[IndentingNewLine]\(Print["\<      DwassAltD: \
formulaNameArray[[\>", \ formulaIndex, \ "\<]] = \>", \ 
                    formulaNameArray[\([formulaIndex]\)]\ , \ "\<   \
rightTailProbabilityDwassAltD = \>", \ \ rightTailProbabilityDwassAltD, \ "\< \
  rTPpowerTen = \>", \ rTPpowerTen, \ "\<   precisionDwassAltD = \>", \ 
                    precisionDwassAltD, \ "\<   computerTime = \>", \ 
                    computerTime];\)\[IndentingNewLine]]; \[IndentingNewLine] \
(*\ DwassD\ computer\ time\ *) \[IndentingNewLine]formulaIndex\  = \ 
                2; \[IndentingNewLine]formulaName\  = \ 
                formulaNameArray[\([formulaIndex]\)]; \
\[IndentingNewLine]functionOutput\  = \ 
                Timing[DwassDKS1SidedOneSampleRTdesiredPrecision[d, 
                    sampleSize, \ 
                    desiredPrecision]]; \
\[IndentingNewLine]rightTailProbabilityDwassD\  = \ 
                functionOutput[\([2]\)]; \[IndentingNewLine]precisionDwassD\  \
= \ Floor[Precision[
                    rightTailProbabilityDwassD]]; \
\[IndentingNewLine]functionTimeString\  = \ 
                functionOutput[\([1]\)]; \[IndentingNewLine]timeString\  = \ 
                functionTimeString\  /. \ 
                  Second \[Rule] 1; \[IndentingNewLine]computerTime\  = \ 
                timeString; \
\[IndentingNewLine]computerTimeArray[\([sampleSizeIndex, \ formulaIndex, \ 
                    desiredPrecisionIndex, \ alphaMDIndex]\)]\  = \ 
                computerTime; \[IndentingNewLine]WriteString[
                outputFileNumber, \ 
                ToString[\ desiredPrecision, \ 
                  FortranForm], \ \ separatorString, \ 
                ToString[\ alphaMD, \ FortranForm], \ \ separatorString, \ 
                ToString[\ sampleSize, \ FortranForm], \ \ separatorString, \ 
                formulaName, \ \ separatorString, \ 
                ToString[\ 
                    computerTimeArray[\([sampleSizeIndex, \ formulaIndex, \ 
                        desiredPrecisionIndex, \ alphaMDIndex]\)], \ 
                    FortranForm]\ "\<\n\>"]; \[IndentingNewLine]If[
                intermediateOutput\  \[GreaterEqual] \ 
                  3, \[IndentingNewLine]\(Print["\<      DwassD: \
formulaNameArray[[\>", \ formulaIndex, \ "\<]] = \>", \ 
                    
                    formulaNameArray[\([formulaIndex]\)]\ , \ "\<   \
rightTailProbabilityDwassD = \>", \ \ rightTailProbabilityDwassD, \ "\<   \
rTPpowerTen = \>", \ rTPpowerTen, \ "\<   precisionDwassD = \>", \ 
                    precisionDwassD, \ "\<   computerTime = \>", \ 
                    computerTime];\)\[IndentingNewLine]]; \[IndentingNewLine] \
(*\ \ \ \ Verify\ if\ rightTailProbabilityDwassAltD\ same\ as\ \
rightTailProbabilityDwassD\ *) \[IndentingNewLine]precisionUsed\  = \ 
                Min[\ precisionDwassAltD, \ 
                  precisionDwassD]; \
\[IndentingNewLine]rightTailProbabilityAbsDifference\  = \ 
                N[\ Abs[
                    rightTailProbabilityDwassAltD\  - \ 
                      rightTailProbabilityDwassD], \ 
                  precisionUsed]; \[IndentingNewLine]powerTenCompare\  = \ \ \
rTPpowerTen\  - \ precisionUsed\  + \ 1; \[IndentingNewLine]If[
                intermediateOutput\  \[GreaterEqual] \ 
                  4, \[IndentingNewLine]\(Print["\<         DwassD verify: \
rightTailProbabilityDwassAltD = \>", \ \ rightTailProbabilityDwassAltD, \ "\< \
  rightTailProbabilityDwassD = \>", \ \ rightTailProbabilityDwassD, \ "\<   \
precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = Min[\>", \ 
                    precisionDwassAltD, "\<,\>", \ 
                    precisionDwassD, \ "\<] = \>", 
                    precisionUsed, \ "\<   rightTailProbabilityAbsDifference \
= \>", \ rightTailProbabilityAbsDifference, \ "\<   rTPpowerTen = \>", \ 
                    rTPpowerTen, \ "\<   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = \>", \ 
                    powerTenCompare];\)\[IndentingNewLine]]; \
\[IndentingNewLine]If[
                rightTailProbabilityAbsDifference\  > \ 
                  10^{powerTenCompare}, \ 
                Print["\<*****ERROR*****:  rightTailProbabilityDwassAltD not \
the same as rightTailProbabilityDwassD.\>"]; \ \[IndentingNewLine]Print["\<   \
      DwassD verify: rightTailProbabilityDwassAltD = \>", \ \ \
rightTailProbabilityDwassAltD, \ "\<   rightTailProbabilityDwassD = \>", \ \ \
rightTailProbabilityDwassD, \ "\<   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassD] = Min[\>", \ precisionDwassAltD, "\<,\>", \ 
                  precisionDwassD, \ "\<] = \>", 
                  precisionUsed, \ "\<   rightTailProbabilityAbsDifference = \
\>", \ rightTailProbabilityAbsDifference, \ "\<   rTPpowerTen = \>", \ 
                  rTPpowerTen, \ "\<   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = \>", \ 
                  powerTenCompare];\[IndentingNewLine]]; \[IndentingNewLine] \
(*\ DwassI\ computer\ time\ *) \[IndentingNewLine]formulaIndex\  = \ 
                3; \[IndentingNewLine]formulaName\  = \ 
                formulaNameArray[\([formulaIndex]\)]; \
\[IndentingNewLine]functionOutput\  = \ 
                Timing[DwassIKS1SidedOneSampleRTdesiredPrecision[d, 
                    sampleSize, \ 
                    desiredPrecision]]; \
\[IndentingNewLine]rightTailProbabilityDwassI\  = \ 
                functionOutput[\([2]\)]; \[IndentingNewLine]precisionDwassI\  \
= \ Floor[Precision[
                    rightTailProbabilityDwassI]]; \
\[IndentingNewLine]functionTimeString\  = \ 
                functionOutput[\([1]\)]; \[IndentingNewLine]timeString\  = \ 
                functionTimeString\  /. \ 
                  Second \[Rule] 1; \[IndentingNewLine]computerTime\  = \ 
                timeString; \
\[IndentingNewLine]computerTimeArray[\([sampleSizeIndex, \ formulaIndex, \ 
                    desiredPrecisionIndex, \ alphaMDIndex]\)]\  = \ 
                computerTime; \[IndentingNewLine]WriteString[
                outputFileNumber, \ 
                ToString[\ desiredPrecision, \ 
                  FortranForm], \ \ separatorString, \ 
                ToString[\ alphaMD, \ FortranForm], \ \ separatorString, \ 
                ToString[\ sampleSize, \ FortranForm], \ \ separatorString, \ 
                formulaName, \ \ separatorString, \ 
                ToString[\ 
                    computerTimeArray[\([sampleSizeIndex, \ formulaIndex, \ 
                        desiredPrecisionIndex, \ alphaMDIndex]\)], \ 
                    FortranForm]\ "\<\n\>"]; \[IndentingNewLine]If[
                intermediateOutput\  \[GreaterEqual] \ 
                  3, \[IndentingNewLine]\(Print["\<      DwassI: \
formulaNameArray[[\>", \ formulaIndex, \ "\<]] = \>", \ 
                    formulaNameArray[\([formulaIndex]\)]\ , \ "\<   \
rightTailProbabilityDwassI = \>", \ \ rightTailProbabilityDwassI, \ "\<   \
rTPpowerTen = \>", \ rTPpowerTen, \ "\<   precisionDwassI = \>", \ 
                    precisionDwassI, \ "\<   computerTime = \>", \ 
                    
                    computerTime];\)\[IndentingNewLine]]; \[IndentingNewLine] \
(*\ \ \ \ Verify\ if\ rightTailProbabilityDwassAltD\ same\ as\ \
rightTailProbabilityDwassI\ *) \[IndentingNewLine]precisionUsed\  = \ 
                Min[\ precisionDwassAltD, \ 
                  precisionDwassI]; \
\[IndentingNewLine]rightTailProbabilityAbsDifference\  = \ 
                N[\ Abs[
                    rightTailProbabilityDwassAltD\  - \ 
                      rightTailProbabilityDwassI], \ 
                  precisionUsed]; \[IndentingNewLine]powerTenCompare\  = \ \ \
rTPpowerTen\  - \ precisionUsed\  + \ 1; \[IndentingNewLine]If[
                intermediateOutput\  \[GreaterEqual] \ 
                  4, \[IndentingNewLine]\(Print["\<         DwassI verify: \
rightTailProbabilityDwassAltD = \>", \ \ rightTailProbabilityDwassAltD, \ "\< \
  rightTailProbabilityDwassI = \>", \ \ rightTailProbabilityDwassI, \ "\<   \
precisionUsed = Min[ precisionDwassAltD, precisionDwassI] = Min[\>", \ 
                    precisionDwassAltD, "\<,\>", \ 
                    precisionDwassI, \ "\<] = \>", 
                    precisionUsed, \ "\<   rightTailProbabilityAbsDifference \
= \>", \ rightTailProbabilityAbsDifference, \ "\<   rTPpowerTen = \>", \ 
                    rTPpowerTen, \ "\<   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = \>", \ 
                    powerTenCompare];\)\[IndentingNewLine]]; \
\[IndentingNewLine]If[
                rightTailProbabilityAbsDifference\  > \ 
                  10^{powerTenCompare}, \ 
                Print["\<*****ERROR*****:  rightTailProbabilityDwassAltD not \
the same as rightTailProbabilityDwassI.\>"]; \ \[IndentingNewLine]Print["\<   \
      DwassI verify: rightTailProbabilityDwassAltD = \>", \ \ \
rightTailProbabilityDwassAltD, \ "\<   rightTailProbabilityDwassI = \>", \ \ \
rightTailProbabilityDwassI, \ "\<   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassI] = Min[\>", \ precisionDwassAltD, "\<,\>", \ 
                  precisionDwassI, \ "\<] = \>", 
                  precisionUsed, \ "\<   rightTailProbabilityAbsDifference = \
\>", \ rightTailProbabilityAbsDifference, \ "\<   rTPpowerTen = \>", \ 
                  rTPpowerTen, \ "\<   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = \>", \ 
                  powerTenCompare];\[IndentingNewLine]]; \[IndentingNewLine] \
(*\ DwassAltI\ computer\ time\ *) \[IndentingNewLine]formulaIndex\  = \ 
                4; \[IndentingNewLine]formulaName\  = \ 
                formulaNameArray[\([formulaIndex]\)]; \
\[IndentingNewLine]functionOutput\  = \ 
                Timing[DwassAltIKS1SidedOneSampleRTdesiredPrecision[d, 
                    sampleSize, \ 
                    desiredPrecision]]; \
\[IndentingNewLine]rightTailProbabilityDwassAltI\  = \ 
                functionOutput[\([2]\)]; \
\[IndentingNewLine]precisionDwassAltI\  = \ 
                Floor[Precision[
                    rightTailProbabilityDwassAltI]]; \
\[IndentingNewLine]functionTimeString\  = \ 
                functionOutput[\([1]\)]; \[IndentingNewLine]timeString\  = \ 
                functionTimeString\  /. \ 
                  Second \[Rule] 1; \[IndentingNewLine]computerTime\  = \ 
                timeString; \
\[IndentingNewLine]computerTimeArray[\([sampleSizeIndex, \ formulaIndex, \ 
                    desiredPrecisionIndex, \ alphaMDIndex]\)]\  = \ 
                computerTime; \[IndentingNewLine]WriteString[
                outputFileNumber, \ 
                ToString[\ desiredPrecision, \ 
                  FortranForm], \ \ separatorString, \ 
                ToString[\ alphaMD, \ FortranForm], \ \ separatorString, \ 
                ToString[\ sampleSize, \ FortranForm], \ \ separatorString, \ 
                formulaName, \ \ separatorString, \ 
                ToString[\ 
                    computerTimeArray[\([sampleSizeIndex, \ formulaIndex, \ 
                        desiredPrecisionIndex, \ alphaMDIndex]\)], \ 
                    FortranForm]\ "\<\n\>"]; \[IndentingNewLine]If[
                intermediateOutput\  \[GreaterEqual] \ 
                  3, \[IndentingNewLine]\(Print["\<      DwassAltI: \
formulaNameArray[[\>", \ formulaIndex, \ "\<]] = \>", \ 
                    formulaNameArray[\([formulaIndex]\)]\ , \ "\<   \
rightTailProbabilityDwassAltI = \>", \ \ rightTailProbabilityDwassAltI, \ "\< \
  rTPpowerTen = \>", \ rTPpowerTen, \ "\<   precisionDwassAltI = \>", \ 
                    precisionDwassAltI, \ "\<   computerTime = \>", \ 
                    computerTime];\)\[IndentingNewLine]]; \[IndentingNewLine] \
(*\ \ \ \ Verify\ if\ rightTailProbabilityDwassAltD\ same\ as\ \
rightTailProbabilityDwassAltI\ *) \[IndentingNewLine]precisionUsed\  = \ 
                Min[\ precisionDwassAltD, \ 
                  precisionDwassAltI]; \
\[IndentingNewLine]rightTailProbabilityAbsDifference\  = \ 
                N[\ Abs[
                    rightTailProbabilityDwassAltD\  - \ 
                      rightTailProbabilityDwassAltI], \ 
                  precisionUsed]; \[IndentingNewLine]powerTenCompare\  = \ \ \
rTPpowerTen\  - \ precisionUsed\  + \ 1; \[IndentingNewLine]If[
                intermediateOutput\  \[GreaterEqual] \ 
                  4, \[IndentingNewLine]\(Print["\<         DwassAltI verify: \
rightTailProbabilityDwassAltD = \>", \ \ rightTailProbabilityDwassAltD, \ "\< \
  rightTailProbabilityDwassAltI = \>", \ \ rightTailProbabilityDwassAltI, \ "\
\<   precisionUsed = Min[ precisionDwassAltD, precisionDwassAltI] = Min[\>", \
\ precisionDwassAltD, "\<,\>", \ precisionDwassAltI, \ "\<] = \>", 
                    precisionUsed, \ "\<   rightTailProbabilityAbsDifference \
= \>", \ rightTailProbabilityAbsDifference, \ "\<   rTPpowerTen = \>", \ 
                    rTPpowerTen, \ "\<   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = \>", \ 
                    powerTenCompare];\)\[IndentingNewLine]]; \
\[IndentingNewLine]If[
                rightTailProbabilityAbsDifference\  > \ 
                  10^{powerTenCompare}, \ 
                Print["\<*****ERROR*****:  rightTailProbabilityDwassAltD not \
the same as rightTailProbabilityDwassAltI.\>"]; \ \
\[IndentingNewLine]Print["\<         DwassAltI verify: \
rightTailProbabilityDwassAltD = \>", \ \ rightTailProbabilityDwassAltD, \ "\< \
  rightTailProbabilityDwassAltI = \>", \ \ rightTailProbabilityDwassAltI, \ "\
\<   precisionUsed = Min[ precisionDwassAltD, precisionDwassAltI] = Min[\>", \
\ precisionDwassAltD, "\<,\>", \ precisionDwassAltI, \ "\<] = \>", 
                  precisionUsed, \ "\<   rightTailProbabilityAbsDifference = \
\>", \ rightTailProbabilityAbsDifference, \ "\<   rTPpowerTen = \>", \ 
                  rTPpowerTen, \ "\<   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = \>", \ 
                  powerTenCompare];\[IndentingNewLine]]; \[IndentingNewLine] \
(*\ Rational\ DwassAltD\ computer\ time\ *) \[IndentingNewLine]formulaIndex\  \
= \ 5; \[IndentingNewLine]formulaName\  = \ 
                formulaNameArray[\([formulaIndex]\)]; \[IndentingNewLine]If[
                desiredPrecisionIndex\  > \ 1.5, \ 
                rightTailProbabilityDwassAltDrational\  = \ 
                  rationalDwassAltDrightTailProbabilityArray[\([\
sampleSizeIndex, \ formulaIndex, \ alphaMDIndex]\)]; \ 
                computerTime\  = \ 
                  computerTimeArray[\([sampleSizeIndex, \ formulaIndex, \ 
                      1, \ alphaMDIndex]\)]; \ 
                computerTimeArray[\([sampleSizeIndex, \ formulaIndex, \ 
                      desiredPrecisionIndex, \ alphaMDIndex]\)]\  = \ 
                  computerTimeArray[\([sampleSizeIndex, \ formulaIndex, \ 
                      1, \ alphaMDIndex]\)]; \ 
                rightTailProbabilityDwassAltDrationalInArbPrecision\ \  = \ \ \
N[rightTailProbabilityDwassAltDrational, \ precisionDwassAltD]; \ \ Goto[
                  RationalDwassAltDrun]\ ]; \[IndentingNewLine]functionOutput\
\  = \ Timing[DwassAltDKS1SidedRTRational[d, 
                    sampleSize]]; \
\[IndentingNewLine]rightTailProbabilityDwassAltDrational\  = \ 
                functionOutput[\([2]\)]; \
\[IndentingNewLine]rightTailProbabilityDwassAltDrationalInArbPrecision\ \  = \
\ \ N[rightTailProbabilityDwassAltDrational, \ 
                  precisionDwassAltD]; \[IndentingNewLine]functionTimeString\ \
 = \ functionOutput[\([1]\)]; \[IndentingNewLine]timeString\  = \ 
                functionTimeString\  /. \ 
                  Second \[Rule] 1; \[IndentingNewLine]computerTime\  = \ 
                timeString; \
\[IndentingNewLine]computerTimeArray[\([sampleSizeIndex, \ formulaIndex, \ 
                    desiredPrecisionIndex, \ alphaMDIndex]\)]\  = \ 
                computerTime; \
\[IndentingNewLine]rationalDwassAltDrightTailProbabilityArray[\([\
sampleSizeIndex, \ formulaIndex, \ alphaMDIndex]\)]\  = \ 
                rightTailProbabilityDwassAltDrational; \
\[IndentingNewLine]Label[
                RationalDwassAltDrun]; \[IndentingNewLine]WriteString[
                outputFileNumber, \ 
                ToString[\ desiredPrecision, \ 
                  FortranForm], \ \ separatorString, \ 
                ToString[\ alphaMD, \ FortranForm], \ \ separatorString, \ 
                ToString[\ sampleSize, \ FortranForm], \ \ separatorString, \ 
                formulaName, \ \ separatorString, \ 
                ToString[\ computerTime, \ 
                    FortranForm]\ "\<\n\>"]; \[IndentingNewLine]If[
                intermediateOutput\  \[GreaterEqual] \ 
                  3, \[IndentingNewLine]\(Print["\<      Rational DwassAltD: \
formulaNameArray[[\>", \ formulaIndex, \ "\<]] = \>", \ 
                    formulaNameArray[\([formulaIndex]\)]\ , \ "\<   \
rightTailProbabilityDwassAltDrationalInArbPrecision = \>", \ \ \
rightTailProbabilityDwassAltDrationalInArbPrecision, \ "\<   rTPpowerTen = \
\>", \ rTPpowerTen, \ "\<   precisionDwassD = \>", \ 
                    precisionDwassD, \ "\<   computerTime = \>", \ 
                    computerTime];\)\[IndentingNewLine]]; \[IndentingNewLine] \
(*\ \ \ \ Verify\ if\ rightTailProbabilityDwassAltD\ same\ as\ \
rightTailProbabilityDwassAltDrationalInArbPrecision\ \
*) \[IndentingNewLine]precisionUsed\  = \ 
                precisionDwassAltD; \
\[IndentingNewLine]rightTailProbabilityAbsDifference\  = \ 
                N[\ Abs[
                    rightTailProbabilityDwassAltD\  - \ 
                      rightTailProbabilityDwassAltDrationalInArbPrecision], \ 
                  precisionUsed]; \[IndentingNewLine]powerTenCompare\  = \ \ \
rTPpowerTen\  - \ precisionUsed\  + \ 1; \[IndentingNewLine]If[
                intermediateOutput\  \[GreaterEqual] \ 
                  4, \[IndentingNewLine]\(Print["\<         DwassD verify: \
rightTailProbabilityDwassAltD = \>", \ \ rightTailProbabilityDwassAltD, \ "\< \
  rightTailProbabilityDwassAltDrationalInArbPrecision = \>", \ \ \
rightTailProbabilityDwassAltDrationalInArbPrecision, \ "\<   precisionUsed = \
Min[ precisionDwassAltD, precisionDwassD] = Min[\>", \ 
                    precisionDwassAltD, "\<,\>", \ 
                    precisionDwassD, \ "\<] = \>", 
                    precisionUsed, \ "\<   rightTailProbabilityAbsDifference \
= \>", \ rightTailProbabilityAbsDifference, \ "\<   rTPpowerTen = \>", \ 
                    rTPpowerTen, \ "\<   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = \>", \ 
                    powerTenCompare];\)\[IndentingNewLine]]; \
\[IndentingNewLine]If[
                rightTailProbabilityAbsDifference\  > \ 
                  10^{powerTenCompare}, \ 
                Print["\<*****ERROR*****:  rightTailProbabilityDwassAltD not \
the same as rightTailProbabilityDwassAltDrationalInArbPrecision.\>"]; \ \
\[IndentingNewLine]Print["\<         DwassD verify: \
rightTailProbabilityDwassAltD = \>", \ \ rightTailProbabilityDwassAltD, \ "\< \
  rightTailProbabilityDwassAltDrationalInArbPrecision = \>", \ \ \
rightTailProbabilityDwassAltDrationalInArbPrecision, \ "\<   precisionUsed = \
Min[ precisionDwassAltD, precisionDwassD] = Min[\>", \ 
                  precisionDwassAltD, "\<,\>", \ 
                  precisionDwassD, \ "\<] = \>", 
                  precisionUsed, \ "\<   rightTailProbabilityAbsDifference = \
\>", \ rightTailProbabilityAbsDifference, \ "\<   rTPpowerTen = \>", \ 
                  rTPpowerTen, \ "\<   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = \>", \ 
                  powerTenCompare];\[IndentingNewLine]];\[IndentingNewLine], \
{alphaMDIndex, \ 1, \ \ numberalphaMDs, \ 
                1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 1, \ 
              numberDesiredPrecisions, \ 
              1}];\[IndentingNewLine], {sampleSizeIndex, \ 1, \ 
            numberSampleSizes, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\n\n\>"\ ]; \[IndentingNewLine] (*\ 
          Computer\ time\ by\ desiredPrecision\ by\ alphaMD\ \
*) \[IndentingNewLine]WriteString[outputFileNumber, \ 
          separatorString, \ \ separatorString, \ "\<Computer Time\>"]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
              outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{stringIndex, \ 1, \ numberDesiredPrecisionsAndalphaMDs\ \ , \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Sample\>", \ \ separatorString]; \
\[IndentingNewLine]Do[\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ separatorString, \ "\<Desired Precision dp \
= \>", \ ToString[\ desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)], \ 
              FortranForm]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{\ alphaMDIndex, \ 1\ , \ numberalphaMDs\  - \ 1, \ 
              1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 
            1, \ \ numberDesiredPrecisions, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Size\>", \ \ separatorString]; \
\[IndentingNewLine]Do[\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ \ separatorString, \ "\<alphaMD\>"]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{\ alphaMDIndex, \ 1\ , \ numberalphaMDs\  - \ 1, \ 
              1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 
            1, \ \ numberDesiredPrecisions, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<n\>", \ 
          separatorString, \ "\<Formula\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]\(WriteString[
                  outputFileNumber, \ \ separatorString, \ 
                  ToString[\ alphaMDVectorIn[\([alphaMDIndex]\)], \ 
                    FortranForm]];\)\[IndentingNewLine], {\ alphaMDIndex, \ 
                1\ , \ numberalphaMDs, \ 
                1}];\)\[IndentingNewLine], {desiredPrecisionIndex, \ 
            1, \ \ numberDesiredPrecisions, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]sampleSize\  = \ 
                sampleSizeVectorIn[\([sampleSizeIndex]\)]; \
\[IndentingNewLine]If\ [formulaIndex\  < \ 1.5, 
                WriteString[outputFileNumber, \ 
                  ToString[\ sampleSize, \ FortranForm], \ separatorString, \ 
                  formulaNameArray[\([formulaIndex]\)]], \ 
                WriteString[outputFileNumber, \ separatorString, \ 
                  formulaNameArray[\([formulaIndex]\)]]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]desiredPrecision\  = \ 
                  desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)]; \
\[IndentingNewLine]Do[\[IndentingNewLine]alphaMD\  = \ \ \
alphaMDVectorIn[\([alphaMDIndex]\)]; \[IndentingNewLine]WriteString[
                    outputFileNumber, \ \ separatorString, \ 
                    ToString[\ 
                      computerTimeArray[\([sampleSizeIndex, \ formulaIndex, \ 
                          desiredPrecisionIndex, \ alphaMDIndex]\)], \ 
                      FortranForm]];\[IndentingNewLine], {alphaMDIndex, \ 
                    1, \ \ numberalphaMDs, \ 
                    1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 1, \ 
                  numberDesiredPrecisions, \ 
                  1}]; \[IndentingNewLine]WriteString[
                outputFileNumber, \ "\<\n\>"\ ];\[IndentingNewLine], \ \
{formulaIndex, \ 1, \ \ numberFormulae, \ 
                1}];\)\[IndentingNewLine], {sampleSizeIndex, \ 1, \ 
            numberSampleSizes, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\n\n\>"\ ]; \[IndentingNewLine] (*\ 
          Computer\ time\ by\ alphaMD\ by\ desiredPrecision\ \
*) \[IndentingNewLine]WriteString[outputFileNumber, \ 
          separatorString, \ \ separatorString, \ "\<Computer Time\>"]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
              outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{stringIndex, \ 1, \ numberDesiredPrecisionsAndalphaMDs\ \ , \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Sample\>", \ \ separatorString]; \
\[IndentingNewLine]Do[\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ separatorString, \ "\<alphaMD = \>", \ 
            ToString[\ alphaMDVectorIn[\([alphaMDIndex]\)], \ 
              FortranForm]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ \ numberDesiredPrecisions\  - \ 1, \ 
              1}];\[IndentingNewLine], {\ alphaMDIndex, \ 1\ , \ 
            numberalphaMDs, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Size\>", \ \ separatorString]; \
\[IndentingNewLine]Do[\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ \ separatorString, \ "\<Desired Precision \
dp\>"]; \[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ \ numberDesiredPrecisions\  - \ 1, \ 
              1}];\[IndentingNewLine], {\ alphaMDIndex, \ 1\ , \ 
            numberalphaMDs, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<n\>", \ 
          separatorString, \ "\<Formula\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]\(WriteString[
                  outputFileNumber, \ \ separatorString, \ 
                  ToString[\ 
                    desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)], \ 
                    FortranForm]];\)\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ \ numberDesiredPrecisions, \ 
                1}];\)\[IndentingNewLine], {\ alphaMDIndex, \ 1\ , \ 
            numberalphaMDs, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]sampleSize\  = \ 
                sampleSizeVectorIn[\([sampleSizeIndex]\)]; \
\[IndentingNewLine]If\ [formulaIndex\  < \ 1.5, 
                WriteString[outputFileNumber, \ 
                  ToString[\ sampleSize, \ FortranForm], \ separatorString, \ 
                  formulaNameArray[\([formulaIndex]\)]], \ 
                WriteString[outputFileNumber, \ separatorString, \ 
                  formulaNameArray[\([formulaIndex]\)]]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]alphaMD\  = \ \ \
alphaMDVectorIn[\([alphaMDIndex]\)]; \
\[IndentingNewLine]Do[\[IndentingNewLine]desiredPrecision\  = \ 
                    desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)]; \
\[IndentingNewLine]WriteString[outputFileNumber, \ \ separatorString, \ 
                    ToString[\ 
                      computerTimeArray[\([sampleSizeIndex, \ formulaIndex, \ 
                          desiredPrecisionIndex, \ alphaMDIndex]\)], \ 
                      FortranForm]];\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ numberDesiredPrecisions, \ 
                    1}];\[IndentingNewLine], {alphaMDIndex, \ 
                  1, \ \ numberalphaMDs, \ 
                  1}]; \[IndentingNewLine]WriteString[
                outputFileNumber, \ "\<\n\>"\ ];\[IndentingNewLine], \ \
{formulaIndex, \ 1, \ \ numberFormulae, \ 
                1}];\)\[IndentingNewLine], {sampleSizeIndex, \ 1, \ 
            numberSampleSizes, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\n\n\>"\ ]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]Close[
          outputFileNumber]; \[IndentingNewLine]computerTimeArray\
\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(KS1SidedOneSampleTestStatisticByMaagDicaire[alphaIn_, sampleSizeIn_, \ 
        rho_]\  := \[IndentingNewLine]Module[{d, \ alpha, \ 
          sampleSize}, \[IndentingNewLine] (*\ 
          For\ the\ KS\ 1\ sided\ one\ sample\ test, \ 
          the\ Maag\ and\ Dicaire\ formula\ is\ used\ *) \[IndentingNewLine] \
(*\ \ \ \ to\ approximate\ the\ test\ statistic\ corresponding\ to\ a\ right\ \
tail\ *) \[IndentingNewLine] (*\ \ \ \ probability\ of\ alphaIn . \ \ The\ \
test\ statistic\ d\ is\ calculated\ to\ *) \[IndentingNewLine] (*\ \ \ \ rho\ \
number\ of\ decimal\ \(\(digits\)\(.\)\)\ *) \[IndentingNewLine]alpha\  = 
          Rationalize[alphaIn, \ 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine] (*\ 
          Use\ Maag\ and\ Dicaire\ \(\(MD\)\(.\)\)\ *) \[IndentingNewLine]d\  \
= \ N[Sqrt[Log[alpha]/\((\(-2\)*sampleSize)\)] - \ \((1/\((6*
                      sampleSize)\))\), 
            rho\ \  + \ 17]; \[IndentingNewLine]d\  = \ 
          N[d, rho]; \[IndentingNewLine]d\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassAltDKS1SidedOneSampleRTdesiredPrecision[dIn_, sampleSizeIn_, \ 
        desiredPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ desiredPrecision, \ internalPrecision, \ j, \ 
          jLowLimit, \ term, \ leftTailProbability, \ rightTailProbability, \ 
          binomialCoefficient, \ secondTerm, \ thirdTerm, \ sumTerms, \ 
          numberIterations, \ alphaPredict, \ 
          resultPrecision}, \[IndentingNewLine] (*\ 
          DwassAltD\ formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ sample\ \
*) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ to\ desiredPrecisionIn\ digits\ of\ *) \[IndentingNewLine] \
(*\ \ \ \ precision\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine]d = 
          Rationalize[dIn, \ 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]desiredPrecision\  = \ 
          Ceiling[desiredPrecisionIn]; \[IndentingNewLine] (*\ 
          Maag\ and\ Dicaire\ approximation\ \
*) \[IndentingNewLine]alphaPredict\  = \ 
          Exp[\(-2\)\ *\ d^2\ *\ 
                sampleSize\  - \ \((2\ *
                  d\ /\ 3)\)\  - \ \((1/\((18\ *\ 
                      sampleSize)\))\)]; \[IndentingNewLine]internalPrecision\
\  = \ Ceiling[
              3\  + \ \((4.84\  + \ 1.033\ *\ Sqrt[sampleSize])\)\ *\ \((\ 
                    0.611\  - \ 0.0904*\ alphaPredict\  - \ 
                      0.357\ *\ alphaPredict^\((1/3)\)\  - \ 
                      0.0998\ *\ alphaPredict^4\  - \ 
                      0.0616\ *\ Log[alphaPredict])\)]\  + \ 
            desiredPrecision; \[IndentingNewLine]numberIterations\  = \ 
          0; \[IndentingNewLine]Label[
          AnotherIteration]; \[IndentingNewLine]numberIterations\  = \ 
          numberIterations\  + \ 
            1; \[IndentingNewLine]rightTailProbability\ \  = \ 
          DwassAltDKS1SidedOneSampleRTArbPrecision[d, sampleSize, 
            internalPrecision]; \[IndentingNewLine]resultPrecision\  = \ 
          Precision[rightTailProbability]; \[IndentingNewLine]If[
          resultPrecision\  < \ 
            desiredPrecision, \[IndentingNewLine]internalPrecision\  = \ 
            internalPrecision\  + \ desiredPrecision; \[IndentingNewLine]Goto[
            AnotherIteration];\[IndentingNewLine]]; \
\[IndentingNewLine]rightTailProbability\ \[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassAltDKS1SidedOneSampleRTArbPrecision[dIn_, sampleSizeIn_, \ 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ 
          rightTailProbability, \ binomialCoefficient, \ secondTerm, \ 
          thirdTerm, \ sumTerms}, \[IndentingNewLine] (*\ 
          Dwass\ Alternate\ Direct\ formula\ to\ calculate\ the\ KS\ 1\ Sided\
\ one\ *) \[IndentingNewLine] (*\ \ \ \ sample\ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ arithmetic\ *) \[IndentingNewLine] (*\ \ \ \ with\ an\ internal\ \
precision\ of\ \(\(internalPrecisionIn\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ 
              d]; \[IndentingNewLine]binomialCoefficient\  = \ 
          1; \[IndentingNewLine]secondTerm\ \  = \ 
          N[sampleSize\  + \ d\ *\ sampleSize, \ 
            internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ \(-d\)\ *\ 
            sampleSize; \[IndentingNewLine]sumTerms\  = \ 
          N[secondTerm^\((sampleSize - 1)\), \ 
            internalPrecision]; \[IndentingNewLine]If[jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]binomialCoefficient\  = \ 
            N[binomialCoefficient\ *\ \((sampleSize\  - \ j\  + \ 1)\)/\ 
                  j\ , \ internalPrecision]; \[IndentingNewLine]secondTerm\  \
= \ N[secondTerm\  - \ 1\ , 
              internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ 
            N[thirdTerm\  + \ 1\ , 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + \((binomialCoefficient\ *\ 
                    secondTerm^\((sampleSize\  - \ j\  - \ 1)\)\ *\ 
                    thirdTerm^j)\), \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1\  - \ \((d\ *\ 
                  sumTerms/sampleSize^\((sampleSize\  - \ 1)\))\), \ 
            internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassDKS1SidedOneSampleRTdesiredPrecision[dIn_, sampleSizeIn_, \ 
        desiredPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ desiredPrecision, \ internalPrecision, \ j, \ 
          jLowLimit, \ term, \ leftTailProbability, \ rightTailProbability, \ 
          binomialCoefficient, \ secondTerm, \ thirdTerm, \ sumTerms, \ 
          numberIterations, \ alphaPredict, \ 
          resultPrecision}, \[IndentingNewLine] (*\ 
          DwassD\ formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ sample\ \
*) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ to\ desiredPrecisionIn\ digits\ of\ *) \[IndentingNewLine] \
(*\ \ \ \ precision\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine]d = 
          Rationalize[dIn, \ 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]desiredPrecision\  = \ 
          Ceiling[desiredPrecisionIn]; \[IndentingNewLine] (*\ 
          Maag\ and\ Dicaire\ approximation\ \
*) \[IndentingNewLine]alphaPredict\  = \ 
          Exp[\(-2\)\ *\ d^2\ *\ 
                sampleSize\  - \ \((2\ *
                  d\ /\ 3)\)\  - \ \((1/\((18\ *\ 
                      sampleSize)\))\)]; \[IndentingNewLine]internalPrecision\
\  = \ Ceiling[
              3\  + \ \((4.84\  + \ 1.033\ *\ Sqrt[sampleSize])\)\ *\ \((\ 
                    0.611\  - \ 0.0904*\ alphaPredict\  - \ 
                      0.357\ *\ alphaPredict^\((1/3)\)\  - \ 
                      0.0998\ *\ alphaPredict^4\  - \ 
                      0.0616\ *\ Log[alphaPredict])\)]\  + \ 
            desiredPrecision; \[IndentingNewLine]numberIterations\  = \ 
          0; \[IndentingNewLine]Label[
          AnotherIteration]; \[IndentingNewLine]numberIterations\  = \ 
          numberIterations\  + \ 
            1; \[IndentingNewLine]rightTailProbability\ \  = \ 
          DwassDKS1SidedOneSampleRTArbPrecision[d, sampleSize, 
            internalPrecision]; \[IndentingNewLine]resultPrecision\  = \ 
          Precision[rightTailProbability]; \[IndentingNewLine]If[
          resultPrecision\  < \ 
            desiredPrecision, \[IndentingNewLine]internalPrecision\  = \ 
            internalPrecision\  + \ desiredPrecision; \[IndentingNewLine]Goto[
            AnotherIteration];\[IndentingNewLine]]; \
\[IndentingNewLine]rightTailProbability\ \[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassDKS1SidedOneSampleRTArbPrecision[dIn_, sampleSizeIn_, 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ 
          rightTailProbability, \ binomialCoefficient, \ secondTerm, \ 
          thirdTerm, \ sumTerms}, \[IndentingNewLine] (*\ 
          Dwass\ Direct\ formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ \
sample\ *) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ 
              d]; \[IndentingNewLine]binomialCoefficient\  = \ 
          1; \[IndentingNewLine]secondTerm\ \  = \ 
          N[1\  + \ d, \ 
            internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ \(-d\); \
\[IndentingNewLine]sumTerms\  = \ 
          N[secondTerm^\((sampleSize - 1)\), \ 
            internalPrecision]; \[IndentingNewLine]If[jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]binomialCoefficient\  = \ 
            N[binomialCoefficient\ *\ \((sampleSize\  - \ j\  + \ 1)\)/\ 
                  j\ , \ internalPrecision]; \[IndentingNewLine]secondTerm\  \
= \ N[secondTerm\  - \ \((1/sampleSize)\)\ , 
              internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ 
            N[thirdTerm\  + \ \((1/sampleSize)\)\ , 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + \((binomialCoefficient\ *\ 
                    secondTerm^\((sampleSize\  - \ j\  - \ 1)\)\ *\ 
                    thirdTerm^j)\), \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1\  - \ \((d\ *\ sumTerms)\), \ 
            internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassIKS1SidedOneSampleRTdesiredPrecision[dIn_, sampleSizeIn_, \ 
        desiredPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ desiredPrecision, \ internalPrecision, \ j, \ 
          jLowLimit, \ term, \ leftTailProbability, \ rightTailProbability, \ 
          binomialCoefficient, \ secondTerm, \ thirdTerm, \ sumTerms, \ 
          numberIterations, \ alphaPredict, \ 
          resultPrecision}, \[IndentingNewLine] (*\ 
          DwassI\ formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ sample\ \
*) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ to\ desiredPrecisionIn\ digits\ of\ *) \[IndentingNewLine] \
(*\ \ \ \ precision\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine]d = 
          Rationalize[dIn, \ 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]desiredPrecision\  = \ 
          Ceiling[desiredPrecisionIn]; \[IndentingNewLine] (*\ 
          Maag\ and\ Dicaire\ approximation\ \
*) \[IndentingNewLine]alphaPredict\  = \ 
          Exp[\(-2\)\ *\ d^2\ *\ 
                sampleSize\  - \ \((2\ *
                  d\ /\ 3)\)\  - \ \((1/\((18\ *\ 
                      sampleSize)\))\)]; \[IndentingNewLine]internalPrecision\
\  = \ Ceiling[
              5\  + \ \((2.986\  + \ 1.032\ *\ Sqrt[sampleSize])\)\ *\ \((\ 
                    0.6875\  - \ 0.1433*\ alphaPredict\  - \ 
                      0.399\ *\ alphaPredict^\((1/4)\)\  + \ 
                      0.04703\ *\ alphaPredict^3\  - \ 
                      0.1323\ *\ alphaPredict^4\  - \ 
                      0.0556\ *\ Log[alphaPredict])\)]\  + \ 
            desiredPrecision; \[IndentingNewLine]numberIterations\  = \ 
          0; \[IndentingNewLine]Label[
          AnotherIteration]; \[IndentingNewLine]numberIterations\  = \ 
          numberIterations\  + \ 
            1; \[IndentingNewLine]rightTailProbability\ \  = \ 
          DwassIKS1SidedOneSampleRTArbPrecision[d, sampleSize, 
            internalPrecision]; \[IndentingNewLine]resultPrecision\  = \ 
          Precision[rightTailProbability]; \[IndentingNewLine]If[
          resultPrecision\  < \ 
            desiredPrecision, \[IndentingNewLine]internalPrecision\  = \ 
            internalPrecision\  + \ desiredPrecision; \[IndentingNewLine]Goto[
            AnotherIteration];\[IndentingNewLine]]; \
\[IndentingNewLine]rightTailProbability\ \[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassIKS1SidedOneSampleRTArbPrecision[dIn_, sampleSizeIn_, \ 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ term, \ 
          leftTailProbability, \ rightTailProbability, \ sumTerms, \ 
          NminusjMinusOne, \ NminusjPlusOne, \ dN, \ jMinusdN, \ 
          nMINUSjPlusOnePLUSdn, \ jMINUSdnMinusOne}, \[IndentingNewLine] (*\ 
          Dwass\ Iterative\ formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ \
sample\ *) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ d]; \[IndentingNewLine]sumTerms\  = \ 
          N[\ d\ *\ \((1\  + \ d)\)^\((sampleSize - 1)\), \ 
            internalPrecision]; \[IndentingNewLine]term\  = \ 
          sumTerms; \[IndentingNewLine]NminusjMinusOne\  = \ 
          N[sampleSize\  - \ 1, \ 
            internalPrecision]; \[IndentingNewLine]NminusjPlusOne\  = \ 
          N[sampleSize\  + \ 1, \ 
            internalPrecision]; \[IndentingNewLine]dN\  = \ 
          N[d\ *\ sampleSize, \ 
            internalPrecision]; \[IndentingNewLine]jHighLimit\  = \ 
          Floor[dN]; \[IndentingNewLine]jMinusdN\  = \ \(-\ 
            dN\); \[IndentingNewLine]nMINUSjPlusOnePLUSdn\  = \ 
          N[\ sampleSize\  + \ 1\  + \ dN, \ 
            internalPrecision]; \[IndentingNewLine]jMINUSdnMinusOne\  = \ 
          N[\(-\ dN\)\  - \ 1, \ internalPrecision]; \[IndentingNewLine]If[
          jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]NminusjMinusOne\  = \ 
            N[NminusjMinusOne\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]NminusjPlusOne\  = \ 
            N[NminusjPlusOne\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]jMinusdN\  = \ 
            N[jMinusdN\  + \ 1\ , \ 
              internalPrecision]; \[IndentingNewLine]nMINUSjPlusOnePLUSdn\  = \
\ N[\ nMINUSjPlusOnePLUSdn\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]jMINUSdnMinusOne\  = \ 
            N[jMINUSdnMinusOne\  + \ 1, \ 
              internalPrecision]; \[IndentingNewLine]term\  = \ 
            N[\ \((\((NminusjPlusOne\ *\ jMinusdN)\)/\((j\ *\ 
                        nMINUSjPlusOnePLUSdn)\))\)*\ \((1\  - \ \((1/
                          nMINUSjPlusOnePLUSdn)\))\)^
                  NminusjMinusOne\ *\ \((1\  + \ \((1/
                          jMINUSdnMinusOne)\))\)^\((j - 1)\)*term, \ 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + term, \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1 - sumTerms, \ internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassAltIKS1SidedOneSampleRTdesiredPrecision[dIn_, sampleSizeIn_, \ 
        desiredPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ desiredPrecision, \ internalPrecision, \ j, \ 
          jLowLimit, \ term, \ leftTailProbability, \ rightTailProbability, \ 
          binomialCoefficient, \ secondTerm, \ thirdTerm, \ sumTerms, \ 
          numberIterations, \ alphaPredict, \ 
          resultPrecision}, \[IndentingNewLine] (*\ 
          DwassAltI\ formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ sample\ \
*) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ to\ desiredPrecisionIn\ digits\ of\ *) \[IndentingNewLine] \
(*\ \ \ \ precision\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine]d = 
          Rationalize[dIn, \ 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]desiredPrecision\  = \ 
          Ceiling[desiredPrecisionIn]; \[IndentingNewLine] (*\ 
          Maag\ and\ Dicaire\ approximation\ \
*) \[IndentingNewLine]alphaPredict\  = \ 
          Exp[\(-2\)\ *\ d^2\ *\ 
                sampleSize\  - \ \((2\ *
                  d\ /\ 3)\)\  - \ \((1/\((18\ *\ 
                      sampleSize)\))\)]; \[IndentingNewLine]internalPrecision\
\  = \ Ceiling[
              5\  + \ \((2.986\  + \ 1.032\ *\ Sqrt[sampleSize])\)\ *\ \((\ 
                    0.6875\  - \ 0.1433*\ alphaPredict\  - \ 
                      0.399\ *\ alphaPredict^\((1/4)\)\  + \ 
                      0.04703\ *\ alphaPredict^3\  - \ 
                      0.1323\ *\ alphaPredict^4\  - \ 
                      0.0556\ *\ Log[alphaPredict])\)]\  + \ 
            desiredPrecision; \[IndentingNewLine]numberIterations\  = \ 
          0; \[IndentingNewLine]Label[
          AnotherIteration]; \[IndentingNewLine]numberIterations\  = \ 
          numberIterations\  + \ 
            1; \[IndentingNewLine]rightTailProbability\ \  = \ 
          DwassAltIKS1SidedOneSampleRTArbPrecision[d, sampleSize, 
            internalPrecision]; \[IndentingNewLine]resultPrecision\  = \ 
          Precision[rightTailProbability]; \[IndentingNewLine]If[
          resultPrecision\  < \ 
            desiredPrecision, \[IndentingNewLine]internalPrecision\  = \ 
            internalPrecision\  + \ desiredPrecision; \[IndentingNewLine]Goto[
            AnotherIteration];\[IndentingNewLine]]; \
\[IndentingNewLine]rightTailProbability\ \[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassAltIKS1SidedOneSampleRTArbPrecision[dIn_, sampleSizeIn_, \ 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ term, \ 
          leftTailProbability, \ rightTailProbability, \ sumTerms, \ 
          NminusjMinusOne, \ NminusjPlusOne, \ dN, \ jMinusdN, \ 
          nMINUSjPlusOnePLUSdn, \ jMINUSdnMinusOne}, \[IndentingNewLine] (*\ 
          Dwass\ Alternate\ Iterative\ formula\ to\ calculate\ the\ KS\ 1\ \
Sided\ one\ *) \[IndentingNewLine] (*\ \ \ \ sample\ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ d]; \[IndentingNewLine]sumTerms\  = \ 
          N[\ d\ *\ \((sampleSize\  + \ d*sampleSize)\)^\((sampleSize - 
                    1)\), \ internalPrecision]; \[IndentingNewLine]term\  = \ 
          sumTerms; \[IndentingNewLine]NminusjMinusOne\  = \ 
          N[sampleSize\  - \ 1, \ 
            internalPrecision]; \[IndentingNewLine]NminusjPlusOne\  = \ 
          N[sampleSize\  + \ 1, \ 
            internalPrecision]; \[IndentingNewLine]dN\  = \ 
          N[d\ *\ sampleSize, \ 
            internalPrecision]; \[IndentingNewLine]jHighLimit\  = \ 
          Floor[dN]; \[IndentingNewLine]jMinusdN\  = \ \(-\ 
            dN\); \[IndentingNewLine]nMINUSjPlusOnePLUSdn\  = \ 
          N[\ sampleSize\  + \ 1\  + \ dN, \ 
            internalPrecision]; \[IndentingNewLine]jMINUSdnMinusOne\  = \ 
          N[\(-\ dN\)\  - \ 1, \ internalPrecision]; \[IndentingNewLine]If[
          jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]NminusjMinusOne\  = \ 
            N[NminusjMinusOne\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]NminusjPlusOne\  = \ 
            N[NminusjPlusOne\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]jMinusdN\  = \ 
            N[jMinusdN\  + \ 1\ , \ 
              internalPrecision]; \[IndentingNewLine]nMINUSjPlusOnePLUSdn\  = \
\ N[\ nMINUSjPlusOnePLUSdn\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]jMINUSdnMinusOne\  = \ 
            N[jMINUSdnMinusOne\  + \ 1, \ 
              internalPrecision]; \[IndentingNewLine]term\  = \ 
            N[\ \((\((NminusjPlusOne\ *\ jMinusdN)\)/\((j\ *\ 
                        nMINUSjPlusOnePLUSdn)\))\)*\ \((1\  - \ \((1/
                          nMINUSjPlusOnePLUSdn)\))\)^
                  NminusjMinusOne\ *\ \((1\  + \ \((1/
                          jMINUSdnMinusOne)\))\)^\((j - 1)\)*term, \ 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + term, \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1 - \((sumTerms/sampleSize^\((sampleSize\  - \ 1)\))\), \ 
            internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassAltDKS1SidedRTRational[dIn_, 
        sampleSizeIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ sampleSize, \ 
          j, \ jHighLimit, \ rightTailProbability, \ binomialCoefficient, \ 
          secondTerm, \ thirdTerm, \ sumTerms}, \[IndentingNewLine] (*\ 
          Dwass\ Alternate\ Direct\ formula\ to\ calculate\ the\ KS\ 1\ Sided\
\ one\ sample\ *) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ rational\ \
\(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ \ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ 
              d]; \[IndentingNewLine]binomialCoefficient\  = \ 
          1; \[IndentingNewLine]secondTerm\ \  = \ 
          Rationalize[sampleSize\  + \ d\ *\ sampleSize, \ 
            0]; \[IndentingNewLine]thirdTerm\  = \ \(-d\)\ *\ 
            sampleSize; \[IndentingNewLine]sumTerms\  = \ 
          Rationalize[secondTerm^\((sampleSize - 1)\), \ 
            0]; \[IndentingNewLine]If[jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]binomialCoefficient\  = \ 
            Rationalize[
              binomialCoefficient\ *\ \((sampleSize\  - \ j\  + \ 1)\)/\ 
                  j\ , \ 0]; \[IndentingNewLine]secondTerm\  = \ 
            Rationalize[secondTerm\  - \ 1\ , 
              0]; \[IndentingNewLine]thirdTerm\  = \ 
            Rationalize[thirdTerm\  + \ 1\ , 
              0]; \[IndentingNewLine]sumTerms\  = \ 
            Rationalize[
              sumTerms\  + \((binomialCoefficient\ *\ 
                    secondTerm^\((sampleSize\  - \ j\  - \ 1)\)\ *\ 
                    thirdTerm^j)\), \ 0];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          Rationalize[
            1\  - \ \((d\ *\ 
                  sumTerms/sampleSize^\((sampleSize\  - \ 1)\))\), \ 
            0]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
22.1  Dwass Arb Precision and Rational Timing To File Sample Intermediate \
Output\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DwassArbPrecisionRationalTimingsToFile[{5000, \ 10000}, \ {20, \ 
        100}, \ {0.001, \ 0.9}, \ 
      4, \ "\<C:/KSoutput/\
KS1SidedOneSampleDwassArbPrecisionRationalTimingsTest.csv\>", \ 
      0, \ "\<,\>", \ 3]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("DwassArbPrecisionRationalTimingsToFile:  For "\
\[InvisibleSpace]2\[InvisibleSpace]" sampleSizes "\[InvisibleSpace]{5000, 
            10000}\[InvisibleSpace]"; "\[InvisibleSpace]2\[InvisibleSpace]" \
desiredPrecisions "\[InvisibleSpace]{20, 
            100}\[InvisibleSpace]"; "\[InvisibleSpace]2\[InvisibleSpace]" \
alphaMDs "\[InvisibleSpace]{0.001`, 
            0.9`}\[InvisibleSpace]"; and \
"\[InvisibleSpace]5\[InvisibleSpace]" formulae \
"\[InvisibleSpace]{"DwassAltD", "DwassD", "DwassI", "DwassAltI", 
            "Rational DwassAltD"}\[InvisibleSpace]", outputFileName = "\
\[InvisibleSpace]"C:/KSoutput/\
KS1SidedOneSampleDwassArbPrecisionRationalTimingsTest.csv"\[InvisibleSpace]", \
howToOpenFile = "\[InvisibleSpace]0\[InvisibleSpace]", and separatorString = \
'"\[InvisibleSpace]","\[InvisibleSpace]"'"\[InvisibleSpace]"   \
intermediateOutput = "\[InvisibleSpace]4\[InvisibleSpace]"   rho = "\
\[InvisibleSpace]3\),
        SequenceForm[ 
        "DwassArbPrecisionRationalTimingsToFile:  For ", 2, " sampleSizes ", {
          5000, 10000}, "; ", 2, " desiredPrecisions ", {20, 100}, "; ", 2, 
          " alphaMDs ", {.001, .90000000000000002}, "; and ", 5, 
          " formulae ", {"DwassAltD", "DwassD", "DwassI", "DwassAltI", 
          "Rational DwassAltD"}, ", outputFileName = ", 
          "C:/KSoutput/KS1SidedOneSampleDwassArbPrecisionRationalTimingsTest.\
csv", ", howToOpenFile = ", 0, ", and separatorString = '", ",", "'", 
          "   intermediateOutput = ", 4, "   rho = ", 3],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("  sampleSize = "\[InvisibleSpace]5000\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   alphaMD = "\[InvisibleSpace]0.001`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]10\/381\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0262467191601049869`2.9999999999999996\),
        SequenceForm[ 
        "  sampleSize = ", 5000, "   desiredPrecision = ", 20, 
          "   alphaMD = ", .001, "   d = ", 
          Rational[ 10, 381], " = ", 
          0.0262467191601049869`2.9999999999999996],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltD: formulaNameArray[["\
\[InvisibleSpace]1\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltD"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.00100060284159016763086884772832046888`23.867838313588344\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-3\)\[InvisibleSpace]" \
  precisionDwassAltD = "\[InvisibleSpace]23\[InvisibleSpace]"   computerTime \
= "\[InvisibleSpace]0.016000000000005343`\),
        SequenceForm[ 
        "      DwassAltD: formulaNameArray[[", 1, "]] = ", "DwassAltD", 
          "   rightTailProbabilityDwassAltD = ", 
          0.00100060284159016763086884772832046888`23.867838313588344, 
          "   rTPpowerTen = ", -3, "   precisionDwassAltD = ", 23, 
          "   computerTime = ", .016000000000005343],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassD: \
formulaNameArray[["\[InvisibleSpace]2\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassD"\[InvisibleSpace]"   rightTailProbabilityDwassD = "\
\[InvisibleSpace]0.00100060284159016763086884772832046886`23.867838313588308\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-3\)\[InvisibleSpace]" \
  precisionDwassD = "\[InvisibleSpace]23\[InvisibleSpace]"   computerTime = "\
\[InvisibleSpace]0.015000000000000568`\),
        SequenceForm[ 
        "      DwassD: formulaNameArray[[", 2, "]] = ", "DwassD", 
          "   rightTailProbabilityDwassD = ", 
          0.00100060284159016763086884772832046886`23.867838313588308, 
          "   rTPpowerTen = ", -3, "   precisionDwassD = ", 23, 
          "   computerTime = ", .015000000000000568],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassD verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.00100060284159016763086884772832046888`23.867838313588344\
\[InvisibleSpace]"   rightTailProbabilityDwassD = \
"\[InvisibleSpace]0.00100060284159016763086884772832046886`23.867838313588308\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassD] = Min["\[InvisibleSpace]23\[InvisibleSpace]","\
\[InvisibleSpace]23\[InvisibleSpace]"] = \
"\[InvisibleSpace]23\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``26.566546586031784\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-3\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-25\)\),
        SequenceForm[ 
        "         DwassD verify: rightTailProbabilityDwassAltD = ", 
          0.00100060284159016763086884772832046888`23.867838313588344, 
          "   rightTailProbabilityDwassD = ", 
          0.00100060284159016763086884772832046886`23.867838313588308, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = \
Min[", 23, ",", 23, "] = ", 23, "   rightTailProbabilityAbsDifference = ", 
          0``26.566546586031784, "   rTPpowerTen = ", -3, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -25],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassI: \
formulaNameArray[["\[InvisibleSpace]3\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassI"\[InvisibleSpace]"   rightTailProbabilityDwassI = "\
\[InvisibleSpace]0.00100060284159016763086884772832083944`25.393530703294402\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-3\)\[InvisibleSpace]" \
  precisionDwassI = "\[InvisibleSpace]25\[InvisibleSpace]"   computerTime = "\
\[InvisibleSpace]0.031999999999996476`\),
        SequenceForm[ 
        "      DwassI: formulaNameArray[[", 3, "]] = ", "DwassI", 
          "   rightTailProbabilityDwassI = ", 
          0.00100060284159016763086884772832083944`25.393530703294402, 
          "   rTPpowerTen = ", -3, "   precisionDwassI = ", 25, 
          "   computerTime = ", .031999999999996476],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.00100060284159016763086884772832046888`23.867838313588344\
\[InvisibleSpace]"   rightTailProbabilityDwassI = \
"\[InvisibleSpace]0.00100060284159016763086884772832083944`25.393530703294402\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassI] = Min["\[InvisibleSpace]23\[InvisibleSpace]","\
\[InvisibleSpace]25\[InvisibleSpace]"] = \
"\[InvisibleSpace]23\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``26.854821050589013\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-3\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-25\)\),
        SequenceForm[ 
        "         DwassI verify: rightTailProbabilityDwassAltD = ", 
          0.00100060284159016763086884772832046888`23.867838313588344, 
          "   rightTailProbabilityDwassI = ", 
          0.00100060284159016763086884772832083944`25.393530703294402, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassI] = \
Min[", 23, ",", 25, "] = ", 23, "   rightTailProbabilityAbsDifference = ", 
          0``26.854821050589013, "   rTPpowerTen = ", -3, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -25],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltI: formulaNameArray[["\
\[InvisibleSpace]4\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltI"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.00100060284159016763086884772832083944`25.393530703297856\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-3\)\[InvisibleSpace]" \
  precisionDwassAltI = "\[InvisibleSpace]25\[InvisibleSpace]"   computerTime \
= "\[InvisibleSpace]0.03100000000000591`\),
        SequenceForm[ 
        "      DwassAltI: formulaNameArray[[", 4, "]] = ", "DwassAltI", 
          "   rightTailProbabilityDwassAltI = ", 
          0.00100060284159016763086884772832083944`25.393530703297856, 
          "   rTPpowerTen = ", -3, "   precisionDwassAltI = ", 25, 
          "   computerTime = ", .031000000000005912],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassAltI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.00100060284159016763086884772832046888`23.867838313588344\
\[InvisibleSpace]"   rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.00100060284159016763086884772832083944`25.393530703297856\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassAltI] = Min["\[InvisibleSpace]23\[InvisibleSpace]","\
\[InvisibleSpace]25\[InvisibleSpace]"] = \
"\[InvisibleSpace]23\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``26.85482105058911\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-3\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-25\)\),
        SequenceForm[ 
        "         DwassAltI verify: rightTailProbabilityDwassAltD = ", 
          0.00100060284159016763086884772832046888`23.867838313588344, 
          "   rightTailProbabilityDwassAltI = ", 
          0.00100060284159016763086884772832083944`25.393530703297856, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassAltI] = \
Min[", 23, ",", 25, "] = ", 23, "   rightTailProbabilityAbsDifference = ", 
          0``26.85482105058911, "   rTPpowerTen = ", -3, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -25],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      Rational DwassAltD: formulaNameArray[["\
\[InvisibleSpace]5\[InvisibleSpace]"]] = "\[InvisibleSpace]"Rational \
DwassAltD"\[InvisibleSpace]"   \
rightTailProbabilityDwassAltDrationalInArbPrecision = \
"\[InvisibleSpace]0.00100060284159016763086884772832046887`23. \
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-3\)\[InvisibleSpace]" \
  precisionDwassD = "\[InvisibleSpace]23\[InvisibleSpace]"   computerTime = "\
\[InvisibleSpace]3.6559999999999917`\),
        SequenceForm[ 
        "      Rational DwassAltD: formulaNameArray[[", 5, "]] = ", 
          "Rational DwassAltD", 
          "   rightTailProbabilityDwassAltDrationalInArbPrecision = ", 
          0.00100060284159016763086884772832046887`23., 
          "   rTPpowerTen = ", -3, "   precisionDwassD = ", 23, 
          "   computerTime = ", 3.6559999999999917],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassD verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.00100060284159016763086884772832046888`23.867838313588344\
\[InvisibleSpace]"   rightTailProbabilityDwassAltDrationalInArbPrecision = "\
\[InvisibleSpace]0.00100060284159016763086884772832046887`23. \
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassD] = Min["\[InvisibleSpace]23\[InvisibleSpace]","\
\[InvisibleSpace]23\[InvisibleSpace]"] = \
"\[InvisibleSpace]23\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``25.944524585471196\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-3\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-25\)\),
        SequenceForm[ 
        "         DwassD verify: rightTailProbabilityDwassAltD = ", 
          0.00100060284159016763086884772832046888`23.867838313588344, 
          "   rightTailProbabilityDwassAltDrationalInArbPrecision = ", 
          0.00100060284159016763086884772832046887`23., 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = \
Min[", 23, ",", 23, "] = ", 23, "   rightTailProbabilityAbsDifference = ", 
          0``25.944524585471196, "   rTPpowerTen = ", -3, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -25],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("  sampleSize = "\[InvisibleSpace]5000\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   alphaMD = "\[InvisibleSpace]0.9`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]1\/311\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0032154340836012862`2.999999999999999\),
        SequenceForm[ 
        "  sampleSize = ", 5000, "   desiredPrecision = ", 20, 
          "   alphaMD = ", .90000000000000002, "   d = ", 
          Rational[ 1, 311], " = ", 0.0032154340836012862`2.999999999999999],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltD: formulaNameArray[["\
\[InvisibleSpace]1\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltD"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.89984803598571783066954008445631735748`22.93992678217666\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]" \
  precisionDwassAltD = "\[InvisibleSpace]22\[InvisibleSpace]"   computerTime \
= "\[InvisibleSpace]0.`\),
        SequenceForm[ 
        "      DwassAltD: formulaNameArray[[", 1, "]] = ", "DwassAltD", 
          "   rightTailProbabilityDwassAltD = ", 
          0.89984803598571783066954008445631735748`22.93992678217666, 
          "   rTPpowerTen = ", -1, "   precisionDwassAltD = ", 22, 
          "   computerTime = ", 0.0],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassD: \
formulaNameArray[["\[InvisibleSpace]2\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassD"\[InvisibleSpace]"   rightTailProbabilityDwassD = "\
\[InvisibleSpace]0.89984803598571783066954008445631714311`22.93992678217826\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]" \
  precisionDwassD = "\[InvisibleSpace]22\[InvisibleSpace]"   computerTime = "\
\[InvisibleSpace]0.016000000000005343`\),
        SequenceForm[ 
        "      DwassD: formulaNameArray[[", 2, "]] = ", "DwassD", 
          "   rightTailProbabilityDwassD = ", 
          0.89984803598571783066954008445631714311`22.93992678217826, 
          "   rTPpowerTen = ", -1, "   precisionDwassD = ", 22, 
          "   computerTime = ", .016000000000005343],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassD verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.89984803598571783066954008445631735748`22.93992678217666\
\[InvisibleSpace]"   rightTailProbabilityDwassD = \
"\[InvisibleSpace]0.89984803598571783066954008445631714311`22.93992678217826\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassD] = Min["\[InvisibleSpace]22\[InvisibleSpace]","\
\[InvisibleSpace]22\[InvisibleSpace]"] = \
"\[InvisibleSpace]22\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``22.684727613413322\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-22\)\),
        SequenceForm[ 
        "         DwassD verify: rightTailProbabilityDwassAltD = ", 
          0.89984803598571783066954008445631735748`22.93992678217666, 
          "   rightTailProbabilityDwassD = ", 
          0.89984803598571783066954008445631714311`22.93992678217826, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = \
Min[", 22, ",", 22, "] = ", 22, "   rightTailProbabilityAbsDifference = ", 
          0``22.684727613413322, "   rTPpowerTen = ", -1, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -22],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassI: \
formulaNameArray[["\[InvisibleSpace]3\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassI"\[InvisibleSpace]"   rightTailProbabilityDwassI = "\
\[InvisibleSpace]0.89984803598571783066954008445671630215`27.364628914927394\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]" \
  precisionDwassI = "\[InvisibleSpace]27\[InvisibleSpace]"   computerTime = "\
\[InvisibleSpace]0.`\),
        SequenceForm[ 
        "      DwassI: formulaNameArray[[", 3, "]] = ", "DwassI", 
          "   rightTailProbabilityDwassI = ", 
          0.89984803598571783066954008445671630215`27.364628914927394, 
          "   rTPpowerTen = ", -1, "   precisionDwassI = ", 27, 
          "   computerTime = ", 0.0],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.89984803598571783066954008445631735748`22.93992678217666\
\[InvisibleSpace]"   rightTailProbabilityDwassI = \
"\[InvisibleSpace]0.89984803598571783066954008445671630215`27.364628914927394\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassI] = Min["\[InvisibleSpace]22\[InvisibleSpace]","\
\[InvisibleSpace]27\[InvisibleSpace]"] = \
"\[InvisibleSpace]22\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``22.985741275773762\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-22\)\),
        SequenceForm[ 
        "         DwassI verify: rightTailProbabilityDwassAltD = ", 
          0.89984803598571783066954008445631735748`22.93992678217666, 
          "   rightTailProbabilityDwassI = ", 
          0.89984803598571783066954008445671630215`27.364628914927394, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassI] = \
Min[", 22, ",", 27, "] = ", 22, "   rightTailProbabilityAbsDifference = ", 
          0``22.985741275773762, "   rTPpowerTen = ", -1, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -22],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltI: formulaNameArray[["\
\[InvisibleSpace]4\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltI"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.89984803598571783066954008445671630216`27.364628914927742\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]" \
  precisionDwassAltI = "\[InvisibleSpace]27\[InvisibleSpace]"   computerTime \
= "\[InvisibleSpace]0.015000000000000568`\),
        SequenceForm[ 
        "      DwassAltI: formulaNameArray[[", 4, "]] = ", "DwassAltI", 
          "   rightTailProbabilityDwassAltI = ", 
          0.89984803598571783066954008445671630216`27.364628914927742, 
          "   rTPpowerTen = ", -1, "   precisionDwassAltI = ", 27, 
          "   computerTime = ", .015000000000000568],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassAltI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.89984803598571783066954008445631735748`22.93992678217666\
\[InvisibleSpace]"   rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.89984803598571783066954008445671630216`27.364628914927742\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassAltI] = Min["\[InvisibleSpace]22\[InvisibleSpace]","\
\[InvisibleSpace]27\[InvisibleSpace]"] = \
"\[InvisibleSpace]22\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``22.985741275773762\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-22\)\),
        SequenceForm[ 
        "         DwassAltI verify: rightTailProbabilityDwassAltD = ", 
          0.89984803598571783066954008445631735748`22.93992678217666, 
          "   rightTailProbabilityDwassAltI = ", 
          0.89984803598571783066954008445671630216`27.364628914927742, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassAltI] = \
Min[", 22, ",", 27, "] = ", 22, "   rightTailProbabilityAbsDifference = ", 
          0``22.985741275773762, "   rTPpowerTen = ", -1, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -22],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      Rational DwassAltD: formulaNameArray[["\
\[InvisibleSpace]5\[InvisibleSpace]"]] = "\[InvisibleSpace]"Rational \
DwassAltD"\[InvisibleSpace]"   \
rightTailProbabilityDwassAltDrationalInArbPrecision = \
"\[InvisibleSpace]0.89984803598571783066954008445631701066`22. \
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]" \
  precisionDwassD = "\[InvisibleSpace]22\[InvisibleSpace]"   computerTime = "\
\[InvisibleSpace]0.4689999999999941`\),
        SequenceForm[ 
        "      Rational DwassAltD: formulaNameArray[[", 5, "]] = ", 
          "Rational DwassAltD", 
          "   rightTailProbabilityDwassAltDrationalInArbPrecision = ", 
          0.89984803598571783066954008445631701066`22., 
          "   rTPpowerTen = ", -1, "   precisionDwassD = ", 22, 
          "   computerTime = ", .46899999999999409],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassD verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.89984803598571783066954008445631735748`22.93992678217666\
\[InvisibleSpace]"   rightTailProbabilityDwassAltDrationalInArbPrecision = "\
\[InvisibleSpace]0.89984803598571783066954008445631701066`22. \
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassD] = Min["\[InvisibleSpace]22\[InvisibleSpace]","\
\[InvisibleSpace]22\[InvisibleSpace]"] = \
"\[InvisibleSpace]22\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``21.998620340933208\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-22\)\),
        SequenceForm[ 
        "         DwassD verify: rightTailProbabilityDwassAltD = ", 
          0.89984803598571783066954008445631735748`22.93992678217666, 
          "   rightTailProbabilityDwassAltDrationalInArbPrecision = ", 
          0.89984803598571783066954008445631701066`22., 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = \
Min[", 22, ",", 22, "] = ", 22, "   rightTailProbabilityAbsDifference = ", 
          0``21.998620340933208, "   rTPpowerTen = ", -1, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -22],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("  sampleSize = "\[InvisibleSpace]5000\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]"   alphaMD = "\[InvisibleSpace]0.001`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]10\/381\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0262467191601049869`2.9999999999999996\),
        SequenceForm[ 
        "  sampleSize = ", 5000, "   desiredPrecision = ", 100, 
          "   alphaMD = ", .001, "   d = ", 
          Rational[ 10, 381], " = ", 
          0.0262467191601049869`2.9999999999999996],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltD: formulaNameArray[["\
\[InvisibleSpace]1\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltD"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
001000602841590167630868847728320468873741141143056145563354609659340033715213\
32368314732969798740270610408666809358312511774`103.86783831358768\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-3\)\[InvisibleSpace]" \
  precisionDwassAltD = "\[InvisibleSpace]103\[InvisibleSpace]"   computerTime \
= "\[InvisibleSpace]0.03100000000000591`\),
        SequenceForm[ 
        "      DwassAltD: formulaNameArray[[", 1, "]] = ", "DwassAltD", 
          "   rightTailProbabilityDwassAltD = ", 
          0.001000602841590167630868847728320468873741141143056145563354609659\
34003371521332368314732969798740270610408666809358312511774`103.\
86783831358768, "   rTPpowerTen = ", -3, "   precisionDwassAltD = ", 103, 
          "   computerTime = ", .031000000000005912],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassD: \
formulaNameArray[["\[InvisibleSpace]2\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassD"\[InvisibleSpace]"   rightTailProbabilityDwassD = "\
\[InvisibleSpace]0.\
001000602841590167630868847728320468873741141143056145563354609659340033715213\
32368314732969798740270610408666809358712187654`103.86783831358828\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-3\)\[InvisibleSpace]" \
  precisionDwassD = "\[InvisibleSpace]103\[InvisibleSpace]"   computerTime = \
"\[InvisibleSpace]0.016000000000005343`\),
        SequenceForm[ 
        "      DwassD: formulaNameArray[[", 2, "]] = ", "DwassD", 
          "   rightTailProbabilityDwassD = ", 
          0.001000602841590167630868847728320468873741141143056145563354609659\
34003371521332368314732969798740270610408666809358712187654`103.\
86783831358828, "   rTPpowerTen = ", -3, "   precisionDwassD = ", 103, 
          "   computerTime = ", .016000000000005343],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassD verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
001000602841590167630868847728320468873741141143056145563354609659340033715213\
32368314732969798740270610408666809358312511774`103.86783831358768\
\[InvisibleSpace]"   rightTailProbabilityDwassD = \
"\[InvisibleSpace]0.\
001000602841590167630868847728320468873741141143056145563354609659340033715213\
32368314732969798740270610408666809358712187654`103.86783831358828\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassD] = Min["\[InvisibleSpace]103\[InvisibleSpace]","\
\[InvisibleSpace]103\[InvisibleSpace]"] = "\[InvisibleSpace]103\
\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``106.56654658603144\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-3\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-105\)\),
        SequenceForm[ 
        "         DwassD verify: rightTailProbabilityDwassAltD = ", 
          0.001000602841590167630868847728320468873741141143056145563354609659\
34003371521332368314732969798740270610408666809358312511774`103.\
86783831358768, "   rightTailProbabilityDwassD = ", 
          0.001000602841590167630868847728320468873741141143056145563354609659\
34003371521332368314732969798740270610408666809358712187654`103.\
86783831358828, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = \
Min[", 103, ",", 103, "] = ", 103, "   rightTailProbabilityAbsDifference = ", 
          0``106.56654658603144, "   rTPpowerTen = ", -3, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -105],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassI: \
formulaNameArray[["\[InvisibleSpace]3\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassI"\[InvisibleSpace]"   rightTailProbabilityDwassI = "\
\[InvisibleSpace]0.\
001000602841590167630868847728320468873741141143056145563354609659340033715213\
32368314732969798740270610408666809363223271492`105.39353070329439\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-3\)\[InvisibleSpace]" \
  precisionDwassI = "\[InvisibleSpace]105\[InvisibleSpace]"   computerTime = \
"\[InvisibleSpace]0.046999999999997044`\),
        SequenceForm[ 
        "      DwassI: formulaNameArray[[", 3, "]] = ", "DwassI", 
          "   rightTailProbabilityDwassI = ", 
          0.001000602841590167630868847728320468873741141143056145563354609659\
34003371521332368314732969798740270610408666809363223271492`105.\
39353070329439, "   rTPpowerTen = ", -3, "   precisionDwassI = ", 105, 
          "   computerTime = ", .046999999999997044],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
001000602841590167630868847728320468873741141143056145563354609659340033715213\
32368314732969798740270610408666809358312511774`103.86783831358768\
\[InvisibleSpace]"   rightTailProbabilityDwassI = \
"\[InvisibleSpace]0.\
001000602841590167630868847728320468873741141143056145563354609659340033715213\
32368314732969798740270610408666809363223271492`105.39353070329439\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassI] = Min["\[InvisibleSpace]103\[InvisibleSpace]","\
\[InvisibleSpace]105\[InvisibleSpace]"] = "\[InvisibleSpace]103\
\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``106.85482105058838\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-3\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-105\)\),
        SequenceForm[ 
        "         DwassI verify: rightTailProbabilityDwassAltD = ", 
          0.001000602841590167630868847728320468873741141143056145563354609659\
34003371521332368314732969798740270610408666809358312511774`103.\
86783831358768, "   rightTailProbabilityDwassI = ", 
          0.001000602841590167630868847728320468873741141143056145563354609659\
34003371521332368314732969798740270610408666809363223271492`105.\
39353070329439, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassI] = \
Min[", 103, ",", 105, "] = ", 103, "   rightTailProbabilityAbsDifference = ", 
          0``106.85482105058838, "   rTPpowerTen = ", -3, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -105],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltI: formulaNameArray[["\
\[InvisibleSpace]4\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltI"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.\
001000602841590167630868847728320468873741141143056145563354609659340033715213\
32368314732969798740270610408666809363223254758`105.39353070329717\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-3\)\[InvisibleSpace]" \
  precisionDwassAltI = "\[InvisibleSpace]105\[InvisibleSpace]"   computerTime \
= "\[InvisibleSpace]0.046999999999997044`\),
        SequenceForm[ 
        "      DwassAltI: formulaNameArray[[", 4, "]] = ", "DwassAltI", 
          "   rightTailProbabilityDwassAltI = ", 
          0.001000602841590167630868847728320468873741141143056145563354609659\
34003371521332368314732969798740270610408666809363223254758`105.\
39353070329717, "   rTPpowerTen = ", -3, "   precisionDwassAltI = ", 105, 
          "   computerTime = ", .046999999999997044],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassAltI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
001000602841590167630868847728320468873741141143056145563354609659340033715213\
32368314732969798740270610408666809358312511774`103.86783831358768\
\[InvisibleSpace]"   rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.\
001000602841590167630868847728320468873741141143056145563354609659340033715213\
32368314732969798740270610408666809363223254758`105.39353070329717\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassAltI] = Min["\[InvisibleSpace]103\[InvisibleSpace]","\
\[InvisibleSpace]105\[InvisibleSpace]"] = "\[InvisibleSpace]103\
\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``106.85482105058846\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-3\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-105\)\),
        SequenceForm[ 
        "         DwassAltI verify: rightTailProbabilityDwassAltD = ", 
          0.001000602841590167630868847728320468873741141143056145563354609659\
34003371521332368314732969798740270610408666809358312511774`103.\
86783831358768, "   rightTailProbabilityDwassAltI = ", 
          0.001000602841590167630868847728320468873741141143056145563354609659\
34003371521332368314732969798740270610408666809363223254758`105.\
39353070329717, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassAltI] = \
Min[", 103, ",", 105, "] = ", 103, "   rightTailProbabilityAbsDifference = ", 
          0``106.85482105058846, "   rTPpowerTen = ", -3, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -105],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      Rational DwassAltD: formulaNameArray[["\
\[InvisibleSpace]5\[InvisibleSpace]"]] = "\[InvisibleSpace]"Rational \
DwassAltD"\[InvisibleSpace]"   \
rightTailProbabilityDwassAltDrationalInArbPrecision = \
"\[InvisibleSpace]0.\
001000602841590167630868847728320468873741141143056145563354609659340033715213\
32368314732969798740270610408666809358311817052`103. \[InvisibleSpace]"   \
rTPpowerTen = "\[InvisibleSpace]\(-3\)\[InvisibleSpace]"   precisionDwassD = \
"\[InvisibleSpace]103\[InvisibleSpace]"   computerTime = \
"\[InvisibleSpace]3.6559999999999917`\),
        SequenceForm[ 
        "      Rational DwassAltD: formulaNameArray[[", 5, "]] = ", 
          "Rational DwassAltD", 
          "   rightTailProbabilityDwassAltDrationalInArbPrecision = ", 
          0.001000602841590167630868847728320468873741141143056145563354609659\
34003371521332368314732969798740270610408666809358311817052`103., 
          "   rTPpowerTen = ", -3, "   precisionDwassD = ", 103, 
          "   computerTime = ", 3.6559999999999917],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassD verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
001000602841590167630868847728320468873741141143056145563354609659340033715213\
32368314732969798740270610408666809358312511774`103.86783831358768\
\[InvisibleSpace]"   rightTailProbabilityDwassAltDrationalInArbPrecision = "\
\[InvisibleSpace]0.\
001000602841590167630868847728320468873741141143056145563354609659340033715213\
32368314732969798740270610408666809358311817052`103. \[InvisibleSpace]"   \
precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = Min["\
\[InvisibleSpace]103\[InvisibleSpace]","\[InvisibleSpace]103\[InvisibleSpace]\
"] = "\[InvisibleSpace]103\[InvisibleSpace]"   \
rightTailProbabilityAbsDifference = "\[InvisibleSpace]0``105.94452458547113\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-3\)\[InvisibleSpace]" \
  powerTenCompare =  rTPpowerTen - precisionUsed + 1 = \
"\[InvisibleSpace]\(-105\)\),
        SequenceForm[ 
        "         DwassD verify: rightTailProbabilityDwassAltD = ", 
          0.001000602841590167630868847728320468873741141143056145563354609659\
34003371521332368314732969798740270610408666809358312511774`103.\
86783831358768, "   rightTailProbabilityDwassAltDrationalInArbPrecision = ", 
          0.001000602841590167630868847728320468873741141143056145563354609659\
34003371521332368314732969798740270610408666809358311817052`103., 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = \
Min[", 103, ",", 103, "] = ", 103, "   rightTailProbabilityAbsDifference = ", 
          0``105.94452458547113, "   rTPpowerTen = ", -3, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -105],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("  sampleSize = "\[InvisibleSpace]5000\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]"   alphaMD = "\[InvisibleSpace]0.9`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]1\/311\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0032154340836012862`2.999999999999999\),
        SequenceForm[ 
        "  sampleSize = ", 5000, "   desiredPrecision = ", 100, 
          "   alphaMD = ", .90000000000000002, "   d = ", 
          Rational[ 1, 311], " = ", 0.0032154340836012862`2.999999999999999],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltD: formulaNameArray[["\
\[InvisibleSpace]1\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltD"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
899848035985717830669540084456317010656904743952939133420493004412486575251684\
0822722439909329086276337516762036594`102.93992678217819\[InvisibleSpace]"   \
rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   precisionDwassAltD \
= "\[InvisibleSpace]102\[InvisibleSpace]"   computerTime = \
"\[InvisibleSpace]0.015000000000000568`\),
        SequenceForm[ 
        "      DwassAltD: formulaNameArray[[", 1, "]] = ", "DwassAltD", 
          "   rightTailProbabilityDwassAltD = ", 
          0.899848035985717830669540084456317010656904743952939133420493004412\
4865752516840822722439909329086276337516762036594`102.93992678217819, 
          "   rTPpowerTen = ", -1, "   precisionDwassAltD = ", 102, 
          "   computerTime = ", .015000000000000568],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassD: \
formulaNameArray[["\[InvisibleSpace]2\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassD"\[InvisibleSpace]"   rightTailProbabilityDwassD = "\
\[InvisibleSpace]0.\
899848035985717830669540084456317010656904743952939133420493004412486575251684\
0822722439909329086276337516762036583`102.93992678217829\[InvisibleSpace]"   \
rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   precisionDwassD = \
"\[InvisibleSpace]102\[InvisibleSpace]"   computerTime = \
"\[InvisibleSpace]0.`\),
        SequenceForm[ 
        "      DwassD: formulaNameArray[[", 2, "]] = ", "DwassD", 
          "   rightTailProbabilityDwassD = ", 
          0.899848035985717830669540084456317010656904743952939133420493004412\
4865752516840822722439909329086276337516762036583`102.93992678217829, 
          "   rTPpowerTen = ", -1, "   precisionDwassD = ", 102, 
          "   computerTime = ", 0.0],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassD verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
899848035985717830669540084456317010656904743952939133420493004412486575251684\
0822722439909329086276337516762036594`102.93992678217819\[InvisibleSpace]"   \
rightTailProbabilityDwassD = \
"\[InvisibleSpace]0.\
899848035985717830669540084456317010656904743952939133420493004412486575251684\
0822722439909329086276337516762036583`102.93992678217829\[InvisibleSpace]"   \
precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = Min["\
\[InvisibleSpace]102\[InvisibleSpace]","\[InvisibleSpace]102\[InvisibleSpace]\
"] = "\[InvisibleSpace]102\[InvisibleSpace]"   \
rightTailProbabilityAbsDifference = "\[InvisibleSpace]0``102.68472761341408\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]" \
  powerTenCompare =  rTPpowerTen - precisionUsed + 1 = \
"\[InvisibleSpace]\(-102\)\),
        SequenceForm[ 
        "         DwassD verify: rightTailProbabilityDwassAltD = ", 
          0.899848035985717830669540084456317010656904743952939133420493004412\
4865752516840822722439909329086276337516762036594`102.93992678217819, 
          "   rightTailProbabilityDwassD = ", 
          0.899848035985717830669540084456317010656904743952939133420493004412\
4865752516840822722439909329086276337516762036583`102.93992678217829, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = \
Min[", 102, ",", 102, "] = ", 102, "   rightTailProbabilityAbsDifference = ", 
          0``102.68472761341408, "   rTPpowerTen = ", -1, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -102],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassI: \
formulaNameArray[["\[InvisibleSpace]3\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassI"\[InvisibleSpace]"   rightTailProbabilityDwassI = "\
\[InvisibleSpace]0.\
899848035985717830669540084456317010656904743952939133420493004412486575251684\
08227224399093290862763375167620358501674248848`107.36462891492741\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]" \
  precisionDwassI = "\[InvisibleSpace]107\[InvisibleSpace]"   computerTime = \
"\[InvisibleSpace]0.`\),
        SequenceForm[ 
        "      DwassI: formulaNameArray[[", 3, "]] = ", "DwassI", 
          "   rightTailProbabilityDwassI = ", 
          0.899848035985717830669540084456317010656904743952939133420493004412\
48657525168408227224399093290862763375167620358501674248848`107.\
36462891492741, "   rTPpowerTen = ", -1, "   precisionDwassI = ", 107, 
          "   computerTime = ", 0.0],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
899848035985717830669540084456317010656904743952939133420493004412486575251684\
0822722439909329086276337516762036594`102.93992678217819\[InvisibleSpace]"   \
rightTailProbabilityDwassI = \
"\[InvisibleSpace]0.\
899848035985717830669540084456317010656904743952939133420493004412486575251684\
08227224399093290862763375167620358501674248848`107.36462891492741\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassI] = Min["\[InvisibleSpace]102\[InvisibleSpace]","\
\[InvisibleSpace]107\[InvisibleSpace]"] = "\[InvisibleSpace]102\
\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``102.98574127577527\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-102\)\),
        SequenceForm[ 
        "         DwassI verify: rightTailProbabilityDwassAltD = ", 
          0.899848035985717830669540084456317010656904743952939133420493004412\
4865752516840822722439909329086276337516762036594`102.93992678217819, 
          "   rightTailProbabilityDwassI = ", 
          0.899848035985717830669540084456317010656904743952939133420493004412\
48657525168408227224399093290862763375167620358501674248848`107.\
36462891492741, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassI] = \
Min[", 102, ",", 107, "] = ", 102, "   rightTailProbabilityAbsDifference = ", 
          0``102.98574127577527, "   rTPpowerTen = ", -1, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -102],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltI: formulaNameArray[["\
\[InvisibleSpace]4\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltI"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.\
899848035985717830669540084456317010656904743952939133420493004412486575251684\
08227224399093290862763375167620358501674250826`107.3646289149271\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]" \
  precisionDwassAltI = "\[InvisibleSpace]107\[InvisibleSpace]"   computerTime \
= "\[InvisibleSpace]0.016000000000005343`\),
        SequenceForm[ 
        "      DwassAltI: formulaNameArray[[", 4, "]] = ", "DwassAltI", 
          "   rightTailProbabilityDwassAltI = ", 
          0.899848035985717830669540084456317010656904743952939133420493004412\
48657525168408227224399093290862763375167620358501674250826`107.3646289149271,
           "   rTPpowerTen = ", -1, "   precisionDwassAltI = ", 107, 
          "   computerTime = ", .016000000000005343],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassAltI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
899848035985717830669540084456317010656904743952939133420493004412486575251684\
0822722439909329086276337516762036594`102.93992678217819\[InvisibleSpace]"   \
rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.\
899848035985717830669540084456317010656904743952939133420493004412486575251684\
08227224399093290862763375167620358501674250826`107.3646289149271\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassAltI] = Min["\[InvisibleSpace]102\[InvisibleSpace]","\
\[InvisibleSpace]107\[InvisibleSpace]"] = "\[InvisibleSpace]102\
\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``102.98574127577527\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-102\)\),
        SequenceForm[ 
        "         DwassAltI verify: rightTailProbabilityDwassAltD = ", 
          0.899848035985717830669540084456317010656904743952939133420493004412\
4865752516840822722439909329086276337516762036594`102.93992678217819, 
          "   rightTailProbabilityDwassAltI = ", 
          0.899848035985717830669540084456317010656904743952939133420493004412\
48657525168408227224399093290862763375167620358501674250826`107.3646289149271,
           "   precisionUsed = Min[ precisionDwassAltD, precisionDwassAltI] = \
Min[", 102, ",", 107, "] = ", 102, "   rightTailProbabilityAbsDifference = ", 
          0``102.98574127577527, "   rTPpowerTen = ", -1, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -102],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      Rational DwassAltD: formulaNameArray[["\
\[InvisibleSpace]5\[InvisibleSpace]"]] = "\[InvisibleSpace]"Rational \
DwassAltD"\[InvisibleSpace]"   \
rightTailProbabilityDwassAltDrationalInArbPrecision = \
"\[InvisibleSpace]0.\
899848035985717830669540084456317010656904743952939133420493004412486575251684\
0822722439909329086276337516762036582`102. \[InvisibleSpace]"   rTPpowerTen = \
"\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   precisionDwassD = "\
\[InvisibleSpace]102\[InvisibleSpace]"   computerTime = \
"\[InvisibleSpace]0.4689999999999941`\),
        SequenceForm[ 
        "      Rational DwassAltD: formulaNameArray[[", 5, "]] = ", 
          "Rational DwassAltD", 
          "   rightTailProbabilityDwassAltDrationalInArbPrecision = ", 
          0.899848035985717830669540084456317010656904743952939133420493004412\
4865752516840822722439909329086276337516762036582`102., 
          "   rTPpowerTen = ", -1, "   precisionDwassD = ", 102, 
          "   computerTime = ", .46899999999999409],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassD verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
899848035985717830669540084456317010656904743952939133420493004412486575251684\
0822722439909329086276337516762036594`102.93992678217819\[InvisibleSpace]"   \
rightTailProbabilityDwassAltDrationalInArbPrecision = \
"\[InvisibleSpace]0.\
899848035985717830669540084456317010656904743952939133420493004412486575251684\
0822722439909329086276337516762036582`102. \[InvisibleSpace]"   precisionUsed \
= Min[ precisionDwassAltD, precisionDwassD] = Min["\[InvisibleSpace]102\
\[InvisibleSpace]","\[InvisibleSpace]102\[InvisibleSpace]"] = "\
\[InvisibleSpace]102\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``101.99862034093337\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-102\)\),
        SequenceForm[ 
        "         DwassD verify: rightTailProbabilityDwassAltD = ", 
          0.899848035985717830669540084456317010656904743952939133420493004412\
4865752516840822722439909329086276337516762036594`102.93992678217819, 
          "   rightTailProbabilityDwassAltDrationalInArbPrecision = ", 
          0.899848035985717830669540084456317010656904743952939133420493004412\
4865752516840822722439909329086276337516762036582`102., 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = \
Min[", 102, ",", 102, "] = ", 102, "   rightTailProbabilityAbsDifference = ", 
          0``101.99862034093337, "   rTPpowerTen = ", -1, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -102],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("  sampleSize = "\[InvisibleSpace]10000\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   alphaMD = "\[InvisibleSpace]0.001`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]6\/323\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0185758513931888545`3.000000000000001\),
        SequenceForm[ 
        "  sampleSize = ", 10000, "   desiredPrecision = ", 20, 
          "   alphaMD = ", .001, "   d = ", 
          Rational[ 6, 323], " = ", 0.0185758513931888545`3.000000000000001],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltD: formulaNameArray[["\
\[InvisibleSpace]1\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltD"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.00099376865362050160212971843975971233`24.442605490584977\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-4\)\[InvisibleSpace]" \
  precisionDwassAltD = "\[InvisibleSpace]24\[InvisibleSpace]"   computerTime \
= "\[InvisibleSpace]0.03100000000000591`\),
        SequenceForm[ 
        "      DwassAltD: formulaNameArray[[", 1, "]] = ", "DwassAltD", 
          "   rightTailProbabilityDwassAltD = ", 
          0.00099376865362050160212971843975971233`24.442605490584977, 
          "   rTPpowerTen = ", -4, "   precisionDwassAltD = ", 24, 
          "   computerTime = ", .031000000000005912],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassD: \
formulaNameArray[["\[InvisibleSpace]2\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassD"\[InvisibleSpace]"   rightTailProbabilityDwassD = "\
\[InvisibleSpace]0.00099376865362050160212971843975971232`24.442605490600247\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-4\)\[InvisibleSpace]" \
  precisionDwassD = "\[InvisibleSpace]24\[InvisibleSpace]"   computerTime = "\
\[InvisibleSpace]0.0309999999999917`\),
        SequenceForm[ 
        "      DwassD: formulaNameArray[[", 2, "]] = ", "DwassD", 
          "   rightTailProbabilityDwassD = ", 
          0.00099376865362050160212971843975971232`24.442605490600247, 
          "   rTPpowerTen = ", -4, "   precisionDwassD = ", 24, 
          "   computerTime = ", .030999999999991701],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassD verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.00099376865362050160212971843975971233`24.442605490584977\
\[InvisibleSpace]"   rightTailProbabilityDwassD = \
"\[InvisibleSpace]0.00099376865362050160212971843975971232`24.442605490600247\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassD] = Min["\[InvisibleSpace]24\[InvisibleSpace]","\
\[InvisibleSpace]24\[InvisibleSpace]"] = \
"\[InvisibleSpace]24\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``27.144290201225445\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-4\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-27\)\),
        SequenceForm[ 
        "         DwassD verify: rightTailProbabilityDwassAltD = ", 
          0.00099376865362050160212971843975971233`24.442605490584977, 
          "   rightTailProbabilityDwassD = ", 
          0.00099376865362050160212971843975971232`24.442605490600247, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = \
Min[", 24, ",", 24, "] = ", 24, "   rightTailProbabilityAbsDifference = ", 
          0``27.144290201225445, "   rTPpowerTen = ", -4, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -27],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassI: \
formulaNameArray[["\[InvisibleSpace]3\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassI"\[InvisibleSpace]"   rightTailProbabilityDwassI = "\
\[InvisibleSpace]0.000993768653620501602129718439759706048884659308`26.\
116898034913536\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-4\)\
\[InvisibleSpace]"   precisionDwassI = "\[InvisibleSpace]26\[InvisibleSpace]" \
  computerTime = "\[InvisibleSpace]0.06300000000000239`\),
        SequenceForm[ 
        "      DwassI: formulaNameArray[[", 3, "]] = ", "DwassI", 
          "   rightTailProbabilityDwassI = ", 
          0.000993768653620501602129718439759706048884659308`26.\
116898034913536, "   rTPpowerTen = ", -4, "   precisionDwassI = ", 26, 
          "   computerTime = ", .063000000000002387],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.00099376865362050160212971843975971233`24.442605490584977\
\[InvisibleSpace]"   rightTailProbabilityDwassI = \
"\[InvisibleSpace]0.000993768653620501602129718439759706048884659308`26.\
116898034913536\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassI] = Min["\[InvisibleSpace]24\[InvisibleSpace]","\
\[InvisibleSpace]26\[InvisibleSpace]"] = \
"\[InvisibleSpace]24\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``27.43622242713578\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-4\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-27\)\),
        SequenceForm[ 
        "         DwassI verify: rightTailProbabilityDwassAltD = ", 
          0.00099376865362050160212971843975971233`24.442605490584977, 
          "   rightTailProbabilityDwassI = ", 
          0.000993768653620501602129718439759706048884659308`26.\
116898034913536, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassI] = \
Min[", 24, ",", 26, "] = ", 24, "   rightTailProbabilityAbsDifference = ", 
          0``27.43622242713578, "   rTPpowerTen = ", -4, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -27],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltI: formulaNameArray[["\
\[InvisibleSpace]4\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltI"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.000993768653620501602129718439759706048884659312`26.\
116898034893456\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-4\)\
\[InvisibleSpace]"   precisionDwassAltI = "\[InvisibleSpace]26\
\[InvisibleSpace]"   computerTime = "\[InvisibleSpace]0.04600000000000648`\),
        SequenceForm[ 
        "      DwassAltI: formulaNameArray[[", 4, "]] = ", "DwassAltI", 
          "   rightTailProbabilityDwassAltI = ", 
          0.000993768653620501602129718439759706048884659312`26.\
116898034893456, "   rTPpowerTen = ", -4, "   precisionDwassAltI = ", 26, 
          "   computerTime = ", .04600000000000648],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassAltI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.00099376865362050160212971843975971233`24.442605490584977\
\[InvisibleSpace]"   rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.000993768653620501602129718439759706048884659312`26.\
116898034893456\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassAltI] = Min["\[InvisibleSpace]24\[InvisibleSpace]","\
\[InvisibleSpace]26\[InvisibleSpace]"] = \
"\[InvisibleSpace]24\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``27.436222427135366\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-4\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-27\)\),
        SequenceForm[ 
        "         DwassAltI verify: rightTailProbabilityDwassAltD = ", 
          0.00099376865362050160212971843975971233`24.442605490584977, 
          "   rightTailProbabilityDwassAltI = ", 
          0.000993768653620501602129718439759706048884659312`26.\
116898034893456, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassAltI] = \
Min[", 24, ",", 26, "] = ", 24, "   rightTailProbabilityAbsDifference = ", 
          0``27.436222427135366, "   rTPpowerTen = ", -4, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -27],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      Rational DwassAltD: formulaNameArray[["\
\[InvisibleSpace]5\[InvisibleSpace]"]] = "\[InvisibleSpace]"Rational \
DwassAltD"\[InvisibleSpace]"   \
rightTailProbabilityDwassAltDrationalInArbPrecision = \
"\[InvisibleSpace]0.00099376865362050160212971843975971233`24. \
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-4\)\[InvisibleSpace]" \
  precisionDwassD = "\[InvisibleSpace]24\[InvisibleSpace]"   computerTime = "\
\[InvisibleSpace]17.125`\),
        SequenceForm[ 
        "      Rational DwassAltD: formulaNameArray[[", 5, "]] = ", 
          "Rational DwassAltD", 
          "   rightTailProbabilityDwassAltDrationalInArbPrecision = ", 
          0.00099376865362050160212971843975971233`24., 
          "   rTPpowerTen = ", -4, "   precisionDwassD = ", 24, 
          "   computerTime = ", 17.125],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassD verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.00099376865362050160212971843975971233`24.442605490584977\
\[InvisibleSpace]"   rightTailProbabilityDwassAltDrationalInArbPrecision = "\
\[InvisibleSpace]0.00099376865362050160212971843975971233`24. \
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassD] = Min["\[InvisibleSpace]24\[InvisibleSpace]","\
\[InvisibleSpace]24\[InvisibleSpace]"] = \
"\[InvisibleSpace]24\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``26.868886469492544\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-4\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-27\)\),
        SequenceForm[ 
        "         DwassD verify: rightTailProbabilityDwassAltD = ", 
          0.00099376865362050160212971843975971233`24.442605490584977, 
          "   rightTailProbabilityDwassAltDrationalInArbPrecision = ", 
          0.00099376865362050160212971843975971233`24., 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = \
Min[", 24, ",", 24, "] = ", 24, "   rightTailProbabilityAbsDifference = ", 
          0``26.868886469492544, "   rTPpowerTen = ", -4, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -27],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("  sampleSize = "\[InvisibleSpace]10000\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   alphaMD = "\[InvisibleSpace]0.9`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]1\/439\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0022779043280182232`2.9999999999999987\),
        SequenceForm[ 
        "  sampleSize = ", 10000, "   desiredPrecision = ", 20, 
          "   alphaMD = ", .90000000000000002, "   d = ", 
          Rational[ 1, 439], " = ", 0.0022779043280182232`2.9999999999999987],
        
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltD: formulaNameArray[["\
\[InvisibleSpace]1\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltD"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.90006044094832201061191068281441502514`23.06748390390467\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]" \
  precisionDwassAltD = "\[InvisibleSpace]23\[InvisibleSpace]"   computerTime \
= "\[InvisibleSpace]0.`\),
        SequenceForm[ 
        "      DwassAltD: formulaNameArray[[", 1, "]] = ", "DwassAltD", 
          "   rightTailProbabilityDwassAltD = ", 
          0.90006044094832201061191068281441502514`23.06748390390467, 
          "   rTPpowerTen = ", -1, "   precisionDwassAltD = ", 23, 
          "   computerTime = ", 0.0],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassD: \
formulaNameArray[["\[InvisibleSpace]2\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassD"\[InvisibleSpace]"   rightTailProbabilityDwassD = "\
\[InvisibleSpace]0.90006044094832201061191068281441507563`23.067483903905472\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]" \
  precisionDwassD = "\[InvisibleSpace]23\[InvisibleSpace]"   computerTime = "\
\[InvisibleSpace]0.`\),
        SequenceForm[ 
        "      DwassD: formulaNameArray[[", 2, "]] = ", "DwassD", 
          "   rightTailProbabilityDwassD = ", 
          0.90006044094832201061191068281441507563`23.067483903905472, 
          "   rTPpowerTen = ", -1, "   precisionDwassD = ", 23, 
          "   computerTime = ", 0.0],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassD verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.90006044094832201061191068281441502514`23.06748390390467\
\[InvisibleSpace]"   rightTailProbabilityDwassD = \
"\[InvisibleSpace]0.90006044094832201061191068281441507563`23.067483903905472\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassD] = Min["\[InvisibleSpace]23\[InvisibleSpace]","\
\[InvisibleSpace]23\[InvisibleSpace]"] = \
"\[InvisibleSpace]23\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``22.812182234036236\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-23\)\),
        SequenceForm[ 
        "         DwassD verify: rightTailProbabilityDwassAltD = ", 
          0.90006044094832201061191068281441502514`23.06748390390467, 
          "   rightTailProbabilityDwassD = ", 
          0.90006044094832201061191068281441507563`23.067483903905472, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = \
Min[", 23, ",", 23, "] = ", 23, "   rightTailProbabilityAbsDifference = ", 
          0``22.812182234036236, "   rTPpowerTen = ", -1, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -23],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassI: \
formulaNameArray[["\[InvisibleSpace]3\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassI"\[InvisibleSpace]"   rightTailProbabilityDwassI = "\
\[InvisibleSpace]0.90006044094832201061191068281452569377`27.64409302871555\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]" \
  precisionDwassI = "\[InvisibleSpace]27\[InvisibleSpace]"   computerTime = "\
\[InvisibleSpace]0.016000000000019554`\),
        SequenceForm[ 
        "      DwassI: formulaNameArray[[", 3, "]] = ", "DwassI", 
          "   rightTailProbabilityDwassI = ", 
          0.90006044094832201061191068281452569377`27.64409302871555, 
          "   rTPpowerTen = ", -1, "   precisionDwassI = ", 27, 
          "   computerTime = ", .016000000000019554],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.90006044094832201061191068281441502514`23.06748390390467\
\[InvisibleSpace]"   rightTailProbabilityDwassI = \
"\[InvisibleSpace]0.90006044094832201061191068281452569377`27.64409302871555\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassI] = Min["\[InvisibleSpace]23\[InvisibleSpace]","\
\[InvisibleSpace]27\[InvisibleSpace]"] = \
"\[InvisibleSpace]23\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``23.113200717205466\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-23\)\),
        SequenceForm[ 
        "         DwassI verify: rightTailProbabilityDwassAltD = ", 
          0.90006044094832201061191068281441502514`23.06748390390467, 
          "   rightTailProbabilityDwassI = ", 
          0.90006044094832201061191068281452569377`27.64409302871555, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassI] = \
Min[", 23, ",", 27, "] = ", 23, "   rightTailProbabilityAbsDifference = ", 
          0``23.113200717205466, "   rTPpowerTen = ", -1, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -23],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltI: formulaNameArray[["\
\[InvisibleSpace]4\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltI"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.90006044094832201061191068281452569376`27.64409302871369\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]" \
  precisionDwassAltI = "\[InvisibleSpace]27\[InvisibleSpace]"   computerTime \
= "\[InvisibleSpace]0.014999999999986358`\),
        SequenceForm[ 
        "      DwassAltI: formulaNameArray[[", 4, "]] = ", "DwassAltI", 
          "   rightTailProbabilityDwassAltI = ", 
          0.90006044094832201061191068281452569376`27.64409302871369, 
          "   rTPpowerTen = ", -1, "   precisionDwassAltI = ", 27, 
          "   computerTime = ", .014999999999986358],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassAltI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.90006044094832201061191068281441502514`23.06748390390467\
\[InvisibleSpace]"   rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.90006044094832201061191068281452569376`27.64409302871369\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassAltI] = Min["\[InvisibleSpace]23\[InvisibleSpace]","\
\[InvisibleSpace]27\[InvisibleSpace]"] = \
"\[InvisibleSpace]23\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``23.113200717205466\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-23\)\),
        SequenceForm[ 
        "         DwassAltI verify: rightTailProbabilityDwassAltD = ", 
          0.90006044094832201061191068281441502514`23.06748390390467, 
          "   rightTailProbabilityDwassAltI = ", 
          0.90006044094832201061191068281452569376`27.64409302871369, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassAltI] = \
Min[", 23, ",", 27, "] = ", 23, "   rightTailProbabilityAbsDifference = ", 
          0``23.113200717205466, "   rTPpowerTen = ", -1, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -23],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      Rational DwassAltD: formulaNameArray[["\
\[InvisibleSpace]5\[InvisibleSpace]"]] = "\[InvisibleSpace]"Rational \
DwassAltD"\[InvisibleSpace]"   \
rightTailProbabilityDwassAltDrationalInArbPrecision = \
"\[InvisibleSpace]0.90006044094832201061191068281441501728`23. \
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]" \
  precisionDwassD = "\[InvisibleSpace]23\[InvisibleSpace]"   computerTime = "\
\[InvisibleSpace]2.203000000000003`\),
        SequenceForm[ 
        "      Rational DwassAltD: formulaNameArray[[", 5, "]] = ", 
          "Rational DwassAltD", 
          "   rightTailProbabilityDwassAltDrationalInArbPrecision = ", 
          0.90006044094832201061191068281441501728`23., 
          "   rTPpowerTen = ", -1, "   precisionDwassD = ", 23, 
          "   computerTime = ", 2.203000000000003],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassD verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.90006044094832201061191068281441502514`23.06748390390467\
\[InvisibleSpace]"   rightTailProbabilityDwassAltDrationalInArbPrecision = "\
\[InvisibleSpace]0.90006044094832201061191068281441501728`23. \
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassD] = Min["\[InvisibleSpace]23\[InvisibleSpace]","\
\[InvisibleSpace]23\[InvisibleSpace]"] = \
"\[InvisibleSpace]23\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``22.777130829857636\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-23\)\),
        SequenceForm[ 
        "         DwassD verify: rightTailProbabilityDwassAltD = ", 
          0.90006044094832201061191068281441502514`23.06748390390467, 
          "   rightTailProbabilityDwassAltDrationalInArbPrecision = ", 
          0.90006044094832201061191068281441501728`23., 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = \
Min[", 23, ",", 23, "] = ", 23, "   rightTailProbabilityAbsDifference = ", 
          0``22.777130829857636, "   rTPpowerTen = ", -1, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -23],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("  sampleSize = "\[InvisibleSpace]10000\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]"   alphaMD = "\[InvisibleSpace]0.001`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]6\/323\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0185758513931888545`3.000000000000001\),
        SequenceForm[ 
        "  sampleSize = ", 10000, "   desiredPrecision = ", 100, 
          "   alphaMD = ", .001, "   d = ", 
          Rational[ 6, 323], " = ", 0.0185758513931888545`3.000000000000001],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltD: formulaNameArray[["\
\[InvisibleSpace]1\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltD"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
000993768653620501602129718439759712327619998158887369106593011245117211212488\
69074620370681307854957009008504784897579720088`104.44260549059307\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-4\)\[InvisibleSpace]" \
  precisionDwassAltD = "\[InvisibleSpace]104\[InvisibleSpace]"   computerTime \
= "\[InvisibleSpace]0.03200000000001069`\),
        SequenceForm[ 
        "      DwassAltD: formulaNameArray[[", 1, "]] = ", "DwassAltD", 
          "   rightTailProbabilityDwassAltD = ", 
          0.000993768653620501602129718439759712327619998158887369106593011245\
11721121248869074620370681307854957009008504784897579720088`104.\
44260549059307, "   rTPpowerTen = ", -4, "   precisionDwassAltD = ", 104, 
          "   computerTime = ", .032000000000010687],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassD: \
formulaNameArray[["\[InvisibleSpace]2\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassD"\[InvisibleSpace]"   rightTailProbabilityDwassD = "\
\[InvisibleSpace]0.\
000993768653620501602129718439759712327619998158887369106593011245117211212488\
69074620370681307854957009008504784897296853505`104.44260549060031\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-4\)\[InvisibleSpace]" \
  precisionDwassD = "\[InvisibleSpace]104\[InvisibleSpace]"   computerTime = \
"\[InvisibleSpace]0.03099999999997749`\),
        SequenceForm[ 
        "      DwassD: formulaNameArray[[", 2, "]] = ", "DwassD", 
          "   rightTailProbabilityDwassD = ", 
          0.000993768653620501602129718439759712327619998158887369106593011245\
11721121248869074620370681307854957009008504784897296853505`104.\
44260549060031, "   rTPpowerTen = ", -4, "   precisionDwassD = ", 104, 
          "   computerTime = ", .03099999999997749],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassD verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
000993768653620501602129718439759712327619998158887369106593011245117211212488\
69074620370681307854957009008504784897579720088`104.44260549059307\
\[InvisibleSpace]"   rightTailProbabilityDwassD = \
"\[InvisibleSpace]0.\
000993768653620501602129718439759712327619998158887369106593011245117211212488\
69074620370681307854957009008504784897296853505`104.44260549060031\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassD] = Min["\[InvisibleSpace]104\[InvisibleSpace]","\
\[InvisibleSpace]104\[InvisibleSpace]"] = "\[InvisibleSpace]104\
\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``107.14429020122952\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-4\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-107\)\),
        SequenceForm[ 
        "         DwassD verify: rightTailProbabilityDwassAltD = ", 
          0.000993768653620501602129718439759712327619998158887369106593011245\
11721121248869074620370681307854957009008504784897579720088`104.\
44260549059307, "   rightTailProbabilityDwassD = ", 
          0.000993768653620501602129718439759712327619998158887369106593011245\
11721121248869074620370681307854957009008504784897296853505`104.\
44260549060031, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = \
Min[", 104, ",", 104, "] = ", 104, "   rightTailProbabilityAbsDifference = ", 
          0``107.14429020122952, "   rTPpowerTen = ", -4, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -107],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassI: \
formulaNameArray[["\[InvisibleSpace]3\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassI"\[InvisibleSpace]"   rightTailProbabilityDwassI = "\
\[InvisibleSpace]0.\
000993768653620501602129718439759712327619998158887369106593011245117211212488\
69074620370681307854957009008504784844802869976`106.11689803491359\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-4\)\[InvisibleSpace]" \
  precisionDwassI = "\[InvisibleSpace]106\[InvisibleSpace]"   computerTime = \
"\[InvisibleSpace]0.06200000000001182`\),
        SequenceForm[ 
        "      DwassI: formulaNameArray[[", 3, "]] = ", "DwassI", 
          "   rightTailProbabilityDwassI = ", 
          0.000993768653620501602129718439759712327619998158887369106593011245\
11721121248869074620370681307854957009008504784844802869976`106.\
11689803491359, "   rTPpowerTen = ", -4, "   precisionDwassI = ", 106, 
          "   computerTime = ", .062000000000011823],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
000993768653620501602129718439759712327619998158887369106593011245117211212488\
69074620370681307854957009008504784897579720088`104.44260549059307\
\[InvisibleSpace]"   rightTailProbabilityDwassI = \
"\[InvisibleSpace]0.\
000993768653620501602129718439759712327619998158887369106593011245117211212488\
69074620370681307854957009008504784844802869976`106.11689803491359\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassI] = Min["\[InvisibleSpace]104\[InvisibleSpace]","\
\[InvisibleSpace]106\[InvisibleSpace]"] = "\[InvisibleSpace]104\
\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``107.43622242714369\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-4\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-107\)\),
        SequenceForm[ 
        "         DwassI verify: rightTailProbabilityDwassAltD = ", 
          0.000993768653620501602129718439759712327619998158887369106593011245\
11721121248869074620370681307854957009008504784897579720088`104.\
44260549059307, "   rightTailProbabilityDwassI = ", 
          0.000993768653620501602129718439759712327619998158887369106593011245\
11721121248869074620370681307854957009008504784844802869976`106.\
11689803491359, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassI] = \
Min[", 104, ",", 106, "] = ", 104, "   rightTailProbabilityAbsDifference = ", 
          0``107.43622242714369, "   rTPpowerTen = ", -4, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -107],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltI: formulaNameArray[["\
\[InvisibleSpace]4\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltI"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.\
000993768653620501602129718439759712327619998158887369106593011245117211212488\
69074620370681307854957009008504784844802869977`106.11689803489278\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-4\)\[InvisibleSpace]" \
  precisionDwassAltI = "\[InvisibleSpace]106\[InvisibleSpace]"   computerTime \
= "\[InvisibleSpace]0.06299999999998818`\),
        SequenceForm[ 
        "      DwassAltI: formulaNameArray[[", 4, "]] = ", "DwassAltI", 
          "   rightTailProbabilityDwassAltI = ", 
          0.000993768653620501602129718439759712327619998158887369106593011245\
11721121248869074620370681307854957009008504784844802869977`106.\
11689803489278, "   rTPpowerTen = ", -4, "   precisionDwassAltI = ", 106, 
          "   computerTime = ", .062999999999988177],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassAltI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
000993768653620501602129718439759712327619998158887369106593011245117211212488\
69074620370681307854957009008504784897579720088`104.44260549059307\
\[InvisibleSpace]"   rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.\
000993768653620501602129718439759712327619998158887369106593011245117211212488\
69074620370681307854957009008504784844802869977`106.11689803489278\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassAltI] = Min["\[InvisibleSpace]104\[InvisibleSpace]","\
\[InvisibleSpace]106\[InvisibleSpace]"] = "\[InvisibleSpace]104\
\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``107.43622242714326\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-4\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-107\)\),
        SequenceForm[ 
        "         DwassAltI verify: rightTailProbabilityDwassAltD = ", 
          0.000993768653620501602129718439759712327619998158887369106593011245\
11721121248869074620370681307854957009008504784897579720088`104.\
44260549059307, "   rightTailProbabilityDwassAltI = ", 
          0.000993768653620501602129718439759712327619998158887369106593011245\
11721121248869074620370681307854957009008504784844802869977`106.\
11689803489278, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassAltI] = \
Min[", 104, ",", 106, "] = ", 104, "   rightTailProbabilityAbsDifference = ", 
          0``107.43622242714326, "   rTPpowerTen = ", -4, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -107],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      Rational DwassAltD: formulaNameArray[["\
\[InvisibleSpace]5\[InvisibleSpace]"]] = "\[InvisibleSpace]"Rational \
DwassAltD"\[InvisibleSpace]"   \
rightTailProbabilityDwassAltDrationalInArbPrecision = \
"\[InvisibleSpace]0.\
000993768653620501602129718439759712327619998158887369106593011245117211212488\
69074620370681307854957009008504784897415388831`104. \[InvisibleSpace]"   \
rTPpowerTen = "\[InvisibleSpace]\(-4\)\[InvisibleSpace]"   precisionDwassD = \
"\[InvisibleSpace]104\[InvisibleSpace]"   computerTime = \
"\[InvisibleSpace]17.125`\),
        SequenceForm[ 
        "      Rational DwassAltD: formulaNameArray[[", 5, "]] = ", 
          "Rational DwassAltD", 
          "   rightTailProbabilityDwassAltDrationalInArbPrecision = ", 
          0.000993768653620501602129718439759712327619998158887369106593011245\
11721121248869074620370681307854957009008504784897415388831`104., 
          "   rTPpowerTen = ", -4, "   precisionDwassD = ", 104, 
          "   computerTime = ", 17.125],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassD verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
000993768653620501602129718439759712327619998158887369106593011245117211212488\
69074620370681307854957009008504784897579720088`104.44260549059307\
\[InvisibleSpace]"   rightTailProbabilityDwassAltDrationalInArbPrecision = "\
\[InvisibleSpace]0.\
000993768653620501602129718439759712327619998158887369106593011245117211212488\
69074620370681307854957009008504784897415388831`104. \[InvisibleSpace]"   \
precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = Min["\
\[InvisibleSpace]104\[InvisibleSpace]","\[InvisibleSpace]104\[InvisibleSpace]\
"] = "\[InvisibleSpace]104\[InvisibleSpace]"   \
rightTailProbabilityAbsDifference = "\[InvisibleSpace]0``106.8688864694947\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-4\)\[InvisibleSpace]" \
  powerTenCompare =  rTPpowerTen - precisionUsed + 1 = \
"\[InvisibleSpace]\(-107\)\),
        SequenceForm[ 
        "         DwassD verify: rightTailProbabilityDwassAltD = ", 
          0.000993768653620501602129718439759712327619998158887369106593011245\
11721121248869074620370681307854957009008504784897579720088`104.\
44260549059307, "   rightTailProbabilityDwassAltDrationalInArbPrecision = ", 
          0.000993768653620501602129718439759712327619998158887369106593011245\
11721121248869074620370681307854957009008504784897415388831`104., 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = \
Min[", 104, ",", 104, "] = ", 104, "   rightTailProbabilityAbsDifference = ", 
          0``106.8688864694947, "   rTPpowerTen = ", -4, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -107],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("  sampleSize = "\[InvisibleSpace]10000\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]"   alphaMD = "\[InvisibleSpace]0.9`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]1\/439\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0022779043280182232`2.9999999999999987\),
        SequenceForm[ 
        "  sampleSize = ", 10000, "   desiredPrecision = ", 100, 
          "   alphaMD = ", .90000000000000002, "   d = ", 
          Rational[ 1, 439], " = ", 0.0022779043280182232`2.9999999999999987],
        
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltD: formulaNameArray[["\
\[InvisibleSpace]1\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltD"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
900060440948322010611910682814415058943426289685555603750837371199777863123265\
9891425675522512904764217386034220882`103.06748390390403\[InvisibleSpace]"   \
rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   precisionDwassAltD \
= "\[InvisibleSpace]103\[InvisibleSpace]"   computerTime = \
"\[InvisibleSpace]0.`\),
        SequenceForm[ 
        "      DwassAltD: formulaNameArray[[", 1, "]] = ", "DwassAltD", 
          "   rightTailProbabilityDwassAltD = ", 
          0.900060440948322010611910682814415058943426289685555603750837371199\
7778631232659891425675522512904764217386034220882`103.06748390390403, 
          "   rTPpowerTen = ", -1, "   precisionDwassAltD = ", 103, 
          "   computerTime = ", 0.0],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassD: \
formulaNameArray[["\[InvisibleSpace]2\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassD"\[InvisibleSpace]"   rightTailProbabilityDwassD = "\
\[InvisibleSpace]0.\
900060440948322010611910682814415058943426289685555603750837371199777863123265\
9891425675522512904764217386034220881`103.06748390390547\[InvisibleSpace]"   \
rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   precisionDwassD = \
"\[InvisibleSpace]103\[InvisibleSpace]"   computerTime = \
"\[InvisibleSpace]0.016000000000019554`\),
        SequenceForm[ 
        "      DwassD: formulaNameArray[[", 2, "]] = ", "DwassD", 
          "   rightTailProbabilityDwassD = ", 
          0.900060440948322010611910682814415058943426289685555603750837371199\
7778631232659891425675522512904764217386034220881`103.06748390390547, 
          "   rTPpowerTen = ", -1, "   precisionDwassD = ", 103, 
          "   computerTime = ", .016000000000019554],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassD verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
900060440948322010611910682814415058943426289685555603750837371199777863123265\
9891425675522512904764217386034220882`103.06748390390403\[InvisibleSpace]"   \
rightTailProbabilityDwassD = \
"\[InvisibleSpace]0.\
900060440948322010611910682814415058943426289685555603750837371199777863123265\
9891425675522512904764217386034220881`103.06748390390547\[InvisibleSpace]"   \
precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = Min["\
\[InvisibleSpace]103\[InvisibleSpace]","\[InvisibleSpace]103\[InvisibleSpace]\
"] = "\[InvisibleSpace]103\[InvisibleSpace]"   \
rightTailProbabilityAbsDifference = "\[InvisibleSpace]0``102.8121822340359\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]" \
  powerTenCompare =  rTPpowerTen - precisionUsed + 1 = \
"\[InvisibleSpace]\(-103\)\),
        SequenceForm[ 
        "         DwassD verify: rightTailProbabilityDwassAltD = ", 
          0.900060440948322010611910682814415058943426289685555603750837371199\
7778631232659891425675522512904764217386034220882`103.06748390390403, 
          "   rightTailProbabilityDwassD = ", 
          0.900060440948322010611910682814415058943426289685555603750837371199\
7778631232659891425675522512904764217386034220881`103.06748390390547, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = \
Min[", 103, ",", 103, "] = ", 103, "   rightTailProbabilityAbsDifference = ", 
          0``102.8121822340359, "   rTPpowerTen = ", -1, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -103],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassI: \
formulaNameArray[["\[InvisibleSpace]3\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassI"\[InvisibleSpace]"   rightTailProbabilityDwassI = "\
\[InvisibleSpace]0.\
900060440948322010611910682814415058943426289685555603750837371199777863123265\
98914256755225129047642173860342209447118435659`107.64409302871557\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]" \
  precisionDwassI = "\[InvisibleSpace]107\[InvisibleSpace]"   computerTime = \
"\[InvisibleSpace]0.014999999999986358`\),
        SequenceForm[ 
        "      DwassI: formulaNameArray[[", 3, "]] = ", "DwassI", 
          "   rightTailProbabilityDwassI = ", 
          0.900060440948322010611910682814415058943426289685555603750837371199\
77786312326598914256755225129047642173860342209447118435659`107.\
64409302871557, "   rTPpowerTen = ", -1, "   precisionDwassI = ", 107, 
          "   computerTime = ", .014999999999986358],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
900060440948322010611910682814415058943426289685555603750837371199777863123265\
9891425675522512904764217386034220882`103.06748390390403\[InvisibleSpace]"   \
rightTailProbabilityDwassI = \
"\[InvisibleSpace]0.\
900060440948322010611910682814415058943426289685555603750837371199777863123265\
98914256755225129047642173860342209447118435659`107.64409302871557\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassI] = Min["\[InvisibleSpace]103\[InvisibleSpace]","\
\[InvisibleSpace]107\[InvisibleSpace]"] = "\[InvisibleSpace]103\
\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``103.11320071720482\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-103\)\),
        SequenceForm[ 
        "         DwassI verify: rightTailProbabilityDwassAltD = ", 
          0.900060440948322010611910682814415058943426289685555603750837371199\
7778631232659891425675522512904764217386034220882`103.06748390390403, 
          "   rightTailProbabilityDwassI = ", 
          0.900060440948322010611910682814415058943426289685555603750837371199\
77786312326598914256755225129047642173860342209447118435659`107.\
64409302871557, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassI] = \
Min[", 103, ",", 107, "] = ", 103, "   rightTailProbabilityAbsDifference = ", 
          0``103.11320071720482, "   rTPpowerTen = ", -1, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -103],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltI: formulaNameArray[["\
\[InvisibleSpace]4\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltI"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.\
900060440948322010611910682814415058943426289685555603750837371199777863123265\
98914256755225129047642173860342209447118435659`107.64409302871304\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]" \
  precisionDwassAltI = "\[InvisibleSpace]107\[InvisibleSpace]"   computerTime \
= "\[InvisibleSpace]0.015999999999991132`\),
        SequenceForm[ 
        "      DwassAltI: formulaNameArray[[", 4, "]] = ", "DwassAltI", 
          "   rightTailProbabilityDwassAltI = ", 
          0.900060440948322010611910682814415058943426289685555603750837371199\
77786312326598914256755225129047642173860342209447118435659`107.\
64409302871304, "   rTPpowerTen = ", -1, "   precisionDwassAltI = ", 107, 
          "   computerTime = ", .015999999999991132],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassAltI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
900060440948322010611910682814415058943426289685555603750837371199777863123265\
9891425675522512904764217386034220882`103.06748390390403\[InvisibleSpace]"   \
rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.\
900060440948322010611910682814415058943426289685555603750837371199777863123265\
98914256755225129047642173860342209447118435659`107.64409302871304\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassAltI] = Min["\[InvisibleSpace]103\[InvisibleSpace]","\
\[InvisibleSpace]107\[InvisibleSpace]"] = "\[InvisibleSpace]103\
\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``103.11320071720482\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-103\)\),
        SequenceForm[ 
        "         DwassAltI verify: rightTailProbabilityDwassAltD = ", 
          0.900060440948322010611910682814415058943426289685555603750837371199\
7778631232659891425675522512904764217386034220882`103.06748390390403, 
          "   rightTailProbabilityDwassAltI = ", 
          0.900060440948322010611910682814415058943426289685555603750837371199\
77786312326598914256755225129047642173860342209447118435659`107.\
64409302871304, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassAltI] = \
Min[", 103, ",", 107, "] = ", 103, "   rightTailProbabilityAbsDifference = ", 
          0``103.11320071720482, "   rTPpowerTen = ", -1, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -103],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      Rational DwassAltD: formulaNameArray[["\
\[InvisibleSpace]5\[InvisibleSpace]"]] = "\[InvisibleSpace]"Rational \
DwassAltD"\[InvisibleSpace]"   \
rightTailProbabilityDwassAltDrationalInArbPrecision = \
"\[InvisibleSpace]0.\
900060440948322010611910682814415058943426289685555603750837371199777863123265\
9891425675522512904764217386034220876`103. \[InvisibleSpace]"   rTPpowerTen = \
"\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   precisionDwassD = "\
\[InvisibleSpace]103\[InvisibleSpace]"   computerTime = \
"\[InvisibleSpace]2.203000000000003`\),
        SequenceForm[ 
        "      Rational DwassAltD: formulaNameArray[[", 5, "]] = ", 
          "Rational DwassAltD", 
          "   rightTailProbabilityDwassAltDrationalInArbPrecision = ", 
          0.900060440948322010611910682814415058943426289685555603750837371199\
7778631232659891425675522512904764217386034220876`103., 
          "   rTPpowerTen = ", -1, "   precisionDwassD = ", 103, 
          "   computerTime = ", 2.203000000000003],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassD verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
900060440948322010611910682814415058943426289685555603750837371199777863123265\
9891425675522512904764217386034220882`103.06748390390403\[InvisibleSpace]"   \
rightTailProbabilityDwassAltDrationalInArbPrecision = \
"\[InvisibleSpace]0.\
900060440948322010611910682814415058943426289685555603750837371199777863123265\
9891425675522512904764217386034220876`103. \[InvisibleSpace]"   precisionUsed \
= Min[ precisionDwassAltD, precisionDwassD] = Min["\[InvisibleSpace]103\
\[InvisibleSpace]","\[InvisibleSpace]103\[InvisibleSpace]"] = "\
\[InvisibleSpace]103\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``102.77713082985734\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-103\)\),
        SequenceForm[ 
        "         DwassD verify: rightTailProbabilityDwassAltD = ", 
          0.900060440948322010611910682814415058943426289685555603750837371199\
7778631232659891425675522512904764217386034220882`103.06748390390403, 
          "   rightTailProbabilityDwassAltDrationalInArbPrecision = ", 
          0.900060440948322010611910682814415058943426289685555603750837371199\
7778631232659891425675522512904764217386034220876`103., 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = \
Min[", 103, ",", 103, "] = ", 103, "   rightTailProbabilityAbsDifference = ", 
          0``102.77713082985734, "   rTPpowerTen = ", -1, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -103],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.016000000000005343`", "0.`"},
                    {"0.03100000000000591`", "0.015000000000000568`"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.015000000000000568`", "0.016000000000005343`"},
                    {"0.016000000000005343`", "0.`"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.031999999999996476`", "0.`"},
                    {"0.046999999999997044`", "0.`"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.03100000000000591`", "0.015000000000000568`"},
                    {"0.046999999999997044`", "0.016000000000005343`"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"3.6559999999999917`", "0.4689999999999941`"},
                    {"3.6559999999999917`", "0.4689999999999941`"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.03100000000000591`", "0.`"},
                    {"0.03200000000001069`", "0.`"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.0309999999999917`", "0.`"},
                    {"0.03099999999997749`", "0.016000000000019554`"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.06300000000000239`", "0.016000000000019554`"},
                    {"0.06200000000001182`", "0.014999999999986358`"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.04600000000000648`", "0.014999999999986358`"},
                    {"0.06299999999998818`", "0.015999999999991132`"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"17.125`", "2.203000000000003`"},
                    {"17.125`", "2.203000000000003`"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
22.2  Dwass Arb Precision and Rational Timing To File Sample Output File, \
C:/KSoutput/KS1SidedOneSampleDwassArbPrecisionRationalTimingsTest.csv\
\>", "Subsection"],

Cell[BoxData[{
    \(rho = 3, , , , Desired, , Sample, , Computer\), "\n", 
    \(Precision, , Size, , Time\ In\), "\n", 
    \(dp, alphaMD, n, Formula, Seconds\), "\n", 
    \(20, 0.001, 5000, DwassAltD, 0.016000000000005343\), "\n", 
    \(20, 0.001, 5000, DwassD, 0.015000000000000568\), "\n", 
    \(20, 0.001, 5000, DwassI, 0.031999999999996476\), "\n", 
    \(20, 0.001, 5000, DwassAltI, 0.03100000000000591\), "\n", 
    \(20, 0.001, 5000, Rational\ DwassAltD, 3.6559999999999917\), "\n", 
    \(20, 0.9, 5000, DwassAltD, 0. \), "\n", 
    \(20, 0.9, 5000, DwassD, 0.016000000000005343\), "\n", 
    \(20, 0.9, 5000, DwassI, 0. \), "\n", 
    \(20, 0.9, 5000, DwassAltI, 0.015000000000000568\), "\n", 
    \(20, 0.9, 5000, Rational\ DwassAltD, 0.4689999999999941\), "\n", 
    \(100, 0.001, 5000, DwassAltD, 0.03100000000000591\), "\n", 
    \(100, 0.001, 5000, DwassD, 0.016000000000005343\), "\n", 
    \(100, 0.001, 5000, DwassI, 0.046999999999997044\), "\n", 
    \(100, 0.001, 5000, DwassAltI, 0.046999999999997044\), "\n", 
    \(100, 0.001, 5000, Rational\ DwassAltD, 3.6559999999999917\), "\n", 
    \(100, 0.9, 5000, DwassAltD, 0.015000000000000568\), "\n", 
    \(100, 0.9, 5000, DwassD, 0. \), "\n", 
    \(100, 0.9, 5000, DwassI, 0. \), "\n", 
    \(100, 0.9, 5000, DwassAltI, 0.016000000000005343\), "\n", 
    \(100, 0.9, 5000, Rational\ DwassAltD, 0.4689999999999941\), "\n", 
    \(20, 0.001, 10000, DwassAltD, 0.03100000000000591\), "\n", 
    \(20, 0.001, 10000, DwassD, 0.0309999999999917\), "\n", 
    \(20, 0.001, 10000, DwassI, 0.06300000000000239\), "\n", 
    \(20, 0.001, 10000, DwassAltI, 0.04600000000000648\), "\n", 
    \(20, 0.001, 10000, Rational\ DwassAltD, 17.125\), "\n", 
    \(20, 0.9, 10000, DwassAltD, 0. \), "\n", 
    \(20, 0.9, 10000, DwassD, 0. \), "\n", 
    \(20, 0.9, 10000, DwassI, 0.016000000000019554\), "\n", 
    \(20, 0.9, 10000, DwassAltI, 0.014999999999986358\), "\n", 
    \(20, 0.9, 10000, Rational\ DwassAltD, 2.203000000000003\), "\n", 
    \(100, 0.001, 10000, DwassAltD, 0.03200000000001069\), "\n", 
    \(100, 0.001, 10000, DwassD, 0.03099999999997749\), "\n", 
    \(100, 0.001, 10000, DwassI, 0.06200000000001182\), "\n", 
    \(100, 0.001, 10000, DwassAltI, 0.06299999999998818\), "\n", 
    \(100, 0.001, 10000, Rational\ DwassAltD, 17.125\), "\n", 
    \(100, 0.9, 10000, DwassAltD, 0. \), "\n", 
    \(100, 0.9, 10000, DwassD, 0.016000000000019554\), "\n", 
    \(100, 0.9, 10000, DwassI, 0.014999999999986358\), "\n", 
    \(100, 0.9, 10000, DwassAltI, 0.015999999999991132\), "\n", 
    \(\(\(100, 0.9, 10000, Rational\ DwassAltD, 
    2.203000000000003\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(,\)\(,\)\(Computer\ \
Time\)\(,\)\(,\)\(,\)\(,\)\(Sample\)\(,\)\(,\)\(Desired\ Precision\ dp = 
      20\)\(,\)\(,\)\(Desired\ Precision\ dp = 
      100\)\(,\)\(Size\)\(,\)\(,\)\(alphaMD\)\(,\)\(,\)\(alphaMD\)\(,\)\(n\)\(\
,\)\(Formula\)\(,\)\(0.001\)\(,\)\(0.9\)\(,\)\(0.001\)\(,\)\(0.9\)\)\), "\n", \

    \(5000, DwassAltD, 0.016000000000005343, 0. , 0.03100000000000591, 
    0.015000000000000568\), "\n", 
    \(\(\(,\)\(DwassD\)\(,\)\(0.015000000000000568\)\(,\)\(0.\
016000000000005343\)\(,\)\(0.016000000000005343\)\(,\)\(0.\)\)\), "\n", 
    \(\(\(,\)\(DwassI\)\(,\)\(0.031999999999996476\)\(,\)\(0.\)\(,\)\(0.\
046999999999997044\)\(,\)\(0.\)\)\), "\n", 
    \(\(\(,\)\(DwassAltI\)\(,\)\(0.03100000000000591\)\(,\)\(0.\
015000000000000568\)\(,\)\(0.046999999999997044\)\(,\)\(0.016000000000005343\)\
\)\), "\n", 
    \(\(\(,\)\(Rational\ \
DwassAltD\)\(,\)\(3.6559999999999917\)\(,\)\(0.4689999999999941\)\(,\)\(3.\
6559999999999917\)\(,\)\(0.4689999999999941\)\)\), "\n", 
    \(10000, DwassAltD, 0.03100000000000591, 0. , 0.03200000000001069, 
    0. \), "\n", 
    \(\(\(,\)\(DwassD\)\(,\)\(0.0309999999999917\)\(,\)\(0.\)\(,\)\(0.\
03099999999997749\)\(,\)\(0.016000000000019554\)\)\), "\n", 
    \(\(\(,\)\(DwassI\)\(,\)\(0.06300000000000239\)\(,\)\(0.\
016000000000019554\)\(,\)\(0.06200000000001182\)\(,\)\(0.014999999999986358\)\
\)\), "\n", 
    \(\(\(,\)\(DwassAltI\)\(,\)\(0.04600000000000648\)\(,\)\(0.\
014999999999986358\)\(,\)\(0.06299999999998818\)\(,\)\(0.015999999999991132\)\
\)\), "\n", 
    \(\(\(\(,\)\(Rational\ DwassAltD\)\(,\)\(17.125\)\(,\)\(2.203000000000003\
\)\(,\)\(17.125\)\(,\)\(2.203000000000003\)\)\(\[IndentingNewLine]\)\(\
\[IndentingNewLine]\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(,\)\(,\)\(Computer\ \
Time\)\(,\)\(,\)\(,\)\(,\)\(Sample\)\(,\)\(,\)\(alphaMD = 
      0.001\)\(,\)\(,\)\(alphaMD = 
      0.9\)\(,\)\(Size\)\(,\)\(,\)\(Desired\ Precision\ \
dp\)\(,\)\(,\)\(Desired\ Precision\ dp\)\(,\)\(n\)\(,\)\(Formula\)\(,\)\(20\)\
\(,\)\(100\)\(,\)\(20\)\(,\)\(100\)\)\), "\n", 
    \(5000, DwassAltD, 0.016000000000005343, 0.03100000000000591, 0. , 
    0.015000000000000568\), "\n", 
    \(\(\(,\)\(DwassD\)\(,\)\(0.015000000000000568\)\(,\)\(0.\
016000000000005343\)\(,\)\(0.016000000000005343\)\(,\)\(0.\)\)\), "\n", 
    \(\(\(,\)\(DwassI\)\(,\)\(0.031999999999996476\)\(,\)\(0.\
046999999999997044\)\(,\)\(0.\)\(,\)\(0.\)\)\), "\n", 
    \(\(\(,\)\(DwassAltI\)\(,\)\(0.03100000000000591\)\(,\)\(0.\
046999999999997044\)\(,\)\(0.015000000000000568\)\(,\)\(0.016000000000005343\)\
\)\), "\n", 
    \(\(\(,\)\(Rational\ \
DwassAltD\)\(,\)\(3.6559999999999917\)\(,\)\(3.6559999999999917\)\(,\)\(0.\
4689999999999941\)\(,\)\(0.4689999999999941\)\)\), "\n", 
    \(10000, DwassAltD, 0.03100000000000591, 0.03200000000001069, 0. , 
    0. \), "\n", 
    \(\(\(,\)\(DwassD\)\(,\)\(0.0309999999999917\)\(,\)\(0.03099999999997749\)\
\(,\)\(0.\)\(,\)\(0.016000000000019554\)\)\), "\n", 
    \(\(\(,\)\(DwassI\)\(,\)\(0.06300000000000239\)\(,\)\(0.06200000000001182\
\)\(,\)\(0.016000000000019554\)\(,\)\(0.014999999999986358\)\)\), "\n", 
    \(\(\(,\)\(DwassAltI\)\(,\)\(0.04600000000000648\)\(,\)\(0.\
06299999999998818\)\(,\)\(0.014999999999986358\)\(,\)\(0.015999999999991132\)\
\)\), "\n", 
    \(\(\(\(,\)\(Rational\ \
DwassAltD\)\(,\)\(17.125\)\(,\)\(17.125\)\(,\)\(2.203000000000003\)\(,\)\(2.\
203000000000003\)\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\)}], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["23. Dwass Arb Precision Timing To File", "Section"],

Cell["\<\
The following is the code of the Mathematica function \
DwassArbPrecisionTimingsToFile that calculates the computer time in seconds \
needed for the arbitrary precision DwassAltD, DwassD, DwassI, and DwassAltI \
formulae.  The computer times are genreated for the sample sizes in the \
vector sampleSizeVectorIn, the desired precisions in the vector \
desiredPrecisionVectorIn, and the Maag and Dicaire test statistic to rho \
digits of precision for the p-values in the vector alphaVectorIn.  For the \
same sample size, desired precision, and test statistic, the right tail \
probabilities produced by all formulae are compared to determine if there are \
any errors.  The results are written to file outputFileName which can be read \
by Execel if separatorString is a comma.  Sample intermediate output is given \
in subsection 23.1.  The sample output file generated by the example in \
subsection 23.1 is given in subsection 23.2.\
\>", "Text"],

Cell[BoxData[
    \(DwassArbPrecisionTimingsToFile[sampleSizeVectorIn_, \ 
        desiredPrecisionVectorIn_, \ alphaMDVectorIn_, \ 
        intermediateOutput_, \ outputFileName_, \ howToOpenFile_, \ 
        separatorString_, \ rhoIn_]\  := \ 
      Module[{numberSampleSizes, \ numberDesiredPrecisions, \ 
          numberalphaMDs, \ VectorDimensions, \ numberFormulae, \ 
          sampleSize, \ desiredPrecision, \ alphaMD, \ 
          numberDesiredPrecisionsAndalphaMDs, \ computerTime, \ 
          sampleSizeIndex, \ desiredPrecisionIndex, \ alphaMDIndex, \ 
          formulaIndex, \ formulaName, \ outputFileNumber, \ 
          computerTimeArray, \ formulaNameArray, \ d, \ rho, \ numExp, \ 
          nOutputString, \ numberTermsOutputString, \ 
          desiredPrecisionOutputString, \ computerTimeOutputString, \ 
          stringIndex, \ functionOutput, \ rightTailProbability, \ 
          rightTailProbabilityPrecision, \ 
          rightTailProbabilityAbsDifference, \ functionTimeString, \ 
          timeString, \ rTPpowerTen, rTP, \ precisionUsed, \ 
          precisionDwassAltD, \ precisionDwassD, \ precisionDwassI, \ 
          precisionDwassAltI, \ rightTailProbabilityDwassAltD, \ 
          rightTailProbabilityDwassD, \ rightTailProbabilityDwassI, \ 
          rightTailProbabilityDwassAltI, \ 
          powerTenCompare}, \[IndentingNewLine] (*\ 
          Generate\ timings\ for\ desired\ precision\ formulae\ \((DwassAltD, \
\ DwassD, \[IndentingNewLine]\ \ \ \ \ DwassI, \ DwassAltI)\), \ 
          check\ to\ see\ if\ all\ formulae\ get\ the\ \
same\[IndentingNewLine]\ \ \ \ \ \ right\ tail\ probability, \ 
          and\ put\ timings\ into\ file, \ 
          outputFileName\ *) \[IndentingNewLine] (*\ 
          Open\ \(file : \ howToOpenFile\) = 0, \ 
          use\ OpenWrite\ which\ creates\ a\ new\ file\[IndentingNewLine]\ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ and\ destroys\ an\ old\ \
file\ *) \ \[IndentingNewLine] (*\ \ \ \ \ \ \ \ \ \ \ \ howToOpenFile = 1, \ 
          use\ OpenAppend\ which\ opens\ file\ and\[IndentingNewLine]\ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ appends\ output\ to\ end\ \
of\ that\ \(\(file\)\(.\)\)\ \ *) \[IndentingNewLine]VectorDimensions\  = \ 
          Dimensions[
            sampleSizeVectorIn]; \[IndentingNewLine]numberSampleSizes\  = \ \ \
VectorDimensions[\([1]\)]; \[IndentingNewLine]VectorDimensions\  = \ 
          Dimensions[
            desiredPrecisionVectorIn]; \
\[IndentingNewLine]numberDesiredPrecisions\  = \ \ VectorDimensions[\([1]\)]; \
\[IndentingNewLine]VectorDimensions\  = \ 
          Dimensions[
            alphaMDVectorIn]; \[IndentingNewLine]numberalphaMDs\  = \ \ \
VectorDimensions[\([1]\)]; \
\[IndentingNewLine]numberDesiredPrecisionsAndalphaMDs\  = \ 
          numberDesiredPrecisions\ *\ 
            numberalphaMDs; \[IndentingNewLine]rho\  = \ 
          Round[rhoIn]; \[IndentingNewLine]If[\ rho\  < \ 2, \ 
          rho\  = \ 2]; \[IndentingNewLine]numberFormulae\  = \ 
          4; \[IndentingNewLine]formulaNameArray\  = \ 
          Array["\<DeassAltD\>", \ {5}]; \[IndentingNewLine]formulaNameArray[\
\([1]\)]\  = \ "\<DwassAltD\>"; \[IndentingNewLine]formulaNameArray[\([2]\)]\ \
 = \ "\<DwassD\>"; \[IndentingNewLine]formulaNameArray[\([3]\)]\  = \ \
"\<DwassI\>"; \[IndentingNewLine]formulaNameArray[\([4]\)]\  = \ "\<DwassAltI\
\>"; \[IndentingNewLine]computerTimeArray\  = \ 
          Array[0, \ {numberSampleSizes, \ numberFormulae, \ 
              numberDesiredPrecisions, \ 
              numberalphaMDs}]; \[IndentingNewLine]If[
          howToOpenFile\  \[LessEqual] \ 0, \ 
          outputFileNumber\  = \ OpenWrite[outputFileName], \ 
          outputFileNumber\  = \ 
            OpenAppend[outputFileName]]; \[IndentingNewLine]If[
          howToOpenFile\  \[LessEqual] \ 0, \ \[IndentingNewLine] (*\ 
            Output\ all\ the\ computer\ times\ in\ a\ vector\ \
*) \[IndentingNewLine]WriteString[outputFileNumber, \ "\<rho = \>", \ 
            rho, \ \ separatorString, \ 
            separatorString, \ \ separatorString, \ 
            separatorString, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<Desired\>", \ \ separatorString, \ 
            separatorString, \ "\<Sample\>", \ \ separatorString, \ 
            separatorString, \ \ "\<Computer\>", \ "\<\n\>"\ ]; \
\[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<Precision\>", \ \ separatorString, \ 
            separatorString, \ "\<Size\>", \ separatorString, \ 
            separatorString, \ "\<Time In\>", \ "\<\n\>"\ ]; \
\[IndentingNewLine]WriteString[
            outputFileNumber, "\<dp\>", \ \ separatorString, \ "\<alphaMD\>", \
\ separatorString, \ "\<n\>", \ 
            separatorString, \ \ "\<Formula\>", \ \ separatorString, \ \
"\<Seconds\>", \ "\<\n\>"\ ];\[IndentingNewLine]]; \[IndentingNewLine]If[
          intermediateOutput\  \[GreaterEqual] \ 
            1, \[IndentingNewLine]\(Print["\<DwassArbPrecisionTimingsToFile:  \
For \>", \ 
              numberSampleSizes, "\< sampleSizes \>", \ \ sampleSizeVectorIn, \
\ "\<; \>", \ numberDesiredPrecisions, "\< desiredPrecisions \>", 
              desiredPrecisionVectorIn, \ \ "\<; \>", \ 
              numberalphaMDs, "\< alphaMDs \>", 
              alphaMDVectorIn, "\<; and \>", \ 
              numberFormulae, "\< formulae \>", \ 
              formulaNameArray, \ "\<, outputFileName = \>", \ 
              outputFileName, \ "\<, howToOpenFile = \>", \ 
              howToOpenFile, \ "\<, and separatorString = '\>", \ 
              separatorString, \ "\<'\>", \ "\<   intermediateOutput = \>", \ 
              intermediateOutput, \ "\<   rho = \>", \ 
              rho];\)\[IndentingNewLine]]; \[IndentingNewLine]Do[\
\[IndentingNewLine]sampleSize\  = \ 
            sampleSizeVectorIn[\([sampleSizeIndex]\)]; \[IndentingNewLine]Do[\
\[IndentingNewLine]desiredPrecision\  = \ 
              desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)]; \
\[IndentingNewLine]Do[\[IndentingNewLine]alphaMD\  = \ \ \
alphaMDVectorIn[\([alphaMDIndex]\)]; \[IndentingNewLine]d\  = \ 
                Rationalize[
                  KS1SidedOneSampleTestStatisticByMaagDicaire[alphaMD, 
                    sampleSize, \ rho], 0]; \[IndentingNewLine]If[
                intermediateOutput\  \[GreaterEqual] \ 
                  2, \[IndentingNewLine]\(Print["\<  sampleSize = \>", \ \ \
sampleSize, \ "\<   desiredPrecision = \>", \ 
                    desiredPrecision, \ "\<   alphaMD = \>", \ 
                    alphaMD, \ "\<   d = \>", \ d, \ "\< = \>", \ 
                    N[d, \ rho]];\)\[IndentingNewLine]]; \[IndentingNewLine] \
(*\ DwassAltD\ computer\ time\ *) \[IndentingNewLine]formulaIndex\  = \ 
                1; \[IndentingNewLine]formulaName\  = \ 
                formulaNameArray[\([formulaIndex]\)]; \
\[IndentingNewLine]functionOutput\  = \ 
                Timing[DwassAltDKS1SidedOneSampleRTdesiredPrecision[d, 
                    sampleSize, \ 
                    desiredPrecision]]; \
\[IndentingNewLine]rightTailProbabilityDwassAltD\  = \ 
                functionOutput[\([2]\)]; \
\[IndentingNewLine]precisionDwassAltD\  = \ 
                Floor[Precision[
                    rightTailProbabilityDwassAltD]]; \
\[IndentingNewLine]functionTimeString\  = \ 
                functionOutput[\([1]\)]; \[IndentingNewLine]timeString\  = \ 
                functionTimeString\  /. \ 
                  Second \[Rule] 1; \[IndentingNewLine]computerTime\  = \ 
                timeString; \[IndentingNewLine]rTP\  = \ 
                rightTailProbabilityDwassAltD; \[IndentingNewLine]rTPpowerTen\
\  = \ 0; \[IndentingNewLine]Label[AnotherPower]; \[IndentingNewLine]If[
                rTP\  < \ 1, \ rTPpowerTen\  = \ rTPpowerTen\  - \ 1; \ 
                rTP\  = \ N[rTP\ *\ 10, precisionDwassAltD\ ]; \ 
                Goto[AnotherPower]\ \ \ ]; \
\[IndentingNewLine]computerTimeArray[\([sampleSizeIndex, \ formulaIndex, \ 
                    desiredPrecisionIndex, \ alphaMDIndex]\)]\  = \ 
                computerTime; \[IndentingNewLine]WriteString[
                outputFileNumber, \ 
                ToString[\ desiredPrecision, \ 
                  FortranForm], \ \ separatorString, \ 
                ToString[\ alphaMD, \ FortranForm], \ \ separatorString, \ 
                ToString[\ sampleSize, \ FortranForm], \ \ separatorString, \ 
                formulaName, \ \ separatorString, \ 
                ToString[\ 
                    computerTimeArray[\([sampleSizeIndex, \ formulaIndex, \ 
                        desiredPrecisionIndex, \ alphaMDIndex]\)], \ 
                    FortranForm]\ "\<\n\>"]; \[IndentingNewLine]If[
                intermediateOutput\  \[GreaterEqual] \ 
                  3, \[IndentingNewLine]\(Print["\<      DwassAltD: \
formulaNameArray[[\>", \ formulaIndex, \ "\<]] = \>", \ 
                    formulaNameArray[\([formulaIndex]\)]\ , \ "\<   \
rightTailProbabilityDwassAltD = \>", \ \ rightTailProbabilityDwassAltD, \ "\< \
  rTPpowerTen = \>", \ rTPpowerTen, \ "\<   precisionDwassAltD = \>", \ 
                    precisionDwassAltD, \ "\<   computerTime = \>", \ 
                    
                    computerTime];\)\[IndentingNewLine]]; \[IndentingNewLine] \
(*\ DwassD\ computer\ time\ *) \[IndentingNewLine]formulaIndex\  = \ 
                2; \[IndentingNewLine]formulaName\  = \ 
                formulaNameArray[\([formulaIndex]\)]; \
\[IndentingNewLine]functionOutput\  = \ 
                Timing[DwassDKS1SidedOneSampleRTdesiredPrecision[d, 
                    sampleSize, \ 
                    desiredPrecision]]; \
\[IndentingNewLine]rightTailProbabilityDwassD\  = \ 
                functionOutput[\([2]\)]; \[IndentingNewLine]precisionDwassD\  \
= \ Floor[Precision[
                    rightTailProbabilityDwassD]]; \
\[IndentingNewLine]functionTimeString\  = \ 
                functionOutput[\([1]\)]; \[IndentingNewLine]timeString\  = \ 
                functionTimeString\  /. \ 
                  Second \[Rule] 1; \[IndentingNewLine]computerTime\  = \ 
                timeString; \
\[IndentingNewLine]computerTimeArray[\([sampleSizeIndex, \ formulaIndex, \ 
                    desiredPrecisionIndex, \ alphaMDIndex]\)]\  = \ 
                computerTime; \[IndentingNewLine]WriteString[
                outputFileNumber, \ 
                ToString[\ desiredPrecision, \ 
                  FortranForm], \ \ separatorString, \ 
                ToString[\ alphaMD, \ FortranForm], \ \ separatorString, \ 
                ToString[\ sampleSize, \ FortranForm], \ \ separatorString, \ 
                formulaName, \ \ separatorString, \ 
                ToString[\ 
                    computerTimeArray[\([sampleSizeIndex, \ formulaIndex, \ 
                        desiredPrecisionIndex, \ alphaMDIndex]\)], \ 
                    FortranForm]\ "\<\n\>"]; \[IndentingNewLine]If[
                intermediateOutput\  \[GreaterEqual] \ 
                  3, \[IndentingNewLine]\(Print["\<      DwassD: \
formulaNameArray[[\>", \ formulaIndex, \ "\<]] = \>", \ 
                    formulaNameArray[\([formulaIndex]\)]\ , \ "\<   \
rightTailProbabilityDwassD = \>", \ \ rightTailProbabilityDwassD, \ "\<   \
rTPpowerTen = \>", \ rTPpowerTen, \ "\<   precisionDwassD = \>", \ 
                    precisionDwassD, \ "\<   computerTime = \>", \ 
                    computerTime];\)\[IndentingNewLine]]; \[IndentingNewLine] \
(*\ \ \ \ Verify\ if\ rightTailProbabilityDwassAltD\ same\ as\ \
rightTailProbabilityDwassD\ *) \[IndentingNewLine]precisionUsed\  = \ 
                Min[\ precisionDwassAltD, \ 
                  
                  precisionDwassD]; \
\[IndentingNewLine]rightTailProbabilityAbsDifference\  = \ 
                N[\ Abs[
                    rightTailProbabilityDwassAltD\  - \ 
                      rightTailProbabilityDwassD], \ 
                  precisionUsed]; \[IndentingNewLine]powerTenCompare\  = \ \ \
rTPpowerTen\  - \ precisionUsed\  + \ 1; \[IndentingNewLine]If[
                intermediateOutput\  \[GreaterEqual] \ 
                  4, \[IndentingNewLine]\(Print["\<         DwassD verify: \
rightTailProbabilityDwassAltD = \>", \ \ rightTailProbabilityDwassAltD, \ "\< \
  rightTailProbabilityDwassD = \>", \ \ rightTailProbabilityDwassD, \ "\<   \
precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = Min[\>", \ 
                    precisionDwassAltD, "\<,\>", \ 
                    precisionDwassD, \ "\<] = \>", 
                    precisionUsed, \ "\<   rightTailProbabilityAbsDifference \
= \>", \ rightTailProbabilityAbsDifference, \ "\<   rTPpowerTen = \>", \ 
                    rTPpowerTen, \ "\<   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = \>", \ 
                    powerTenCompare];\)\[IndentingNewLine]]; \
\[IndentingNewLine]If[
                rightTailProbabilityAbsDifference\  > \ 
                  10^{powerTenCompare}, \ 
                Print["\<*****ERROR*****:  rightTailProbabilityDwassAltD not \
the same as rightTailProbabilityDwassD.\>"]; \ \[IndentingNewLine]Print["\<   \
      DwassD verify: rightTailProbabilityDwassAltD = \>", \ \ \
rightTailProbabilityDwassAltD, \ "\<   rightTailProbabilityDwassD = \>", \ \ \
rightTailProbabilityDwassD, \ "\<   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassD] = Min[\>", \ precisionDwassAltD, "\<,\>", \ 
                  precisionDwassD, \ "\<] = \>", 
                  precisionUsed, \ "\<   rightTailProbabilityAbsDifference = \
\>", \ rightTailProbabilityAbsDifference, \ "\<   rTPpowerTen = \>", \ 
                  rTPpowerTen, \ "\<   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = \>", \ 
                  powerTenCompare];\[IndentingNewLine]]; \[IndentingNewLine] \
(*\ DwassI\ computer\ time\ *) \[IndentingNewLine]formulaIndex\  = \ 
                3; \[IndentingNewLine]formulaName\  = \ 
                formulaNameArray[\([formulaIndex]\)]; \
\[IndentingNewLine]functionOutput\  = \ 
                Timing[DwassIKS1SidedOneSampleRTdesiredPrecision[d, 
                    sampleSize, \ 
                    desiredPrecision]]; \
\[IndentingNewLine]rightTailProbabilityDwassI\  = \ 
                functionOutput[\([2]\)]; \[IndentingNewLine]precisionDwassI\  \
= \ Floor[Precision[
                    rightTailProbabilityDwassI]]; \
\[IndentingNewLine]functionTimeString\  = \ 
                functionOutput[\([1]\)]; \[IndentingNewLine]timeString\  = \ 
                functionTimeString\  /. \ 
                  Second \[Rule] 1; \[IndentingNewLine]computerTime\  = \ 
                timeString; \
\[IndentingNewLine]computerTimeArray[\([sampleSizeIndex, \ formulaIndex, \ 
                    desiredPrecisionIndex, \ alphaMDIndex]\)]\  = \ 
                computerTime; \[IndentingNewLine]WriteString[
                outputFileNumber, \ 
                ToString[\ desiredPrecision, \ 
                  FortranForm], \ \ separatorString, \ 
                ToString[\ alphaMD, \ FortranForm], \ \ separatorString, \ 
                ToString[\ sampleSize, \ FortranForm], \ \ separatorString, \ 
                formulaName, \ \ separatorString, \ 
                ToString[\ 
                    computerTimeArray[\([sampleSizeIndex, \ formulaIndex, \ 
                        desiredPrecisionIndex, \ alphaMDIndex]\)], \ 
                    FortranForm]\ "\<\n\>"]; \[IndentingNewLine]If[
                intermediateOutput\  \[GreaterEqual] \ 
                  3, \[IndentingNewLine]\(Print["\<      DwassI: \
formulaNameArray[[\>", \ formulaIndex, \ "\<]] = \>", \ 
                    formulaNameArray[\([formulaIndex]\)]\ , \ "\<   \
rightTailProbabilityDwassI = \>", \ \ rightTailProbabilityDwassI, \ "\<   \
rTPpowerTen = \>", \ rTPpowerTen, \ "\<   precisionDwassI = \>", \ 
                    precisionDwassI, \ "\<   computerTime = \>", \ 
                    computerTime];\)\[IndentingNewLine]]; \[IndentingNewLine] \
(*\ \ \ \ Verify\ if\ rightTailProbabilityDwassAltD\ same\ as\ \
rightTailProbabilityDwassI\ *) \[IndentingNewLine]precisionUsed\  = \ 
                Min[\ precisionDwassAltD, \ 
                  precisionDwassI]; \
\[IndentingNewLine]rightTailProbabilityAbsDifference\  = \ 
                N[\ Abs[
                    rightTailProbabilityDwassAltD\  - \ 
                      rightTailProbabilityDwassI], \ 
                  precisionUsed]; \[IndentingNewLine]powerTenCompare\  = \ \ \
rTPpowerTen\  - \ precisionUsed\  + \ 1; \[IndentingNewLine]If[
                intermediateOutput\  \[GreaterEqual] \ 
                  4, \[IndentingNewLine]\(Print["\<         DwassI verify: \
rightTailProbabilityDwassAltD = \>", \ \ rightTailProbabilityDwassAltD, \ "\< \
  rightTailProbabilityDwassI = \>", \ \ rightTailProbabilityDwassI, \ "\<   \
precisionUsed = Min[ precisionDwassAltD, precisionDwassI] = Min[\>", \ 
                    precisionDwassAltD, "\<,\>", \ 
                    precisionDwassI, \ "\<] = \>", 
                    precisionUsed, \ "\<   rightTailProbabilityAbsDifference \
= \>", \ rightTailProbabilityAbsDifference, \ "\<   rTPpowerTen = \>", \ 
                    rTPpowerTen, \ "\<   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = \>", \ 
                    powerTenCompare];\)\[IndentingNewLine]]; \
\[IndentingNewLine]If[
                rightTailProbabilityAbsDifference\  > \ 
                  10^{powerTenCompare}, \ 
                Print["\<*****ERROR*****:  rightTailProbabilityDwassAltD not \
the same as rightTailProbabilityDwassI.\>"]; \ \[IndentingNewLine]Print["\<   \
      DwassI verify: rightTailProbabilityDwassAltD = \>", \ \ \
rightTailProbabilityDwassAltD, \ "\<   rightTailProbabilityDwassI = \>", \ \ \
rightTailProbabilityDwassI, \ "\<   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassI] = Min[\>", \ precisionDwassAltD, "\<,\>", \ 
                  precisionDwassI, \ "\<] = \>", 
                  precisionUsed, \ "\<   rightTailProbabilityAbsDifference = \
\>", \ rightTailProbabilityAbsDifference, \ "\<   rTPpowerTen = \>", \ 
                  rTPpowerTen, \ "\<   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = \>", \ 
                  powerTenCompare];\[IndentingNewLine]]; \[IndentingNewLine] \
(*\ DwassAltI\ computer\ time\ *) \[IndentingNewLine]formulaIndex\  = \ 
                4; \[IndentingNewLine]formulaName\  = \ 
                formulaNameArray[\([formulaIndex]\)]; \
\[IndentingNewLine]functionOutput\  = \ 
                Timing[DwassAltIKS1SidedOneSampleRTdesiredPrecision[d, 
                    sampleSize, \ 
                    desiredPrecision]]; \
\[IndentingNewLine]rightTailProbabilityDwassAltI\  = \ 
                functionOutput[\([2]\)]; \
\[IndentingNewLine]precisionDwassAltI\  = \ 
                Floor[Precision[
                    rightTailProbabilityDwassAltI]]; \
\[IndentingNewLine]functionTimeString\  = \ 
                functionOutput[\([1]\)]; \[IndentingNewLine]timeString\  = \ 
                functionTimeString\  /. \ 
                  Second \[Rule] 1; \[IndentingNewLine]computerTime\  = \ 
                timeString; \
\[IndentingNewLine]computerTimeArray[\([sampleSizeIndex, \ formulaIndex, \ 
                    desiredPrecisionIndex, \ alphaMDIndex]\)]\  = \ 
                computerTime; \[IndentingNewLine]WriteString[
                outputFileNumber, \ 
                ToString[\ desiredPrecision, \ 
                  FortranForm], \ \ separatorString, \ 
                ToString[\ alphaMD, \ FortranForm], \ \ separatorString, \ 
                ToString[\ sampleSize, \ FortranForm], \ \ separatorString, \ 
                formulaName, \ \ separatorString, \ 
                ToString[\ 
                    computerTimeArray[\([sampleSizeIndex, \ formulaIndex, \ 
                        desiredPrecisionIndex, \ alphaMDIndex]\)], \ 
                    FortranForm]\ "\<\n\>"]; \[IndentingNewLine]If[
                intermediateOutput\  \[GreaterEqual] \ 
                  3, \[IndentingNewLine]\(Print["\<      DwassAltI: \
formulaNameArray[[\>", \ formulaIndex, \ "\<]] = \>", \ 
                    formulaNameArray[\([formulaIndex]\)]\ , \ "\<   \
rightTailProbabilityDwassAltI = \>", \ \ rightTailProbabilityDwassAltI, \ "\< \
  rTPpowerTen = \>", \ rTPpowerTen, \ "\<   precisionDwassAltI = \>", \ 
                    precisionDwassAltI, \ "\<   computerTime = \>", \ 
                    computerTime];\)\[IndentingNewLine]]; \[IndentingNewLine] \
(*\ \ \ \ Verify\ if\ rightTailProbabilityDwassAltD\ same\ as\ \
rightTailProbabilityDwassAltI\ *) \[IndentingNewLine]precisionUsed\  = \ 
                Min[\ precisionDwassAltD, \ 
                  precisionDwassAltI]; \
\[IndentingNewLine]rightTailProbabilityAbsDifference\  = \ 
                N[\ Abs[
                    rightTailProbabilityDwassAltD\  - \ 
                      rightTailProbabilityDwassAltI], \ 
                  precisionUsed]; \[IndentingNewLine]powerTenCompare\  = \ \ \
rTPpowerTen\  - \ precisionUsed\  + \ 1; \[IndentingNewLine]If[
                intermediateOutput\  \[GreaterEqual] \ 
                  4, \[IndentingNewLine]\(Print["\<         DwassAltI verify: \
rightTailProbabilityDwassAltD = \>", \ \ rightTailProbabilityDwassAltD, \ "\< \
  rightTailProbabilityDwassAltI = \>", \ \ rightTailProbabilityDwassAltI, \ "\
\<   precisionUsed = Min[ precisionDwassAltD, precisionDwassAltI] = Min[\>", \
\ precisionDwassAltD, "\<,\>", \ precisionDwassAltI, \ "\<] = \>", 
                    precisionUsed, \ "\<   rightTailProbabilityAbsDifference \
= \>", \ rightTailProbabilityAbsDifference, \ "\<   rTPpowerTen = \>", \ 
                    rTPpowerTen, \ "\<   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = \>", \ 
                    powerTenCompare];\)\[IndentingNewLine]]; \
\[IndentingNewLine]If[
                rightTailProbabilityAbsDifference\  > \ 
                  10^{powerTenCompare}, \ 
                Print["\<*****ERROR*****:  rightTailProbabilityDwassAltD not \
the same as rightTailProbabilityDwassAltI.\>"]; \ \
\[IndentingNewLine]Print["\<         DwassAltI verify: \
rightTailProbabilityDwassAltD = \>", \ \ rightTailProbabilityDwassAltD, \ "\< \
  rightTailProbabilityDwassAltI = \>", \ \ rightTailProbabilityDwassAltI, \ "\
\<   precisionUsed = Min[ precisionDwassAltD, precisionDwassAltI] = Min[\>", \
\ precisionDwassAltD, "\<,\>", \ precisionDwassAltI, \ "\<] = \>", 
                  precisionUsed, \ "\<   rightTailProbabilityAbsDifference = \
\>", \ rightTailProbabilityAbsDifference, \ "\<   rTPpowerTen = \>", \ 
                  rTPpowerTen, \ "\<   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = \>", \ 
                  powerTenCompare];\[IndentingNewLine]];\[IndentingNewLine], \
{alphaMDIndex, \ 1, \ \ numberalphaMDs, \ 
                1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 1, \ 
              numberDesiredPrecisions, \ 
              1}];\[IndentingNewLine], {sampleSizeIndex, \ 1, \ 
            numberSampleSizes, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\n\n\>"\ ]; \[IndentingNewLine] (*\ 
          Computer\ time\ by\ desiredPrecision\ by\ alphaMD\ \
*) \[IndentingNewLine]WriteString[outputFileNumber, \ 
          separatorString, \ \ separatorString, \ "\<Computer Time\>"]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
              
              outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{stringIndex, \ 1, \ numberDesiredPrecisionsAndalphaMDs\ \ , \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Sample\>", \ \ separatorString]; \
\[IndentingNewLine]Do[\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ separatorString, \ "\<Desired Precision dp \
= \>", \ ToString[\ desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)], \ 
              FortranForm]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{\ alphaMDIndex, \ 1\ , \ numberalphaMDs\  - \ 1, \ 
              1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 
            1, \ \ numberDesiredPrecisions, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Size\>", \ \ separatorString]; \
\[IndentingNewLine]Do[\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ \ separatorString, \ "\<alphaMD\>"]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{\ alphaMDIndex, \ 1\ , \ numberalphaMDs\  - \ 1, \ 
              1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 
            1, \ \ numberDesiredPrecisions, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<n\>", \ 
          separatorString, \ "\<Formula\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]\(WriteString[
                  outputFileNumber, \ \ separatorString, \ 
                  ToString[\ alphaMDVectorIn[\([alphaMDIndex]\)], \ 
                    FortranForm]];\)\[IndentingNewLine], {\ alphaMDIndex, \ 
                1\ , \ numberalphaMDs, \ 
                1}];\)\[IndentingNewLine], {desiredPrecisionIndex, \ 
            1, \ \ numberDesiredPrecisions, \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]sampleSize\  = \ 
                sampleSizeVectorIn[\([sampleSizeIndex]\)]; \
\[IndentingNewLine]If\ [formulaIndex\  < \ 1.5, 
                WriteString[outputFileNumber, \ 
                  ToString[\ sampleSize, \ FortranForm], \ separatorString, \ 
                  formulaNameArray[\([formulaIndex]\)]], \ 
                WriteString[outputFileNumber, \ separatorString, \ 
                  formulaNameArray[\([formulaIndex]\)]]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]desiredPrecision\  = \ 
                  desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)]; \
\[IndentingNewLine]Do[\[IndentingNewLine]alphaMD\  = \ \ \
alphaMDVectorIn[\([alphaMDIndex]\)]; \[IndentingNewLine]WriteString[
                    outputFileNumber, \ \ separatorString, \ 
                    ToString[\ 
                      computerTimeArray[\([sampleSizeIndex, \ formulaIndex, \ 
                          desiredPrecisionIndex, \ alphaMDIndex]\)], \ 
                      FortranForm]];\[IndentingNewLine], {alphaMDIndex, \ 
                    1, \ \ numberalphaMDs, \ 
                    1}];\[IndentingNewLine], {desiredPrecisionIndex, \ 1, \ 
                  numberDesiredPrecisions, \ 
                  1}]; \[IndentingNewLine]WriteString[
                outputFileNumber, \ "\<\n\>"\ ];\[IndentingNewLine], \ \
{formulaIndex, \ 1, \ \ numberFormulae, \ 
                1}];\)\[IndentingNewLine], {sampleSizeIndex, \ 1, \ 
            numberSampleSizes, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\n\n\>"\ ]; \[IndentingNewLine] (*\ 
          Computer\ time\ by\ alphaMD\ by\ desiredPrecision\ \
*) \[IndentingNewLine]WriteString[outputFileNumber, \ 
          separatorString, \ \ separatorString, \ "\<Computer Time\>"]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
              outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{stringIndex, \ 1, \ numberDesiredPrecisionsAndalphaMDs\ \ , \ 
            1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Sample\>", \ \ separatorString]; \
\[IndentingNewLine]Do[\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ separatorString, \ "\<alphaMD = \>", \ 
            ToString[\ alphaMDVectorIn[\([alphaMDIndex]\)], \ 
              
              FortranForm]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ \ numberDesiredPrecisions\  - \ 1, \ 
              1}];\[IndentingNewLine], {\ alphaMDIndex, \ 1\ , \ 
            numberalphaMDs, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<Size\>", \ \ separatorString]; \
\[IndentingNewLine]Do[\[IndentingNewLine]WriteString[
            outputFileNumber, \ \ \ separatorString, \ "\<Desired Precision \
dp\>"]; \[IndentingNewLine]Do[\[IndentingNewLine]\(WriteString[
                outputFileNumber, \ \ separatorString];\)\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ \ numberDesiredPrecisions\  - \ 1, \ 
              1}];\[IndentingNewLine], {\ alphaMDIndex, \ 1\ , \ 
            numberalphaMDs, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<n\>", \ 
          separatorString, \ "\<Formula\>"]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]\(WriteString[
                  outputFileNumber, \ \ separatorString, \ 
                  ToString[\ 
                    desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)], \ 
                    FortranForm]];\)\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ \ numberDesiredPrecisions, \ 
                1}];\)\[IndentingNewLine], {\ alphaMDIndex, \ 1\ , \ 
            numberalphaMDs, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(Do[\[IndentingNewLine]sampleSize\  = \ 
                sampleSizeVectorIn[\([sampleSizeIndex]\)]; \
\[IndentingNewLine]If\ [formulaIndex\  < \ 1.5, 
                WriteString[outputFileNumber, \ 
                  ToString[\ sampleSize, \ FortranForm], \ separatorString, \ 
                  formulaNameArray[\([formulaIndex]\)]], \ 
                WriteString[outputFileNumber, \ separatorString, \ 
                  formulaNameArray[\([formulaIndex]\)]]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]alphaMD\  = \ \ \
alphaMDVectorIn[\([alphaMDIndex]\)]; \
\[IndentingNewLine]Do[\[IndentingNewLine]desiredPrecision\  = \ 
                    desiredPrecisionVectorIn[\([desiredPrecisionIndex]\)]; \
\[IndentingNewLine]WriteString[outputFileNumber, \ \ separatorString, \ 
                    ToString[\ 
                      computerTimeArray[\([sampleSizeIndex, \ formulaIndex, \ 
                          desiredPrecisionIndex, \ alphaMDIndex]\)], \ 
                      FortranForm]];\[IndentingNewLine], \
{desiredPrecisionIndex, \ 1, \ numberDesiredPrecisions, \ 
                    1}];\[IndentingNewLine], {alphaMDIndex, \ 
                  1, \ \ numberalphaMDs, \ 
                  1}]; \[IndentingNewLine]WriteString[
                outputFileNumber, \ "\<\n\>"\ ];\[IndentingNewLine], \ \
{formulaIndex, \ 1, \ \ numberFormulae, \ 
                1}];\)\[IndentingNewLine], {sampleSizeIndex, \ 1, \ 
            numberSampleSizes, \ 1}]; \[IndentingNewLine]WriteString[
          outputFileNumber, \ "\<\n\n\n\>"\ ]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]Close[
          outputFileNumber]; \[IndentingNewLine]computerTimeArray\
\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(KS1SidedOneSampleTestStatisticByMaagDicaire[alphaIn_, sampleSizeIn_, \ 
        rho_]\  := \[IndentingNewLine]Module[{d, \ alpha, \ 
          sampleSize}, \[IndentingNewLine] (*\ 
          For\ the\ KS\ 1\ sided\ one\ sample\ test, \ 
          the\ Maag\ and\ Dicaire\ formula\ is\ used\ *) \[IndentingNewLine] \
(*\ \ \ \ to\ approximate\ the\ test\ statistic\ corresponding\ to\ a\ right\ \
tail\ *) \[IndentingNewLine] (*\ \ \ \ probability\ of\ alphaIn . \ \ The\ \
test\ statistic\ d\ is\ calculated\ to\ *) \[IndentingNewLine] (*\ \ \ \ rho\ \
number\ of\ decimal\ \(\(digits\)\(.\)\)\ *) \[IndentingNewLine]alpha\  = 
          Rationalize[alphaIn, \ 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine] (*\ 
          Use\ Maag\ and\ Dicaire\ \(\(MD\)\(.\)\)\ *) \[IndentingNewLine]d\  \
= \ N[Sqrt[Log[alpha]/\((\(-2\)*sampleSize)\)] - \ \((1/\((6*
                      sampleSize)\))\), 
            rho\ \  + \ 17]; \[IndentingNewLine]d\  = \ 
          N[d, rho]; \[IndentingNewLine]d\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassAltDKS1SidedOneSampleRTdesiredPrecision[dIn_, sampleSizeIn_, \ 
        desiredPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ desiredPrecision, \ internalPrecision, \ j, \ 
          jLowLimit, \ term, \ leftTailProbability, \ rightTailProbability, \ 
          binomialCoefficient, \ secondTerm, \ thirdTerm, \ sumTerms, \ 
          numberIterations, \ alphaPredict, \ 
          resultPrecision}, \[IndentingNewLine] (*\ 
          DwassAltD\ formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ sample\ \
*) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ to\ desiredPrecisionIn\ digits\ of\ *) \[IndentingNewLine] \
(*\ \ \ \ precision\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine]d = 
          Rationalize[dIn, \ 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]desiredPrecision\  = \ 
          Ceiling[desiredPrecisionIn]; \[IndentingNewLine] (*\ 
          Maag\ and\ Dicaire\ approximation\ \
*) \[IndentingNewLine]alphaPredict\  = \ 
          Exp[\(-2\)\ *\ d^2\ *\ 
                sampleSize\  - \ \((2\ *
                  d\ /\ 3)\)\  - \ \((1/\((18\ *\ 
                      sampleSize)\))\)]; \[IndentingNewLine]internalPrecision\
\  = \ Ceiling[
              3\  + \ \((4.84\  + \ 1.033\ *\ Sqrt[sampleSize])\)\ *\ \((\ 
                    0.611\  - \ 0.0904*\ alphaPredict\  - \ 
                      0.357\ *\ alphaPredict^\((1/3)\)\  - \ 
                      0.0998\ *\ alphaPredict^4\  - \ 
                      0.0616\ *\ Log[alphaPredict])\)]\  + \ 
            desiredPrecision; \[IndentingNewLine]numberIterations\  = \ 
          0; \[IndentingNewLine]Label[
          AnotherIteration]; \[IndentingNewLine]numberIterations\  = \ 
          numberIterations\  + \ 
            1; \[IndentingNewLine]rightTailProbability\ \  = \ 
          DwassAltDKS1SidedOneSampleRTArbPrecision[d, sampleSize, 
            internalPrecision]; \[IndentingNewLine]resultPrecision\  = \ 
          Precision[rightTailProbability]; \[IndentingNewLine]If[
          resultPrecision\  < \ 
            desiredPrecision, \[IndentingNewLine]internalPrecision\  = \ 
            internalPrecision\  + \ desiredPrecision; \[IndentingNewLine]Goto[
            AnotherIteration];\[IndentingNewLine]]; \
\[IndentingNewLine]rightTailProbability\ \[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassAltDKS1SidedOneSampleRTArbPrecision[dIn_, sampleSizeIn_, \ 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ 
          rightTailProbability, \ binomialCoefficient, \ secondTerm, \ 
          thirdTerm, \ sumTerms}, \[IndentingNewLine] (*\ 
          Dwass\ Alternate\ Direct\ formula\ to\ calculate\ the\ KS\ 1\ Sided\
\ one\ *) \[IndentingNewLine] (*\ \ \ \ sample\ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ arithmetic\ *) \[IndentingNewLine] (*\ \ \ \ with\ an\ internal\ \
precision\ of\ \(\(internalPrecisionIn\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ 
              d]; \[IndentingNewLine]binomialCoefficient\  = \ 
          1; \[IndentingNewLine]secondTerm\ \  = \ 
          N[sampleSize\  + \ d\ *\ sampleSize, \ 
            internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ \(-d\)\ *\ 
            sampleSize; \[IndentingNewLine]sumTerms\  = \ 
          N[secondTerm^\((sampleSize - 1)\), \ 
            internalPrecision]; \[IndentingNewLine]If[jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]binomialCoefficient\  = \ 
            N[binomialCoefficient\ *\ \((sampleSize\  - \ j\  + \ 1)\)/\ 
                  j\ , \ internalPrecision]; \[IndentingNewLine]secondTerm\  \
= \ N[secondTerm\  - \ 1\ , 
              internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ 
            N[thirdTerm\  + \ 1\ , 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + \((binomialCoefficient\ *\ 
                    secondTerm^\((sampleSize\  - \ j\  - \ 1)\)\ *\ 
                    thirdTerm^j)\), \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1\  - \ \((d\ *\ 
                  sumTerms/sampleSize^\((sampleSize\  - \ 1)\))\), \ 
            internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassDKS1SidedOneSampleRTdesiredPrecision[dIn_, sampleSizeIn_, \ 
        desiredPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ desiredPrecision, \ internalPrecision, \ j, \ 
          jLowLimit, \ term, \ leftTailProbability, \ rightTailProbability, \ 
          binomialCoefficient, \ secondTerm, \ thirdTerm, \ sumTerms, \ 
          numberIterations, \ alphaPredict, \ 
          resultPrecision}, \[IndentingNewLine] (*\ 
          DwassD\ formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ sample\ \
*) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ to\ desiredPrecisionIn\ digits\ of\ *) \[IndentingNewLine] \
(*\ \ \ \ precision\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine]d = 
          Rationalize[dIn, \ 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]desiredPrecision\  = \ 
          Ceiling[desiredPrecisionIn]; \[IndentingNewLine] (*\ 
          Maag\ and\ Dicaire\ approximation\ \
*) \[IndentingNewLine]alphaPredict\  = \ 
          Exp[\(-2\)\ *\ d^2\ *\ 
                sampleSize\  - \ \((2\ *
                  d\ /\ 3)\)\  - \ \((1/\((18\ *\ 
                      sampleSize)\))\)]; \[IndentingNewLine]internalPrecision\
\  = \ Ceiling[
              3\  + \ \((4.84\  + \ 1.033\ *\ Sqrt[sampleSize])\)\ *\ \((\ 
                    0.611\  - \ 0.0904*\ alphaPredict\  - \ 
                      0.357\ *\ alphaPredict^\((1/3)\)\  - \ 
                      0.0998\ *\ alphaPredict^4\  - \ 
                      0.0616\ *\ Log[alphaPredict])\)]\  + \ 
            desiredPrecision; \[IndentingNewLine]numberIterations\  = \ 
          0; \[IndentingNewLine]Label[
          AnotherIteration]; \[IndentingNewLine]numberIterations\  = \ 
          numberIterations\  + \ 
            1; \[IndentingNewLine]rightTailProbability\ \  = \ 
          DwassDKS1SidedOneSampleRTArbPrecision[d, sampleSize, 
            internalPrecision]; \[IndentingNewLine]resultPrecision\  = \ 
          Precision[rightTailProbability]; \[IndentingNewLine]If[
          resultPrecision\  < \ 
            desiredPrecision, \[IndentingNewLine]internalPrecision\  = \ 
            internalPrecision\  + \ desiredPrecision; \[IndentingNewLine]Goto[
            AnotherIteration];\[IndentingNewLine]]; \
\[IndentingNewLine]rightTailProbability\ \[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassDKS1SidedOneSampleRTArbPrecision[dIn_, sampleSizeIn_, 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ 
          rightTailProbability, \ binomialCoefficient, \ secondTerm, \ 
          thirdTerm, \ sumTerms}, \[IndentingNewLine] (*\ 
          Dwass\ Direct\ formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ \
sample\ *) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ 
              d]; \[IndentingNewLine]binomialCoefficient\  = \ 
          1; \[IndentingNewLine]secondTerm\ \  = \ 
          N[1\  + \ d, \ 
            internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ \(-d\); \
\[IndentingNewLine]sumTerms\  = \ 
          N[secondTerm^\((sampleSize - 1)\), \ 
            internalPrecision]; \[IndentingNewLine]If[jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]binomialCoefficient\  = \ 
            N[binomialCoefficient\ *\ \((sampleSize\  - \ j\  + \ 1)\)/\ 
                  j\ , \ internalPrecision]; \[IndentingNewLine]secondTerm\  \
= \ N[secondTerm\  - \ \((1/sampleSize)\)\ , 
              internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ 
            N[thirdTerm\  + \ \((1/sampleSize)\)\ , 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + \((binomialCoefficient\ *\ 
                    secondTerm^\((sampleSize\  - \ j\  - \ 1)\)\ *\ 
                    thirdTerm^j)\), \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1\  - \ \((d\ *\ sumTerms)\), \ 
            internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassIKS1SidedOneSampleRTdesiredPrecision[dIn_, sampleSizeIn_, \ 
        desiredPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ desiredPrecision, \ internalPrecision, \ j, \ 
          jLowLimit, \ term, \ leftTailProbability, \ rightTailProbability, \ 
          binomialCoefficient, \ secondTerm, \ thirdTerm, \ sumTerms, \ 
          numberIterations, \ alphaPredict, \ 
          resultPrecision}, \[IndentingNewLine] (*\ 
          DwassI\ formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ sample\ \
*) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ to\ desiredPrecisionIn\ digits\ of\ *) \[IndentingNewLine] \
(*\ \ \ \ precision\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine]d = 
          Rationalize[dIn, \ 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]desiredPrecision\  = \ 
          Ceiling[desiredPrecisionIn]; \[IndentingNewLine] (*\ 
          Maag\ and\ Dicaire\ approximation\ \
*) \[IndentingNewLine]alphaPredict\  = \ 
          Exp[\(-2\)\ *\ d^2\ *\ 
                sampleSize\  - \ \((2\ *
                  d\ /\ 3)\)\  - \ \((1/\((18\ *\ 
                      sampleSize)\))\)]; \[IndentingNewLine]internalPrecision\
\  = \ Ceiling[
              5\  + \ \((2.986\  + \ 1.032\ *\ Sqrt[sampleSize])\)\ *\ \((\ 
                    0.6875\  - \ 0.1433*\ alphaPredict\  - \ 
                      0.399\ *\ alphaPredict^\((1/4)\)\  + \ 
                      0.04703\ *\ alphaPredict^3\  - \ 
                      0.1323\ *\ alphaPredict^4\  - \ 
                      0.0556\ *\ Log[alphaPredict])\)]\  + \ 
            desiredPrecision; \[IndentingNewLine]numberIterations\  = \ 
          0; \[IndentingNewLine]Label[
          AnotherIteration]; \[IndentingNewLine]numberIterations\  = \ 
          numberIterations\  + \ 
            1; \[IndentingNewLine]rightTailProbability\ \  = \ 
          DwassIKS1SidedOneSampleRTArbPrecision[d, sampleSize, 
            internalPrecision]; \[IndentingNewLine]resultPrecision\  = \ 
          Precision[rightTailProbability]; \[IndentingNewLine]If[
          resultPrecision\  < \ 
            desiredPrecision, \[IndentingNewLine]internalPrecision\  = \ 
            internalPrecision\  + \ desiredPrecision; \[IndentingNewLine]Goto[
            AnotherIteration];\[IndentingNewLine]]; \
\[IndentingNewLine]rightTailProbability\ \[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassIKS1SidedOneSampleRTArbPrecision[dIn_, sampleSizeIn_, \ 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ term, \ 
          leftTailProbability, \ rightTailProbability, \ sumTerms, \ 
          NminusjMinusOne, \ NminusjPlusOne, \ dN, \ jMinusdN, \ 
          nMINUSjPlusOnePLUSdn, \ jMINUSdnMinusOne}, \[IndentingNewLine] (*\ 
          Dwass\ Iterative\ formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ \
sample\ *) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ d]; \[IndentingNewLine]sumTerms\  = \ 
          N[\ d\ *\ \((1\  + \ d)\)^\((sampleSize - 1)\), \ 
            internalPrecision]; \[IndentingNewLine]term\  = \ 
          sumTerms; \[IndentingNewLine]NminusjMinusOne\  = \ 
          N[sampleSize\  - \ 1, \ 
            internalPrecision]; \[IndentingNewLine]NminusjPlusOne\  = \ 
          N[sampleSize\  + \ 1, \ 
            internalPrecision]; \[IndentingNewLine]dN\  = \ 
          N[d\ *\ sampleSize, \ 
            internalPrecision]; \[IndentingNewLine]jHighLimit\  = \ 
          Floor[dN]; \[IndentingNewLine]jMinusdN\  = \ \(-\ 
            dN\); \[IndentingNewLine]nMINUSjPlusOnePLUSdn\  = \ 
          N[\ sampleSize\  + \ 1\  + \ dN, \ 
            internalPrecision]; \[IndentingNewLine]jMINUSdnMinusOne\  = \ 
          N[\(-\ dN\)\  - \ 1, \ internalPrecision]; \[IndentingNewLine]If[
          jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]NminusjMinusOne\  = \ 
            N[NminusjMinusOne\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]NminusjPlusOne\  = \ 
            N[NminusjPlusOne\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]jMinusdN\  = \ 
            N[jMinusdN\  + \ 1\ , \ 
              internalPrecision]; \[IndentingNewLine]nMINUSjPlusOnePLUSdn\  = \
\ N[\ nMINUSjPlusOnePLUSdn\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]jMINUSdnMinusOne\  = \ 
            N[jMINUSdnMinusOne\  + \ 1, \ 
              internalPrecision]; \[IndentingNewLine]term\  = \ 
            N[\ \((\((NminusjPlusOne\ *\ jMinusdN)\)/\((j\ *\ 
                        nMINUSjPlusOnePLUSdn)\))\)*\ \((1\  - \ \((1/
                          nMINUSjPlusOnePLUSdn)\))\)^
                  NminusjMinusOne\ *\ \((1\  + \ \((1/
                          jMINUSdnMinusOne)\))\)^\((j - 1)\)*term, \ 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + term, \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1 - sumTerms, \ internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassAltIKS1SidedOneSampleRTdesiredPrecision[dIn_, sampleSizeIn_, \ 
        desiredPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ desiredPrecision, \ internalPrecision, \ j, \ 
          jLowLimit, \ term, \ leftTailProbability, \ rightTailProbability, \ 
          binomialCoefficient, \ secondTerm, \ thirdTerm, \ sumTerms, \ 
          numberIterations, \ alphaPredict, \ 
          resultPrecision}, \[IndentingNewLine] (*\ 
          DwassAltI\ formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ sample\ \
*) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ to\ desiredPrecisionIn\ digits\ of\ *) \[IndentingNewLine] \
(*\ \ \ \ precision\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine]d = 
          Rationalize[dIn, \ 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]desiredPrecision\  = \ 
          Ceiling[desiredPrecisionIn]; \[IndentingNewLine] (*\ 
          Maag\ and\ Dicaire\ approximation\ \
*) \[IndentingNewLine]alphaPredict\  = \ 
          Exp[\(-2\)\ *\ d^2\ *\ 
                sampleSize\  - \ \((2\ *
                  d\ /\ 3)\)\  - \ \((1/\((18\ *\ 
                      sampleSize)\))\)]; \[IndentingNewLine]internalPrecision\
\  = \ Ceiling[
              5\  + \ \((2.986\  + \ 1.032\ *\ Sqrt[sampleSize])\)\ *\ \((\ 
                    0.6875\  - \ 0.1433*\ alphaPredict\  - \ 
                      0.399\ *\ alphaPredict^\((1/4)\)\  + \ 
                      0.04703\ *\ alphaPredict^3\  - \ 
                      0.1323\ *\ alphaPredict^4\  - \ 
                      0.0556\ *\ Log[alphaPredict])\)]\  + \ 
            desiredPrecision; \[IndentingNewLine]numberIterations\  = \ 
          0; \[IndentingNewLine]Label[
          AnotherIteration]; \[IndentingNewLine]numberIterations\  = \ 
          numberIterations\  + \ 
            1; \[IndentingNewLine]rightTailProbability\ \  = \ 
          DwassAltIKS1SidedOneSampleRTArbPrecision[d, sampleSize, 
            internalPrecision]; \[IndentingNewLine]resultPrecision\  = \ 
          Precision[rightTailProbability]; \[IndentingNewLine]If[
          resultPrecision\  < \ 
            desiredPrecision, \[IndentingNewLine]internalPrecision\  = \ 
            internalPrecision\  + \ desiredPrecision; \[IndentingNewLine]Goto[
            AnotherIteration];\[IndentingNewLine]]; \
\[IndentingNewLine]rightTailProbability\ \[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassAltIKS1SidedOneSampleRTArbPrecision[dIn_, sampleSizeIn_, \ 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ term, \ 
          leftTailProbability, \ rightTailProbability, \ sumTerms, \ 
          NminusjMinusOne, \ NminusjPlusOne, \ dN, \ jMinusdN, \ 
          nMINUSjPlusOnePLUSdn, \ jMINUSdnMinusOne}, \[IndentingNewLine] (*\ 
          Dwass\ Alternate\ Iterative\ formula\ to\ calculate\ the\ KS\ 1\ \
Sided\ one\ *) \[IndentingNewLine] (*\ \ \ \ sample\ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ d]; \[IndentingNewLine]sumTerms\  = \ 
          N[\ d\ *\ \((sampleSize\  + \ d*sampleSize)\)^\((sampleSize - 
                    1)\), \ internalPrecision]; \[IndentingNewLine]term\  = \ 
          sumTerms; \[IndentingNewLine]NminusjMinusOne\  = \ 
          N[sampleSize\  - \ 1, \ 
            internalPrecision]; \[IndentingNewLine]NminusjPlusOne\  = \ 
          N[sampleSize\  + \ 1, \ 
            internalPrecision]; \[IndentingNewLine]dN\  = \ 
          N[d\ *\ sampleSize, \ 
            internalPrecision]; \[IndentingNewLine]jHighLimit\  = \ 
          Floor[dN]; \[IndentingNewLine]jMinusdN\  = \ \(-\ 
            dN\); \[IndentingNewLine]nMINUSjPlusOnePLUSdn\  = \ 
          N[\ sampleSize\  + \ 1\  + \ dN, \ 
            internalPrecision]; \[IndentingNewLine]jMINUSdnMinusOne\  = \ 
          N[\(-\ dN\)\  - \ 1, \ internalPrecision]; \[IndentingNewLine]If[
          jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]NminusjMinusOne\  = \ 
            N[NminusjMinusOne\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]NminusjPlusOne\  = \ 
            N[NminusjPlusOne\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]jMinusdN\  = \ 
            N[jMinusdN\  + \ 1\ , \ 
              internalPrecision]; \[IndentingNewLine]nMINUSjPlusOnePLUSdn\  = \
\ N[\ nMINUSjPlusOnePLUSdn\  - \ 1, \ 
              internalPrecision]; \[IndentingNewLine]jMINUSdnMinusOne\  = \ 
            N[jMINUSdnMinusOne\  + \ 1, \ 
              internalPrecision]; \[IndentingNewLine]term\  = \ 
            N[\ \((\((NminusjPlusOne\ *\ jMinusdN)\)/\((j\ *\ 
                        nMINUSjPlusOnePLUSdn)\))\)*\ \((1\  - \ \((1/
                          nMINUSjPlusOnePLUSdn)\))\)^
                  NminusjMinusOne\ *\ \((1\  + \ \((1/
                          jMINUSdnMinusOne)\))\)^\((j - 1)\)*term, \ 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + term, \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1 - \((sumTerms/sampleSize^\((sampleSize\  - \ 1)\))\), \ 
            internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
23.1  Dwass Arb Precision Timing To File Sample Intermediate Output\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DwassArbPrecisionTimingsToFile[{500000, \ 1000000}, \ {20, \ 
        100}, \ {0.001, \ 0.9}, \ 
      4, \ "\<C:/KSoutput/KS1SidedOneSampleDwassArbPrecisionTimingsTest.csv\>\
", \ 0, \ "\<,\>", \ 3]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("DwassArbPrecisionTimingsToFile:  For "\
\[InvisibleSpace]2\[InvisibleSpace]" sampleSizes "\[InvisibleSpace]{500000, 
            1000000}\[InvisibleSpace]"; "\[InvisibleSpace]2\[InvisibleSpace]" \
desiredPrecisions "\[InvisibleSpace]{20, 
            100}\[InvisibleSpace]"; "\[InvisibleSpace]2\[InvisibleSpace]" \
alphaMDs "\[InvisibleSpace]{0.001`, 
            0.9`}\[InvisibleSpace]"; and \
"\[InvisibleSpace]4\[InvisibleSpace]" formulae \
"\[InvisibleSpace]{"DwassAltD", "DwassD", "DwassI", "DwassAltI", 
            "DeassAltD"[
              5]}\[InvisibleSpace]", outputFileName = \
"\[InvisibleSpace]"C:/KSoutput/KS1SidedOneSampleDwassArbPrecisionTimingsTest.\
csv"\[InvisibleSpace]", howToOpenFile = \
"\[InvisibleSpace]0\[InvisibleSpace]", and separatorString = '"\
\[InvisibleSpace]","\[InvisibleSpace]"'"\[InvisibleSpace]"   \
intermediateOutput = "\[InvisibleSpace]4\[InvisibleSpace]"   rho = "\
\[InvisibleSpace]3\),
        SequenceForm[ 
        "DwassArbPrecisionTimingsToFile:  For ", 2, " sampleSizes ", {500000, 
          1000000}, "; ", 2, " desiredPrecisions ", {20, 100}, "; ", 2, 
          " alphaMDs ", {.001, .90000000000000002}, "; and ", 4, 
          " formulae ", {"DwassAltD", "DwassD", "DwassI", "DwassAltI", 
          "DeassAltD"[ 5]}, ", outputFileName = ", 
          "C:/KSoutput/KS1SidedOneSampleDwassArbPrecisionTimingsTest.csv", 
          ", howToOpenFile = ", 0, ", and separatorString = '", ",", "'", 
          "   intermediateOutput = ", 4, "   rho = ", 3],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("  sampleSize = "\[InvisibleSpace]500000\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   alphaMD = "\[InvisibleSpace]0.001`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]1\/381\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0026246719160104987`2.9999999999999996\),
        SequenceForm[ 
        "  sampleSize = ", 500000, "   desiredPrecision = ", 20, 
          "   alphaMD = ", .001, "   d = ", 
          Rational[ 1, 381], " = ", 0.0026246719160104987`2.9999999999999996],
        
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltD: formulaNameArray[["\
\[InvisibleSpace]1\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltD"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.00101724230490188475878613742519942`24.09517116062227\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-3\)\[InvisibleSpace]" \
  precisionDwassAltD = "\[InvisibleSpace]24\[InvisibleSpace]"   computerTime \
= "\[InvisibleSpace]1.625`\),
        SequenceForm[ 
        "      DwassAltD: formulaNameArray[[", 1, "]] = ", "DwassAltD", 
          "   rightTailProbabilityDwassAltD = ", 
          0.00101724230490188475878613742519942`24.09517116062227, 
          "   rTPpowerTen = ", -3, "   precisionDwassAltD = ", 24, 
          "   computerTime = ", 1.625],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassD: \
formulaNameArray[["\[InvisibleSpace]2\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassD"\[InvisibleSpace]"   rightTailProbabilityDwassD = "\
\[InvisibleSpace]0.00101724230490188475878613742519942001`24.095171158585483\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-3\)\[InvisibleSpace]" \
  precisionDwassD = "\[InvisibleSpace]24\[InvisibleSpace]"   computerTime = "\
\[InvisibleSpace]1.0619999999999834`\),
        SequenceForm[ 
        "      DwassD: formulaNameArray[[", 2, "]] = ", "DwassD", 
          "   rightTailProbabilityDwassD = ", 
          0.00101724230490188475878613742519942001`24.095171158585483, 
          "   rTPpowerTen = ", -3, "   precisionDwassD = ", 24, 
          "   computerTime = ", 1.0619999999999834],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassD verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.00101724230490188475878613742519942`24.09517116062227\
\[InvisibleSpace]"   rightTailProbabilityDwassD = \
"\[InvisibleSpace]0.00101724230490188475878613742519942001`24.095171158585483\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassD] = Min["\[InvisibleSpace]24\[InvisibleSpace]","\
\[InvisibleSpace]24\[InvisibleSpace]"] = \
"\[InvisibleSpace]24\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``26.78671675069478\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-3\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-26\)\),
        SequenceForm[ 
        "         DwassD verify: rightTailProbabilityDwassAltD = ", 
          0.00101724230490188475878613742519942`24.09517116062227, 
          "   rightTailProbabilityDwassD = ", 
          0.00101724230490188475878613742519942001`24.095171158585483, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = \
Min[", 24, ",", 24, "] = ", 24, "   rightTailProbabilityAbsDifference = ", 
          0``26.78671675069478, "   rTPpowerTen = ", -3, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -26],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassI: \
formulaNameArray[["\[InvisibleSpace]3\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassI"\[InvisibleSpace]"   rightTailProbabilityDwassI = "\
\[InvisibleSpace]0.001017242304901884758786137425199420003219176866`26.\
616059553396934\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-3\)\
\[InvisibleSpace]"   precisionDwassI = "\[InvisibleSpace]26\[InvisibleSpace]" \
  computerTime = "\[InvisibleSpace]3.9070000000000107`\),
        SequenceForm[ 
        "      DwassI: formulaNameArray[[", 3, "]] = ", "DwassI", 
          "   rightTailProbabilityDwassI = ", 
          0.001017242304901884758786137425199420003219176866`26.\
616059553396934, "   rTPpowerTen = ", -3, "   precisionDwassI = ", 26, 
          "   computerTime = ", 3.9070000000000107],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.00101724230490188475878613742519942`24.09517116062227\
\[InvisibleSpace]"   rightTailProbabilityDwassI = \
"\[InvisibleSpace]0.001017242304901884758786137425199420003219176866`26.\
616059553396934\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassI] = Min["\[InvisibleSpace]24\[InvisibleSpace]","\
\[InvisibleSpace]26\[InvisibleSpace]"] = \
"\[InvisibleSpace]24\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``27.08643984753732\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-3\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-26\)\),
        SequenceForm[ 
        "         DwassI verify: rightTailProbabilityDwassAltD = ", 
          0.00101724230490188475878613742519942`24.09517116062227, 
          "   rightTailProbabilityDwassI = ", 
          0.001017242304901884758786137425199420003219176866`26.\
616059553396934, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassI] = \
Min[", 24, ",", 26, "] = ", 24, "   rightTailProbabilityAbsDifference = ", 
          0``27.08643984753732, "   rTPpowerTen = ", -3, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -26],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltI: formulaNameArray[["\
\[InvisibleSpace]4\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltI"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.001017242304901884758786137425199420002952768341`26.\
616059551250263\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-3\)\
\[InvisibleSpace]"   precisionDwassAltI = "\[InvisibleSpace]26\
\[InvisibleSpace]"   computerTime = "\[InvisibleSpace]5.078000000000003`\),
        SequenceForm[ 
        "      DwassAltI: formulaNameArray[[", 4, "]] = ", "DwassAltI", 
          "   rightTailProbabilityDwassAltI = ", 
          0.001017242304901884758786137425199420002952768341`26.\
616059551250263, "   rTPpowerTen = ", -3, "   precisionDwassAltI = ", 26, 
          "   computerTime = ", 5.078000000000003],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassAltI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.00101724230490188475878613742519942`24.09517116062227\
\[InvisibleSpace]"   rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.001017242304901884758786137425199420002952768341`26.\
616059551250263\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassAltI] = Min["\[InvisibleSpace]24\[InvisibleSpace]","\
\[InvisibleSpace]26\[InvisibleSpace]"] = \
"\[InvisibleSpace]24\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``27.08643984753087\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-3\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-26\)\),
        SequenceForm[ 
        "         DwassAltI verify: rightTailProbabilityDwassAltD = ", 
          0.00101724230490188475878613742519942`24.09517116062227, 
          "   rightTailProbabilityDwassAltI = ", 
          0.001017242304901884758786137425199420002952768341`26.\
616059551250263, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassAltI] = \
Min[", 24, ",", 26, "] = ", 24, "   rightTailProbabilityAbsDifference = ", 
          0``27.08643984753087, "   rTPpowerTen = ", -3, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -26],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("  sampleSize = "\[InvisibleSpace]500000\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   alphaMD = "\[InvisibleSpace]0.9`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]1\/3083\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0003243593902043464`2.999999999999999\),
        SequenceForm[ 
        "  sampleSize = ", 500000, "   desiredPrecision = ", 20, 
          "   alphaMD = ", .90000000000000002, "   d = ", 
          Rational[ 1, 3083], " = ", 0.0003243593902043464`2.999999999999999],
        
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltD: formulaNameArray[["\
\[InvisibleSpace]1\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltD"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.89994177764391489369442021999623799745`23.815336238780276\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]" \
  precisionDwassAltD = "\[InvisibleSpace]23\[InvisibleSpace]"   computerTime \
= "\[InvisibleSpace]0.578000000000003`\),
        SequenceForm[ 
        "      DwassAltD: formulaNameArray[[", 1, "]] = ", "DwassAltD", 
          "   rightTailProbabilityDwassAltD = ", 
          0.89994177764391489369442021999623799745`23.815336238780276, 
          "   rTPpowerTen = ", -1, "   precisionDwassAltD = ", 23, 
          "   computerTime = ", .57800000000000296],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassD: \
formulaNameArray[["\[InvisibleSpace]2\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassD"\[InvisibleSpace]"   rightTailProbabilityDwassD = "\
\[InvisibleSpace]0.89994177764391489369442021999623818936`23.81533623808141\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]" \
  precisionDwassD = "\[InvisibleSpace]23\[InvisibleSpace]"   computerTime = "\
\[InvisibleSpace]0.015999999999991132`\),
        SequenceForm[ 
        "      DwassD: formulaNameArray[[", 2, "]] = ", "DwassD", 
          "   rightTailProbabilityDwassD = ", 
          0.89994177764391489369442021999623818936`23.81533623808141, 
          "   rTPpowerTen = ", -1, "   precisionDwassD = ", 23, 
          "   computerTime = ", .015999999999991132],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassD verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.89994177764391489369442021999623799745`23.815336238780276\
\[InvisibleSpace]"   rightTailProbabilityDwassD = \
"\[InvisibleSpace]0.89994177764391489369442021999623818936`23.81533623808141\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassD] = Min["\[InvisibleSpace]23\[InvisibleSpace]","\
\[InvisibleSpace]23\[InvisibleSpace]"] = \
"\[InvisibleSpace]23\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``23.560091829400747\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-23\)\),
        SequenceForm[ 
        "         DwassD verify: rightTailProbabilityDwassAltD = ", 
          0.89994177764391489369442021999623799745`23.815336238780276, 
          "   rightTailProbabilityDwassD = ", 
          0.89994177764391489369442021999623818936`23.81533623808141, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = \
Min[", 23, ",", 23, "] = ", 23, "   rightTailProbabilityAbsDifference = ", 
          0``23.560091829400747, "   rTPpowerTen = ", -1, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -23],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassI: \
formulaNameArray[["\[InvisibleSpace]3\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassI"\[InvisibleSpace]"   rightTailProbabilityDwassI = "\
\[InvisibleSpace]0.89994177764391489369442021999623190215`27.242983389176615\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]" \
  precisionDwassI = "\[InvisibleSpace]27\[InvisibleSpace]"   computerTime = "\
\[InvisibleSpace]0.7959999999999923`\),
        SequenceForm[ 
        "      DwassI: formulaNameArray[[", 3, "]] = ", "DwassI", 
          "   rightTailProbabilityDwassI = ", 
          0.89994177764391489369442021999623190215`27.242983389176615, 
          "   rTPpowerTen = ", -1, "   precisionDwassI = ", 27, 
          "   computerTime = ", .79599999999999227],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.89994177764391489369442021999623799745`23.815336238780276\
\[InvisibleSpace]"   rightTailProbabilityDwassI = \
"\[InvisibleSpace]0.89994177764391489369442021999623190215`27.242983389176615\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassI] = Min["\[InvisibleSpace]23\[InvisibleSpace]","\
\[InvisibleSpace]27\[InvisibleSpace]"] = \
"\[InvisibleSpace]23\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``23.860959623469242\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-23\)\),
        SequenceForm[ 
        "         DwassI verify: rightTailProbabilityDwassAltD = ", 
          0.89994177764391489369442021999623799745`23.815336238780276, 
          "   rightTailProbabilityDwassI = ", 
          0.89994177764391489369442021999623190215`27.242983389176615, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassI] = \
Min[", 23, ",", 27, "] = ", 23, "   rightTailProbabilityAbsDifference = ", 
          0``23.860959623469242, "   rTPpowerTen = ", -1, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -23],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltI: formulaNameArray[["\
\[InvisibleSpace]4\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltI"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.89994177764391489369442021999623190215`27.242983389353384\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]" \
  precisionDwassAltI = "\[InvisibleSpace]27\[InvisibleSpace]"   computerTime \
= "\[InvisibleSpace]1.9850000000000136`\),
        SequenceForm[ 
        "      DwassAltI: formulaNameArray[[", 4, "]] = ", "DwassAltI", 
          "   rightTailProbabilityDwassAltI = ", 
          0.89994177764391489369442021999623190215`27.242983389353384, 
          "   rTPpowerTen = ", -1, "   precisionDwassAltI = ", 27, 
          "   computerTime = ", 1.9850000000000136],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassAltI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.89994177764391489369442021999623799745`23.815336238780276\
\[InvisibleSpace]"   rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.89994177764391489369442021999623190215`27.242983389353384\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassAltI] = Min["\[InvisibleSpace]23\[InvisibleSpace]","\
\[InvisibleSpace]27\[InvisibleSpace]"] = \
"\[InvisibleSpace]23\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``23.86095962346931\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-23\)\),
        SequenceForm[ 
        "         DwassAltI verify: rightTailProbabilityDwassAltD = ", 
          0.89994177764391489369442021999623799745`23.815336238780276, 
          "   rightTailProbabilityDwassAltI = ", 
          0.89994177764391489369442021999623190215`27.242983389353384, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassAltI] = \
Min[", 23, ",", 27, "] = ", 23, "   rightTailProbabilityAbsDifference = ", 
          0``23.86095962346931, "   rTPpowerTen = ", -1, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -23],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("  sampleSize = "\[InvisibleSpace]500000\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]"   alphaMD = "\[InvisibleSpace]0.001`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]1\/381\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0026246719160104987`2.9999999999999996\),
        SequenceForm[ 
        "  sampleSize = ", 500000, "   desiredPrecision = ", 100, 
          "   alphaMD = ", .001, "   d = ", 
          Rational[ 1, 381], " = ", 0.0026246719160104987`2.9999999999999996],
        
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltD: formulaNameArray[["\
\[InvisibleSpace]1\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltD"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
001017242304901884758786137425199420003232943199276382430125326857518839776245\
08377343406581668588996990296070073796975093904`104.09517116059533\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-3\)\[InvisibleSpace]" \
  precisionDwassAltD = "\[InvisibleSpace]104\[InvisibleSpace]"   computerTime \
= "\[InvisibleSpace]1.796999999999997`\),
        SequenceForm[ 
        "      DwassAltD: formulaNameArray[[", 1, "]] = ", "DwassAltD", 
          "   rightTailProbabilityDwassAltD = ", 
          0.001017242304901884758786137425199420003232943199276382430125326857\
51883977624508377343406581668588996990296070073796975093904`104.\
09517116059533, "   rTPpowerTen = ", -3, "   precisionDwassAltD = ", 104, 
          "   computerTime = ", 1.796999999999997],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassD: \
formulaNameArray[["\[InvisibleSpace]2\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassD"\[InvisibleSpace]"   rightTailProbabilityDwassD = "\
\[InvisibleSpace]0.\
001017242304901884758786137425199420003232943199276382430125326857518839776245\
08377343406581668588996990296070073797015061492`104.09517115858567\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-3\)\[InvisibleSpace]" \
  precisionDwassD = "\[InvisibleSpace]104\[InvisibleSpace]"   computerTime = \
"\[InvisibleSpace]1.25`\),
        SequenceForm[ 
        "      DwassD: formulaNameArray[[", 2, "]] = ", "DwassD", 
          "   rightTailProbabilityDwassD = ", 
          0.001017242304901884758786137425199420003232943199276382430125326857\
51883977624508377343406581668588996990296070073797015061492`104.\
09517115858567, "   rTPpowerTen = ", -3, "   precisionDwassD = ", 104, 
          "   computerTime = ", 1.25],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassD verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
001017242304901884758786137425199420003232943199276382430125326857518839776245\
08377343406581668588996990296070073796975093904`104.09517116059533\
\[InvisibleSpace]"   rightTailProbabilityDwassD = \
"\[InvisibleSpace]0.\
001017242304901884758786137425199420003232943199276382430125326857518839776245\
08377343406581668588996990296070073797015061492`104.09517115858567\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassD] = Min["\[InvisibleSpace]104\[InvisibleSpace]","\
\[InvisibleSpace]104\[InvisibleSpace]"] = "\[InvisibleSpace]104\
\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``106.78671675068139\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-3\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-106\)\),
        SequenceForm[ 
        "         DwassD verify: rightTailProbabilityDwassAltD = ", 
          0.001017242304901884758786137425199420003232943199276382430125326857\
51883977624508377343406581668588996990296070073796975093904`104.\
09517116059533, "   rightTailProbabilityDwassD = ", 
          0.001017242304901884758786137425199420003232943199276382430125326857\
51883977624508377343406581668588996990296070073797015061492`104.\
09517115858567, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = \
Min[", 104, ",", 104, "] = ", 104, "   rightTailProbabilityAbsDifference = ", 
          0``106.78671675068139, "   rTPpowerTen = ", -3, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -106],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassI: \
formulaNameArray[["\[InvisibleSpace]3\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassI"\[InvisibleSpace]"   rightTailProbabilityDwassI = "\
\[InvisibleSpace]0.\
001017242304901884758786137425199420003232943199276382430125326857518839776245\
08377343406581668588996990296070073796935752936`106.616059553397\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-3\)\[InvisibleSpace]" \
  precisionDwassI = "\[InvisibleSpace]106\[InvisibleSpace]"   computerTime = \
"\[InvisibleSpace]4.5160000000000196`\),
        SequenceForm[ 
        "      DwassI: formulaNameArray[[", 3, "]] = ", "DwassI", 
          "   rightTailProbabilityDwassI = ", 
          0.001017242304901884758786137425199420003232943199276382430125326857\
51883977624508377343406581668588996990296070073796935752936`106.616059553397, 
          "   rTPpowerTen = ", -3, "   precisionDwassI = ", 106, 
          "   computerTime = ", 4.5160000000000196],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
001017242304901884758786137425199420003232943199276382430125326857518839776245\
08377343406581668588996990296070073796975093904`104.09517116059533\
\[InvisibleSpace]"   rightTailProbabilityDwassI = \
"\[InvisibleSpace]0.\
001017242304901884758786137425199420003232943199276382430125326857518839776245\
08377343406581668588996990296070073796935752936`106.616059553397\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassI] = Min["\[InvisibleSpace]104\[InvisibleSpace]","\
\[InvisibleSpace]106\[InvisibleSpace]"] = "\[InvisibleSpace]104\
\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``107.08643984751045\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-3\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-106\)\),
        SequenceForm[ 
        "         DwassI verify: rightTailProbabilityDwassAltD = ", 
          0.001017242304901884758786137425199420003232943199276382430125326857\
51883977624508377343406581668588996990296070073796975093904`104.\
09517116059533, "   rightTailProbabilityDwassI = ", 
          0.001017242304901884758786137425199420003232943199276382430125326857\
51883977624508377343406581668588996990296070073796935752936`106.616059553397, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassI] = \
Min[", 104, ",", 106, "] = ", 104, "   rightTailProbabilityAbsDifference = ", 
          0``107.08643984751045, "   rTPpowerTen = ", -3, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -106],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltI: formulaNameArray[["\
\[InvisibleSpace]4\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltI"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.\
001017242304901884758786137425199420003232943199276382430125326857518839776245\
08377343406581668588996990296070073796935752929`106.61605955122332\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-3\)\[InvisibleSpace]" \
  precisionDwassAltI = "\[InvisibleSpace]106\[InvisibleSpace]"   computerTime \
= "\[InvisibleSpace]5.765999999999991`\),
        SequenceForm[ 
        "      DwassAltI: formulaNameArray[[", 4, "]] = ", "DwassAltI", 
          "   rightTailProbabilityDwassAltI = ", 
          0.001017242304901884758786137425199420003232943199276382430125326857\
51883977624508377343406581668588996990296070073796935752929`106.\
61605955122332, "   rTPpowerTen = ", -3, "   precisionDwassAltI = ", 106, 
          "   computerTime = ", 5.7659999999999911],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassAltI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
001017242304901884758786137425199420003232943199276382430125326857518839776245\
08377343406581668588996990296070073796975093904`104.09517116059533\
\[InvisibleSpace]"   rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.\
001017242304901884758786137425199420003232943199276382430125326857518839776245\
08377343406581668588996990296070073796935752929`106.61605955122332\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassAltI] = Min["\[InvisibleSpace]104\[InvisibleSpace]","\
\[InvisibleSpace]106\[InvisibleSpace]"] = "\[InvisibleSpace]104\
\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``107.08643984750391\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-3\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-106\)\),
        SequenceForm[ 
        "         DwassAltI verify: rightTailProbabilityDwassAltD = ", 
          0.001017242304901884758786137425199420003232943199276382430125326857\
51883977624508377343406581668588996990296070073796975093904`104.\
09517116059533, "   rightTailProbabilityDwassAltI = ", 
          0.001017242304901884758786137425199420003232943199276382430125326857\
51883977624508377343406581668588996990296070073796935752929`106.\
61605955122332, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassAltI] = \
Min[", 104, ",", 106, "] = ", 104, "   rightTailProbabilityAbsDifference = ", 
          0``107.08643984750391, "   rTPpowerTen = ", -3, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -106],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("  sampleSize = "\[InvisibleSpace]500000\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]"   alphaMD = "\[InvisibleSpace]0.9`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]1\/3083\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0003243593902043464`2.999999999999999\),
        SequenceForm[ 
        "  sampleSize = ", 500000, "   desiredPrecision = ", 100, 
          "   alphaMD = ", .90000000000000002, "   d = ", 
          Rational[ 1, 3083], " = ", 0.0003243593902043464`2.999999999999999],
        
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltD: formulaNameArray[["\
\[InvisibleSpace]1\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltD"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
899941777643914893694420219996238175328813200447487921752302487471046435094610\
8962023257464938055544825403323986319`103.81533623875335\[InvisibleSpace]"   \
rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   precisionDwassAltD \
= "\[InvisibleSpace]103\[InvisibleSpace]"   computerTime = \
"\[InvisibleSpace]0.578000000000003`\),
        SequenceForm[ 
        "      DwassAltD: formulaNameArray[[", 1, "]] = ", "DwassAltD", 
          "   rightTailProbabilityDwassAltD = ", 
          0.899941777643914893694420219996238175328813200447487921752302487471\
0464350946108962023257464938055544825403323986319`103.81533623875335, 
          "   rTPpowerTen = ", -1, "   precisionDwassAltD = ", 103, 
          "   computerTime = ", .57800000000000296],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassD: \
formulaNameArray[["\[InvisibleSpace]2\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassD"\[InvisibleSpace]"   rightTailProbabilityDwassD = "\
\[InvisibleSpace]0.\
899941777643914893694420219996238175328813200447487921752302487471046435094610\
8962023257464938055544825403323986322`103.81533623808147\[InvisibleSpace]"   \
rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   precisionDwassD = \
"\[InvisibleSpace]103\[InvisibleSpace]"   computerTime = \
"\[InvisibleSpace]0.016000000000019554`\),
        SequenceForm[ 
        "      DwassD: formulaNameArray[[", 2, "]] = ", "DwassD", 
          "   rightTailProbabilityDwassD = ", 
          0.899941777643914893694420219996238175328813200447487921752302487471\
0464350946108962023257464938055544825403323986322`103.81533623808147, 
          "   rTPpowerTen = ", -1, "   precisionDwassD = ", 103, 
          "   computerTime = ", .016000000000019554],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassD verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
899941777643914893694420219996238175328813200447487921752302487471046435094610\
8962023257464938055544825403323986319`103.81533623875335\[InvisibleSpace]"   \
rightTailProbabilityDwassD = \
"\[InvisibleSpace]0.\
899941777643914893694420219996238175328813200447487921752302487471046435094610\
8962023257464938055544825403323986322`103.81533623808147\[InvisibleSpace]"   \
precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = Min["\
\[InvisibleSpace]103\[InvisibleSpace]","\[InvisibleSpace]103\[InvisibleSpace]\
"] = "\[InvisibleSpace]103\[InvisibleSpace]"   \
rightTailProbabilityAbsDifference = "\[InvisibleSpace]0``103.5600918293873\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]" \
  powerTenCompare =  rTPpowerTen - precisionUsed + 1 = \
"\[InvisibleSpace]\(-103\)\),
        SequenceForm[ 
        "         DwassD verify: rightTailProbabilityDwassAltD = ", 
          0.899941777643914893694420219996238175328813200447487921752302487471\
0464350946108962023257464938055544825403323986319`103.81533623875335, 
          "   rightTailProbabilityDwassD = ", 
          0.899941777643914893694420219996238175328813200447487921752302487471\
0464350946108962023257464938055544825403323986322`103.81533623808147, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = \
Min[", 103, ",", 103, "] = ", 103, "   rightTailProbabilityAbsDifference = ", 
          0``103.5600918293873, "   rTPpowerTen = ", -1, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -103],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassI: \
formulaNameArray[["\[InvisibleSpace]3\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassI"\[InvisibleSpace]"   rightTailProbabilityDwassI = "\
\[InvisibleSpace]0.\
899941777643914893694420219996238175328813200447487921752302487471046435094610\
89620232574649380555448254033239858215213539155`107.24298338917659\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]" \
  precisionDwassI = "\[InvisibleSpace]107\[InvisibleSpace]"   computerTime = \
"\[InvisibleSpace]0.8439999999999941`\),
        SequenceForm[ 
        "      DwassI: formulaNameArray[[", 3, "]] = ", "DwassI", 
          "   rightTailProbabilityDwassI = ", 
          0.899941777643914893694420219996238175328813200447487921752302487471\
04643509461089620232574649380555448254033239858215213539155`107.\
24298338917659, "   rTPpowerTen = ", -1, "   precisionDwassI = ", 107, 
          "   computerTime = ", .84399999999999409],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
899941777643914893694420219996238175328813200447487921752302487471046435094610\
8962023257464938055544825403323986319`103.81533623875335\[InvisibleSpace]"   \
rightTailProbabilityDwassI = \
"\[InvisibleSpace]0.\
899941777643914893694420219996238175328813200447487921752302487471046435094610\
89620232574649380555448254033239858215213539155`107.24298338917659\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassI] = Min["\[InvisibleSpace]103\[InvisibleSpace]","\
\[InvisibleSpace]107\[InvisibleSpace]"] = "\[InvisibleSpace]103\
\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``103.86095962344233\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-103\)\),
        SequenceForm[ 
        "         DwassI verify: rightTailProbabilityDwassAltD = ", 
          0.899941777643914893694420219996238175328813200447487921752302487471\
0464350946108962023257464938055544825403323986319`103.81533623875335, 
          "   rightTailProbabilityDwassI = ", 
          0.899941777643914893694420219996238175328813200447487921752302487471\
04643509461089620232574649380555448254033239858215213539155`107.\
24298338917659, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassI] = \
Min[", 103, ",", 107, "] = ", 103, "   rightTailProbabilityAbsDifference = ", 
          0``103.86095962344233, "   rTPpowerTen = ", -1, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -103],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltI: formulaNameArray[["\
\[InvisibleSpace]4\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltI"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.\
899941777643914893694420219996238175328813200447487921752302487471046435094610\
89620232574649380555448254033239858215176132477`107.24298338932645\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]" \
  precisionDwassAltI = "\[InvisibleSpace]107\[InvisibleSpace]"   computerTime \
= "\[InvisibleSpace]1.9679999999999893`\),
        SequenceForm[ 
        "      DwassAltI: formulaNameArray[[", 4, "]] = ", "DwassAltI", 
          "   rightTailProbabilityDwassAltI = ", 
          0.899941777643914893694420219996238175328813200447487921752302487471\
04643509461089620232574649380555448254033239858215176132477`107.\
24298338932645, "   rTPpowerTen = ", -1, "   precisionDwassAltI = ", 107, 
          "   computerTime = ", 1.9679999999999893],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassAltI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
899941777643914893694420219996238175328813200447487921752302487471046435094610\
8962023257464938055544825403323986319`103.81533623875335\[InvisibleSpace]"   \
rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.\
899941777643914893694420219996238175328813200447487921752302487471046435094610\
89620232574649380555448254033239858215176132477`107.24298338932645\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassAltI] = Min["\[InvisibleSpace]103\[InvisibleSpace]","\
\[InvisibleSpace]107\[InvisibleSpace]"] = "\[InvisibleSpace]103\
\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``103.86095962344237\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-103\)\),
        SequenceForm[ 
        "         DwassAltI verify: rightTailProbabilityDwassAltD = ", 
          0.899941777643914893694420219996238175328813200447487921752302487471\
0464350946108962023257464938055544825403323986319`103.81533623875335, 
          "   rightTailProbabilityDwassAltI = ", 
          0.899941777643914893694420219996238175328813200447487921752302487471\
04643509461089620232574649380555448254033239858215176132477`107.\
24298338932645, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassAltI] = \
Min[", 103, ",", 107, "] = ", 103, "   rightTailProbabilityAbsDifference = ", 
          0``103.86095962344237, "   rTPpowerTen = ", -1, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -103],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("  sampleSize = "\[InvisibleSpace]1000000\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   alphaMD = "\[InvisibleSpace]0.001`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]1\/538\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0018587360594795539`2.999999999999999\),
        SequenceForm[ 
        "  sampleSize = ", 1000000, "   desiredPrecision = ", 20, 
          "   alphaMD = ", .001, "   d = ", 
          Rational[ 1, 538], " = ", 0.0018587360594795539`2.999999999999999],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltD: formulaNameArray[["\
\[InvisibleSpace]1\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltD"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.00099671826991440728062887474726032063`24.55975763570859\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-4\)\[InvisibleSpace]" \
  precisionDwassAltD = "\[InvisibleSpace]24\[InvisibleSpace]"   computerTime \
= "\[InvisibleSpace]3.796999999999997`\),
        SequenceForm[ 
        "      DwassAltD: formulaNameArray[[", 1, "]] = ", "DwassAltD", 
          "   rightTailProbabilityDwassAltD = ", 
          0.00099671826991440728062887474726032063`24.55975763570859, 
          "   rTPpowerTen = ", -4, "   precisionDwassAltD = ", 24, 
          "   computerTime = ", 3.796999999999997],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassD: \
formulaNameArray[["\[InvisibleSpace]2\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassD"\[InvisibleSpace]"   rightTailProbabilityDwassD = "\
\[InvisibleSpace]0.00099671826991440728062887474726032063`24.559757634963688\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-4\)\[InvisibleSpace]" \
  precisionDwassD = "\[InvisibleSpace]24\[InvisibleSpace]"   computerTime = "\
\[InvisibleSpace]2.6570000000000107`\),
        SequenceForm[ 
        "      DwassD: formulaNameArray[[", 2, "]] = ", "DwassD", 
          "   rightTailProbabilityDwassD = ", 
          0.00099671826991440728062887474726032063`24.559757634963688, 
          "   rTPpowerTen = ", -4, "   precisionDwassD = ", 24, 
          "   computerTime = ", 2.6570000000000107],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassD verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.00099671826991440728062887474726032063`24.55975763570859\
\[InvisibleSpace]"   rightTailProbabilityDwassD = \
"\[InvisibleSpace]0.00099671826991440728062887474726032063`24.559757634963688\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassD] = Min["\[InvisibleSpace]24\[InvisibleSpace]","\
\[InvisibleSpace]24\[InvisibleSpace]"] = \
"\[InvisibleSpace]24\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``27.26015522069055\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-4\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-27\)\),
        SequenceForm[ 
        "         DwassD verify: rightTailProbabilityDwassAltD = ", 
          0.00099671826991440728062887474726032063`24.55975763570859, 
          "   rightTailProbabilityDwassD = ", 
          0.00099671826991440728062887474726032063`24.559757634963688, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = \
Min[", 24, ",", 24, "] = ", 24, "   rightTailProbabilityAbsDifference = ", 
          0``27.26015522069055, "   rTPpowerTen = ", -4, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -27],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassI: \
formulaNameArray[["\[InvisibleSpace]3\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassI"\[InvisibleSpace]"   rightTailProbabilityDwassI = "\
\[InvisibleSpace]0.000996718269914407280628874747260320629003570507`26.\
230342778512266\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-4\)\
\[InvisibleSpace]"   precisionDwassI = "\[InvisibleSpace]26\[InvisibleSpace]" \
  computerTime = "\[InvisibleSpace]10.515000000000015`\),
        SequenceForm[ 
        "      DwassI: formulaNameArray[[", 3, "]] = ", "DwassI", 
          "   rightTailProbabilityDwassI = ", 
          0.000996718269914407280628874747260320629003570507`26.\
230342778512266, "   rTPpowerTen = ", -4, "   precisionDwassI = ", 26, 
          "   computerTime = ", 10.515000000000015],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.00099671826991440728062887474726032063`24.55975763570859\
\[InvisibleSpace]"   rightTailProbabilityDwassI = \
"\[InvisibleSpace]0.000996718269914407280628874747260320629003570507`26.\
230342778512266\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassI] = Min["\[InvisibleSpace]24\[InvisibleSpace]","\
\[InvisibleSpace]26\[InvisibleSpace]"] = \
"\[InvisibleSpace]24\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``27.552010268586486\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-4\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-27\)\),
        SequenceForm[ 
        "         DwassI verify: rightTailProbabilityDwassAltD = ", 
          0.00099671826991440728062887474726032063`24.55975763570859, 
          "   rightTailProbabilityDwassI = ", 
          0.000996718269914407280628874747260320629003570507`26.\
230342778512266, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassI] = \
Min[", 24, ",", 26, "] = ", 24, "   rightTailProbabilityAbsDifference = ", 
          0``27.552010268586486, "   rTPpowerTen = ", -4, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -27],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltI: formulaNameArray[["\
\[InvisibleSpace]4\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltI"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.000996718269914407280628874747260320629003570413`26.\
230342775295153\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-4\)\
\[InvisibleSpace]"   precisionDwassAltI = "\[InvisibleSpace]26\
\[InvisibleSpace]"   computerTime = "\[InvisibleSpace]13.109999999999985`\),
        SequenceForm[ 
        "      DwassAltI: formulaNameArray[[", 4, "]] = ", "DwassAltI", 
          "   rightTailProbabilityDwassAltI = ", 
          0.000996718269914407280628874747260320629003570413`26.\
230342775295153, "   rTPpowerTen = ", -4, "   precisionDwassAltI = ", 26, 
          "   computerTime = ", 13.109999999999985],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassAltI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.00099671826991440728062887474726032063`24.55975763570859\
\[InvisibleSpace]"   rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.000996718269914407280628874747260320629003570413`26.\
230342775295153\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassAltI] = Min["\[InvisibleSpace]24\[InvisibleSpace]","\
\[InvisibleSpace]26\[InvisibleSpace]"] = \
"\[InvisibleSpace]24\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``27.552010268519236\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-4\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-27\)\),
        SequenceForm[ 
        "         DwassAltI verify: rightTailProbabilityDwassAltD = ", 
          0.00099671826991440728062887474726032063`24.55975763570859, 
          "   rightTailProbabilityDwassAltI = ", 
          0.000996718269914407280628874747260320629003570413`26.\
230342775295153, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassAltI] = \
Min[", 24, ",", 26, "] = ", 24, "   rightTailProbabilityAbsDifference = ", 
          0``27.552010268519236, "   rTPpowerTen = ", -4, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -27],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("  sampleSize = "\[InvisibleSpace]1000000\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]20\[InvisibleSpace]"   alphaMD = "\[InvisibleSpace]0.9`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]1\/4360\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0002293577981651376`2.999999999999999\),
        SequenceForm[ 
        "  sampleSize = ", 1000000, "   desiredPrecision = ", 20, 
          "   alphaMD = ", .90000000000000002, "   d = ", 
          Rational[ 1, 4360], " = ", 0.0002293577981651376`2.999999999999999],
        
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltD: formulaNameArray[["\
\[InvisibleSpace]1\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltD"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.89999787012424795585662289341686998196`24.365525725614216\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]" \
  precisionDwassAltD = "\[InvisibleSpace]24\[InvisibleSpace]"   computerTime \
= "\[InvisibleSpace]1.2180000000000177`\),
        SequenceForm[ 
        "      DwassAltD: formulaNameArray[[", 1, "]] = ", "DwassAltD", 
          "   rightTailProbabilityDwassAltD = ", 
          0.89999787012424795585662289341686998196`24.365525725614216, 
          "   rTPpowerTen = ", -1, "   precisionDwassAltD = ", 24, 
          "   computerTime = ", 1.2180000000000177],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassD: \
formulaNameArray[["\[InvisibleSpace]2\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassD"\[InvisibleSpace]"   rightTailProbabilityDwassD = "\
\[InvisibleSpace]0.89999787012424795585662289341686999322`24.36552572283403\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]" \
  precisionDwassD = "\[InvisibleSpace]24\[InvisibleSpace]"   computerTime = "\
\[InvisibleSpace]0.015999999999991132`\),
        SequenceForm[ 
        "      DwassD: formulaNameArray[[", 2, "]] = ", "DwassD", 
          "   rightTailProbabilityDwassD = ", 
          0.89999787012424795585662289341686999322`24.36552572283403, 
          "   rTPpowerTen = ", -1, "   precisionDwassD = ", 24, 
          "   computerTime = ", .015999999999991132],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassD verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.89999787012424795585662289341686998196`24.365525725614216\
\[InvisibleSpace]"   rightTailProbabilityDwassD = \
"\[InvisibleSpace]0.89999787012424795585662289341686999322`24.36552572283403\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassD] = Min["\[InvisibleSpace]24\[InvisibleSpace]","\
\[InvisibleSpace]24\[InvisibleSpace]"] = \
"\[InvisibleSpace]24\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``24.11025424689235\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-24\)\),
        SequenceForm[ 
        "         DwassD verify: rightTailProbabilityDwassAltD = ", 
          0.89999787012424795585662289341686998196`24.365525725614216, 
          "   rightTailProbabilityDwassD = ", 
          0.89999787012424795585662289341686999322`24.36552572283403, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = \
Min[", 24, ",", 24, "] = ", 24, "   rightTailProbabilityAbsDifference = ", 
          0``24.11025424689235, "   rTPpowerTen = ", -1, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -24],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassI: \
formulaNameArray[["\[InvisibleSpace]3\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassI"\[InvisibleSpace]"   rightTailProbabilityDwassI = "\
\[InvisibleSpace]0.89999787012424795585662289341686987004`26.943901911683724\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]" \
  precisionDwassI = "\[InvisibleSpace]26\[InvisibleSpace]"   computerTime = "\
\[InvisibleSpace]1.75`\),
        SequenceForm[ 
        "      DwassI: formulaNameArray[[", 3, "]] = ", "DwassI", 
          "   rightTailProbabilityDwassI = ", 
          0.89999787012424795585662289341686987004`26.943901911683724, 
          "   rTPpowerTen = ", -1, "   precisionDwassI = ", 26, 
          "   computerTime = ", 1.75],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.89999787012424795585662289341686998196`24.365525725614216\
\[InvisibleSpace]"   rightTailProbabilityDwassI = \
"\[InvisibleSpace]0.89999787012424795585662289341686987004`26.943901911683724\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassI] = Min["\[InvisibleSpace]24\[InvisibleSpace]","\
\[InvisibleSpace]26\[InvisibleSpace]"] = \
"\[InvisibleSpace]24\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``24.41013916492044\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-24\)\),
        SequenceForm[ 
        "         DwassI verify: rightTailProbabilityDwassAltD = ", 
          0.89999787012424795585662289341686998196`24.365525725614216, 
          "   rightTailProbabilityDwassI = ", 
          0.89999787012424795585662289341686987004`26.943901911683724, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassI] = \
Min[", 24, ",", 26, "] = ", 24, "   rightTailProbabilityAbsDifference = ", 
          0``24.41013916492044, "   rTPpowerTen = ", -1, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -24],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltI: formulaNameArray[["\
\[InvisibleSpace]4\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltI"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.89999787012424795585662289341686987008`26.943901911922985\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]" \
  precisionDwassAltI = "\[InvisibleSpace]26\[InvisibleSpace]"   computerTime \
= "\[InvisibleSpace]5.609000000000009`\),
        SequenceForm[ 
        "      DwassAltI: formulaNameArray[[", 4, "]] = ", "DwassAltI", 
          "   rightTailProbabilityDwassAltI = ", 
          0.89999787012424795585662289341686987008`26.943901911922985, 
          "   rTPpowerTen = ", -1, "   precisionDwassAltI = ", 26, 
          "   computerTime = ", 5.6090000000000089],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassAltI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.89999787012424795585662289341686998196`24.365525725614216\
\[InvisibleSpace]"   rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.89999787012424795585662289341686987008`26.943901911922985\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassAltI] = Min["\[InvisibleSpace]24\[InvisibleSpace]","\
\[InvisibleSpace]26\[InvisibleSpace]"] = \
"\[InvisibleSpace]24\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``24.410139164921073\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-24\)\),
        SequenceForm[ 
        "         DwassAltI verify: rightTailProbabilityDwassAltD = ", 
          0.89999787012424795585662289341686998196`24.365525725614216, 
          "   rightTailProbabilityDwassAltI = ", 
          0.89999787012424795585662289341686987008`26.943901911922985, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassAltI] = \
Min[", 24, ",", 26, "] = ", 24, "   rightTailProbabilityAbsDifference = ", 
          0``24.410139164921073, "   rTPpowerTen = ", -1, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -24],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("  sampleSize = "\[InvisibleSpace]1000000\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]"   alphaMD = "\[InvisibleSpace]0.001`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]1\/538\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0018587360594795539`2.999999999999999\),
        SequenceForm[ 
        "  sampleSize = ", 1000000, "   desiredPrecision = ", 100, 
          "   alphaMD = ", .001, "   d = ", 
          Rational[ 1, 538], " = ", 0.0018587360594795539`2.999999999999999],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltD: formulaNameArray[["\
\[InvisibleSpace]1\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltD"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
000996718269914407280628874747260320629003569859863278915329163474563281634898\
6558527528219792926196321214893160068414953523`104.55975763568163\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-4\)\[InvisibleSpace]" \
  precisionDwassAltD = "\[InvisibleSpace]104\[InvisibleSpace]"   computerTime \
= "\[InvisibleSpace]7.015999999999991`\),
        SequenceForm[ 
        "      DwassAltD: formulaNameArray[[", 1, "]] = ", "DwassAltD", 
          "   rightTailProbabilityDwassAltD = ", 
          0.000996718269914407280628874747260320629003569859863278915329163474\
5632816348986558527528219792926196321214893160068414953523`104.55975763568163,
           "   rTPpowerTen = ", -4, "   precisionDwassAltD = ", 104, 
          "   computerTime = ", 7.0159999999999911],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassD: \
formulaNameArray[["\[InvisibleSpace]2\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassD"\[InvisibleSpace]"   rightTailProbabilityDwassD = "\
\[InvisibleSpace]0.\
000996718269914407280628874747260320629003569859863278915329163474563281634898\
65585275282197929261963212148931600684107078953`104.55975763496387\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-4\)\[InvisibleSpace]" \
  precisionDwassD = "\[InvisibleSpace]104\[InvisibleSpace]"   computerTime = \
"\[InvisibleSpace]4.953000000000003`\),
        SequenceForm[ 
        "      DwassD: formulaNameArray[[", 2, "]] = ", "DwassD", 
          "   rightTailProbabilityDwassD = ", 
          0.000996718269914407280628874747260320629003569859863278915329163474\
56328163489865585275282197929261963212148931600684107078953`104.\
55975763496387, "   rTPpowerTen = ", -4, "   precisionDwassD = ", 104, 
          "   computerTime = ", 4.953000000000003],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassD verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
000996718269914407280628874747260320629003569859863278915329163474563281634898\
6558527528219792926196321214893160068414953523`104.55975763568163\
\[InvisibleSpace]"   rightTailProbabilityDwassD = \
"\[InvisibleSpace]0.\
000996718269914407280628874747260320629003569859863278915329163474563281634898\
65585275282197929261963212148931600684107078953`104.55975763496387\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassD] = Min["\[InvisibleSpace]104\[InvisibleSpace]","\
\[InvisibleSpace]104\[InvisibleSpace]"] = "\[InvisibleSpace]104\
\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``107.26015522067716\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-4\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-107\)\),
        SequenceForm[ 
        "         DwassD verify: rightTailProbabilityDwassAltD = ", 
          0.000996718269914407280628874747260320629003569859863278915329163474\
5632816348986558527528219792926196321214893160068414953523`104.55975763568163,
           "   rightTailProbabilityDwassD = ", 
          0.000996718269914407280628874747260320629003569859863278915329163474\
56328163489865585275282197929261963212148931600684107078953`104.\
55975763496387, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = \
Min[", 104, ",", 104, "] = ", 104, "   rightTailProbabilityAbsDifference = ", 
          0``107.26015522067716, "   rTPpowerTen = ", -4, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -107],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassI: \
formulaNameArray[["\[InvisibleSpace]3\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassI"\[InvisibleSpace]"   rightTailProbabilityDwassI = "\
\[InvisibleSpace]0.\
000996718269914407280628874747260320629003569859863278915329163474563281634898\
65585275282197929261963212148931600684162131288`106.2303427785122\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-4\)\[InvisibleSpace]" \
  precisionDwassI = "\[InvisibleSpace]106\[InvisibleSpace]"   computerTime = \
"\[InvisibleSpace]11.765999999999991`\),
        SequenceForm[ 
        "      DwassI: formulaNameArray[[", 3, "]] = ", "DwassI", 
          "   rightTailProbabilityDwassI = ", 
          0.000996718269914407280628874747260320629003569859863278915329163474\
56328163489865585275282197929261963212148931600684162131288`106.2303427785122,
           "   rTPpowerTen = ", -4, "   precisionDwassI = ", 106, 
          "   computerTime = ", 11.765999999999991],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
000996718269914407280628874747260320629003569859863278915329163474563281634898\
6558527528219792926196321214893160068414953523`104.55975763568163\
\[InvisibleSpace]"   rightTailProbabilityDwassI = \
"\[InvisibleSpace]0.\
000996718269914407280628874747260320629003569859863278915329163474563281634898\
65585275282197929261963212148931600684162131288`106.2303427785122\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassI] = Min["\[InvisibleSpace]104\[InvisibleSpace]","\
\[InvisibleSpace]106\[InvisibleSpace]"] = "\[InvisibleSpace]104\
\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``107.5520102685601\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-4\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-107\)\),
        SequenceForm[ 
        "         DwassI verify: rightTailProbabilityDwassAltD = ", 
          0.000996718269914407280628874747260320629003569859863278915329163474\
5632816348986558527528219792926196321214893160068414953523`104.55975763568163,
           "   rightTailProbabilityDwassI = ", 
          0.000996718269914407280628874747260320629003569859863278915329163474\
56328163489865585275282197929261963212148931600684162131288`106.2303427785122,
           "   precisionUsed = Min[ precisionDwassAltD, precisionDwassI] = \
Min[", 104, ",", 106, "] = ", 104, "   rightTailProbabilityAbsDifference = ", 
          0``107.5520102685601, "   rTPpowerTen = ", -4, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -107],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltI: formulaNameArray[["\
\[InvisibleSpace]4\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltI"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.\
000996718269914407280628874747260320629003569859863278915329163474563281634898\
6558527528219792926196321214893160068416213141`106.2303427752682\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-4\)\[InvisibleSpace]" \
  precisionDwassAltI = "\[InvisibleSpace]106\[InvisibleSpace]"   computerTime \
= "\[InvisibleSpace]18.343000000000018`\),
        SequenceForm[ 
        "      DwassAltI: formulaNameArray[[", 4, "]] = ", "DwassAltI", 
          "   rightTailProbabilityDwassAltI = ", 
          0.000996718269914407280628874747260320629003569859863278915329163474\
5632816348986558527528219792926196321214893160068416213141`106.2303427752682, 
          "   rTPpowerTen = ", -4, "   precisionDwassAltI = ", 106, 
          "   computerTime = ", 18.343000000000018],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassAltI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
000996718269914407280628874747260320629003569859863278915329163474563281634898\
6558527528219792926196321214893160068414953523`104.55975763568163\
\[InvisibleSpace]"   rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.\
000996718269914407280628874747260320629003569859863278915329163474563281634898\
6558527528219792926196321214893160068416213141`106.2303427752682\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassAltI] = Min["\[InvisibleSpace]104\[InvisibleSpace]","\
\[InvisibleSpace]106\[InvisibleSpace]"] = "\[InvisibleSpace]104\
\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``107.55201026849228\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-4\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-107\)\),
        SequenceForm[ 
        "         DwassAltI verify: rightTailProbabilityDwassAltD = ", 
          0.000996718269914407280628874747260320629003569859863278915329163474\
5632816348986558527528219792926196321214893160068414953523`104.55975763568163,
           "   rightTailProbabilityDwassAltI = ", 
          0.000996718269914407280628874747260320629003569859863278915329163474\
5632816348986558527528219792926196321214893160068416213141`106.2303427752682, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassAltI] = \
Min[", 104, ",", 106, "] = ", 104, "   rightTailProbabilityAbsDifference = ", 
          0``107.55201026849228, "   rTPpowerTen = ", -4, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -107],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("  sampleSize = "\[InvisibleSpace]1000000\
\[InvisibleSpace]"   desiredPrecision = \
"\[InvisibleSpace]100\[InvisibleSpace]"   alphaMD = "\[InvisibleSpace]0.9`\
\[InvisibleSpace]"   d = "\[InvisibleSpace]1\/4360\[InvisibleSpace]" = "\
\[InvisibleSpace]0.0002293577981651376`2.999999999999999\),
        SequenceForm[ 
        "  sampleSize = ", 1000000, "   desiredPrecision = ", 100, 
          "   alphaMD = ", .90000000000000002, "   d = ", 
          Rational[ 1, 4360], " = ", 0.0002293577981651376`2.999999999999999],
        
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltD: formulaNameArray[["\
\[InvisibleSpace]1\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltD"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
899997870124247955856622893416869983554342938954967888059883191679204762647566\
5321440171757992984390666828616458256`104.36552572558728\[InvisibleSpace]"   \
rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   precisionDwassAltD \
= "\[InvisibleSpace]104\[InvisibleSpace]"   computerTime = \
"\[InvisibleSpace]1.406000000000006`\),
        SequenceForm[ 
        "      DwassAltD: formulaNameArray[[", 1, "]] = ", "DwassAltD", 
          "   rightTailProbabilityDwassAltD = ", 
          0.899997870124247955856622893416869983554342938954967888059883191679\
2047626475665321440171757992984390666828616458256`104.36552572558728, 
          "   rTPpowerTen = ", -1, "   precisionDwassAltD = ", 104, 
          "   computerTime = ", 1.4060000000000059],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassD: \
formulaNameArray[["\[InvisibleSpace]2\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassD"\[InvisibleSpace]"   rightTailProbabilityDwassD = "\
\[InvisibleSpace]0.\
899997870124247955856622893416869983554342938954967888059883191679204762647566\
5321440171757992984390666828616458258`104.36552572283395\[InvisibleSpace]"   \
rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   precisionDwassD = \
"\[InvisibleSpace]104\[InvisibleSpace]"   computerTime = \
"\[InvisibleSpace]0.07800000000003138`\),
        SequenceForm[ 
        "      DwassD: formulaNameArray[[", 2, "]] = ", "DwassD", 
          "   rightTailProbabilityDwassD = ", 
          0.899997870124247955856622893416869983554342938954967888059883191679\
2047626475665321440171757992984390666828616458258`104.36552572283395, 
          "   rTPpowerTen = ", -1, "   precisionDwassD = ", 104, 
          "   computerTime = ", .078000000000031378],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassD verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
899997870124247955856622893416869983554342938954967888059883191679204762647566\
5321440171757992984390666828616458256`104.36552572558728\[InvisibleSpace]"   \
rightTailProbabilityDwassD = \
"\[InvisibleSpace]0.\
899997870124247955856622893416869983554342938954967888059883191679204762647566\
5321440171757992984390666828616458258`104.36552572283395\[InvisibleSpace]"   \
precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = Min["\
\[InvisibleSpace]104\[InvisibleSpace]","\[InvisibleSpace]104\[InvisibleSpace]\
"] = "\[InvisibleSpace]104\[InvisibleSpace]"   \
rightTailProbabilityAbsDifference = "\[InvisibleSpace]0``104.11025424687884\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]" \
  powerTenCompare =  rTPpowerTen - precisionUsed + 1 = \
"\[InvisibleSpace]\(-104\)\),
        SequenceForm[ 
        "         DwassD verify: rightTailProbabilityDwassAltD = ", 
          0.899997870124247955856622893416869983554342938954967888059883191679\
2047626475665321440171757992984390666828616458256`104.36552572558728, 
          "   rightTailProbabilityDwassD = ", 
          0.899997870124247955856622893416869983554342938954967888059883191679\
2047626475665321440171757992984390666828616458258`104.36552572283395, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassD] = \
Min[", 104, ",", 104, "] = ", 104, "   rightTailProbabilityAbsDifference = ", 
          0``104.11025424687884, "   rTPpowerTen = ", -1, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -104],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassI: \
formulaNameArray[["\[InvisibleSpace]3\[InvisibleSpace]"]] = \
"\[InvisibleSpace]"DwassI"\[InvisibleSpace]"   rightTailProbabilityDwassI = "\
\[InvisibleSpace]0.\
899997870124247955856622893416869983554342938954967888059883191679204762647566\
53214401717579929843906668286164582873643017733`106.94390191168364\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]" \
  precisionDwassI = "\[InvisibleSpace]106\[InvisibleSpace]"   computerTime = \
"\[InvisibleSpace]3.0469999999999686`\),
        SequenceForm[ 
        "      DwassI: formulaNameArray[[", 3, "]] = ", "DwassI", 
          "   rightTailProbabilityDwassI = ", 
          0.899997870124247955856622893416869983554342938954967888059883191679\
20476264756653214401717579929843906668286164582873643017733`106.\
94390191168364, "   rTPpowerTen = ", -1, "   precisionDwassI = ", 106, 
          "   computerTime = ", 3.0469999999999686],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
899997870124247955856622893416869983554342938954967888059883191679204762647566\
5321440171757992984390666828616458256`104.36552572558728\[InvisibleSpace]"   \
rightTailProbabilityDwassI = \
"\[InvisibleSpace]0.\
899997870124247955856622893416869983554342938954967888059883191679204762647566\
53214401717579929843906668286164582873643017733`106.94390191168364\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassI] = Min["\[InvisibleSpace]104\[InvisibleSpace]","\
\[InvisibleSpace]106\[InvisibleSpace]"] = "\[InvisibleSpace]104\
\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``104.41013916489358\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-104\)\),
        SequenceForm[ 
        "         DwassI verify: rightTailProbabilityDwassAltD = ", 
          0.899997870124247955856622893416869983554342938954967888059883191679\
2047626475665321440171757992984390666828616458256`104.36552572558728, 
          "   rightTailProbabilityDwassI = ", 
          0.899997870124247955856622893416869983554342938954967888059883191679\
20476264756653214401717579929843906668286164582873643017733`106.\
94390191168364, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassI] = \
Min[", 104, ",", 106, "] = ", 104, "   rightTailProbabilityAbsDifference = ", 
          0``104.41013916489358, "   rTPpowerTen = ", -1, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -104],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("      DwassAltI: formulaNameArray[["\
\[InvisibleSpace]4\[InvisibleSpace]"]] = "\[InvisibleSpace]"DwassAltI"\
\[InvisibleSpace]"   rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.\
899997870124247955856622893416869983554342938954967888059883191679204762647566\
53214401717579929843906668286164582873643017729`106.94390191189603\
\[InvisibleSpace]"   rTPpowerTen = "\[InvisibleSpace]\(-1\)\[InvisibleSpace]" \
  precisionDwassAltI = "\[InvisibleSpace]106\[InvisibleSpace]"   computerTime \
= "\[InvisibleSpace]6.718999999999994`\),
        SequenceForm[ 
        "      DwassAltI: formulaNameArray[[", 4, "]] = ", "DwassAltI", 
          "   rightTailProbabilityDwassAltI = ", 
          0.899997870124247955856622893416869983554342938954967888059883191679\
20476264756653214401717579929843906668286164582873643017729`106.\
94390191189603, "   rTPpowerTen = ", -1, "   precisionDwassAltI = ", 106, 
          "   computerTime = ", 6.7189999999999941],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("         DwassAltI verify: \
rightTailProbabilityDwassAltD = \
"\[InvisibleSpace]0.\
899997870124247955856622893416869983554342938954967888059883191679204762647566\
5321440171757992984390666828616458256`104.36552572558728\[InvisibleSpace]"   \
rightTailProbabilityDwassAltI = \
"\[InvisibleSpace]0.\
899997870124247955856622893416869983554342938954967888059883191679204762647566\
53214401717579929843906668286164582873643017729`106.94390191189603\
\[InvisibleSpace]"   precisionUsed = Min[ precisionDwassAltD, \
precisionDwassAltI] = Min["\[InvisibleSpace]104\[InvisibleSpace]","\
\[InvisibleSpace]106\[InvisibleSpace]"] = "\[InvisibleSpace]104\
\[InvisibleSpace]"   rightTailProbabilityAbsDifference = \
"\[InvisibleSpace]0``104.41013916489412\[InvisibleSpace]"   rTPpowerTen = "\
\[InvisibleSpace]\(-1\)\[InvisibleSpace]"   powerTenCompare =  rTPpowerTen - \
precisionUsed + 1 = "\[InvisibleSpace]\(-104\)\),
        SequenceForm[ 
        "         DwassAltI verify: rightTailProbabilityDwassAltD = ", 
          0.899997870124247955856622893416869983554342938954967888059883191679\
2047626475665321440171757992984390666828616458256`104.36552572558728, 
          "   rightTailProbabilityDwassAltI = ", 
          0.899997870124247955856622893416869983554342938954967888059883191679\
20476264756653214401717579929843906668286164582873643017729`106.\
94390191189603, 
          "   precisionUsed = Min[ precisionDwassAltD, precisionDwassAltI] = \
Min[", 104, ",", 106, "] = ", 104, "   rightTailProbabilityAbsDifference = ", 
          0``104.41013916489412, "   rTPpowerTen = ", -1, 
          "   powerTenCompare =  rTPpowerTen - precisionUsed + 1 = ", -104],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.625`", "0.578000000000003`"},
                    {"1.796999999999997`", "0.578000000000003`"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1.0619999999999834`", "0.015999999999991132`"},
                    {"1.25`", "0.016000000000019554`"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"3.9070000000000107`", "0.7959999999999923`"},
                    {"4.5160000000000196`", "0.8439999999999941`"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"5.078000000000003`", "1.9850000000000136`"},
                    {"5.765999999999991`", "1.9679999999999893`"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"3.796999999999997`", "1.2180000000000177`"},
                    {"7.015999999999991`", "1.406000000000006`"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"2.6570000000000107`", "0.015999999999991132`"},
                    {"4.953000000000003`", "0.07800000000003138`"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"10.515000000000015`", "1.75`"},
                    {"11.765999999999991`", "3.0469999999999686`"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"13.109999999999985`", "5.609000000000009`"},
                    {"18.343000000000018`", "6.718999999999994`"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
23.2  Dwass Arb Precision Timing To File Sample Output File, \
C:/KSoutput/KS1SidedOneSampleDwassArbPrecisionTimingsTest.csv\
\>", "Subsection"],

Cell[BoxData[{
    \(rho = 3, , , , Desired, , Sample, , Computer\), "\n", 
    \(Precision, , Size, , Time\ In\), "\n", 
    \(dp, alphaMD, n, Formula, Seconds\), "\n", 
    \(20, 0.001, 500000, DwassAltD, 1.625\), "\n", 
    \(20, 0.001, 500000, DwassD, 1.0619999999999834\), "\n", 
    \(20, 0.001, 500000, DwassI, 3.9070000000000107\), "\n", 
    \(20, 0.001, 500000, DwassAltI, 5.078000000000003\), "\n", 
    \(20, 0.9, 500000, DwassAltD, 0.578000000000003\), "\n", 
    \(20, 0.9, 500000, DwassD, 0.015999999999991132\), "\n", 
    \(20, 0.9, 500000, DwassI, 0.7959999999999923\), "\n", 
    \(20, 0.9, 500000, DwassAltI, 1.9850000000000136\), "\n", 
    \(100, 0.001, 500000, DwassAltD, 1.796999999999997\), "\n", 
    \(100, 0.001, 500000, DwassD, 1.25\), "\n", 
    \(100, 0.001, 500000, DwassI, 4.5160000000000196\), "\n", 
    \(100, 0.001, 500000, DwassAltI, 5.765999999999991\), "\n", 
    \(100, 0.9, 500000, DwassAltD, 0.578000000000003\), "\n", 
    \(100, 0.9, 500000, DwassD, 0.016000000000019554\), "\n", 
    \(100, 0.9, 500000, DwassI, 0.8439999999999941\), "\n", 
    \(100, 0.9, 500000, DwassAltI, 1.9679999999999893\), "\n", 
    \(20, 0.001, 1000000, DwassAltD, 3.796999999999997\), "\n", 
    \(20, 0.001, 1000000, DwassD, 2.6570000000000107\), "\n", 
    \(20, 0.001, 1000000, DwassI, 10.515000000000015\), "\n", 
    \(20, 0.001, 1000000, DwassAltI, 13.109999999999985\), "\n", 
    \(20, 0.9, 1000000, DwassAltD, 1.2180000000000177\), "\n", 
    \(20, 0.9, 1000000, DwassD, 0.015999999999991132\), "\n", 
    \(20, 0.9, 1000000, DwassI, 1.75\), "\n", 
    \(20, 0.9, 1000000, DwassAltI, 5.609000000000009\), "\n", 
    \(100, 0.001, 1000000, DwassAltD, 7.015999999999991\), "\n", 
    \(100, 0.001, 1000000, DwassD, 4.953000000000003\), "\n", 
    \(100, 0.001, 1000000, DwassI, 11.765999999999991\), "\n", 
    \(100, 0.001, 1000000, DwassAltI, 18.343000000000018\), "\n", 
    \(100, 0.9, 1000000, DwassAltD, 1.406000000000006\), "\n", 
    \(100, 0.9, 1000000, DwassD, 0.07800000000003138\), "\n", 
    \(100, 0.9, 1000000, DwassI, 3.0469999999999686\), "\n", 
    \(\(\(100, 0.9, 1000000, DwassAltI, 
    6.718999999999994\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(,\)\(,\)\(Computer\ \
Time\)\(,\)\(,\)\(,\)\(,\)\(Sample\)\(,\)\(,\)\(Desired\ Precision\ dp = 
      20\)\(,\)\(,\)\(Desired\ Precision\ dp = 
      100\)\(,\)\(Size\)\(,\)\(,\)\(alphaMD\)\(,\)\(,\)\(alphaMD\)\(,\)\(n\)\(\
,\)\(Formula\)\(,\)\(0.001\)\(,\)\(0.9\)\(,\)\(0.001\)\(,\)\(0.9\)\)\), "\n", \

    \(500000, DwassAltD, 1.625, 0.578000000000003, 1.796999999999997, 
    0.578000000000003\), "\n", 
    \(\(\(,\)\(DwassD\)\(,\)\(1.0619999999999834\)\(,\)\(0.015999999999991132\
\)\(,\)\(1.25\)\(,\)\(0.016000000000019554\)\)\), "\n", 
    \(\(\(,\)\(DwassI\)\(,\)\(3.9070000000000107\)\(,\)\(0.7959999999999923\)\
\(,\)\(4.5160000000000196\)\(,\)\(0.8439999999999941\)\)\), "\n", 
    \(\(\(,\)\(DwassAltI\)\(,\)\(5.078000000000003\)\(,\)\(1.9850000000000136\
\)\(,\)\(5.765999999999991\)\(,\)\(1.9679999999999893\)\)\), "\n", 
    \(1000000, DwassAltD, 3.796999999999997, 1.2180000000000177, 
    7.015999999999991, 1.406000000000006\), "\n", 
    \(\(\(,\)\(DwassD\)\(,\)\(2.6570000000000107\)\(,\)\(0.015999999999991132\
\)\(,\)\(4.953000000000003\)\(,\)\(0.07800000000003138\)\)\), "\n", 
    \(\(\(,\)\(DwassI\)\(,\)\(10.515000000000015\)\(,\)\(1.75\)\(,\)\(11.\
765999999999991\)\(,\)\(3.0469999999999686\)\)\), "\n", 
    \(\(\(\(,\)\(DwassAltI\)\(,\)\(13.109999999999985\)\(,\)\(5.\
609000000000009\)\(,\)\(18.343000000000018\)\(,\)\(6.718999999999994\)\)\(\
\[IndentingNewLine]\)\(\[IndentingNewLine]\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(,\)\(,\)\(Computer\ \
Time\)\(,\)\(,\)\(,\)\(,\)\(Sample\)\(,\)\(,\)\(alphaMD = 
      0.001\)\(,\)\(,\)\(alphaMD = 
      0.9\)\(,\)\(Size\)\(,\)\(,\)\(Desired\ Precision\ \
dp\)\(,\)\(,\)\(Desired\ Precision\ dp\)\(,\)\(n\)\(,\)\(Formula\)\(,\)\(20\)\
\(,\)\(100\)\(,\)\(20\)\(,\)\(100\)\)\), "\n", 
    \(500000, DwassAltD, 1.625, 1.796999999999997, 0.578000000000003, 
    0.578000000000003\), "\n", 
    \(\(\(,\)\(DwassD\)\(,\)\(1.0619999999999834\)\(,\)\(1.25\)\(,\)\(0.\
015999999999991132\)\(,\)\(0.016000000000019554\)\)\), "\n", 
    \(\(\(,\)\(DwassI\)\(,\)\(3.9070000000000107\)\(,\)\(4.5160000000000196\)\
\(,\)\(0.7959999999999923\)\(,\)\(0.8439999999999941\)\)\), "\n", 
    \(\(\(,\)\(DwassAltI\)\(,\)\(5.078000000000003\)\(,\)\(5.765999999999991\)\
\(,\)\(1.9850000000000136\)\(,\)\(1.9679999999999893\)\)\), "\n", 
    \(1000000, DwassAltD, 3.796999999999997, 7.015999999999991, 
    1.2180000000000177, 1.406000000000006\), "\n", 
    \(\(\(,\)\(DwassD\)\(,\)\(2.6570000000000107\)\(,\)\(4.953000000000003\)\(\
,\)\(0.015999999999991132\)\(,\)\(0.07800000000003138\)\)\), "\n", 
    \(\(\(,\)\(DwassI\)\(,\)\(10.515000000000015\)\(,\)\(11.765999999999991\)\
\(,\)\(1.75\)\(,\)\(3.0469999999999686\)\)\), "\n", 
    \(\(\(\(,\)\(DwassAltI\)\(,\)\(13.109999999999985\)\(,\)\(18.\
343000000000018\)\(,\)\(5.609000000000009\)\(,\)\(6.718999999999994\)\)\(\
\[IndentingNewLine]\)\(\[IndentingNewLine]\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\)}], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
24. Linear Search DwassD Bandwidths with Sample Intermediate Output\
\>", "Section"],

Cell["\<\
The following is the code of the Mathematica function \
KS1SidedOneSampleBandwidthArbPrecision which finds the bandwidth using linear \
search and DwassD.   Sample intermediate output is given in subsection \
24.1.\
\>", "Text"],

Cell[BoxData[
    \(KS1SidedOneSampleBandwidthArbPrecision[alphaIn_, \ sampleSizeIn_, \ 
        rhoIn_, \ intermediateOutput_]\  := \ 
      Module[{alpha, \ sampleSize, \ rho, \ alphaPrecision, \ 
          alphaDesiredPrecision, \ dMD, \ rD, \ dLowLimitNumerator, \ 
          dLowLimitDenominator, \ dLowLimitAlpha, \ dHighLimitNumerator, \ 
          dHighLimitDenominator, \ dHighLimitAlpha, \ dNumeratorIncrement, \ 
          numberTries, \ dTryNumerator, \ dTryDenominator, \ dInput, \ 
          alphaOutput, \ dHighLimitMinusLowLimit, \ dNumeratorFinal, \ 
          dDenominatorFinal, \ dFinal}, \[IndentingNewLine] (*\ 
          Calculate\ one - 
            sided\ one\ sample\ KS\ bandwidth\ to\ *) \[IndentingNewLine] (*\ \
\ \ \ rhoIn\ significant\ digits\ *) \[IndentingNewLine] (*\ \ \ \ for\ \
sample\ size\ sampleSizeIn\ and\ alpha\ *) \[IndentingNewLine] (*\ \ \ \ \
alphaIn\ using\ arbitrary\ precision\ \(\(arithmetic\)\(.\)\)\ \ \ \
*) \[IndentingNewLine] (*\ \ \ \ \ \ intermediateOutput\  - \ 
            the\ amount\ of\ detail\ \((intermediate\ output)\)\ \
*) \[IndentingNewLine] (*\ \ \ \ \ \ \ \ printed\ during\ the\ execution\ of\ \
the\ \(\(function\)\(.\)\)\ *) \[IndentingNewLine] (*\ \ \ \ \ \ \ \ \ \ \ 0\ \
 = \ no\ intermediate\ output\ *) \[IndentingNewLine] (*\ \ \ \ \ \ \ \ \ \ \ \
1, 2\  = \ 
            increasing\ amounts\ of\ intermediate\ output\ \
*) \[IndentingNewLine] (*\ \ \ \ \ \ \ \ \ \ \ 3\  = \ 
            maximum\ intermediate\ output\ *) \[IndentingNewLine]alpha\  = \ 
          Rationalize[alphaIn, \ 0]; \[IndentingNewLine]alphaPrecision\  = \ 
          Floor[Precision[N[alpha]]]; \[IndentingNewLine]If[
          alphaPrecision\  < \ 18, \ \ alphaDesiredPrecision\  = \ 20, \ 
          alphaDesiredPrecision\  = \ 
            alphaPrecision\  + \ 2]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]rho\  = \ 
          Floor[rhoIn]; \[IndentingNewLine]numberTries\  = \ 
          0; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 1, \ 
          Print["\<KS1SidedOneSampleBandwidthArbPrecision:\>", \ "\< \
sampleSize = \>", \ sampleSize, \ "\<   alpha = \>", \ alpha, \ "\< = \>", \ 
            N[alpha], \ "\<   alphaPrecision = \>", 
            alphaPrecision, \ "\<   alphaDesiredPrecision = \>", \ 
            alphaDesiredPrecision, \ "\<    rho = \>", \ 
            rho, "\<    numberTries = \>", \ 
            numberTries]]; \[IndentingNewLine] (*\ 
          Check\ for\ reasonableness\ of\ inputs\ *) \[IndentingNewLine]If[
          sampleSize\  < \ 2, \ 
          Print["\<KS1SidedOneSampleBandwidthArbPrecision ERROR: sampleSize = \
\>", \ sampleSize, \ "\< is less than 2.\>"]; \ dFinal\  = \ \(-99\); \ 
          Goto[ExitNow]\ ]; \[IndentingNewLine]If[alpha\  \[LessEqual] \ 0, \ 
          Print["\<KS1SidedOneSampleBandwidthArbPrecision ERROR: alpha = \>", \
\ alpha, \ "\< is less than or equal to zero.\>"]; \ dFinal\  = \ \(-99\); \ 
          Goto[ExitNow]\ ]; \[IndentingNewLine]If[
          alpha\  \[GreaterEqual] \ 1, \ 
          Print["\<KS1SidedOneSampleBandwidthArbPrecision ERROR: alpha = \>", \
\ alpha, \ "\< is greater than or equal to one.\>"]; \ 
          dFinal\  = \ \(-99\); \ Goto[ExitNow]\ ]; \[IndentingNewLine]If[
          rho\  < \ 2, \ 
          Print["\<KS1SidedOneSampleBandwidthArbPrecision ERROR: rho = \>", \ 
            rho, \ "\< is less than 2.\>"]; \ dFinal\  = \ \(-99\); \ 
          Goto[ExitNow]\ ]; \[IndentingNewLine] (*\ 
          Use\ Maag\ and\ Dicaire\ MD\ approximation\ to\ get\ initial\ value\
\ of\ d, \ dMD\ *) \[IndentingNewLine]dMD\  = 
          N[Sqrt[Log[
                    alpha]/\((\(-2\)\ *\ sampleSize)\)]\  - \ \((1/\((6*
                      sampleSize)\))\), rho]; \[IndentingNewLine]If[
          dMD\  > \ 1, \ dMD\  = \ 1]; \[IndentingNewLine]If[dMD\  < \ 0, \ 
          dMD\  = \ 0]; \[IndentingNewLine]rD\  = \ 
          RealDigits[dMD]; \[IndentingNewLine] (*\ Using\ dMD, \ 
          create\ the\ first\ guess\ for\ d\ and\ determine\ whether\ it\ is\ \
lower\ or\ higher\ than\ the\ actual\ value\ \
*) \[IndentingNewLine]alphaOutput\  = \ 
          DwassDKS1SidedOneSampleRTdesiredPrecision[dMD, sampleSize, \ 
            alphaDesiredPrecision]; \[IndentingNewLine]numberTries\  = \ 
          1; \[IndentingNewLine]If[alphaOutput\  > \ alpha, \ 
          Goto[InitialLowLimit], \ 
          Goto[InitialHighLimit]\ ]; \[IndentingNewLine] (*\ 
          Initial\ guess\ dMD\ is\ lower\ than\ the\ actual\ d\ \
*) \[IndentingNewLine]Label[
          InitialLowLimit]; \[IndentingNewLine]dLowLimitDenominator\  = \ 
          Floor[10^\((rho\  - \ 
                  rD[\([2]\)])\)]; \[IndentingNewLine]dLowLimitNumerator\  = \
\ Floor[dMD\ *\ \ dLowLimitDenominator]; \[IndentingNewLine]dLowLimitAlpha\  \
= \ alphaOutput; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   Maag and Dicaire approximation is a low limit:  dMD = \
\>", \ dMD, \ "\<   dLowLimitNumerator = \>", \ 
            dLowLimitNumerator\ , \ "\<   dLowLimitDenominator = \>", \ 
            dLowLimitDenominator\ , \ "\<   dLowLimitAlpha = \>", \ 
            dLowLimitAlpha, \ "\< is greater than alpha = \>", \ \ N[
              alpha], "\<   numberTries = \>", \ 
            numberTries]]; \[IndentingNewLine] (*\ Based\ on\ dLowLimit, \ 
          find\ dHighLimit\ *) \[IndentingNewLine]If[
          rho\  > \ 
            4, \ \(dNumeratorIncrement\  = \ 
              Floor[10^\((rho\  - \ 5)\)];\)\ , \ 
          dNumeratorIncrement\  = \ 
            1]; \[IndentingNewLine]dTryDenominator\  = \ 
          dLowLimitDenominator; \[IndentingNewLine]Label[
          InitialHighLimitIteration]; \[IndentingNewLine]dNumeratorIncrement\ \
 = \ dNumeratorIncrement\ *\ 
            10; \[IndentingNewLine]dTryNumerator\  = \ \ Floor[
            dLowLimitNumerator\  + \ 
              dNumeratorIncrement]; \[IndentingNewLine]dInput\  = \ 
          Rationalize[dTryNumerator/dTryDenominator, \ 
            0]; \[IndentingNewLine]If[dInput\  \[GreaterEqual] \ 1, \ 
          dHighLimitNumerator\  = \ dLowLimitNumerator; \ 
          dHighLimitDenominator\  = \ dLowLimitNumerator; \ 
          dHighLimitAlpha\  = \ Rationalize[0, \ 0]; \ 
          Goto[InitialLowAndHighLimitsFound]\ ]; \
\[IndentingNewLine]alphaOutput\  = \ 
          DwassDKS1SidedOneSampleRTdesiredPrecision[dInput, sampleSize, \ 
            alphaDesiredPrecision]; \[IndentingNewLine]numberTries\  = \ 
          numberTries\  + \ 1; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 3, \ 
          
          Print["\<   Try to find the initial HighLimit:  dNumeratorIncrement \
= \>", \ dNumeratorIncrement, \ "\<   dTryNumerator = \>", \ 
            dTryNumerator, \ "\<   dTryDenominator = \>", \ 
            dTryDenominator\ , \ "\<   dInput = \>", \ 
            N[dInput, \ 
              rho], \ "\<   alphaOutput = \>", \ \ alphaOutput, "\<   \
numberTries = \>", \ numberTries]]; \[IndentingNewLine]If[
          alphaOutput\  \[LessEqual] \ alpha, \ 
          dHighLimitNumerator\  = \ dTryNumerator; \ 
          dHighLimitDenominator\  = \ dTryDenominator; \ 
          dHighLimitAlpha\  = \ alphaOutput; \ 
          Goto[InitialLowAndHighLimitsFound]\ ]; \[IndentingNewLine] (*\ 
          New\ dLowLimit\ found\ trying\ to\ find\ initial\ dHighLimit\ \
*) \[IndentingNewLine]dLowLimitNumerator\  = \ 
          dTryNumerator; \[IndentingNewLine]dLowLimitDenominator\  = \ 
          dTryDenominator; \[IndentingNewLine]dLowLimitAlpha\  = \ 
          alphaOutput; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 3, \ 
          Print["\<   In trying to find the initial HighLimit a new LowLimit \
was found:    dLowLimitNumerator = \>", \ 
            dLowLimitNumerator, \ "\<   dLowLimitDenominator = \>", \ 
            dLowLimitDenominator, \ "\<   dLowLimitAlpha = \>", \ \ \
dLowLimitAlpha]]; \[IndentingNewLine]Goto[
          InitialHighLimitIteration]; \[IndentingNewLine] (*\ 
          Initial\ guess\ dMD\ is\ highed\ than\ the\ actual\ d\ \
*) \[IndentingNewLine]Label[
          InitialHighLimit]; \[IndentingNewLine]dHighLimitDenominator\  = \ 
          Floor[10^\((rho\  - \ 
                  rD[\([2]\)])\)]; \[IndentingNewLine]dHighLimitNumerator\  = \
\ Floor[dMD\ *\ \ dHighLimitDenominator]; \[IndentingNewLine]dHighLimitAlpha\ \
 = \ alphaOutput; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   Maag and Dicaire approximation is a high limit:  dMD = \
\>", \ dMD, \ "\<   dHighLimitNumerator = \>", \ 
            dHighLimitNumerator\ , \ "\<   dHighLimitDenominator = \>", \ 
            dHighLimitDenominator\ , \ "\<   dHighLimitAlpha = \>", \ 
            dHighLimitAlpha, \ "\< is less than alpha = \>", \ \ N[
              alpha], "\<   numberTries = \>", \ 
            numberTries]]; \[IndentingNewLine] (*\ Based\ on\ dHighLimit, \ 
          find\ dLowLimit\ *) \[IndentingNewLine]If[
          rho\  > \ 
            4, \ \(dNumeratorIncrement\  = \ 
              Floor[10^\((rho\  - \ 5)\)];\)\ , \ 
          dNumeratorIncrement\  = \ 
            1]; \[IndentingNewLine]dTryDenominator\  = \ 
          dHighLimitDenominator; \[IndentingNewLine]Label[
          InitialLowLimitIteration]; \[IndentingNewLine]dNumeratorIncrement\  \
= \ dNumeratorIncrement\ *\ 
            10; \[IndentingNewLine]dTryNumerator\  = \ \ Floor[
            dHighLimitNumerator\  - \ 
              dNumeratorIncrement]; \[IndentingNewLine]If[
          dTryNumerator\  < \ 10^\((rho - 1)\), \ 
          dHighLimitDenominator\  = \ 
            Floor[dHighLimitDenominator*10]; \ \ dHighLimitNumerator\  = \ 
            Floor[dHighLimitNumerator*10]; \ \ dTryDenominator\  = \ 
            Floor[dTryDenominator*10]; \ \ \ \ dTryNumerator\  = \ 
            Floor[dTryNumerator*10]; \ 
          dNumeratorIncrement\  = \ 
            Floor[dNumeratorIncrement*10]\ \ ]; \[IndentingNewLine]dInput\  = \
\ Rationalize[dTryNumerator/dTryDenominator, \ 0]; \[IndentingNewLine]If[
          dInput\  \[LessEqual] \ 0, \ 
          dLowLimitNumerator\  = \ dHighLimitNumerator; \ 
          dLowLimitDenominator\  = \ dHighLimitNumerator; \ 
          dLowLimitAlpha\  = \ Rationalize[1, \ 0]; \ 
          Goto[InitialLowAndHighLimitsFound]\ ]; \
\[IndentingNewLine]alphaOutput\  = \ 
          DwassDKS1SidedOneSampleRTdesiredPrecision[dInput, sampleSize, \ 
            alphaDesiredPrecision]; \[IndentingNewLine]numberTries\  = \ 
          numberTries\  + \ 1; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 3, \ 
          Print["\<   Try to find the initial LowLimit:  dNumeratorIncrement \
= \>", \ dNumeratorIncrement, \ "\<   dTryNumerator = \>", \ 
            dTryNumerator, \ "\<   dTryDenominator = \>", \ 
            dTryDenominator\ , \ "\<   dInput = \>", \ 
            N[dInput, \ 
              rho], \ "\<   alphaOutput = \>", \ \ alphaOutput, "\<   \
numberTries = \>", \ numberTries]]; \[IndentingNewLine]If[
          alphaOutput\  \[GreaterEqual] \ alpha, \ 
          dLowLimitNumerator\  = \ dTryNumerator; \ 
          dLowLimitDenominator\  = \ dTryDenominator; \ 
          dLowLimitAlpha\  = \ alphaOutput; \ 
          Goto[InitialLowAndHighLimitsFound]\ ]; \[IndentingNewLine] (*\ 
          New\ dHighLimit\ found\ trying\ to\ find\ initial\ dLowLimit\ \
*) \[IndentingNewLine]dHighLimitNumerator\  = \ 
          dTryNumerator; \[IndentingNewLine]dHighLimitDenominator\  = \ 
          dTryDenominator; \[IndentingNewLine]dHighLimitAlpha\  = \ 
          alphaOutput; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 3, \ 
          Print["\<   In trying to find the initial LowLimit a new HighLimit \
was found:    dHighLimitNumerator = \>", \ 
            dHighLimitNumerator, \ "\<   dHighLimitDenominator = \>", \ 
            dHighLimitDenominator, \ "\< dHighLimitAlpha = \>", \ \ \
dHighLimitAlpha]]; \[IndentingNewLine]Goto[
          InitialLowLimitIteration]; \[IndentingNewLine] (*\ 
          Initial\ dLowLimit\ and\ dHighLimit\ found\ \
*) \[IndentingNewLine]Label[
          InitialLowAndHighLimitsFound]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   Initial Low and High Limits found:    \
dLowLimitNumerator = \>", \ 
            dLowLimitNumerator\ , \ "\<   dLowLimitDenominator = \>", \ 
            dLowLimitDenominator\ , \ "\<   dLowLimitAlpha = \>", \ 
            dLowLimitAlpha, \ "\< is greater than alpha = \>", \ \ N[
              alpha], \ "\<   dHighLimitNumerator = \>", \ 
            dHighLimitNumerator\ , \ "\<   dHighLimitDenominator = \>", \ 
            dHighLimitDenominator\ , \ "\<   dHighLimitAlpha = \>", \ 
            dHighLimitAlpha, \ "\< is less than alpha = \>", \ \ N[
              alpha], "\<   numberTries = \>", \ 
            numberTries]]; \[IndentingNewLine] (*\ 
          Begin\ search\ between\ dLowLimit\ and\ dHighLimit\ \
*) \[IndentingNewLine]Label[
          SearchIteration]; \[IndentingNewLine]dHighLimitMinusLowLimit\  = \ 
          Floor[dHighLimitNumerator\  - \ 
              dLowLimitNumerator]; \[IndentingNewLine]If[
          dHighLimitMinusLowLimit\  \[LessEqual] \ 1, \ 
          Goto[dFinalDetermination]\ ]; \[IndentingNewLine]dTryDenominator\  \
= \ dHighLimitDenominator; \[IndentingNewLine]dTryNumerator\  = \ 
          Floor[
            Rationalize[
              dLowLimitNumerator\  + \ 
                dHighLimitMinusLowLimit*\((dLowLimitAlpha\  - \ 
                        alpha)\)/\((dLowLimitAlpha\  - \ 
                        dHighLimitAlpha)\), \ 0]]; \[IndentingNewLine]If[
          dTryNumerator\  \[GreaterEqual] \ dHighLimitNumerator, \ 
          dTryNumerator\  = \ 
            Floor[dTryNumerator\  - \ 1]\ ]; \[IndentingNewLine]If[
          dTryNumerator \[LessEqual] \ dLowLimitNumerator, \ 
          dTryNumerator\  = \ 
            Floor[dTryNumerator\  + \ 1]\ ]; \[IndentingNewLine]dInput\  = \ 
          Rationalize[dTryNumerator/dTryDenominator, \ 
            0]; \[IndentingNewLine]alphaOutput\  = \ 
          DwassDKS1SidedOneSampleRTdesiredPrecision[dInput, sampleSize, \ 
            alphaDesiredPrecision]; \[IndentingNewLine]numberTries\  = \ 
          numberTries\  + \ 1; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 3, \ 
          Print["\<   Search:   dTryNumerator = \>", \ 
            dTryNumerator, \ "\<   dTryDenominator = \>", \ 
            dTryDenominator\ , \ "\<   dInput = \>", \ 
            N[dInput, \ 
              rho], \ "\<   alphaOutput = \>", \ \ alphaOutput, "\<   \
numberTries = \>", \ numberTries, \ "\<   dLowLimitNumerator = \>", \ 
            dLowLimitNumerator, \ "\<   dHighLimitNumerator = \>", \ 
            dHighLimitNumerator, \ "\<   dLowLimitAlpha = \>", \ 
            dLowLimitAlpha, \ "\<   dHighLimitAlpha = \>", \ 
            dHighLimitAlpha]]; \[IndentingNewLine]If[
          alphaOutput\  > \ alpha, \ 
          dLowLimitNumerator\  = \ dTryNumerator; \ 
          dLowLimitDenominator\  = \ dTryDenominator; \ 
          dLowLimitAlpha\  = \ 
            alphaOutput;\ , \ \ \ dHighLimitNumerator\  = \ dTryNumerator; \ 
          dHighLimitDenominator\  = \ dTryDenominator; \ 
          dHighLimitAlpha\  = \ alphaOutput;]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 3, \ 
          If[alphaOutput\  > \ alpha, \ 
            Print["\<      New search above is a new LowLimit\>"], \ 
            Print["\<      New search above is a new HighLimit\>"]\ ]\ ]; \
\[IndentingNewLine]Goto[SearchIteration]; \[IndentingNewLine] (*\ 
          Determine\ whether\ LowLimit\ or\ HighLimit\ is\ dFinal\ \
*) \[IndentingNewLine]Label[dFinalDetermination]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   Low and High Limits found:   dLowLimitNumerator = \>", \
\ dLowLimitNumerator, \ "\<   dHighLimitNumerator = \>", \ 
            dHighLimitNumerator, \ "\<   dLowLimitAlpha = \>", \ 
            dLowLimitAlpha, \ "\<   dHighLimitAlpha = \>", \ 
            dHighLimitAlpha, \ "\<   dLowLimitDenominator = \>", \ 
            dLowLimitDenominator, \ "\<   dHighLimitDenominator = \>", \ 
            dHighLimitDenominator]]; \[IndentingNewLine]dTryDenominator\  = \ 
          Floor[dLowLimitDenominator\ *\ 
              10]; \[IndentingNewLine]dTryNumerator\  = \ 
          Floor[dLowLimitNumerator\ *\ 10\  + \ 
              5]; \[IndentingNewLine]dInput\  = \ 
          Rationalize[dTryNumerator/dTryDenominator, \ 
            0]; \[IndentingNewLine]alphaOutput\  = \ 
          DwassDKS1SidedOneSampleRTdesiredPrecision[dInput, sampleSize, \ 
            alphaDesiredPrecision]; \[IndentingNewLine]numberTries\  = \ 
          numberTries\  + \ 1; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 3, \ 
          Print["\<   Determine whether LowLimit or HighLimit is dFinal:   \
dTryNumerator = \>", \ dTryNumerator, \ "\<   dTryDenominator = \>", \ 
            dTryDenominator\ , \ "\<   dInput = \>", \ 
            N[dInput, \ 
              rho], \ "\<   alphaOutput = \>", \ \ alphaOutput, "\<   \
numberTries = \>", \ numberTries]]; \[IndentingNewLine]If[
          alphaOutput\  < \ alpha, \ \ dNumeratorFinal\  = \ 
            dLowLimitNumerator; \ 
          dDenominatorFinal\  = \ dLowLimitDenominator;\ \ , \ 
          dNumeratorFinal\  = \ dHighLimitNumerator; \ 
          dDenominatorFinal\  = \ 
            dHighLimitDenominator;\ \ ]; \[IndentingNewLine]dFinal\  = \ 
          Rationalize[\ dNumeratorFinal/dDenominatorFinal, \ 
            0]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 1, \ 
          Print["\<   dFinal found:   dNumeratorFinal = \>", \ 
            dNumeratorFinal, \ "\<   dDenominatorFinal = \>", \ 
            dDenominatorFinal\ , \ "\<   dFinal = \>", \ 
            dFinal, \ "\< = \>", \ 
            N[dFinal, \ rho], "\<   numberTries = \>", \ 
            numberTries]]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]N[dFinal, \ 
          rho]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassDKS1SidedOneSampleRTdesiredPrecision[dIn_, sampleSizeIn_, \ 
        desiredPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ desiredPrecision, \ internalPrecision, \ j, \ 
          jLowLimit, \ term, \ leftTailProbability, \ rightTailProbability, \ 
          binomialCoefficient, \ secondTerm, \ thirdTerm, \ sumTerms, \ 
          numberIterations, \ alphaPredict, \ 
          resultPrecision}, \[IndentingNewLine] (*\ 
          DwassD\ formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ sample\ \
*) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ to\ desiredPrecisionIn\ digits\ of\ *) \[IndentingNewLine] \
(*\ \ \ \ precision\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine]d = 
          Rationalize[dIn, \ 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]desiredPrecision\  = \ 
          Ceiling[desiredPrecisionIn]; \[IndentingNewLine] (*\ 
          Maag\ and\ Dicaire\ approximation\ \
*) \[IndentingNewLine]alphaPredict\  = \ 
          Exp[\(-2\)\ *\ d^2\ *\ 
                sampleSize\  - \ \((2\ *
                  d\ /\ 3)\)\  - \ \((1/\((18\ *\ 
                      sampleSize)\))\)]; \[IndentingNewLine]internalPrecision\
\  = \ Ceiling[
              3\  + \ \((4.84\  + \ 1.033\ *\ Sqrt[sampleSize])\)\ *\ \((\ 
                    0.611\  - \ 0.0904*\ alphaPredict\  - \ 
                      0.357\ *\ alphaPredict^\((1/3)\)\  - \ 
                      0.0998\ *\ alphaPredict^4\  - \ 
                      0.0616\ *\ Log[alphaPredict])\)]\  + \ 
            desiredPrecision; \[IndentingNewLine]numberIterations\  = \ 
          0; \[IndentingNewLine]Label[
          AnotherIteration]; \[IndentingNewLine]numberIterations\  = \ 
          numberIterations\  + \ 
            1; \[IndentingNewLine]rightTailProbability\ \  = \ 
          DwassDKS1SidedOneSampleRTArbPrecision[d, sampleSize, 
            internalPrecision]; \[IndentingNewLine]resultPrecision\  = \ 
          Precision[rightTailProbability]; \[IndentingNewLine]If[
          resultPrecision\  < \ 
            desiredPrecision, \[IndentingNewLine]internalPrecision\  = \ 
            internalPrecision\  + \ desiredPrecision; \[IndentingNewLine]Goto[
            AnotherIteration];\[IndentingNewLine]]; \
\[IndentingNewLine]rightTailProbability\ \[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassDKS1SidedOneSampleRTArbPrecision[dIn_, sampleSizeIn_, 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ 
          rightTailProbability, \ binomialCoefficient, \ secondTerm, \ 
          thirdTerm, \ sumTerms}, \[IndentingNewLine] (*\ 
          Dwass\ Direct\ formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ \
sample\ *) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ 
              d]; \[IndentingNewLine]binomialCoefficient\  = \ 
          1; \[IndentingNewLine]secondTerm\ \  = \ 
          N[1\  + \ d, \ 
            internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ \(-d\); \
\[IndentingNewLine]sumTerms\  = \ 
          N[secondTerm^\((sampleSize - 1)\), \ 
            internalPrecision]; \[IndentingNewLine]If[jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]binomialCoefficient\  = \ 
            N[binomialCoefficient\ *\ \((sampleSize\  - \ j\  + \ 1)\)/\ 
                  j\ , \ internalPrecision]; \[IndentingNewLine]secondTerm\  \
= \ N[secondTerm\  - \ \((1/sampleSize)\)\ , 
              internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ 
            N[thirdTerm\  + \ \((1/sampleSize)\)\ , 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + \((binomialCoefficient\ *\ 
                    secondTerm^\((sampleSize\  - \ j\  - \ 1)\)\ *\ 
                    thirdTerm^j)\), \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1\  - \ \((d\ *\ sumTerms)\), \ 
            internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
24.1  Linear Search DwassD Bandwidths Sample Intermediate Output\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(KS1SidedOneSampleBandwidthArbPrecision[0.001, \ 100, \ 6, \ 
      3]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("KS1SidedOneSampleBandwidthArbPrecision:"\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]100\[InvisibleSpace]"   \
alpha = "\[InvisibleSpace]1\/1000\[InvisibleSpace]" = \
"\[InvisibleSpace]0.001`\[InvisibleSpace]"   alphaPrecision = "\
\[InvisibleSpace]15\[InvisibleSpace]"   alphaDesiredPrecision = "\
\[InvisibleSpace]20\[InvisibleSpace]"    rho = "\[InvisibleSpace]6\
\[InvisibleSpace]"    numberTries = "\[InvisibleSpace]0\),
        SequenceForm[ 
        "KS1SidedOneSampleBandwidthArbPrecision:", " sampleSize = ", 100, 
          "   alpha = ", 
          Rational[ 1, 1000], " = ", .001, "   alphaPrecision = ", 15, 
          "   alphaDesiredPrecision = ", 20, "    rho = ", 6, 
          "    numberTries = ", 0],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Maag and Dicaire approximation is a high limit: \
 dMD = "\[InvisibleSpace]0.1841794427758252557`6. \[InvisibleSpace]"   \
dHighLimitNumerator = "\[InvisibleSpace]184179\[InvisibleSpace]"   \
dHighLimitDenominator = "\[InvisibleSpace]1000000\[InvisibleSpace]"   \
dHighLimitAlpha = \
"\[InvisibleSpace]0.00096335247016778455280773148224721117`25.312314453522145\
\[InvisibleSpace]" is less than alpha = "\[InvisibleSpace]0.001`\
\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]1\),
        SequenceForm[ 
        "   Maag and Dicaire approximation is a high limit:  dMD = ", 
          0.1841794427758252557`6., "   dHighLimitNumerator = ", 184179, 
          "   dHighLimitDenominator = ", 1000000, "   dHighLimitAlpha = ", 
          0.00096335247016778455280773148224721117`25.312314453522145, 
          " is less than alpha = ", .001, "   numberTries = ", 1],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Try to find the initial LowLimit:  \
dNumeratorIncrement = "\[InvisibleSpace]100\[InvisibleSpace]"   dTryNumerator \
= "\[InvisibleSpace]184079\[InvisibleSpace]"   dTryDenominator = "\
\[InvisibleSpace]1000000\[InvisibleSpace]"   dInput = \
"\[InvisibleSpace]0.184079`5.999999999999998\[InvisibleSpace]"   alphaOutput \
= "\[InvisibleSpace]0.00097066823253656061568905801779859769`25.\
320683484284547\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]2\),
        SequenceForm[ 
        "   Try to find the initial LowLimit:  dNumeratorIncrement = ", 100, 
          "   dTryNumerator = ", 184079, "   dTryDenominator = ", 1000000, 
          "   dInput = ", 0.184079`5.999999999999998, "   alphaOutput = ", 
          0.00097066823253656061568905801779859769`25.320683484284547, 
          "   numberTries = ", 2],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   In trying to find the initial LowLimit a new \
HighLimit was found:    dHighLimitNumerator = "\[InvisibleSpace]184079\
\[InvisibleSpace]"   dHighLimitDenominator = "\[InvisibleSpace]1000000\
\[InvisibleSpace]" dHighLimitAlpha = \
"\[InvisibleSpace]0.00097066823253656061568905801779859769`25.320683484284547\
\),
        SequenceForm[ 
        "   In trying to find the initial LowLimit a new HighLimit was found: \
   dHighLimitNumerator = ", 184079, "   dHighLimitDenominator = ", 1000000, 
          " dHighLimitAlpha = ", 
          0.00097066823253656061568905801779859769`25.320683484284547],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Try to find the initial LowLimit:  \
dNumeratorIncrement = "\[InvisibleSpace]1000\[InvisibleSpace]"   \
dTryNumerator = "\[InvisibleSpace]183079\[InvisibleSpace]"   dTryDenominator \
= "\[InvisibleSpace]1000000\[InvisibleSpace]"   dInput = \
"\[InvisibleSpace]0.183079`6.000000000000002\[InvisibleSpace]"   alphaOutput \
= "\[InvisibleSpace]0.001046351211780727268435700712523915`25.403919300863695\
\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]3\),
        SequenceForm[ 
        "   Try to find the initial LowLimit:  dNumeratorIncrement = ", 1000, 
          "   dTryNumerator = ", 183079, "   dTryDenominator = ", 1000000, 
          "   dInput = ", 0.183079`6.000000000000002, "   alphaOutput = ", 
          0.001046351211780727268435700712523915`25.403919300863695, 
          "   numberTries = ", 3],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Initial Low and High Limits found:    \
dLowLimitNumerator = "\[InvisibleSpace]183079\[InvisibleSpace]"   \
dLowLimitDenominator = "\[InvisibleSpace]1000000\[InvisibleSpace]"   \
dLowLimitAlpha = \
"\[InvisibleSpace]0.001046351211780727268435700712523915`25.403919300863695\
\[InvisibleSpace]" is greater than alpha = "\[InvisibleSpace]0.001`\
\[InvisibleSpace]"   dHighLimitNumerator = "\[InvisibleSpace]184079\
\[InvisibleSpace]"   dHighLimitDenominator = "\[InvisibleSpace]1000000\
\[InvisibleSpace]"   dHighLimitAlpha = \
"\[InvisibleSpace]0.00097066823253656061568905801779859769`25.320683484284547\
\[InvisibleSpace]" is less than alpha = "\[InvisibleSpace]0.001`\
\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]3\),
        SequenceForm[ 
        "   Initial Low and High Limits found:    dLowLimitNumerator = ", 
          183079, "   dLowLimitDenominator = ", 1000000, 
          "   dLowLimitAlpha = ", 
          0.001046351211780727268435700712523915`25.403919300863695, 
          " is greater than alpha = ", .001, "   dHighLimitNumerator = ", 
          184079, "   dHighLimitDenominator = ", 1000000, 
          "   dHighLimitAlpha = ", 
          0.00097066823253656061568905801779859769`25.320683484284547, 
          " is less than alpha = ", .001, "   numberTries = ", 3],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Search:   dTryNumerator = \
"\[InvisibleSpace]183691\[InvisibleSpace]"   dTryDenominator = "\
\[InvisibleSpace]1000000\[InvisibleSpace]"   dInput = \
"\[InvisibleSpace]0.183691`5.999999999999998\[InvisibleSpace]"   alphaOutput \
= "\[InvisibleSpace]0.00099941015724734849174624205118141249`25.\
352994909753352\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]4\
\[InvisibleSpace]"   dLowLimitNumerator = "\[InvisibleSpace]183079\
\[InvisibleSpace]"   dHighLimitNumerator = "\[InvisibleSpace]184079\
\[InvisibleSpace]"   dLowLimitAlpha = \
"\[InvisibleSpace]0.001046351211780727268435700712523915`25.403919300863695\
\[InvisibleSpace]"   dHighLimitAlpha = \
"\[InvisibleSpace]0.00097066823253656061568905801779859769`25.320683484284547\
\),
        SequenceForm[ 
        "   Search:   dTryNumerator = ", 183691, "   dTryDenominator = ", 
          1000000, "   dInput = ", 0.183691`5.999999999999998, 
          "   alphaOutput = ", 
          0.00099941015724734849174624205118141249`25.352994909753352, 
          "   numberTries = ", 4, "   dLowLimitNumerator = ", 183079, 
          "   dHighLimitNumerator = ", 184079, "   dLowLimitAlpha = ", 
          0.001046351211780727268435700712523915`25.403919300863695, 
          "   dHighLimitAlpha = ", 
          0.00097066823253656061568905801779859769`25.320683484284547],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`"      New search above is a new HighLimit"\)], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Search:   dTryNumerator = \
"\[InvisibleSpace]183683\[InvisibleSpace]"   dTryDenominator = "\
\[InvisibleSpace]1000000\[InvisibleSpace]"   dInput = \
"\[InvisibleSpace]0.183683`5.999999999999998\[InvisibleSpace]"   alphaOutput \
= "\[InvisibleSpace]0.00100001098138500960328024671562706022`25.\
353660912113405\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]5\
\[InvisibleSpace]"   dLowLimitNumerator = "\[InvisibleSpace]183079\
\[InvisibleSpace]"   dHighLimitNumerator = "\[InvisibleSpace]183691\
\[InvisibleSpace]"   dLowLimitAlpha = \
"\[InvisibleSpace]0.001046351211780727268435700712523915`25.403919300863695\
\[InvisibleSpace]"   dHighLimitAlpha = \
"\[InvisibleSpace]0.00099941015724734849174624205118141249`25.352994909753352\
\),
        SequenceForm[ 
        "   Search:   dTryNumerator = ", 183683, "   dTryDenominator = ", 
          1000000, "   dInput = ", 0.183683`5.999999999999998, 
          "   alphaOutput = ", 
          0.00100001098138500960328024671562706022`25.353660912113405, 
          "   numberTries = ", 5, "   dLowLimitNumerator = ", 183079, 
          "   dHighLimitNumerator = ", 183691, "   dLowLimitAlpha = ", 
          0.001046351211780727268435700712523915`25.403919300863695, 
          "   dHighLimitAlpha = ", 
          0.00099941015724734849174624205118141249`25.352994909753352],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`"      New search above is a new LowLimit"\)], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Search:   dTryNumerator = \
"\[InvisibleSpace]183684\[InvisibleSpace]"   dTryDenominator = "\
\[InvisibleSpace]1000000\[InvisibleSpace]"   dInput = \
"\[InvisibleSpace]0.183684`5.999999999999999\[InvisibleSpace]"   alphaOutput \
= "\[InvisibleSpace]0.00099993586008214995406688831932145381`25.\
353577662288032\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]6\
\[InvisibleSpace]"   dLowLimitNumerator = "\[InvisibleSpace]183683\
\[InvisibleSpace]"   dHighLimitNumerator = "\[InvisibleSpace]183691\
\[InvisibleSpace]"   dLowLimitAlpha = \
"\[InvisibleSpace]0.00100001098138500960328024671562706022`25.353660912113405\
\[InvisibleSpace]"   dHighLimitAlpha = \
"\[InvisibleSpace]0.00099941015724734849174624205118141249`25.352994909753352\
\),
        SequenceForm[ 
        "   Search:   dTryNumerator = ", 183684, "   dTryDenominator = ", 
          1000000, "   dInput = ", 0.183684`5.999999999999999, 
          "   alphaOutput = ", 
          0.00099993586008214995406688831932145381`25.353577662288032, 
          "   numberTries = ", 6, "   dLowLimitNumerator = ", 183683, 
          "   dHighLimitNumerator = ", 183691, "   dLowLimitAlpha = ", 
          0.00100001098138500960328024671562706022`25.353660912113405, 
          "   dHighLimitAlpha = ", 
          0.00099941015724734849174624205118141249`25.352994909753352],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`"      New search above is a new HighLimit"\)], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Low and High Limits found:   dLowLimitNumerator \
= "\[InvisibleSpace]183683\[InvisibleSpace]"   dHighLimitNumerator = "\
\[InvisibleSpace]183684\[InvisibleSpace]"   dLowLimitAlpha = "\
\[InvisibleSpace]0.00100001098138500960328024671562706022`25.353660912113405\
\[InvisibleSpace]"   dHighLimitAlpha = \
"\[InvisibleSpace]0.00099993586008214995406688831932145381`25.353577662288032\
\[InvisibleSpace]"   dLowLimitDenominator = "\[InvisibleSpace]1000000\
\[InvisibleSpace]"   dHighLimitDenominator = "\[InvisibleSpace]1000000\),
        SequenceForm[ 
        "   Low and High Limits found:   dLowLimitNumerator = ", 183683, 
          "   dHighLimitNumerator = ", 183684, "   dLowLimitAlpha = ", 
          0.00100001098138500960328024671562706022`25.353660912113405, 
          "   dHighLimitAlpha = ", 
          0.00099993586008214995406688831932145381`25.353577662288032, 
          "   dLowLimitDenominator = ", 1000000, 
          "   dHighLimitDenominator = ", 1000000],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Determine whether LowLimit or HighLimit is \
dFinal:   dTryNumerator = "\[InvisibleSpace]1836835\[InvisibleSpace]"   \
dTryDenominator = "\[InvisibleSpace]10000000\[InvisibleSpace]"   dInput = "\
\[InvisibleSpace]0.1836835`5.999999999999998\[InvisibleSpace]"   alphaOutput \
= "\[InvisibleSpace]0.00099997342008041768159733765315013637`25.\
35361928721749\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]7\),
        SequenceForm[ 
        "   Determine whether LowLimit or HighLimit is dFinal:   \
dTryNumerator = ", 1836835, "   dTryDenominator = ", 10000000, "   dInput = ",
           0.1836835`5.999999999999998, "   alphaOutput = ", 
          0.00099997342008041768159733765315013637`25.35361928721749, 
          "   numberTries = ", 7],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   dFinal found:   dNumeratorFinal = "\
\[InvisibleSpace]183683\[InvisibleSpace]"   dDenominatorFinal = "\
\[InvisibleSpace]1000000\[InvisibleSpace]"   dFinal = \
"\[InvisibleSpace]183683\/1000000\[InvisibleSpace]" = \
"\[InvisibleSpace]0.183683`5.999999999999998\[InvisibleSpace]"   numberTries \
= "\[InvisibleSpace]7\),
        SequenceForm[ 
        "   dFinal found:   dNumeratorFinal = ", 183683, 
          "   dDenominatorFinal = ", 1000000, "   dFinal = ", 
          Rational[ 183683, 1000000], " = ", 0.183683`5.999999999999998, 
          "   numberTries = ", 7],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`0.183683`5.999999999999998\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(KS1SidedOneSampleBandwidthArbPrecision[0.001, \ 10000000, \ 6, \ 
      3]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("KS1SidedOneSampleBandwidthArbPrecision:"\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000000\[InvisibleSpace]"  \
 alpha = "\[InvisibleSpace]1\/1000\[InvisibleSpace]" = \
"\[InvisibleSpace]0.001`\[InvisibleSpace]"   alphaPrecision = "\
\[InvisibleSpace]15\[InvisibleSpace]"   alphaDesiredPrecision = "\
\[InvisibleSpace]20\[InvisibleSpace]"    rho = "\[InvisibleSpace]6\
\[InvisibleSpace]"    numberTries = "\[InvisibleSpace]0\),
        SequenceForm[ 
        "KS1SidedOneSampleBandwidthArbPrecision:", " sampleSize = ", 10000000,
           "   alpha = ", 
          Rational[ 1, 1000], " = ", .001, "   alphaPrecision = ", 15, 
          "   alphaDesiredPrecision = ", 20, "    rho = ", 6, 
          "    numberTries = ", 0],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Maag and Dicaire approximation is a low limit:  \
dMD = "\[InvisibleSpace]0.0005876803334525333`6.000000000000002\
\[InvisibleSpace]"   dLowLimitNumerator = "\[InvisibleSpace]587680\
\[InvisibleSpace]"   dLowLimitDenominator = "\[InvisibleSpace]1000000000\
\[InvisibleSpace]"   dLowLimitAlpha = \
"\[InvisibleSpace]0.001000005391206789451928160858312602629512011889`28.\
110689938229644\[InvisibleSpace]" is greater than alpha = \
"\[InvisibleSpace]0.001`\[InvisibleSpace]"   numberTries = \
"\[InvisibleSpace]1\),
        SequenceForm[ 
        "   Maag and Dicaire approximation is a low limit:  dMD = ", 
          0.0005876803334525333`6.000000000000002, "   dLowLimitNumerator = ",
           587680, "   dLowLimitDenominator = ", 1000000000, 
          "   dLowLimitAlpha = ", 
          0.001000005391206789451928160858312602629512011889`28.\
110689938229644, " is greater than alpha = ", .001, "   numberTries = ", 1],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Try to find the initial HighLimit:  \
dNumeratorIncrement = "\[InvisibleSpace]100\[InvisibleSpace]"   dTryNumerator \
= "\[InvisibleSpace]587780\[InvisibleSpace]"   dTryDenominator = "\
\[InvisibleSpace]1000000000\[InvisibleSpace]"   dInput = \
"\[InvisibleSpace]0.00058778`5.999999999999999\[InvisibleSpace]"   \
alphaOutput = \
"\[InvisibleSpace]0.000997659224567037888786443633384680705222020564`28.\
55511126885834\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]2\),
        SequenceForm[ 
        "   Try to find the initial HighLimit:  dNumeratorIncrement = ", 100, 
          "   dTryNumerator = ", 587780, "   dTryDenominator = ", 1000000000, 
          "   dInput = ", 0.00058778`5.999999999999999, "   alphaOutput = ", 
          0.000997659224567037888786443633384680705222020564`28.\
55511126885834, "   numberTries = ", 2],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Initial Low and High Limits found:    \
dLowLimitNumerator = "\[InvisibleSpace]587680\[InvisibleSpace]"   \
dLowLimitDenominator = "\[InvisibleSpace]1000000000\[InvisibleSpace]"   \
dLowLimitAlpha = \
"\[InvisibleSpace]0.001000005391206789451928160858312602629512011889`28.\
110689938229644\[InvisibleSpace]" is greater than alpha = \
"\[InvisibleSpace]0.001`\[InvisibleSpace]"   dHighLimitNumerator = "\
\[InvisibleSpace]587780\[InvisibleSpace]"   dHighLimitDenominator = "\
\[InvisibleSpace]1000000000\[InvisibleSpace]"   dHighLimitAlpha = "\
\[InvisibleSpace]0.000997659224567037888786443633384680705222020564`28.\
55511126885834\[InvisibleSpace]" is less than alpha = \
"\[InvisibleSpace]0.001`\[InvisibleSpace]"   numberTries = \
"\[InvisibleSpace]2\),
        SequenceForm[ 
        "   Initial Low and High Limits found:    dLowLimitNumerator = ", 
          587680, "   dLowLimitDenominator = ", 1000000000, 
          "   dLowLimitAlpha = ", 
          0.001000005391206789451928160858312602629512011889`28.\
110689938229644, " is greater than alpha = ", .001, 
          "   dHighLimitNumerator = ", 587780, "   dHighLimitDenominator = ", 
          1000000000, "   dHighLimitAlpha = ", 
          0.000997659224567037888786443633384680705222020564`28.\
55511126885834, " is less than alpha = ", .001, "   numberTries = ", 2],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Search:   dTryNumerator = \
"\[InvisibleSpace]587681\[InvisibleSpace]"   dTryDenominator = "\
\[InvisibleSpace]1000000000\[InvisibleSpace]"   dInput = \
"\[InvisibleSpace]0.000587681`6.000000000000002\[InvisibleSpace]"   \
alphaOutput = \
"\[InvisibleSpace]0.00099998395988374621078949737153328702132750171`28.\
10562041733821\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]3\
\[InvisibleSpace]"   dLowLimitNumerator = "\[InvisibleSpace]587680\
\[InvisibleSpace]"   dHighLimitNumerator = "\[InvisibleSpace]587780\
\[InvisibleSpace]"   dLowLimitAlpha = \
"\[InvisibleSpace]0.001000005391206789451928160858312602629512011889`28.\
110689938229644\[InvisibleSpace]"   dHighLimitAlpha = \
"\[InvisibleSpace]0.000997659224567037888786443633384680705222020564`28.\
55511126885834\),
        SequenceForm[ 
        "   Search:   dTryNumerator = ", 587681, "   dTryDenominator = ", 
          1000000000, "   dInput = ", 0.000587681`6.000000000000002, 
          "   alphaOutput = ", 
          0.00099998395988374621078949737153328702132750171`28.10562041733821,
           "   numberTries = ", 3, "   dLowLimitNumerator = ", 587680, 
          "   dHighLimitNumerator = ", 587780, "   dLowLimitAlpha = ", 
          0.001000005391206789451928160858312602629512011889`28.\
110689938229644, "   dHighLimitAlpha = ", 
          0.000997659224567037888786443633384680705222020564`28.\
55511126885834],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`"      New search above is a new HighLimit"\)], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Low and High Limits found:   dLowLimitNumerator \
= "\[InvisibleSpace]587680\[InvisibleSpace]"   dHighLimitNumerator = "\
\[InvisibleSpace]587681\[InvisibleSpace]"   dLowLimitAlpha = "\
\[InvisibleSpace]0.001000005391206789451928160858312602629512011889`28.\
110689938229644\[InvisibleSpace]"   dHighLimitAlpha = \
"\[InvisibleSpace]0.00099998395988374621078949737153328702132750171`28.\
10562041733821\[InvisibleSpace]"   dLowLimitDenominator = \
"\[InvisibleSpace]1000000000\[InvisibleSpace]"   dHighLimitDenominator = "\
\[InvisibleSpace]1000000000\),
        SequenceForm[ 
        "   Low and High Limits found:   dLowLimitNumerator = ", 587680, 
          "   dHighLimitNumerator = ", 587681, "   dLowLimitAlpha = ", 
          0.001000005391206789451928160858312602629512011889`28.\
110689938229644, "   dHighLimitAlpha = ", 
          0.00099998395988374621078949737153328702132750171`28.10562041733821,
           "   dLowLimitDenominator = ", 1000000000, 
          "   dHighLimitDenominator = ", 1000000000],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Determine whether LowLimit or HighLimit is \
dFinal:   dTryNumerator = "\[InvisibleSpace]5876805\[InvisibleSpace]"   \
dTryDenominator = "\[InvisibleSpace]10000000000\[InvisibleSpace]"   dInput = \
"\[InvisibleSpace]0.0005876805`6.000000000000002\[InvisibleSpace]"   \
alphaOutput = \
"\[InvisibleSpace]0.000999995713714164716995467780475516348940711618`28.\
108400766279903\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]4\),
        SequenceForm[ 
        "   Determine whether LowLimit or HighLimit is dFinal:   \
dTryNumerator = ", 5876805, "   dTryDenominator = ", 10000000000, 
          "   dInput = ", 0.0005876805`6.000000000000002, "   alphaOutput = ",
           0.000999995713714164716995467780475516348940711618`28.\
108400766279903, "   numberTries = ", 4],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   dFinal found:   dNumeratorFinal = "\
\[InvisibleSpace]587680\[InvisibleSpace]"   dDenominatorFinal = "\
\[InvisibleSpace]1000000000\[InvisibleSpace]"   dFinal = \
"\[InvisibleSpace]3673\/6250000\[InvisibleSpace]" = \
"\[InvisibleSpace]0.00058768`6.000000000000002\[InvisibleSpace]"   \
numberTries = "\[InvisibleSpace]4\),
        SequenceForm[ 
        "   dFinal found:   dNumeratorFinal = ", 587680, 
          "   dDenominatorFinal = ", 1000000000, "   dFinal = ", 
          Rational[ 3673, 6250000], " = ", 0.00058768`6.000000000000002, 
          "   numberTries = ", 4],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`0.00058768`6.000000000000002\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(KS1SidedOneSampleBandwidthArbPrecision[0.2, \ 10000000, \ 6, \ 
      3]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("KS1SidedOneSampleBandwidthArbPrecision:"\
\[InvisibleSpace]" sampleSize = "\[InvisibleSpace]10000000\[InvisibleSpace]"  \
 alpha = "\[InvisibleSpace]1\/5\[InvisibleSpace]" = "\[InvisibleSpace]0.2`\
\[InvisibleSpace]"   alphaPrecision = "\[InvisibleSpace]15\[InvisibleSpace]"  \
 alphaDesiredPrecision = "\[InvisibleSpace]20\[InvisibleSpace]"    rho = "\
\[InvisibleSpace]6\[InvisibleSpace]"    numberTries = "\[InvisibleSpace]0\),
        SequenceForm[ 
        "KS1SidedOneSampleBandwidthArbPrecision:", " sampleSize = ", 10000000,
           "   alpha = ", 
          Rational[ 1, 5], " = ", .20000000000000001, "   alphaPrecision = ", 
          15, "   alphaDesiredPrecision = ", 20, "    rho = ", 6, 
          "    numberTries = ", 0],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Maag and Dicaire approximation is a high limit: \
 dMD = "\[InvisibleSpace]0.0002836590207330558`6.000000000000002\
\[InvisibleSpace]"   dHighLimitNumerator = "\[InvisibleSpace]283659\
\[InvisibleSpace]"   dHighLimitDenominator = "\[InvisibleSpace]1000000000\
\[InvisibleSpace]"   dHighLimitAlpha = \
"\[InvisibleSpace]0.19999958721833609126815583242523328576`25.16839969055223\
\[InvisibleSpace]" is less than alpha = "\[InvisibleSpace]0.2`\
\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]1\),
        SequenceForm[ 
        "   Maag and Dicaire approximation is a high limit:  dMD = ", 
          0.0002836590207330558`6.000000000000002, 
          "   dHighLimitNumerator = ", 283659, "   dHighLimitDenominator = ", 
          1000000000, "   dHighLimitAlpha = ", 
          0.19999958721833609126815583242523328576`25.16839969055223, 
          " is less than alpha = ", .20000000000000001, "   numberTries = ", 
          1],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Try to find the initial LowLimit:  \
dNumeratorIncrement = "\[InvisibleSpace]100\[InvisibleSpace]"   dTryNumerator \
= "\[InvisibleSpace]283559\[InvisibleSpace]"   dTryDenominator = "\
\[InvisibleSpace]1000000000\[InvisibleSpace]"   dInput = \
"\[InvisibleSpace]0.000283559`6.000000000000002\[InvisibleSpace]"   \
alphaOutput = \
"\[InvisibleSpace]0.20022707891068979672285237444399350701`24.725284687602926\
\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]2\),
        SequenceForm[ 
        "   Try to find the initial LowLimit:  dNumeratorIncrement = ", 100, 
          "   dTryNumerator = ", 283559, "   dTryDenominator = ", 1000000000, 
          "   dInput = ", 0.000283559`6.000000000000002, "   alphaOutput = ", 
          0.20022707891068979672285237444399350701`24.725284687602926, 
          "   numberTries = ", 2],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Initial Low and High Limits found:    \
dLowLimitNumerator = "\[InvisibleSpace]283559\[InvisibleSpace]"   \
dLowLimitDenominator = "\[InvisibleSpace]1000000000\[InvisibleSpace]"   \
dLowLimitAlpha = \
"\[InvisibleSpace]0.20022707891068979672285237444399350701`24.725284687602926\
\[InvisibleSpace]" is greater than alpha = "\[InvisibleSpace]0.2`\
\[InvisibleSpace]"   dHighLimitNumerator = "\[InvisibleSpace]283659\
\[InvisibleSpace]"   dHighLimitDenominator = "\[InvisibleSpace]1000000000\
\[InvisibleSpace]"   dHighLimitAlpha = \
"\[InvisibleSpace]0.19999958721833609126815583242523328576`25.16839969055223\
\[InvisibleSpace]" is less than alpha = "\[InvisibleSpace]0.2`\
\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]2\),
        SequenceForm[ 
        "   Initial Low and High Limits found:    dLowLimitNumerator = ", 
          283559, "   dLowLimitDenominator = ", 1000000000, 
          "   dLowLimitAlpha = ", 
          0.20022707891068979672285237444399350701`24.725284687602926, 
          " is greater than alpha = ", .20000000000000001, 
          "   dHighLimitNumerator = ", 283659, "   dHighLimitDenominator = ", 
          1000000000, "   dHighLimitAlpha = ", 
          0.19999958721833609126815583242523328576`25.16839969055223, 
          " is less than alpha = ", .20000000000000001, "   numberTries = ", 
          2],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Search:   dTryNumerator = \
"\[InvisibleSpace]283658\[InvisibleSpace]"   dTryDenominator = "\
\[InvisibleSpace]1000000000\[InvisibleSpace]"   dInput = \
"\[InvisibleSpace]0.000283658`6.000000000000002\[InvisibleSpace]"   \
alphaOutput = \
"\[InvisibleSpace]0.20000231897450989244722886385403403853`25.175089443254446\
\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]3\[InvisibleSpace]"   \
dLowLimitNumerator = "\[InvisibleSpace]283559\[InvisibleSpace]"   \
dHighLimitNumerator = "\[InvisibleSpace]283659\[InvisibleSpace]"   \
dLowLimitAlpha = \
"\[InvisibleSpace]0.20022707891068979672285237444399350701`24.725284687602926\
\[InvisibleSpace]"   dHighLimitAlpha = \
"\[InvisibleSpace]0.19999958721833609126815583242523328576`25.16839969055223\)\
,
        SequenceForm[ 
        "   Search:   dTryNumerator = ", 283658, "   dTryDenominator = ", 
          1000000000, "   dInput = ", 0.000283658`6.000000000000002, 
          "   alphaOutput = ", 
          0.20000231897450989244722886385403403853`25.175089443254446, 
          "   numberTries = ", 3, "   dLowLimitNumerator = ", 283559, 
          "   dHighLimitNumerator = ", 283659, "   dLowLimitAlpha = ", 
          0.20022707891068979672285237444399350701`24.725284687602926, 
          "   dHighLimitAlpha = ", 
          0.19999958721833609126815583242523328576`25.16839969055223],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`"      New search above is a new LowLimit"\)], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Low and High Limits found:   dLowLimitNumerator \
= "\[InvisibleSpace]283658\[InvisibleSpace]"   dHighLimitNumerator = "\
\[InvisibleSpace]283659\[InvisibleSpace]"   dLowLimitAlpha = "\
\[InvisibleSpace]0.20000231897450989244722886385403403853`25.175089443254446\
\[InvisibleSpace]"   dHighLimitAlpha = \
"\[InvisibleSpace]0.19999958721833609126815583242523328576`25.16839969055223\
\[InvisibleSpace]"   dLowLimitDenominator = "\[InvisibleSpace]1000000000\
\[InvisibleSpace]"   dHighLimitDenominator = "\[InvisibleSpace]1000000000\),
        SequenceForm[ 
        "   Low and High Limits found:   dLowLimitNumerator = ", 283658, 
          "   dHighLimitNumerator = ", 283659, "   dLowLimitAlpha = ", 
          0.20000231897450989244722886385403403853`25.175089443254446, 
          "   dHighLimitAlpha = ", 
          0.19999958721833609126815583242523328576`25.16839969055223, 
          "   dLowLimitDenominator = ", 1000000000, 
          "   dHighLimitDenominator = ", 1000000000],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   Determine whether LowLimit or HighLimit is \
dFinal:   dTryNumerator = "\[InvisibleSpace]2836585\[InvisibleSpace]"   \
dTryDenominator = "\[InvisibleSpace]10000000000\[InvisibleSpace]"   dInput = \
"\[InvisibleSpace]0.0002836585`5.999999999999998\[InvisibleSpace]"   \
alphaOutput = \
"\[InvisibleSpace]0.20000118426489005146562999457402763373`25.172310679203974\
\[InvisibleSpace]"   numberTries = "\[InvisibleSpace]4\),
        SequenceForm[ 
        "   Determine whether LowLimit or HighLimit is dFinal:   \
dTryNumerator = ", 2836585, "   dTryDenominator = ", 10000000000, 
          "   dInput = ", 0.0002836585`5.999999999999998, "   alphaOutput = ",
           0.20000118426489005146562999457402763373`25.172310679203974, 
          "   numberTries = ", 4],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("   dFinal found:   dNumeratorFinal = "\
\[InvisibleSpace]283659\[InvisibleSpace]"   dDenominatorFinal = "\
\[InvisibleSpace]1000000000\[InvisibleSpace]"   dFinal = \
"\[InvisibleSpace]283659\/1000000000\[InvisibleSpace]" = \
"\[InvisibleSpace]0.000283659`6.000000000000002\[InvisibleSpace]"   \
numberTries = "\[InvisibleSpace]4\),
        SequenceForm[ 
        "   dFinal found:   dNumeratorFinal = ", 283659, 
          "   dDenominatorFinal = ", 1000000000, "   dFinal = ", 
          Rational[ 283659, 1000000000], " = ", 0.000283659`6.000000000000002,
           "   numberTries = ", 4],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`0.000283659`6.000000000000002\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
25. Produce Files of Bandwidths with Sample Intermediate Output\
\>", "Section"],

Cell["\<\
The following is the code of the \[AliasDelimiter] which finds bandwidths \
using linear search with DwassD and writes these bandwidths to a comma \
delimited file for input into Excel and a text file that can be used as input \
into timing programs.   Sample intermediate output is given in subsection \
25.1.  For the intermediate output in subsection 25.1, subsection 25.2 \
contains the file produced with the file name contained in the variable: \
outputFileName.  For the file in subsection 25.2, the character input into \
separatorString is used as a delimiter so if separatorString contains a \
comma, the file can be read into Excel.  For the intermediate output in \
subsection 25.1, subsection 25.3 contains the file produced with the file \
name contained in the variable: exportFileName.  The file in subsection 25.3 \
is designed to be used as input to the functions listed in sections 19 \
through 23.\
\>", "Text"],

Cell[BoxData[
    \(KS1SidedOneSampleArbPrecisionBandwidthsToFile[sampleSizeVectorIn_, \ 
        alphaVectorIn_, \ rhoIn_, \ intermediateOutput_, \ outputFileName_, \ 
        howToOpenFile_, \ separatorString_, \ exportFileName_]\ \  := \ 
      Module[{sampleSize, \ numberSampleSizes, alpha, \ numberOfAlphas, 
          dataVectorDimensions, \ outputFileNumber, \ 
          sampleSizeVectorIndex, \ alphaVectorIndex, rightTailProbability, \ 
          functionOutput, \ functionTimeString, \ timeString, \ rho, \ 
          rhoPlusOne, \ dCalculated, \ sampleSizeByAlpha, \ ssbaIndex, 
          ssbaNumberColumns, \ ssbaNumberRows, \ digitsIndex, \ rD, \ 
          dCalculatedString, \ 
          dCalculatedStringLength}, \[IndentingNewLine] (*\ 
          Generate\ d\ and\ timings\ for\ an\ alpha\ and\ sampleSize\ and\ \
put\ *) \[IndentingNewLine] (*\ \ \ \ into\ matrix\ \
\(\(sampleSizeByAlpha\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          Export\ sampleSizeByAlpha\ table\ to\ exportFileName\ and\ also\ \
*) \[IndentingNewLine] (*\ \ \ \ put\ into\ file, \ \(\(outputFileName\)\(.\)\
\)\ *) \[IndentingNewLine] (*\ \ \ \ \ \ intermediateOutput\  - \ 
            the\ amount\ of\ detail\ \((intermediate\ output)\)\ \
*) \[IndentingNewLine] (*\ \ \ \ \ \ \ \ printed\ during\ the\ execution\ of\ \
the\ \(\(function\)\(.\)\)\ *) \[IndentingNewLine] (*\ \ \ \ \ \ \ \ \ \ \ 0\ \
 = \ no\ intermediate\ output\ *) \[IndentingNewLine] (*\ \ \ \ \ \ \ \ \ \ \ \
1\  = \ increasing\ amount\ of\ intermediate\ output\ *) \[IndentingNewLine] \
(*\ \ \ \ \ \ \ \ \ \ \ 2\  = \ 
            maximum\ intermediate\ output\ *) \[IndentingNewLine] (*\ \ \ \ \ \
\ separatorString\  - \ 
            the\ character\ used\ to\ separate\ the\ output\ in\ file\ \
\(\(exportFileName\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          Open\ \(file : \ howToOpenFile\) = 0, \ 
          use\ OpenWrite\ which\ creates\ a\ *) \[IndentingNewLine] (*\ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ new\ file\ and\ destroys\ an\ old\ file\ \
*) \ \[IndentingNewLine] (*\ \ \ \ \ \ \ \ \ \ \ \ howToOpenFile = 1, \ 
          
          use\ OpenAppend\ which\ opens\ file\ *) \[IndentingNewLine] (*\ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ and\ appends\ output\ to\ end\ of\ that\
\ \(\(file\)\(.\)\)\ \ *) \[IndentingNewLine]\ 
        dataVectorDimensions\  = \ 
          Dimensions[
            sampleSizeVectorIn]; \[IndentingNewLine]numberSampleSizes\  = \ \ \
dataVectorDimensions[\([1]\)]; \[IndentingNewLine]dataVectorDimensions\  = \ 
          Dimensions[
            alphaVectorIn]; \[IndentingNewLine]numberOfAlphas\  = \ \ \
dataVectorDimensions[\([1]\)]; \[IndentingNewLine]rho\  = \ 
          Floor[rhoIn]; \[IndentingNewLine]rhoPlusOne\  = \ \ rho\  + \ 
            1; \[IndentingNewLine]ssbaNumberColumns\  = \ 
          rho\  + \ 7; \[IndentingNewLine]ssbaNumberRows\  = \ 
          numberSampleSizes\ *\ numberOfAlphas\  + \ 
            1; \[IndentingNewLine]sampleSizeByAlpha\  = \ 
          Array[0, \ {ssbaNumberRows, \ 
              ssbaNumberColumns}]; \[IndentingNewLine]sampleSizeByAlpha[\([1, 
              1]\)]\ \  = \ "\<n\>"; \
\[IndentingNewLine]sampleSizeByAlpha[\([1, 
              2]\)]\ \  = \ "\<alpha\>"; \
\[IndentingNewLine]sampleSizeByAlpha[\([1, 
              3]\)]\ \  = \ "\<d\>"; \
\[IndentingNewLine]sampleSizeByAlpha[\([1, 
              4]\)]\ \  = \ "\<numDigitsleft\>"; \
\[IndentingNewLine]sampleSizeByAlpha[\([1, 
              5]\)]\ \  = \ "\<numDigits\>"; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(sampleSizeByAlpha[\([1, digitsIndex\ ]\)]\ \  = \ 
              digitsIndex\  - \ 5;\)\[IndentingNewLine], \ {digitsIndex, \ 
            6, \ \ ssbaNumberColumns, \ 
            1}\[IndentingNewLine]]; \[IndentingNewLine]\ 
        ssbaIndex\  = \ 1; \[IndentingNewLine]If[
          howToOpenFile\  \[LessEqual] \ 0, \ 
          outputFileNumber\  = \ OpenWrite[outputFileName], \ 
          outputFileNumber\  = \ 
            OpenAppend[outputFileName]]; \[IndentingNewLine]If[
          howToOpenFile\  \[LessEqual] \ 0, \ \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<DwassD desired precision linear search to \
find d to rho = \>", \ \ rho, "\< for a specified sampleSize and alpha\>"]; \
\[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<\n\>"\ ]; \[IndentingNewLine]WriteString[
            
            outputFileNumber, \ "\<alphaIn, sampleSize, rho, timeInSeconds, \
actualAlpha, d\>"]; \[IndentingNewLine]WriteString[
            outputFileNumber, \ "\<\n\>"\ ];\[IndentingNewLine]]; \
\[IndentingNewLine]If[
          intermediateOutput\  \[GreaterEqual] \ 
            1, \ \[IndentingNewLine]\(Print["\<\
KS1SidedOneSampleArbPrecisionBandwidthsToFile:   outputFileName = \>", \ 
              outputFileName, \ "\<, howToOpenFile = \>", \ 
              howToOpenFile, \ "\<, separatorString = '\>", \ 
              separatorString, \ "\<'\>", "\<   exportFileName = \>", \ 
              exportFileName, \ "\<,  sampleSizeVectorIn =  \>", \ 
              sampleSizeVectorIn, \ "\< with \>", \ 
              numberSampleSizes, \ "\< sampleSizes,   and alphaVectorIn = \
\>", \ alphaVectorIn, \ "\< with \>", \ 
              numberOfAlphas, \ "\< alpha's\>"];\)\[IndentingNewLine]]; \
\[IndentingNewLine] (*\ 
          Begin\ \(\(iterations\)\(.\)\)\ *) \[IndentingNewLine]Do[\
\[IndentingNewLine]sampleSize\  = \ 
            sampleSizeVectorIn[\([sampleSizeVectorIndex]\)]; \
\[IndentingNewLine]Do[\[IndentingNewLine]ssbaIndex\  = \ 
              ssbaIndex\  + \ 1; \[IndentingNewLine]alpha\  = \ 
              alphaVectorIn[\([alphaVectorIndex]\)]; \
\[IndentingNewLine]functionOutput\  = \ \ Timing[
                KS1SidedOneSampleBandwidthArbPrecision[alpha, \ sampleSize, \ 
                  rho, \ 0]\ ]\ ; \[IndentingNewLine]dCalculated\  = \ 
              functionOutput[\([2]\)]; \[IndentingNewLine]rD\  = \ 
              RealDigits[
                dCalculated]; \[IndentingNewLine]dCalculatedString\  = \ 
              ToString[
                dCalculated]; \[IndentingNewLine]dCalculatedStringLength\  = \
\ StringLength[dCalculatedString]\  - \ 
                2; \[IndentingNewLine]sampleSizeByAlpha[\([ssbaIndex, \ 
                  1]\)]\  = \ 
              sampleSize; \[IndentingNewLine]sampleSizeByAlpha[\([ssbaIndex, \
\ 2]\)]\  = \ 
              alpha; \[IndentingNewLine]sampleSizeByAlpha[\([ssbaIndex, \ 
                  3]\)]\  = \ 
              dCalculatedString; \
\[IndentingNewLine]sampleSizeByAlpha[\([ssbaIndex, \ 4]\)]\  = \ 
              rD[\([2]\)]; \[IndentingNewLine]sampleSizeByAlpha[\([ssbaIndex, \
\ 5]\)]\  = \ 
              dCalculatedStringLength; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(sampleSizeByAlpha[\([ssbaIndex, 
                      digitsIndex\ ]\)]\ \  = \ 
                  0;\)\[IndentingNewLine], \ {digitsIndex, \ 
                6, \ \ ssbaNumberColumns, \ 
                1}\[IndentingNewLine]]; \[IndentingNewLine]Do[\
\[IndentingNewLine]\(If[\ 
                  digitsIndex\  + \ 5\  \[LessEqual] \ ssbaNumberColumns\ , 
                  sampleSizeByAlpha[\([ssbaIndex, 
                        digitsIndex\  + \ 5\ ]\)]\ \  = \ 
                    StringTake[
                      dCalculatedString, \ {digitsIndex\  + \ 2\  - \ 
                          rD[\([2]\)]}]\ ];\)\[IndentingNewLine], \ \
{digitsIndex, \ 1, \ dCalculatedStringLength\  + \ rD[\([2]\)], \ 
                1}\[IndentingNewLine]]; \
\[IndentingNewLine]rightTailProbability\  = \ 
              DwassDKS1SidedOneSampleRTdesiredPrecision[
                dCalculated, \ \ sampleSize, \ 
                rho]; \[IndentingNewLine]functionTimeString\  = \ 
              functionOutput[\([1]\)]; \[IndentingNewLine]timeString\  = \ 
              functionTimeString\  /. \ 
                Second \[Rule] 1; \[IndentingNewLine]WriteString[
              outputFileNumber, \ ToString[alpha, \ FortranForm], \ 
              separatorString, ToString[sampleSize, \ FortranForm], \ 
              separatorString, ToString[rho, \ FortranForm], \ 
              separatorString, \ timeString, \ separatorString, 
              ToString[\ rightTailProbability, \ FortranForm], \ 
              separatorString, 
              ToString[dCalculated, \ 
                FortranForm], \ "\<\n\>"]; \[IndentingNewLine]If[
              intermediateOutput\  \[GreaterEqual] \ 
                2, \[IndentingNewLine]\(Print["\<Bandwidth using DwassD \
desired precision for alpha = \>", \ alpha, \ "\<  sampleSize = \>", \ 
                  sampleSize\ , \ "\<  rho = \>", \ 
                  rho, \ \ "\<  timeInSeconds = \>", \ 
                  timeString, \ "\<  actualAlpha = \>", \ 
                  rightTailProbability, \ "\<  dCalculated = \>", \ 
                  dCalculated];\)\[IndentingNewLine]];\[IndentingNewLine], \ \
{alphaVectorIndex, \ 1, \ numberOfAlphas\ , \ 
              1}\[IndentingNewLine]];\[IndentingNewLine], \ \
{sampleSizeVectorIndex, \ 1, \ numberSampleSizes\ , \ 
            1}\[IndentingNewLine]]; \[IndentingNewLine]If[
          intermediateOutput\  \[GreaterEqual] \ 
            1, \ \ Print["\<      sampleSizeByAlpha = \>", \ 
            sampleSizeByAlpha]\ ]; \[IndentingNewLine]Export[
          exportFileName, \ 
          sampleSizeByAlpha, \ "\<Table\>"]; \[IndentingNewLine]Close[
          outputFileNumber]; \[IndentingNewLine]numberSampleSizes\
\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(KS1SidedOneSampleBandwidthArbPrecision[alphaIn_, \ sampleSizeIn_, \ 
        rhoIn_, \ intermediateOutput_]\  := \ 
      Module[{alpha, \ sampleSize, \ rho, \ alphaPrecision, \ 
          alphaDesiredPrecision, \ dMD, \ rD, \ dLowLimitNumerator, \ 
          dLowLimitDenominator, \ dLowLimitAlpha, \ dHighLimitNumerator, \ 
          dHighLimitDenominator, \ dHighLimitAlpha, \ dNumeratorIncrement, \ 
          numberTries, \ dTryNumerator, \ dTryDenominator, \ dInput, \ 
          alphaOutput, \ dHighLimitMinusLowLimit, \ dNumeratorFinal, \ 
          dDenominatorFinal, \ dFinal}, \[IndentingNewLine] (*\ 
          Calculate\ one - 
            sided\ one\ sample\ KS\ bandwidth\ to\ *) \[IndentingNewLine] (*\ \
\ \ \ rhoIn\ significant\ digits\ *) \[IndentingNewLine] (*\ \ \ \ for\ \
sample\ size\ sampleSizeIn\ and\ alpha\ *) \[IndentingNewLine] (*\ \ \ \ \
alphaIn\ using\ arbitrary\ precision\ \(\(arithmetic\)\(.\)\)\ \ \ \
*) \[IndentingNewLine] (*\ \ \ \ \ \ intermediateOutput\  - \ 
            the\ amount\ of\ detail\ \((intermediate\ output)\)\ \
*) \[IndentingNewLine] (*\ \ \ \ \ \ \ \ printed\ during\ the\ execution\ of\ \
the\ \(\(function\)\(.\)\)\ *) \[IndentingNewLine] (*\ \ \ \ \ \ \ \ \ \ \ 0\ \
 = \ no\ intermediate\ output\ *) \[IndentingNewLine] (*\ \ \ \ \ \ \ \ \ \ \ \
1, 2\  = \ 
            increasing\ amounts\ of\ intermediate\ output\ \
*) \[IndentingNewLine] (*\ \ \ \ \ \ \ \ \ \ \ 3\  = \ 
            maximum\ intermediate\ output\ *) \[IndentingNewLine]alpha\  = \ 
          Rationalize[alphaIn, \ 0]; \[IndentingNewLine]alphaPrecision\  = \ 
          Floor[Precision[N[alpha]]]; \[IndentingNewLine]If[
          alphaPrecision\  < \ 18, \ \ alphaDesiredPrecision\  = \ 20, \ 
          alphaDesiredPrecision\  = \ 
            alphaPrecision\  + \ 2]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]rho\  = \ 
          Floor[rhoIn]; \[IndentingNewLine]numberTries\  = \ 
          0; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 1, \ 
          Print["\<KS1SidedOneSampleBandwidthArbPrecision:\>", \ "\< \
sampleSize = \>", \ sampleSize, \ "\<   alpha = \>", \ alpha, \ "\< = \>", \ 
            N[alpha], \ "\<   alphaPrecision = \>", 
            alphaPrecision, \ "\<   alphaDesiredPrecision = \>", \ 
            alphaDesiredPrecision, \ "\<    rho = \>", \ 
            rho, "\<    numberTries = \>", \ 
            numberTries]]; \[IndentingNewLine] (*\ 
          Check\ for\ reasonableness\ of\ inputs\ *) \[IndentingNewLine]If[
          sampleSize\  < \ 2, \ 
          Print["\<KS1SidedOneSampleBandwidthArbPrecision ERROR: sampleSize = \
\>", \ sampleSize, \ "\< is less than 2.\>"]; \ dFinal\  = \ \(-99\); \ 
          Goto[ExitNow]\ ]; \[IndentingNewLine]If[alpha\  \[LessEqual] \ 0, \ 
          Print["\<KS1SidedOneSampleBandwidthArbPrecision ERROR: alpha = \>", \
\ alpha, \ "\< is less than or equal to zero.\>"]; \ dFinal\  = \ \(-99\); \ 
          Goto[ExitNow]\ ]; \[IndentingNewLine]If[
          alpha\  \[GreaterEqual] \ 1, \ 
          Print["\<KS1SidedOneSampleBandwidthArbPrecision ERROR: alpha = \>", \
\ alpha, \ "\< is greater than or equal to one.\>"]; \ 
          dFinal\  = \ \(-99\); \ Goto[ExitNow]\ ]; \[IndentingNewLine]If[
          rho\  < \ 2, \ 
          Print["\<KS1SidedOneSampleBandwidthArbPrecision ERROR: rho = \>", \ 
            rho, \ "\< is less than 2.\>"]; \ dFinal\  = \ \(-99\); \ 
          Goto[ExitNow]\ ]; \[IndentingNewLine] (*\ 
          Use\ Maag\ and\ Dicaire\ MD\ approximation\ to\ get\ initial\ value\
\ of\ d, \ dMD\ *) \[IndentingNewLine]dMD\  = 
          N[Sqrt[Log[
                    alpha]/\((\(-2\)\ *\ sampleSize)\)]\  - \ \((1/\((6*
                      sampleSize)\))\), rho]; \[IndentingNewLine]If[
          dMD\  > \ 1, \ dMD\  = \ 1]; \[IndentingNewLine]If[dMD\  < \ 0, \ 
          dMD\  = \ 0]; \[IndentingNewLine]rD\  = \ 
          RealDigits[dMD]; \[IndentingNewLine] (*\ Using\ dMD, \ 
          create\ the\ first\ guess\ for\ d\ and\ determine\ whether\ it\ is\ \
lower\ or\ higher\ than\ the\ actual\ value\ \
*) \[IndentingNewLine]alphaOutput\  = \ 
          DwassDKS1SidedOneSampleRTdesiredPrecision[dMD, sampleSize, \ 
            alphaDesiredPrecision]; \[IndentingNewLine]numberTries\  = \ 
          1; \[IndentingNewLine]If[alphaOutput\  > \ alpha, \ 
          Goto[InitialLowLimit], \ 
          Goto[InitialHighLimit]\ ]; \[IndentingNewLine] (*\ 
          Initial\ guess\ dMD\ is\ lower\ than\ the\ actual\ d\ \
*) \[IndentingNewLine]Label[
          InitialLowLimit]; \[IndentingNewLine]dLowLimitDenominator\  = \ 
          Floor[10^\((rho\  - \ 
                  rD[\([2]\)])\)]; \[IndentingNewLine]dLowLimitNumerator\  = \
\ Floor[dMD\ *\ \ dLowLimitDenominator]; \[IndentingNewLine]dLowLimitAlpha\  \
= \ alphaOutput; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   Maag and Dicaire approximation is a low limit:  dMD = \
\>", \ dMD, \ "\<   dLowLimitNumerator = \>", \ 
            dLowLimitNumerator\ , \ "\<   dLowLimitDenominator = \>", \ 
            dLowLimitDenominator\ , \ "\<   dLowLimitAlpha = \>", \ 
            dLowLimitAlpha, \ "\< is greater than alpha = \>", \ \ N[
              alpha], "\<   numberTries = \>", \ 
            numberTries]]; \[IndentingNewLine] (*\ Based\ on\ dLowLimit, \ 
          find\ dHighLimit\ *) \[IndentingNewLine]If[
          rho\  > \ 
            4, \ \(dNumeratorIncrement\  = \ 
              Floor[10^\((rho\  - \ 5)\)];\)\ , \ 
          dNumeratorIncrement\  = \ 
            1]; \[IndentingNewLine]dTryDenominator\  = \ 
          dLowLimitDenominator; \[IndentingNewLine]Label[
          InitialHighLimitIteration]; \[IndentingNewLine]dNumeratorIncrement\ \
 = \ dNumeratorIncrement\ *\ 
            10; \[IndentingNewLine]dTryNumerator\  = \ \ Floor[
            dLowLimitNumerator\  + \ 
              dNumeratorIncrement]; \[IndentingNewLine]dInput\  = \ 
          Rationalize[dTryNumerator/dTryDenominator, \ 
            0]; \[IndentingNewLine]If[dInput\  \[GreaterEqual] \ 1, \ 
          dHighLimitNumerator\  = \ dLowLimitNumerator; \ 
          dHighLimitDenominator\  = \ dLowLimitNumerator; \ 
          dHighLimitAlpha\  = \ Rationalize[0, \ 0]; \ 
          Goto[InitialLowAndHighLimitsFound]\ ]; \
\[IndentingNewLine]alphaOutput\  = \ 
          DwassDKS1SidedOneSampleRTdesiredPrecision[dInput, sampleSize, \ 
            alphaDesiredPrecision]; \[IndentingNewLine]numberTries\  = \ 
          numberTries\  + \ 1; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 3, \ 
          
          Print["\<   Try to find the initial HighLimit:  dNumeratorIncrement \
= \>", \ dNumeratorIncrement, \ "\<   dTryNumerator = \>", \ 
            dTryNumerator, \ "\<   dTryDenominator = \>", \ 
            dTryDenominator\ , \ "\<   dInput = \>", \ 
            N[dInput, \ 
              rho], \ "\<   alphaOutput = \>", \ \ alphaOutput, "\<   \
numberTries = \>", \ numberTries]]; \[IndentingNewLine]If[
          alphaOutput\  \[LessEqual] \ alpha, \ 
          dHighLimitNumerator\  = \ dTryNumerator; \ 
          dHighLimitDenominator\  = \ dTryDenominator; \ 
          dHighLimitAlpha\  = \ alphaOutput; \ 
          Goto[InitialLowAndHighLimitsFound]\ ]; \[IndentingNewLine] (*\ 
          New\ dLowLimit\ found\ trying\ to\ find\ initial\ dHighLimit\ \
*) \[IndentingNewLine]dLowLimitNumerator\  = \ 
          dTryNumerator; \[IndentingNewLine]dLowLimitDenominator\  = \ 
          dTryDenominator; \[IndentingNewLine]dLowLimitAlpha\  = \ 
          alphaOutput; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 3, \ 
          Print["\<   In trying to find the initial HighLimit a new LowLimit \
was found:    dLowLimitNumerator = \>", \ 
            dLowLimitNumerator, \ "\<   dLowLimitDenominator = \>", \ 
            dLowLimitDenominator, \ "\<   dLowLimitAlpha = \>", \ \ \
dLowLimitAlpha]]; \[IndentingNewLine]Goto[
          InitialHighLimitIteration]; \[IndentingNewLine] (*\ 
          Initial\ guess\ dMD\ is\ highed\ than\ the\ actual\ d\ \
*) \[IndentingNewLine]Label[
          InitialHighLimit]; \[IndentingNewLine]dHighLimitDenominator\  = \ 
          Floor[10^\((rho\  - \ 
                  rD[\([2]\)])\)]; \[IndentingNewLine]dHighLimitNumerator\  = \
\ Floor[dMD\ *\ \ dHighLimitDenominator]; \[IndentingNewLine]dHighLimitAlpha\ \
 = \ alphaOutput; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   Maag and Dicaire approximation is a high limit:  dMD = \
\>", \ dMD, \ "\<   dHighLimitNumerator = \>", \ 
            dHighLimitNumerator\ , \ "\<   dHighLimitDenominator = \>", \ 
            dHighLimitDenominator\ , \ "\<   dHighLimitAlpha = \>", \ 
            dHighLimitAlpha, \ "\< is less than alpha = \>", \ \ N[
              alpha], "\<   numberTries = \>", \ 
            numberTries]]; \[IndentingNewLine] (*\ Based\ on\ dHighLimit, \ 
          find\ dLowLimit\ *) \[IndentingNewLine]If[
          rho\  > \ 
            4, \ \(dNumeratorIncrement\  = \ 
              Floor[10^\((rho\  - \ 5)\)];\)\ , \ 
          dNumeratorIncrement\  = \ 
            1]; \[IndentingNewLine]dTryDenominator\  = \ 
          dHighLimitDenominator; \[IndentingNewLine]Label[
          InitialLowLimitIteration]; \[IndentingNewLine]dNumeratorIncrement\  \
= \ dNumeratorIncrement\ *\ 
            10; \[IndentingNewLine]dTryNumerator\  = \ \ Floor[
            dHighLimitNumerator\  - \ 
              dNumeratorIncrement]; \[IndentingNewLine]If[
          dTryNumerator\  < \ 10^\((rho - 1)\), \ 
          dHighLimitDenominator\  = \ 
            Floor[dHighLimitDenominator*10]; \ \ dHighLimitNumerator\  = \ 
            Floor[dHighLimitNumerator*10]; \ \ dTryDenominator\  = \ 
            Floor[dTryDenominator*10]; \ \ \ \ dTryNumerator\  = \ 
            Floor[dTryNumerator*10]; \ 
          dNumeratorIncrement\  = \ 
            Floor[dNumeratorIncrement*10]\ \ ]; \[IndentingNewLine]dInput\  = \
\ Rationalize[dTryNumerator/dTryDenominator, \ 0]; \[IndentingNewLine]If[
          dInput\  \[LessEqual] \ 0, \ 
          dLowLimitNumerator\  = \ dHighLimitNumerator; \ 
          dLowLimitDenominator\  = \ dHighLimitNumerator; \ 
          dLowLimitAlpha\  = \ Rationalize[1, \ 0]; \ 
          Goto[InitialLowAndHighLimitsFound]\ ]; \
\[IndentingNewLine]alphaOutput\  = \ 
          DwassDKS1SidedOneSampleRTdesiredPrecision[dInput, sampleSize, \ 
            alphaDesiredPrecision]; \[IndentingNewLine]numberTries\  = \ 
          numberTries\  + \ 1; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 3, \ 
          Print["\<   Try to find the initial LowLimit:  dNumeratorIncrement \
= \>", \ dNumeratorIncrement, \ "\<   dTryNumerator = \>", \ 
            dTryNumerator, \ "\<   dTryDenominator = \>", \ 
            dTryDenominator\ , \ "\<   dInput = \>", \ 
            N[dInput, \ 
              rho], \ "\<   alphaOutput = \>", \ \ alphaOutput, "\<   \
numberTries = \>", \ numberTries]]; \[IndentingNewLine]If[
          alphaOutput\  \[GreaterEqual] \ alpha, \ 
          dLowLimitNumerator\  = \ dTryNumerator; \ 
          dLowLimitDenominator\  = \ dTryDenominator; \ 
          dLowLimitAlpha\  = \ alphaOutput; \ 
          Goto[InitialLowAndHighLimitsFound]\ ]; \[IndentingNewLine] (*\ 
          New\ dHighLimit\ found\ trying\ to\ find\ initial\ dLowLimit\ \
*) \[IndentingNewLine]dHighLimitNumerator\  = \ 
          dTryNumerator; \[IndentingNewLine]dHighLimitDenominator\  = \ 
          dTryDenominator; \[IndentingNewLine]dHighLimitAlpha\  = \ 
          alphaOutput; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 3, \ 
          Print["\<   In trying to find the initial LowLimit a new HighLimit \
was found:    dHighLimitNumerator = \>", \ 
            dHighLimitNumerator, \ "\<   dHighLimitDenominator = \>", \ 
            dHighLimitDenominator, \ "\< dHighLimitAlpha = \>", \ \ \
dHighLimitAlpha]]; \[IndentingNewLine]Goto[
          InitialLowLimitIteration]; \[IndentingNewLine] (*\ 
          Initial\ dLowLimit\ and\ dHighLimit\ found\ \
*) \[IndentingNewLine]Label[
          InitialLowAndHighLimitsFound]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   Initial Low and High Limits found:    \
dLowLimitNumerator = \>", \ 
            dLowLimitNumerator\ , \ "\<   dLowLimitDenominator = \>", \ 
            dLowLimitDenominator\ , \ "\<   dLowLimitAlpha = \>", \ 
            dLowLimitAlpha, \ "\< is greater than alpha = \>", \ \ N[
              alpha], \ "\<   dHighLimitNumerator = \>", \ 
            dHighLimitNumerator\ , \ "\<   dHighLimitDenominator = \>", \ 
            dHighLimitDenominator\ , \ "\<   dHighLimitAlpha = \>", \ 
            dHighLimitAlpha, \ "\< is less than alpha = \>", \ \ N[
              alpha], "\<   numberTries = \>", \ 
            numberTries]]; \[IndentingNewLine] (*\ 
          Begin\ search\ between\ dLowLimit\ and\ dHighLimit\ \
*) \[IndentingNewLine]Label[
          SearchIteration]; \[IndentingNewLine]dHighLimitMinusLowLimit\  = \ 
          Floor[dHighLimitNumerator\  - \ 
              dLowLimitNumerator]; \[IndentingNewLine]If[
          dHighLimitMinusLowLimit\  \[LessEqual] \ 1, \ 
          Goto[dFinalDetermination]\ ]; \[IndentingNewLine]dTryDenominator\  \
= \ dHighLimitDenominator; \[IndentingNewLine]dTryNumerator\  = \ 
          Floor[
            Rationalize[
              dLowLimitNumerator\  + \ 
                dHighLimitMinusLowLimit*\((dLowLimitAlpha\  - \ 
                        alpha)\)/\((dLowLimitAlpha\  - \ 
                        dHighLimitAlpha)\), \ 0]]; \[IndentingNewLine]If[
          dTryNumerator\  \[GreaterEqual] \ dHighLimitNumerator, \ 
          dTryNumerator\  = \ 
            Floor[dTryNumerator\  - \ 1]\ ]; \[IndentingNewLine]If[
          dTryNumerator \[LessEqual] \ dLowLimitNumerator, \ 
          dTryNumerator\  = \ 
            Floor[dTryNumerator\  + \ 1]\ ]; \[IndentingNewLine]dInput\  = \ 
          Rationalize[dTryNumerator/dTryDenominator, \ 
            0]; \[IndentingNewLine]alphaOutput\  = \ 
          DwassDKS1SidedOneSampleRTdesiredPrecision[dInput, sampleSize, \ 
            alphaDesiredPrecision]; \[IndentingNewLine]numberTries\  = \ 
          numberTries\  + \ 1; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 3, \ 
          Print["\<   Search:   dTryNumerator = \>", \ 
            dTryNumerator, \ "\<   dTryDenominator = \>", \ 
            dTryDenominator\ , \ "\<   dInput = \>", \ 
            N[dInput, \ 
              rho], \ "\<   alphaOutput = \>", \ \ alphaOutput, "\<   \
numberTries = \>", \ numberTries, \ "\<   dLowLimitNumerator = \>", \ 
            dLowLimitNumerator, \ "\<   dHighLimitNumerator = \>", \ 
            dHighLimitNumerator, \ "\<   dLowLimitAlpha = \>", \ 
            dLowLimitAlpha, \ "\<   dHighLimitAlpha = \>", \ 
            dHighLimitAlpha]]; \[IndentingNewLine]If[
          alphaOutput\  > \ alpha, \ 
          dLowLimitNumerator\  = \ dTryNumerator; \ 
          dLowLimitDenominator\  = \ dTryDenominator; \ 
          dLowLimitAlpha\  = \ 
            alphaOutput;\ , \ \ \ dHighLimitNumerator\  = \ dTryNumerator; \ 
          dHighLimitDenominator\  = \ dTryDenominator; \ 
          dHighLimitAlpha\  = \ alphaOutput;]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 3, \ 
          If[alphaOutput\  > \ alpha, \ 
            Print["\<      New search above is a new LowLimit\>"], \ 
            Print["\<      New search above is a new HighLimit\>"]\ ]\ ]; \
\[IndentingNewLine]Goto[SearchIteration]; \[IndentingNewLine] (*\ 
          Determine\ whether\ LowLimit\ or\ HighLimit\ is\ dFinal\ \
*) \[IndentingNewLine]Label[dFinalDetermination]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 2, \ 
          Print["\<   Low and High Limits found:   dLowLimitNumerator = \>", \
\ dLowLimitNumerator, \ "\<   dHighLimitNumerator = \>", \ 
            dHighLimitNumerator, \ "\<   dLowLimitAlpha = \>", \ 
            dLowLimitAlpha, \ "\<   dHighLimitAlpha = \>", \ 
            dHighLimitAlpha, \ "\<   dLowLimitDenominator = \>", \ 
            dLowLimitDenominator, \ "\<   dHighLimitDenominator = \>", \ 
            dHighLimitDenominator]]; \[IndentingNewLine]dTryDenominator\  = \ 
          Floor[dLowLimitDenominator\ *\ 
              10]; \[IndentingNewLine]dTryNumerator\  = \ 
          Floor[dLowLimitNumerator\ *\ 10\  + \ 
              5]; \[IndentingNewLine]dInput\  = \ 
          Rationalize[dTryNumerator/dTryDenominator, \ 
            0]; \[IndentingNewLine]alphaOutput\  = \ 
          DwassDKS1SidedOneSampleRTdesiredPrecision[dInput, sampleSize, \ 
            alphaDesiredPrecision]; \[IndentingNewLine]numberTries\  = \ 
          numberTries\  + \ 1; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 3, \ 
          Print["\<   Determine whether LowLimit or HighLimit is dFinal:   \
dTryNumerator = \>", \ dTryNumerator, \ "\<   dTryDenominator = \>", \ 
            dTryDenominator\ , \ "\<   dInput = \>", \ 
            N[dInput, \ 
              rho], \ "\<   alphaOutput = \>", \ \ alphaOutput, "\<   \
numberTries = \>", \ numberTries]]; \[IndentingNewLine]If[
          alphaOutput\  < \ alpha, \ \ dNumeratorFinal\  = \ 
            dLowLimitNumerator; \ 
          dDenominatorFinal\  = \ dLowLimitDenominator;\ \ , \ 
          dNumeratorFinal\  = \ dHighLimitNumerator; \ 
          dDenominatorFinal\  = \ 
            dHighLimitDenominator;\ \ ]; \[IndentingNewLine]dFinal\  = \ 
          Rationalize[\ dNumeratorFinal/dDenominatorFinal, \ 
            0]; \[IndentingNewLine]If[\ 
          intermediateOutput \[GreaterEqual] \ 1, \ 
          Print["\<   dFinal found:   dNumeratorFinal = \>", \ 
            dNumeratorFinal, \ "\<   dDenominatorFinal = \>", \ 
            dDenominatorFinal\ , \ "\<   dFinal = \>", \ 
            dFinal, \ "\< = \>", \ 
            N[dFinal, \ rho], "\<   numberTries = \>", \ 
            numberTries]]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]N[dFinal, \ 
          rho]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassDKS1SidedOneSampleRTdesiredPrecision[dIn_, sampleSizeIn_, \ 
        desiredPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ desiredPrecision, \ internalPrecision, \ j, \ 
          jLowLimit, \ term, \ leftTailProbability, \ rightTailProbability, \ 
          binomialCoefficient, \ secondTerm, \ thirdTerm, \ sumTerms, \ 
          numberIterations, \ alphaPredict, \ 
          resultPrecision}, \[IndentingNewLine] (*\ 
          DwassD\ formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ sample\ \
*) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ to\ desiredPrecisionIn\ digits\ of\ *) \[IndentingNewLine] \
(*\ \ \ \ precision\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine]d = 
          Rationalize[dIn, \ 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]desiredPrecision\  = \ 
          Ceiling[desiredPrecisionIn]; \[IndentingNewLine] (*\ 
          Maag\ and\ Dicaire\ approximation\ \
*) \[IndentingNewLine]alphaPredict\  = \ 
          Exp[\(-2\)\ *\ d^2\ *\ 
                sampleSize\  - \ \((2\ *
                  d\ /\ 3)\)\  - \ \((1/\((18\ *\ 
                      sampleSize)\))\)]; \[IndentingNewLine]internalPrecision\
\  = \ Ceiling[
              3\  + \ \((4.84\  + \ 1.033\ *\ Sqrt[sampleSize])\)\ *\ \((\ 
                    0.611\  - \ 0.0904*\ alphaPredict\  - \ 
                      0.357\ *\ alphaPredict^\((1/3)\)\  - \ 
                      0.0998\ *\ alphaPredict^4\  - \ 
                      0.0616\ *\ Log[alphaPredict])\)]\  + \ 
            desiredPrecision; \[IndentingNewLine]numberIterations\  = \ 
          0; \[IndentingNewLine]Label[
          AnotherIteration]; \[IndentingNewLine]numberIterations\  = \ 
          numberIterations\  + \ 
            1; \[IndentingNewLine]rightTailProbability\ \  = \ 
          DwassDKS1SidedOneSampleRTArbPrecision[d, sampleSize, 
            internalPrecision]; \[IndentingNewLine]resultPrecision\  = \ 
          Precision[rightTailProbability]; \[IndentingNewLine]If[
          resultPrecision\  < \ 
            desiredPrecision, \[IndentingNewLine]internalPrecision\  = \ 
            internalPrecision\  + \ desiredPrecision; \[IndentingNewLine]Goto[
            AnotherIteration];\[IndentingNewLine]]; \
\[IndentingNewLine]rightTailProbability\ \[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(DwassDKS1SidedOneSampleRTArbPrecision[dIn_, sampleSizeIn_, 
        internalPrecisionIn_]\  := \ \ \[IndentingNewLine]Module[{d, \ 
          sampleSize, \ internalPrecision, \ j, \ jHighLimit, \ 
          rightTailProbability, \ binomialCoefficient, \ secondTerm, \ 
          thirdTerm, \ sumTerms}, \[IndentingNewLine] (*\ 
          Dwass\ Direct\ formula\ to\ calculate\ the\ KS\ 1\ Sided\ one\ \
sample\ *) \[IndentingNewLine] (*\ \ \ \ right\ tail\ p - 
            value\ for\ sample\ size\ sampleSizeIn\ and\ \
*) \[IndentingNewLine] (*\ \ \ \ test\ statistic\ dIn\ using\ arbitrary\ \
precision\ \(\(arithmetic\)\(.\)\)\ *) \[IndentingNewLine] (*\ 
          M . \ Dwass\[IndentingNewLine]\ \ \ "\<The Distribution of the \
generalized Dn+,\>"\[IndentingNewLine]\ \ \ Annals\ of\ Mathematical\ \
Statistics\ 19\ \((1959)\), \ pp . \ 1024 - 1028. \ *) \[IndentingNewLine]d = 
          Rationalize[dIn, 0]; \[IndentingNewLine]sampleSize\  = \ 
          Floor[sampleSizeIn]; \[IndentingNewLine]internalPrecision\  = \ 
          Floor[\ internalPrecisionIn]; \[IndentingNewLine]If[
          d\  \[LessEqual] \ 
            0, \ \[IndentingNewLine]rightTailProbability\  = \ 
            1; \[IndentingNewLine]Goto[
            ExitNow];\[IndentingNewLine], \ \(If[
              d\  \[GreaterEqual] \ 
                1, \[IndentingNewLine]rightTailProbability\  = \ 
                0; \ \[IndentingNewLine]Goto[
                ExitNow];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]jHighLimit\  = \ 
          Floor[sampleSize\ *\ 
              d]; \[IndentingNewLine]binomialCoefficient\  = \ 
          1; \[IndentingNewLine]secondTerm\ \  = \ 
          N[1\  + \ d, \ 
            internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ \(-d\); \
\[IndentingNewLine]sumTerms\  = \ 
          N[secondTerm^\((sampleSize - 1)\), \ 
            internalPrecision]; \[IndentingNewLine]If[jHighLimit\  < \ 1, \ 
          Goto[summationDone]]; \
\[IndentingNewLine]Do[\[IndentingNewLine]binomialCoefficient\  = \ 
            N[binomialCoefficient\ *\ \((sampleSize\  - \ j\  + \ 1)\)/\ 
                  j\ , \ internalPrecision]; \[IndentingNewLine]secondTerm\  \
= \ N[secondTerm\  - \ \((1/sampleSize)\)\ , 
              internalPrecision]; \[IndentingNewLine]thirdTerm\  = \ 
            N[thirdTerm\  + \ \((1/sampleSize)\)\ , 
              internalPrecision]; \[IndentingNewLine]sumTerms\  = \ 
            N[sumTerms\  + \((binomialCoefficient\ *\ 
                    secondTerm^\((sampleSize\  - \ j\  - \ 1)\)\ *\ 
                    thirdTerm^j)\), \ 
              internalPrecision];\[IndentingNewLine], {j, \ 1, \ 
            jHighLimit, \ 1}]; \[IndentingNewLine]Label[
          summationDone]; \[IndentingNewLine]rightTailProbability\ \  = \ 
          N[1\  - \ \((d\ *\ sumTerms)\), \ 
            internalPrecision]; \[IndentingNewLine]Label[
          ExitNow]; \[IndentingNewLine]rightTailProbability\ \
\[IndentingNewLine]]\)], "Input"],

Cell[CellGroupData[{

Cell["25.1  Produce Files of Bandwidths Sample Intermediate Output", \
"Subsection"],

Cell[BoxData[
    \(\(\(KS1SidedOneSampleArbPrecisionBandwidthsToFile[{1950, \ 
        2000}, \ {0.2, \ 0.1, \ 0.05, \ 0.02, \ 0.01, \ 0.001}, \ 6, \ 
      2, \ "\<C:/KSoutput/BandwidthsKS1SidedOneSampleArbPrecisionN1950And2000.\
csv\>", \ 
      0, \ "\<,\>", \ \
"\<C:/KSoutput/BandwidthsKS1SidedOneSampleArbPrecisionN1950And2000.dat\>"]\)\(\
\ \)\)\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("KS1SidedOneSampleArbPrecisionBandwidthsToFile:   \
outputFileName = \
"\[InvisibleSpace]"C:/KSoutput/\
BandwidthsKS1SidedOneSampleArbPrecisionN1950And2000.csv"\[InvisibleSpace]", \
howToOpenFile = "\[InvisibleSpace]0\[InvisibleSpace]", separatorString = '"\
\[InvisibleSpace]","\[InvisibleSpace]"'"\[InvisibleSpace]"   exportFileName = \
"\[InvisibleSpace]"C:/KSoutput/\
BandwidthsKS1SidedOneSampleArbPrecisionN1950And2000.dat"\[InvisibleSpace]",  \
sampleSizeVectorIn =  "\[InvisibleSpace]{1950, 
            2000}\[InvisibleSpace]" with \
"\[InvisibleSpace]2\[InvisibleSpace]" sampleSizes,   and alphaVectorIn = "\
\[InvisibleSpace]{0.2`, 0.1`, 0.05`, 0.02`, 0.01`, 
            0.001`}\[InvisibleSpace]" with "\[InvisibleSpace]6\
\[InvisibleSpace]" alpha's"\),
        SequenceForm[ 
        "KS1SidedOneSampleArbPrecisionBandwidthsToFile:   outputFileName = ", 
          "C:/KSoutput/BandwidthsKS1SidedOneSampleArbPrecisionN1950And2000.\
csv", ", howToOpenFile = ", 0, ", separatorString = '", ",", "'", 
          "   exportFileName = ", 
          "C:/KSoutput/BandwidthsKS1SidedOneSampleArbPrecisionN1950And2000.\
dat", ",  sampleSizeVectorIn =  ", {1950, 2000}, " with ", 2, 
          " sampleSizes,   and alphaVectorIn = ", {.20000000000000001, \
.10000000000000001, .050000000000000003, .02, .01, .001}, " with ", 6, 
          " alpha's"],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("Bandwidth using DwassD desired precision for alpha \
= "\[InvisibleSpace]0.2`\[InvisibleSpace]"  sampleSize = \
"\[InvisibleSpace]1950\[InvisibleSpace]"  rho = "\[InvisibleSpace]6\
\[InvisibleSpace]"  timeInSeconds = \
"\[InvisibleSpace]0.031`\[InvisibleSpace]"  actualAlpha = \
"\[InvisibleSpace]0.19999899694871166082971152331693754384`24.084634552952117\
\[InvisibleSpace]"  dCalculated = \
"\[InvisibleSpace]0.0202294`6.000000000000002\),
        SequenceForm[ 
        "Bandwidth using DwassD desired precision for alpha = ", \
.20000000000000001, "  sampleSize = ", 1950, "  rho = ", 6, 
          "  timeInSeconds = ", .031, "  actualAlpha = ", 
          0.19999899694871166082971152331693754384`24.084634552952117, 
          "  dCalculated = ", 0.0202294`6.000000000000002],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("Bandwidth using DwassD desired precision for alpha \
= "\[InvisibleSpace]0.1`\[InvisibleSpace]"  sampleSize = \
"\[InvisibleSpace]1950\[InvisibleSpace]"  rho = "\[InvisibleSpace]6\
\[InvisibleSpace]"  timeInSeconds = "\[InvisibleSpace]0.015999999999999986`\
\[InvisibleSpace]"  actualAlpha = \
"\[InvisibleSpace]0.09999911876410281693895514716712308233`24.467252904016508\
\[InvisibleSpace]"  dCalculated = "\[InvisibleSpace]0.0242128`6. \),
        SequenceForm[ 
        "Bandwidth using DwassD desired precision for alpha = ", \
.10000000000000001, "  sampleSize = ", 1950, "  rho = ", 6, 
          "  timeInSeconds = ", .015999999999999986, "  actualAlpha = ", 
          0.09999911876410281693895514716712308233`24.467252904016508, 
          "  dCalculated = ", 0.0242128`6.],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("Bandwidth using DwassD desired precision for alpha \
= "\[InvisibleSpace]0.05`\[InvisibleSpace]"  sampleSize = \
"\[InvisibleSpace]1950\[InvisibleSpace]"  rho = "\[InvisibleSpace]6\
\[InvisibleSpace]"  timeInSeconds = "\[InvisibleSpace]0.031000000000000028`\
\[InvisibleSpace]"  actualAlpha = \
"\[InvisibleSpace]0.04999951658344463610088712387801200457`24.48425378830843\
\[InvisibleSpace]"  dCalculated = \
"\[InvisibleSpace]0.0276292`6.000000000000002\),
        SequenceForm[ 
        "Bandwidth using DwassD desired precision for alpha = ", \
.050000000000000003, "  sampleSize = ", 1950, "  rho = ", 6, 
          "  timeInSeconds = ", .031000000000000028, "  actualAlpha = ", 
          0.04999951658344463610088712387801200457`24.48425378830843, 
          "  dCalculated = ", 0.0276292`6.000000000000002],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("Bandwidth using DwassD desired precision for alpha \
= "\[InvisibleSpace]0.02`\[InvisibleSpace]"  sampleSize = \
"\[InvisibleSpace]1950\[InvisibleSpace]"  rho = "\[InvisibleSpace]6\
\[InvisibleSpace]"  timeInSeconds = "\[InvisibleSpace]0.030999999999999972`\
\[InvisibleSpace]"  actualAlpha = \
"\[InvisibleSpace]0.01999983249713764057256609100619330021`24.843771096109542\
\[InvisibleSpace]"  dCalculated = \
"\[InvisibleSpace]0.0315844`5.999999999999999\),
        SequenceForm[ 
        "Bandwidth using DwassD desired precision for alpha = ", .02, 
          "  sampleSize = ", 1950, "  rho = ", 6, 
          "  timeInSeconds = ", .030999999999999972, "  actualAlpha = ", 
          0.01999983249713764057256609100619330021`24.843771096109542, 
          "  dCalculated = ", 0.0315844`5.999999999999999],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("Bandwidth using DwassD desired precision for alpha \
= "\[InvisibleSpace]0.01`\[InvisibleSpace]"  sampleSize = \
"\[InvisibleSpace]1950\[InvisibleSpace]"  rho = "\[InvisibleSpace]6\
\[InvisibleSpace]"  timeInSeconds = "\[InvisibleSpace]0.031000000000000028`\
\[InvisibleSpace]"  actualAlpha = \
"\[InvisibleSpace]0.00999979576048988284932886196938294298`24.66789219181145\
\[InvisibleSpace]"  dCalculated = "\[InvisibleSpace]0.0342751`6. \),
        SequenceForm[ 
        "Bandwidth using DwassD desired precision for alpha = ", .01, 
          "  sampleSize = ", 1950, "  rho = ", 6, 
          "  timeInSeconds = ", .031000000000000028, "  actualAlpha = ", 
          0.00999979576048988284932886196938294298`24.66789219181145, 
          "  dCalculated = ", 0.0342751`6.],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("Bandwidth using DwassD desired precision for alpha \
= "\[InvisibleSpace]0.001`\[InvisibleSpace]"  sampleSize = \
"\[InvisibleSpace]1950\[InvisibleSpace]"  rho = "\[InvisibleSpace]6\
\[InvisibleSpace]"  timeInSeconds = "\[InvisibleSpace]0.046999999999999986`\
\[InvisibleSpace]"  actualAlpha = \
"\[InvisibleSpace]0.00100000040086965960053777044362414997`24.466175589540157\
\[InvisibleSpace]"  dCalculated = \
"\[InvisibleSpace]0.0419946`6.000000000000002\),
        SequenceForm[ 
        "Bandwidth using DwassD desired precision for alpha = ", .001, 
          "  sampleSize = ", 1950, "  rho = ", 6, 
          "  timeInSeconds = ", .046999999999999986, "  actualAlpha = ", 
          0.00100000040086965960053777044362414997`24.466175589540157, 
          "  dCalculated = ", 0.0419946`6.000000000000002],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("Bandwidth using DwassD desired precision for alpha \
= "\[InvisibleSpace]0.2`\[InvisibleSpace]"  sampleSize = \
"\[InvisibleSpace]2000\[InvisibleSpace]"  rho = "\[InvisibleSpace]6\
\[InvisibleSpace]"  timeInSeconds = "\[InvisibleSpace]0.016000000000000014`\
\[InvisibleSpace]"  actualAlpha = \
"\[InvisibleSpace]0.1999988248940094062493831753450204974`23.798909466740167\
\[InvisibleSpace]"  dCalculated = \
"\[InvisibleSpace]0.019976`6.000000000000002\),
        SequenceForm[ 
        "Bandwidth using DwassD desired precision for alpha = ", \
.20000000000000001, "  sampleSize = ", 2000, "  rho = ", 6, 
          "  timeInSeconds = ", .016000000000000014, "  actualAlpha = ", 
          0.1999988248940094062493831753450204974`23.798909466740167, 
          "  dCalculated = ", 0.019976`6.000000000000002],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("Bandwidth using DwassD desired precision for alpha \
= "\[InvisibleSpace]0.1`\[InvisibleSpace]"  sampleSize = \
"\[InvisibleSpace]2000\[InvisibleSpace]"  rho = "\[InvisibleSpace]6\
\[InvisibleSpace]"  timeInSeconds = "\[InvisibleSpace]0.016000000000000014`\
\[InvisibleSpace]"  actualAlpha = \
"\[InvisibleSpace]0.10000077575059069185426136152095616885`24.126694432389915\
\[InvisibleSpace]"  dCalculated = \
"\[InvisibleSpace]0.0239092`6.000000000000002\),
        SequenceForm[ 
        "Bandwidth using DwassD desired precision for alpha = ", \
.10000000000000001, "  sampleSize = ", 2000, "  rho = ", 6, 
          "  timeInSeconds = ", .016000000000000014, "  actualAlpha = ", 
          0.10000077575059069185426136152095616885`24.126694432389915, 
          "  dCalculated = ", 0.0239092`6.000000000000002],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("Bandwidth using DwassD desired precision for alpha \
= "\[InvisibleSpace]0.05`\[InvisibleSpace]"  sampleSize = \
"\[InvisibleSpace]2000\[InvisibleSpace]"  rho = "\[InvisibleSpace]6\
\[InvisibleSpace]"  timeInSeconds = "\[InvisibleSpace]0.016000000000000014`\
\[InvisibleSpace]"  actualAlpha = \
"\[InvisibleSpace]0.04999949074378656686884773728709892276`24.096465634016806\
\[InvisibleSpace]"  dCalculated = \
"\[InvisibleSpace]0.0272827`6.000000000000003\),
        SequenceForm[ 
        "Bandwidth using DwassD desired precision for alpha = ", \
.050000000000000003, "  sampleSize = ", 2000, "  rho = ", 6, 
          "  timeInSeconds = ", .016000000000000014, "  actualAlpha = ", 
          0.04999949074378656686884773728709892276`24.096465634016806, 
          "  dCalculated = ", 0.0272827`6.000000000000003],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("Bandwidth using DwassD desired precision for alpha \
= "\[InvisibleSpace]0.02`\[InvisibleSpace]"  sampleSize = \
"\[InvisibleSpace]2000\[InvisibleSpace]"  rho = "\[InvisibleSpace]6\
\[InvisibleSpace]"  timeInSeconds = "\[InvisibleSpace]0.03199999999999997`\
\[InvisibleSpace]"  actualAlpha = \
"\[InvisibleSpace]0.0199998920337058543388654243030270391`24.401441364402142\
\[InvisibleSpace]"  dCalculated = \
"\[InvisibleSpace]0.0311882`6.000000000000002\),
        SequenceForm[ 
        "Bandwidth using DwassD desired precision for alpha = ", .02, 
          "  sampleSize = ", 2000, "  rho = ", 6, 
          "  timeInSeconds = ", .031999999999999973, "  actualAlpha = ", 
          0.0199998920337058543388654243030270391`24.401441364402142, 
          "  dCalculated = ", 0.0311882`6.000000000000002],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("Bandwidth using DwassD desired precision for alpha \
= "\[InvisibleSpace]0.01`\[InvisibleSpace]"  sampleSize = \
"\[InvisibleSpace]2000\[InvisibleSpace]"  rho = "\[InvisibleSpace]6\
\[InvisibleSpace]"  timeInSeconds = "\[InvisibleSpace]0.030999999999999972`\
\[InvisibleSpace]"  actualAlpha = \
"\[InvisibleSpace]0.01000001973665160189318313335987508961`24.1885313303424\
\[InvisibleSpace]"  dCalculated = "\[InvisibleSpace]0.033845`6. \),
        SequenceForm[ 
        "Bandwidth using DwassD desired precision for alpha = ", .01, 
          "  sampleSize = ", 2000, "  rho = ", 6, 
          "  timeInSeconds = ", .030999999999999972, "  actualAlpha = ", 
          0.01000001973665160189318313335987508961`24.1885313303424, 
          "  dCalculated = ", 0.033845`6.],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[\("Bandwidth using DwassD desired precision for alpha \
= "\[InvisibleSpace]0.001`\[InvisibleSpace]"  sampleSize = \
"\[InvisibleSpace]2000\[InvisibleSpace]"  rho = "\[InvisibleSpace]6\
\[InvisibleSpace]"  timeInSeconds = "\[InvisibleSpace]0.031000000000000028`\
\[InvisibleSpace]"  actualAlpha = \
"\[InvisibleSpace]0.0009999803671584807499888879658561061`24.880147284058534\
\[InvisibleSpace]"  dCalculated = \
"\[InvisibleSpace]0.0414676`5.999999999999999\),
        SequenceForm[ 
        "Bandwidth using DwassD desired precision for alpha = ", .001, 
          "  sampleSize = ", 2000, "  rho = ", 6, 
          "  timeInSeconds = ", .031000000000000028, "  actualAlpha = ", 
          0.0009999803671584807499888879658561061`24.880147284058534, 
          "  dCalculated = ", 0.0414676`5.999999999999999],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        RowBox[{"\<\"      sampleSizeByAlpha = \"\>", "\[InvisibleSpace]", 
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"\<\"n\"\>", "\<\"alpha\"\>", "\<\"d\"\>", \
"\<\"numDigitsleft\"\>", "\<\"numDigits\"\>", "1", "2", "3", "4", "5", "6", 
                  "7", "8"},
                {"1950", "0.2`", "\<\"0.0202294\"\>", \(-1\), 
                  "7", "\<\"2\"\>", "\<\"0\"\>", "\<\"2\"\>", "\<\"2\"\>", \
"\<\"9\"\>", "\<\"4\"\>", "0", "0"},
                {"1950", "0.1`", "\<\"0.0242128\"\>", \(-1\), 
                  "7", "\<\"2\"\>", "\<\"4\"\>", "\<\"2\"\>", "\<\"1\"\>", \
"\<\"2\"\>", "\<\"8\"\>", "0", "0"},
                {"1950", "0.05`", "\<\"0.0276292\"\>", \(-1\), 
                  "7", "\<\"2\"\>", "\<\"7\"\>", "\<\"6\"\>", "\<\"2\"\>", \
"\<\"9\"\>", "\<\"2\"\>", "0", "0"},
                {"1950", "0.02`", "\<\"0.0315844\"\>", \(-1\), 
                  "7", "\<\"3\"\>", "\<\"1\"\>", "\<\"5\"\>", "\<\"8\"\>", \
"\<\"4\"\>", "\<\"4\"\>", "0", "0"},
                {"1950", "0.01`", "\<\"0.0342751\"\>", \(-1\), 
                  "7", "\<\"3\"\>", "\<\"4\"\>", "\<\"2\"\>", "\<\"7\"\>", \
"\<\"5\"\>", "\<\"1\"\>", "0", "0"},
                {"1950", "0.001`", "\<\"0.0419946\"\>", \(-1\), 
                  "7", "\<\"4\"\>", "\<\"1\"\>", "\<\"9\"\>", "\<\"9\"\>", \
"\<\"4\"\>", "\<\"6\"\>", "0", "0"},
                {"2000", "0.2`", "\<\"0.0199760\"\>", \(-1\), 
                  "7", "\<\"1\"\>", "\<\"9\"\>", "\<\"9\"\>", "\<\"7\"\>", \
"\<\"6\"\>", "\<\"0\"\>", "0", "0"},
                {"2000", "0.1`", "\<\"0.0239092\"\>", \(-1\), 
                  "7", "\<\"2\"\>", "\<\"3\"\>", "\<\"9\"\>", "\<\"0\"\>", \
"\<\"9\"\>", "\<\"2\"\>", "0", "0"},
                {"2000", "0.05`", "\<\"0.0272827\"\>", \(-1\), 
                  "7", "\<\"2\"\>", "\<\"7\"\>", "\<\"2\"\>", "\<\"8\"\>", \
"\<\"2\"\>", "\<\"7\"\>", "0", "0"},
                {"2000", "0.02`", "\<\"0.0311882\"\>", \(-1\), 
                  "7", "\<\"3\"\>", "\<\"1\"\>", "\<\"1\"\>", "\<\"8\"\>", \
"\<\"8\"\>", "\<\"2\"\>", "0", "0"},
                {"2000", "0.01`", "\<\"0.0338450\"\>", \(-1\), 
                  "7", "\<\"3\"\>", "\<\"3\"\>", "\<\"8\"\>", "\<\"4\"\>", \
"\<\"5\"\>", "\<\"0\"\>", "0", "0"},
                {"2000", "0.001`", "\<\"0.0414676\"\>", \(-1\), 
                  "7", "\<\"4\"\>", "\<\"1\"\>", "\<\"4\"\>", "\<\"6\"\>", \
"\<\"7\"\>", "\<\"6\"\>", "0", "0"}
                },
              RowSpacings->1,
              ColumnSpacings->1,
              ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}],
        SequenceForm[ 
        "      sampleSizeByAlpha = ", {{"n", "alpha", "d", "numDigitsleft", 
          "numDigits", 1, 2, 3, 4, 5, 6, 7, 8}, {1950, .20000000000000001, 
          "0.0202294", -1, 7, "2", "0", "2", "2", "9", "4", 0, 0}, {
          1950, .10000000000000001, "0.0242128", -1, 7, "2", "4", "2", "1", 
          "2", "8", 0, 0}, {1950, .050000000000000003, "0.0276292", -1, 7, 
          "2", "7", "6", "2", "9", "2", 0, 0}, {1950, .02, "0.0315844", -1, 7,
           "3", "1", "5", "8", "4", "4", 0, 0}, {1950, .01, "0.0342751", -1, 
          7, "3", "4", "2", "7", "5", "1", 0, 0}, {1950, .001, 
          "0.0419946", -1, 7, "4", "1", "9", "9", "4", "6", 0, 0}, {
          2000, .20000000000000001, "0.0199760", -1, 7, "1", "9", "9", "7", 
          "6", "0", 0, 0}, {2000, .10000000000000001, "0.0239092", -1, 7, "2",
           "3", "9", "0", "9", "2", 0, 0}, {2000, .050000000000000003, 
          "0.0272827", -1, 7, "2", "7", "2", "8", "2", "7", 0, 0}, {2000, .02,
           "0.0311882", -1, 7, "3", "1", "1", "8", "8", "2", 0, 0}, {
          2000, .01, "0.0338450", -1, 7, "3", "3", "8", "4", "5", "0", 0, 
          0}, {2000, .001, "0.0414676", -1, 7, "4", "1", "4", "6", "7", "6", 
          0, 0}}],
        Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
    \(TraditionalForm\`2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
25.2  Produce Files of Bandwidths Sample Output File, \
BandwidthsKS1SidedOneSampleArbPrecisionN1950And2000.csv\
\>", "Subsection"],

Cell[BoxData[{
    \(DwassD\ desired\ precision\ linear\ search\ to\ find\ d\ to\ rho = 
      6\ for\ a\ specified\ sampleSize\ and\ alpha\), "\n", 
    \(alphaIn, sampleSize, rho, timeInSeconds, actualAlpha, d\), "\n", 
    \(0.2, 1950, 6, 0.031, 0.1999989969, 0.0202294\), "\n", 
    \(0.1, 1950, 6, 0.016, 0.09999911876, 0.0242128\), "\n", 
    \(0.05, 1950, 6, 0.015, 0.04999951658, 0.0276292\), "\n", 
    \(0.02, 1950, 6, 0.031, 0.019999832497, 0.0315844\), "\n", 
    \(0.01, 1950, 6, 0.031, 0.00999979576, 0.0342751\), "\n", 
    \(0.001, 1950, 6, 0.031, 0.0010000004009, 0.0419946\), "\n", 
    \(0.2, 2000, 6, 0. , 0.1999988249, 0.019976\), "\n", 
    \(0.1, 2000, 6, 0.031, 0.10000077575, 0.0239092\), "\n", 
    \(0.05, 2000, 6, 0.031, 0.04999949074, 0.0272827\), "\n", 
    \(0.02, 2000, 6, 0.032, 0.019999892034, 0.0311882\), "\n", 
    \(0.01, 2000, 6, 0.031, 0.010000019737, 0.033845\), "\n", 
    \(0.001, 2000, 6, 0.031, 0.0009999803672, 0.0414676\), "\n", 
    \(\)}], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
25.3  Produce Files of Bandwidths Sample Output File, \
BandwidthsKS1SidedOneSampleArbPrecisionN1950And2000.dat\
\>", "Subsection"],

Cell[BoxData[{
    \(n\ alpha\ d\ numDigitsleft\ numDigits\ 1\ 2\ 3\ 4\ 5\ 6\ 7\ 8\), "\n", 
    \(1950\ 0.2\ 0.0202294 - 1\ 7\ 2\ 0\ 2\ 2\ 9\ 4\ 0\ 0\), "\n", 
    \(1950\ 0.1\ 0.0242128 - 1\ 7\ 2\ 4\ 2\ 1\ 2\ 8\ 0\ 0\), "\n", 
    \(1950\ 0.05\ 0.0276292 - 1\ 7\ 2\ 7\ 6\ 2\ 9\ 2\ 0\ 0\), "\n", 
    \(1950\ 0.02\ 0.0315844 - 1\ 7\ 3\ 1\ 5\ 8\ 4\ 4\ 0\ 0\), "\n", 
    \(1950\ 0.01\ 0.0342751 - 1\ 7\ 3\ 4\ 2\ 7\ 5\ 1\ 0\ 0\), "\n", 
    \(1950\ 0.001\ 0.0419946 - 1\ 7\ 4\ 1\ 9\ 9\ 4\ 6\ 0\ 0\), "\n", 
    \(2000\ 0.2\ 0.0199760 - 1\ 7\ 1\ 9\ 9\ 7\ 6\ 0\ 0\ 0\), "\n", 
    \(2000\ 0.1\ 0.0239092 - 1\ 7\ 2\ 3\ 9\ 0\ 9\ 2\ 0\ 0\), "\n", 
    \(2000\ 0.05\ 0.0272827 - 1\ 7\ 2\ 7\ 2\ 8\ 2\ 7\ 0\ 0\), "\n", 
    \(2000\ 0.02\ 0.0311882 - 1\ 7\ 3\ 1\ 1\ 8\ 8\ 2\ 0\ 0\), "\n", 
    \(2000\ 0.01\ 0.0338450 - 1\ 7\ 3\ 3\ 8\ 4\ 5\ 0\ 0\ 0\), "\n", 
    \(2000\ 0.001\ 0.0414676 - 1\ 7\ 4\ 1\ 4\ 6\ 7\ 6\ 0\ 0\), "\n", 
    \(\)}], "Output"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
CellGrouping->Manual,
WindowSize->{1259, 874},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 51, 0, 73, "Section"],
Cell[1830, 55, 685, 11, 71, "Text"],
Cell[2518, 68, 3198, 53, 750, "Input"],
Cell[5719, 123, 3397, 58, 770, "Input"],

Cell[CellGroupData[{
Cell[9141, 185, 70, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[9236, 189, 117, 2, 30, "Input"],
Cell[9356, 193, 121, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9514, 200, 125, 3, 30, "Input"],
Cell[9642, 205, 69, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9748, 211, 141, 2, 30, "Input"],
Cell[9892, 215, 78, 1, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10007, 221, 149, 3, 30, "Input"],
Cell[10159, 226, 67, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10263, 232, 115, 2, 30, "Input"],
Cell[10381, 236, 110, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10528, 243, 123, 3, 30, "Input"],
Cell[10654, 248, 70, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10761, 254, 139, 2, 30, "Input"],
Cell[10903, 258, 71, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11011, 264, 147, 3, 30, "Input"],
Cell[11161, 269, 67, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11265, 275, 127, 3, 30, "Input"],
Cell[11395, 280, 70, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11502, 286, 127, 3, 30, "Input"],
Cell[11632, 291, 70, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11739, 297, 127, 3, 30, "Input"],
Cell[11869, 302, 69, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11975, 308, 127, 3, 30, "Input"],
Cell[12105, 313, 70, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12212, 319, 129, 3, 30, "Input"],
Cell[12344, 324, 69, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12450, 330, 129, 3, 30, "Input"],
Cell[12582, 335, 70, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12689, 341, 120, 2, 30, "Input"],
Cell[12812, 345, 72, 1, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12921, 351, 128, 3, 30, "Input"],
Cell[13052, 356, 54, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[13167, 364, 73, 0, 73, "Section"],
Cell[13243, 366, 454, 8, 52, "Text"],
Cell[13700, 376, 9130, 150, 1490, "Input"],
Cell[22833, 528, 3198, 53, 750, "Input"],

Cell[CellGroupData[{
Cell[26056, 585, 115, 3, 38, "Subsection"],

Cell[CellGroupData[{
Cell[26196, 592, 142, 2, 30, "Input"],
Cell[26341, 596, 622, 11, 25, "Print"],
Cell[26966, 609, 982, 17, 25, "Print"],
Cell[27951, 628, 1006, 18, 25, "Print"],
Cell[28960, 648, 1012, 18, 25, "Print"],
Cell[29975, 668, 1017, 18, 25, "Print"],
Cell[30995, 688, 1012, 18, 25, "Print"],
Cell[32010, 708, 1122, 19, 44, "Print"],
Cell[33135, 729, 950, 16, 25, "Print"],
Cell[34088, 747, 59, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34184, 753, 143, 2, 30, "Input"],
Cell[34330, 757, 624, 11, 25, "Print"],
Cell[34957, 770, 1144, 20, 44, "Print"],
Cell[36104, 792, 1166, 20, 44, "Print"],
Cell[37273, 814, 1170, 20, 44, "Print"],
Cell[38446, 836, 1170, 20, 44, "Print"],
Cell[39619, 858, 1168, 20, 44, "Print"],
Cell[40790, 880, 1278, 21, 44, "Print"],
Cell[42071, 903, 952, 16, 25, "Print"],
Cell[43026, 921, 59, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43122, 927, 143, 2, 30, "Input"],
Cell[43268, 931, 626, 11, 25, "Print"],
Cell[43897, 944, 1186, 21, 44, "Print"],
Cell[45086, 967, 1057, 19, 44, "Print"],
Cell[46146, 988, 1017, 18, 44, "Print"],
Cell[47166, 1008, 969, 16, 25, "Print"],
Cell[48138, 1026, 1000, 17, 25, "Print"],
Cell[49141, 1045, 1000, 17, 25, "Print"],
Cell[50144, 1064, 973, 16, 25, "Print"],
Cell[51120, 1082, 995, 17, 25, "Print"],
Cell[52118, 1101, 1094, 18, 44, "Print"],
Cell[53215, 1121, 950, 16, 25, "Print"],
Cell[54168, 1139, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54263, 1145, 144, 2, 30, "Input"],
Cell[54410, 1149, 628, 11, 25, "Print"],
Cell[55041, 1162, 1353, 23, 44, "Print"],
Cell[56397, 1187, 1256, 22, 44, "Print"],
Cell[57656, 1211, 1196, 21, 44, "Print"],
Cell[58855, 1234, 1168, 20, 44, "Print"],
Cell[60026, 1256, 1174, 20, 44, "Print"],
Cell[61203, 1278, 1170, 20, 44, "Print"],
Cell[62376, 1300, 1170, 20, 44, "Print"],
Cell[63549, 1322, 1174, 20, 44, "Print"],
Cell[64726, 1344, 1280, 21, 44, "Print"],
Cell[66009, 1367, 954, 16, 25, "Print"],
Cell[66966, 1385, 58, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[67085, 1393, 67, 0, 73, "Section"],
Cell[67155, 1395, 350, 6, 52, "Text"],
Cell[67508, 1403, 1092, 16, 270, "Input"],

Cell[CellGroupData[{
Cell[68625, 1423, 93, 2, 38, "Subsection"],

Cell[CellGroupData[{
Cell[68743, 1429, 116, 2, 30, "Input"],
Cell[68862, 1433, 86, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[68985, 1439, 117, 2, 30, "Input"],
Cell[69105, 1443, 86, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[69252, 1451, 118, 2, 30, "Input"],
Cell[69373, 1455, 76, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[69486, 1461, 52, 0, 73, "Section"],
Cell[69541, 1463, 172, 4, 33, "Text"],
Cell[69716, 1469, 3661, 57, 650, "Input"],
Cell[73380, 1528, 1092, 16, 270, "Input"],
Cell[74475, 1546, 9130, 150, 1490, "Input"],
Cell[83608, 1698, 3198, 53, 750, "Input"],

Cell[CellGroupData[{
Cell[86831, 1755, 103, 2, 38, "Subsection"],

Cell[CellGroupData[{
Cell[86959, 1761, 115, 2, 30, "Input"],
Cell[87077, 1765, 1329, 23, 44, "Print"],
Cell[88409, 1790, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[88504, 1796, 116, 2, 30, "Input"],
Cell[88623, 1800, 1485, 25, 44, "Print"],
Cell[90111, 1827, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[90206, 1833, 113, 2, 30, "Input"],
Cell[90322, 1837, 1381, 23, 44, "Print"],
Cell[91706, 1862, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[91801, 1868, 115, 2, 30, "Input"],
Cell[91919, 1872, 1353, 23, 44, "Print"],
Cell[93275, 1897, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[93370, 1903, 116, 2, 30, "Input"],
Cell[93489, 1907, 1515, 25, 44, "Print"],
Cell[95007, 1934, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[95102, 1940, 113, 2, 30, "Input"],
Cell[95218, 1944, 1385, 23, 44, "Print"],
Cell[96606, 1969, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[96701, 1975, 116, 2, 30, "Input"],
Cell[96820, 1979, 1355, 23, 44, "Print"],
Cell[98178, 2004, 59, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[98274, 2010, 117, 2, 30, "Input"],
Cell[98394, 2014, 1517, 25, 44, "Print"],
Cell[99914, 2041, 59, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[100010, 2047, 114, 2, 30, "Input"],
Cell[100127, 2051, 1383, 23, 44, "Print"],
Cell[101513, 2076, 59, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[101633, 2084, 89, 2, 73, "Section"],
Cell[101725, 2088, 748, 11, 71, "Text"],
Cell[102476, 2101, 21135, 355, 4450, "Input"],
Cell[123614, 2458, 1092, 16, 270, "Input"],
Cell[124709, 2476, 9130, 150, 1490, "Input"],
Cell[133842, 2628, 3198, 53, 750, "Input"],

Cell[CellGroupData[{
Cell[137065, 2685, 123, 3, 38, "Subsection"],

Cell[CellGroupData[{
Cell[137213, 2692, 238, 4, 50, "Input"],
Cell[137454, 2698, 1289, 22, 44, "Print"],
Cell[138746, 2722, 682, 13, 41, "Print"],
Cell[139431, 2737, 738, 14, 41, "Print"],
Cell[140172, 2753, 686, 13, 41, "Print"],
Cell[140861, 2768, 742, 14, 41, "Print"],
Cell[141606, 2784, 686, 13, 41, "Print"],
Cell[142295, 2799, 740, 14, 41, "Print"],
Cell[143038, 2815, 690, 13, 41, "Print"],
Cell[143731, 2830, 744, 14, 41, "Print"],
Cell[144478, 2846, 320, 9, 45, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[144847, 2861, 170, 3, 38, "Subsection"],
Cell[145020, 2866, 1897, 41, 713, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[146966, 2913, 49, 0, 73, "Section"],
Cell[147018, 2915, 253, 5, 33, "Text"],
Cell[147274, 2922, 2529, 41, 550, "Input"],
Cell[149806, 2965, 3198, 53, 750, "Input"],

Cell[CellGroupData[{
Cell[153029, 3022, 68, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[153122, 3026, 112, 2, 30, "Input"],
Cell[153237, 3030, 132, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[153406, 3038, 113, 2, 30, "Input"],
Cell[153522, 3042, 132, 3, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[153715, 3052, 48, 0, 73, "Section"],
Cell[153766, 3054, 394, 7, 52, "Text"],
Cell[154163, 3063, 3018, 51, 730, "Input"],

Cell[CellGroupData[{
Cell[157206, 3118, 67, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[157298, 3122, 112, 2, 30, "Input"],
Cell[157413, 3126, 111, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[157561, 3133, 120, 3, 30, "Input"],
Cell[157684, 3138, 69, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[157790, 3144, 114, 2, 30, "Input"],
Cell[157907, 3148, 120, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[158064, 3155, 122, 3, 30, "Input"],
Cell[158189, 3160, 69, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[158319, 3168, 70, 0, 73, "Section"],
Cell[158392, 3170, 446, 7, 52, "Text"],
Cell[158841, 3179, 8479, 140, 1370, "Input"],
Cell[167323, 3321, 3018, 51, 730, "Input"],

Cell[CellGroupData[{
Cell[170366, 3376, 112, 3, 38, "Subsection"],

Cell[CellGroupData[{
Cell[170503, 3383, 144, 2, 30, "Input"],
Cell[170650, 3387, 616, 11, 25, "Print"],
Cell[171269, 3400, 982, 17, 25, "Print"],
Cell[172254, 3419, 1006, 18, 25, "Print"],
Cell[173263, 3439, 1012, 18, 25, "Print"],
Cell[174278, 3459, 1017, 18, 25, "Print"],
Cell[175298, 3479, 1012, 18, 25, "Print"],
Cell[176313, 3499, 1122, 19, 44, "Print"],
Cell[177438, 3520, 950, 16, 25, "Print"],
Cell[178391, 3538, 59, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[178487, 3544, 145, 2, 30, "Input"],
Cell[178635, 3548, 618, 11, 25, "Print"],
Cell[179256, 3561, 1144, 20, 44, "Print"],
Cell[180403, 3583, 1168, 20, 44, "Print"],
Cell[181574, 3605, 1170, 20, 44, "Print"],
Cell[182747, 3627, 1166, 20, 44, "Print"],
Cell[183916, 3649, 1168, 20, 44, "Print"],
Cell[185087, 3671, 1278, 21, 44, "Print"],
Cell[186368, 3694, 952, 16, 25, "Print"],
Cell[187323, 3712, 59, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[187419, 3718, 145, 2, 30, "Input"],
Cell[187567, 3722, 620, 11, 25, "Print"],
Cell[188190, 3735, 1186, 21, 44, "Print"],
Cell[189379, 3758, 1059, 19, 44, "Print"],
Cell[190441, 3779, 1015, 18, 25, "Print"],
Cell[191459, 3799, 973, 16, 25, "Print"],
Cell[192435, 3817, 995, 17, 25, "Print"],
Cell[193433, 3836, 1000, 17, 25, "Print"],
Cell[194436, 3855, 973, 16, 25, "Print"],
Cell[195412, 3873, 1000, 17, 25, "Print"],
Cell[196415, 3892, 1094, 18, 44, "Print"],
Cell[197512, 3912, 950, 16, 25, "Print"],
Cell[198465, 3930, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[198560, 3936, 146, 2, 30, "Input"],
Cell[198709, 3940, 622, 11, 25, "Print"],
Cell[199334, 3953, 1348, 23, 44, "Print"],
Cell[200685, 3978, 1256, 22, 44, "Print"],
Cell[201944, 4002, 1196, 21, 44, "Print"],
Cell[203143, 4025, 1168, 20, 44, "Print"],
Cell[204314, 4047, 1174, 20, 44, "Print"],
Cell[205491, 4069, 1174, 20, 44, "Print"],
Cell[206668, 4091, 1170, 20, 44, "Print"],
Cell[207841, 4113, 1174, 20, 44, "Print"],
Cell[209018, 4135, 1280, 21, 44, "Print"],
Cell[210301, 4158, 954, 16, 25, "Print"],
Cell[211258, 4176, 58, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[211377, 4184, 49, 0, 73, "Section"],
Cell[211429, 4186, 169, 4, 33, "Text"],
Cell[211601, 4192, 3634, 56, 630, "Input"],
Cell[215238, 4250, 1092, 16, 270, "Input"],
Cell[216333, 4268, 8479, 140, 1370, "Input"],
Cell[224815, 4410, 3018, 51, 730, "Input"],

Cell[CellGroupData[{
Cell[227858, 4465, 100, 2, 38, "Subsection"],

Cell[CellGroupData[{
Cell[227983, 4471, 112, 2, 30, "Input"],
Cell[228098, 4475, 1318, 23, 44, "Print"],
Cell[229419, 4500, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[229514, 4506, 113, 2, 30, "Input"],
Cell[229630, 4510, 1480, 25, 44, "Print"],
Cell[231113, 4537, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[231208, 4543, 110, 2, 30, "Input"],
Cell[231321, 4547, 1376, 23, 44, "Print"],
Cell[232700, 4572, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[232795, 4578, 112, 2, 30, "Input"],
Cell[232910, 4582, 1347, 23, 44, "Print"],
Cell[234260, 4607, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[234355, 4613, 113, 2, 30, "Input"],
Cell[234471, 4617, 1508, 25, 44, "Print"],
Cell[235982, 4644, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[236077, 4650, 110, 2, 30, "Input"],
Cell[236190, 4654, 1374, 23, 44, "Print"],
Cell[237567, 4679, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[237662, 4685, 113, 2, 30, "Input"],
Cell[237778, 4689, 1355, 23, 44, "Print"],
Cell[239136, 4714, 59, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[239232, 4720, 114, 2, 30, "Input"],
Cell[239349, 4724, 1510, 25, 44, "Print"],
Cell[240862, 4751, 59, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[240958, 4757, 111, 2, 30, "Input"],
Cell[241072, 4761, 1378, 23, 44, "Print"],
Cell[242453, 4786, 59, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[242573, 4794, 79, 0, 73, "Section"],
Cell[242655, 4796, 745, 11, 71, "Text"],
Cell[243403, 4809, 21097, 354, 4450, "Input"],
Cell[264503, 5165, 1092, 16, 270, "Input"],
Cell[265598, 5183, 8479, 140, 1370, "Input"],
Cell[274080, 5325, 3018, 51, 730, "Input"],

Cell[CellGroupData[{
Cell[277123, 5380, 121, 3, 38, "Subsection"],

Cell[CellGroupData[{
Cell[277269, 5387, 232, 4, 50, "Input"],
Cell[277504, 5393, 1277, 22, 44, "Print"],
Cell[278784, 5417, 682, 13, 41, "Print"],
Cell[279469, 5432, 738, 14, 41, "Print"],
Cell[280210, 5448, 686, 13, 41, "Print"],
Cell[280899, 5463, 742, 14, 41, "Print"],
Cell[281644, 5479, 686, 13, 41, "Print"],
Cell[282333, 5494, 740, 14, 41, "Print"],
Cell[283076, 5510, 690, 13, 41, "Print"],
Cell[283769, 5525, 744, 14, 41, "Print"],
Cell[284516, 5541, 320, 9, 45, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[284885, 5556, 165, 3, 38, "Subsection"],
Cell[285053, 5561, 1882, 41, 694, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[286984, 5608, 47, 0, 73, "Section"],
Cell[287034, 5610, 251, 5, 33, "Text"],
Cell[287288, 5617, 2520, 41, 550, "Input"],
Cell[289811, 5660, 3018, 51, 730, "Input"],

Cell[CellGroupData[{
Cell[292854, 5715, 66, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[292945, 5719, 109, 2, 30, "Input"],
Cell[293057, 5723, 131, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[293225, 5731, 110, 2, 30, "Input"],
Cell[293338, 5735, 132, 3, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[293531, 5745, 49, 0, 73, "Section"],
Cell[293583, 5747, 395, 7, 52, "Text"],
Cell[293981, 5756, 4019, 67, 930, "Input"],

Cell[CellGroupData[{
Cell[298025, 5827, 68, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[298118, 5831, 112, 2, 30, "Input"],
Cell[298233, 5835, 112, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[298382, 5842, 120, 3, 30, "Input"],
Cell[298505, 5847, 70, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[298612, 5853, 114, 2, 30, "Input"],
Cell[298729, 5857, 122, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[298888, 5864, 122, 3, 30, "Input"],
Cell[299013, 5869, 70, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[299144, 5877, 71, 0, 73, "Section"],
Cell[299218, 5879, 447, 7, 52, "Text"],
Cell[299668, 5888, 8387, 140, 1330, "Input"],
Cell[308058, 6030, 4019, 67, 930, "Input"],

Cell[CellGroupData[{
Cell[312102, 6101, 113, 3, 38, "Subsection"],

Cell[CellGroupData[{
Cell[312240, 6108, 144, 2, 30, "Input"],
Cell[312387, 6112, 616, 11, 25, "Print"],
Cell[313006, 6125, 978, 17, 25, "Print"],
Cell[313987, 6144, 1011, 18, 25, "Print"],
Cell[315001, 6164, 1006, 17, 25, "Print"],
Cell[316010, 6183, 1012, 18, 25, "Print"],
Cell[317025, 6203, 1017, 18, 25, "Print"],
Cell[318045, 6223, 1120, 19, 44, "Print"],
Cell[319168, 6244, 950, 16, 25, "Print"],
Cell[320121, 6262, 59, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[320217, 6268, 145, 2, 30, "Input"],
Cell[320365, 6272, 618, 11, 25, "Print"],
Cell[320986, 6285, 1164, 20, 44, "Print"],
Cell[322153, 6307, 1168, 20, 44, "Print"],
Cell[323324, 6329, 1170, 20, 44, "Print"],
Cell[324497, 6351, 1170, 20, 44, "Print"],
Cell[325670, 6373, 1170, 20, 44, "Print"],
Cell[326843, 6395, 1280, 21, 44, "Print"],
Cell[328126, 6418, 952, 16, 25, "Print"],
Cell[329081, 6436, 59, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[329177, 6442, 145, 2, 30, "Input"],
Cell[329325, 6446, 620, 11, 25, "Print"],
Cell[329948, 6459, 1186, 21, 44, "Print"],
Cell[331137, 6482, 1077, 19, 44, "Print"],
Cell[332217, 6503, 1017, 18, 44, "Print"],
Cell[333237, 6523, 995, 17, 25, "Print"],
Cell[334235, 6542, 973, 16, 25, "Print"],
Cell[335211, 6560, 971, 16, 25, "Print"],
Cell[336185, 6578, 973, 16, 25, "Print"],
Cell[337161, 6596, 995, 17, 25, "Print"],
Cell[338159, 6615, 1116, 19, 44, "Print"],
Cell[339278, 6636, 950, 16, 25, "Print"],
Cell[340231, 6654, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[340326, 6660, 146, 2, 30, "Input"],
Cell[340475, 6664, 622, 11, 25, "Print"],
Cell[341100, 6677, 1342, 22, 44, "Print"],
Cell[342445, 6701, 1256, 22, 44, "Print"],
Cell[343704, 6725, 1196, 21, 44, "Print"],
Cell[344903, 6748, 1174, 20, 44, "Print"],
Cell[346080, 6770, 1150, 20, 44, "Print"],
Cell[347233, 6792, 1170, 20, 44, "Print"],
Cell[348406, 6814, 1170, 20, 44, "Print"],
Cell[349579, 6836, 1170, 20, 44, "Print"],
Cell[350752, 6858, 1280, 21, 44, "Print"],
Cell[352035, 6881, 954, 16, 25, "Print"],
Cell[352992, 6899, 58, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[353111, 6907, 50, 0, 73, "Section"],
Cell[353164, 6909, 170, 4, 33, "Text"],
Cell[353337, 6915, 3634, 56, 630, "Input"],
Cell[356974, 6973, 1092, 16, 270, "Input"],
Cell[358069, 6991, 8387, 140, 1330, "Input"],
Cell[366459, 7133, 4019, 67, 930, "Input"],

Cell[CellGroupData[{
Cell[370503, 7204, 101, 2, 38, "Subsection"],

Cell[CellGroupData[{
Cell[370629, 7210, 112, 2, 30, "Input"],
Cell[370744, 7214, 1323, 23, 44, "Print"],
Cell[372070, 7239, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[372165, 7245, 113, 2, 30, "Input"],
Cell[372281, 7249, 1478, 25, 44, "Print"],
Cell[373762, 7276, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[373857, 7282, 110, 2, 30, "Input"],
Cell[373970, 7286, 1381, 23, 44, "Print"],
Cell[375354, 7311, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[375449, 7317, 112, 2, 30, "Input"],
Cell[375564, 7321, 1347, 23, 44, "Print"],
Cell[376914, 7346, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[377009, 7352, 113, 2, 30, "Input"],
Cell[377125, 7356, 1509, 25, 44, "Print"],
Cell[378637, 7383, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[378732, 7389, 110, 2, 30, "Input"],
Cell[378845, 7393, 1380, 23, 44, "Print"],
Cell[380228, 7418, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[380323, 7424, 113, 2, 30, "Input"],
Cell[380439, 7428, 1347, 23, 44, "Print"],
Cell[381789, 7453, 59, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[381885, 7459, 114, 2, 30, "Input"],
Cell[382002, 7463, 1489, 25, 44, "Print"],
Cell[383494, 7490, 59, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[383590, 7496, 111, 2, 30, "Input"],
Cell[383704, 7500, 1383, 23, 44, "Print"],
Cell[385090, 7525, 59, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[385210, 7533, 79, 0, 73, "Section"],
Cell[385292, 7535, 745, 11, 71, "Text"],
Cell[386040, 7548, 21097, 354, 4450, "Input"],
Cell[407140, 7904, 1092, 16, 270, "Input"],
Cell[408235, 7922, 8387, 140, 1330, "Input"],
Cell[416625, 8064, 4019, 67, 930, "Input"],

Cell[CellGroupData[{
Cell[420669, 8135, 121, 3, 38, "Subsection"],

Cell[CellGroupData[{
Cell[420815, 8142, 232, 4, 50, "Input"],
Cell[421050, 8148, 1277, 22, 44, "Print"],
Cell[422330, 8172, 682, 13, 41, "Print"],
Cell[423015, 8187, 738, 14, 41, "Print"],
Cell[423756, 8203, 686, 13, 41, "Print"],
Cell[424445, 8218, 742, 14, 41, "Print"],
Cell[425190, 8234, 686, 13, 41, "Print"],
Cell[425879, 8249, 740, 14, 41, "Print"],
Cell[426622, 8265, 690, 13, 41, "Print"],
Cell[427315, 8280, 744, 14, 41, "Print"],
Cell[428062, 8296, 320, 9, 45, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[428431, 8311, 165, 3, 38, "Subsection"],
Cell[428599, 8316, 1882, 41, 694, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[430530, 8363, 47, 0, 73, "Section"],
Cell[430580, 8365, 252, 5, 33, "Text"],
Cell[430835, 8372, 2578, 42, 550, "Input"],
Cell[433416, 8416, 4019, 67, 930, "Input"],

Cell[CellGroupData[{
Cell[437460, 8487, 66, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[437551, 8491, 109, 2, 30, "Input"],
Cell[437663, 8495, 131, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[437831, 8503, 110, 2, 30, "Input"],
Cell[437944, 8507, 132, 3, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[438137, 8517, 52, 0, 73, "Section"],
Cell[438192, 8519, 401, 7, 52, "Text"],
Cell[438596, 8528, 4118, 68, 930, "Input"],

Cell[CellGroupData[{
Cell[442739, 8600, 71, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[442835, 8604, 115, 2, 30, "Input"],
Cell[442953, 8608, 112, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[443102, 8615, 123, 3, 30, "Input"],
Cell[443228, 8620, 70, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[443335, 8626, 117, 2, 30, "Input"],
Cell[443455, 8630, 121, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[443613, 8637, 125, 3, 30, "Input"],
Cell[443741, 8642, 69, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[443871, 8650, 74, 0, 73, "Section"],
Cell[443948, 8652, 455, 8, 52, "Text"],
Cell[444406, 8662, 8402, 140, 1330, "Input"],
Cell[452811, 8804, 4118, 68, 930, "Input"],

Cell[CellGroupData[{
Cell[456954, 8876, 116, 3, 38, "Subsection"],

Cell[CellGroupData[{
Cell[457095, 8883, 142, 2, 30, "Input"],
Cell[457240, 8887, 622, 11, 25, "Print"],
Cell[457865, 8900, 982, 17, 25, "Print"],
Cell[458850, 8919, 1000, 17, 25, "Print"],
Cell[459853, 8938, 1017, 18, 25, "Print"],
Cell[460873, 8958, 1012, 18, 25, "Print"],
Cell[461888, 8978, 1012, 18, 25, "Print"],
Cell[462903, 8998, 1122, 19, 44, "Print"],
Cell[464028, 9019, 950, 16, 25, "Print"],
Cell[464981, 9037, 59, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[465077, 9043, 143, 2, 30, "Input"],
Cell[465223, 9047, 624, 11, 25, "Print"],
Cell[465850, 9060, 1164, 20, 44, "Print"],
Cell[467017, 9082, 1168, 20, 44, "Print"],
Cell[468188, 9104, 1170, 20, 44, "Print"],
Cell[469361, 9126, 1170, 20, 44, "Print"],
Cell[470534, 9148, 1170, 20, 44, "Print"],
Cell[471707, 9170, 1280, 21, 44, "Print"],
Cell[472990, 9193, 952, 16, 25, "Print"],
Cell[473945, 9211, 59, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[474041, 9217, 143, 2, 30, "Input"],
Cell[474187, 9221, 626, 11, 25, "Print"],
Cell[474816, 9234, 1186, 21, 44, "Print"],
Cell[476005, 9257, 1079, 19, 44, "Print"],
Cell[477087, 9278, 1017, 18, 44, "Print"],
Cell[478107, 9298, 989, 16, 25, "Print"],
Cell[479099, 9316, 973, 16, 25, "Print"],
Cell[480075, 9334, 973, 16, 25, "Print"],
Cell[481051, 9352, 973, 16, 25, "Print"],
Cell[482027, 9370, 987, 16, 25, "Print"],
Cell[483017, 9388, 1110, 19, 44, "Print"],
Cell[484130, 9409, 950, 16, 25, "Print"],
Cell[485083, 9427, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[485178, 9433, 144, 2, 30, "Input"],
Cell[485325, 9437, 628, 11, 25, "Print"],
Cell[485956, 9450, 1353, 23, 44, "Print"],
Cell[487312, 9475, 1256, 22, 44, "Print"],
Cell[488571, 9499, 1194, 21, 44, "Print"],
Cell[489768, 9522, 1174, 20, 44, "Print"],
Cell[490945, 9544, 1150, 20, 44, "Print"],
Cell[492098, 9566, 1170, 20, 44, "Print"],
Cell[493271, 9588, 1170, 20, 44, "Print"],
Cell[494444, 9610, 1170, 20, 44, "Print"],
Cell[495617, 9632, 1280, 21, 44, "Print"],
Cell[496900, 9655, 954, 16, 25, "Print"],
Cell[497857, 9673, 58, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[497976, 9681, 53, 0, 73, "Section"],
Cell[498032, 9683, 173, 4, 33, "Text"],
Cell[498208, 9689, 3661, 57, 650, "Input"],
Cell[501872, 9748, 1092, 16, 270, "Input"],
Cell[502967, 9766, 8402, 140, 1330, "Input"],
Cell[511372, 9908, 4118, 68, 930, "Input"],

Cell[CellGroupData[{
Cell[515515, 9980, 104, 2, 38, "Subsection"],

Cell[CellGroupData[{
Cell[515644, 9986, 115, 2, 30, "Input"],
Cell[515762, 9990, 1324, 23, 44, "Print"],
Cell[517089, 10015, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[517184, 10021, 116, 2, 30, "Input"],
Cell[517303, 10025, 1486, 25, 44, "Print"],
Cell[518792, 10052, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[518887, 10058, 113, 2, 30, "Input"],
Cell[519003, 10062, 1385, 23, 44, "Print"],
Cell[520391, 10087, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[520486, 10093, 115, 2, 30, "Input"],
Cell[520604, 10097, 1353, 23, 44, "Print"],
Cell[521960, 10122, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[522055, 10128, 116, 2, 30, "Input"],
Cell[522174, 10132, 1515, 25, 44, "Print"],
Cell[523692, 10159, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[523787, 10165, 113, 2, 30, "Input"],
Cell[523903, 10169, 1387, 23, 44, "Print"],
Cell[525293, 10194, 58, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[525388, 10200, 116, 2, 30, "Input"],
Cell[525507, 10204, 1361, 23, 44, "Print"],
Cell[526871, 10229, 59, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[526967, 10235, 117, 2, 30, "Input"],
Cell[527087, 10239, 1515, 25, 44, "Print"],
Cell[528605, 10266, 59, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[528701, 10272, 114, 2, 30, "Input"],
Cell[528818, 10276, 1388, 23, 44, "Print"],
Cell[530209, 10301, 59, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[530329, 10309, 90, 2, 73, "Section"],
Cell[530422, 10313, 751, 11, 90, "Text"],
Cell[531176, 10326, 21135, 355, 4450, "Input"],
Cell[552314, 10683, 1092, 16, 270, "Input"],
Cell[553409, 10701, 8402, 140, 1330, "Input"],
Cell[561814, 10843, 4118, 68, 930, "Input"],

Cell[CellGroupData[{
Cell[565957, 10915, 124, 3, 38, "Subsection"],

Cell[CellGroupData[{
Cell[566106, 10922, 238, 4, 50, "Input"],
Cell[566347, 10928, 1289, 22, 44, "Print"],
Cell[567639, 10952, 682, 13, 41, "Print"],
Cell[568324, 10967, 738, 14, 41, "Print"],
Cell[569065, 10983, 686, 13, 41, "Print"],
Cell[569754, 10998, 742, 14, 41, "Print"],
Cell[570499, 11014, 686, 13, 41, "Print"],
Cell[571188, 11029, 740, 14, 41, "Print"],
Cell[571931, 11045, 690, 13, 41, "Print"],
Cell[572624, 11060, 744, 14, 41, "Print"],
Cell[573371, 11076, 320, 9, 45, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[573740, 11091, 171, 3, 38, "Subsection"],
Cell[573914, 11096, 1897, 41, 713, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[575860, 11143, 50, 0, 73, "Section"],
Cell[575913, 11145, 254, 5, 33, "Text"],
Cell[576170, 11152, 2587, 42, 550, "Input"],
Cell[578760, 11196, 4118, 68, 930, "Input"],

Cell[CellGroupData[{
Cell[582903, 11268, 69, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[582997, 11272, 112, 2, 30, "Input"],
Cell[583112, 11276, 133, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[583282, 11284, 113, 2, 30, "Input"],
Cell[583398, 11288, 133, 3, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[583592, 11298, 70, 0, 73, "Section"],
Cell[583665, 11300, 1023, 15, 109, "Text"],
Cell[584691, 11317, 37799, 622, 6550, "Input"],
Cell[622493, 11941, 1092, 16, 270, "Input"],
Cell[623588, 11959, 2529, 41, 550, "Input"],
Cell[626120, 12002, 3198, 53, 750, "Input"],
Cell[629321, 12057, 2520, 41, 550, "Input"],
Cell[631844, 12100, 3018, 51, 730, "Input"],
Cell[634865, 12153, 2578, 42, 550, "Input"],
Cell[637446, 12197, 4019, 67, 930, "Input"],
Cell[641468, 12266, 2587, 42, 550, "Input"],
Cell[644058, 12310, 4118, 68, 930, "Input"],
Cell[648179, 12380, 2947, 52, 710, "Input"],

Cell[CellGroupData[{
Cell[651151, 12436, 112, 3, 38, "Subsection"],

Cell[CellGroupData[{
Cell[651288, 12443, 251, 5, 50, "Input"],
Cell[651542, 12450, 1624, 27, 44, "Print"],
Cell[653169, 12479, 623, 12, 41, "Print"],
Cell[653795, 12493, 895, 15, 25, "Print"],
Cell[654693, 12510, 871, 15, 25, "Print"],
Cell[655567, 12527, 1403, 23, 44, "Print"],
Cell[656973, 12552, 871, 15, 25, "Print"],
Cell[657847, 12569, 1403, 23, 44, "Print"],
Cell[659253, 12594, 894, 15, 25, "Print"],
Cell[660150, 12611, 1419, 23, 44, "Print"],
Cell[661572, 12636, 950, 17, 44, "Print"],
Cell[662525, 12655, 1424, 23, 44, "Print"],
Cell[663952, 12680, 620, 11, 41, "Print"],
Cell[664575, 12693, 859, 15, 25, "Print"],
Cell[665437, 12710, 869, 15, 25, "Print"],
Cell[666309, 12727, 1399, 23, 44, "Print"],
Cell[667711, 12752, 837, 15, 25, "Print"],
Cell[668551, 12769, 1401, 23, 44, "Print"],
Cell[669955, 12794, 895, 15, 25, "Print"],
Cell[670853, 12811, 1419, 23, 44, "Print"],
Cell[672275, 12836, 950, 17, 25, "Print"],
Cell[673228, 12855, 1422, 23, 44, "Print"],
Cell[674653, 12880, 625, 12, 41, "Print"],
Cell[675281, 12894, 1067, 18, 44, "Print"],
Cell[676351, 12914, 1044, 18, 44, "Print"],
Cell[677398, 12934, 1764, 30, 63, "Print"],
Cell[679165, 12966, 1044, 18, 44, "Print"],
Cell[680212, 12986, 1764, 30, 63, "Print"],
Cell[681979, 13018, 1068, 18, 44, "Print"],
Cell[683050, 13038, 1782, 30, 63, "Print"],
Cell[684835, 13070, 1134, 20, 44, "Print"],
Cell[685972, 13092, 1785, 29, 63, "Print"],
Cell[687760, 13123, 622, 11, 41, "Print"],
Cell[688385, 13136, 1057, 18, 44, "Print"],
Cell[689445, 13156, 999, 18, 44, "Print"],
Cell[690447, 13176, 1731, 29, 63, "Print"],
Cell[692181, 13207, 1010, 18, 44, "Print"],
Cell[693194, 13227, 1753, 30, 63, "Print"],
Cell[694950, 13259, 1075, 18, 44, "Print"],
Cell[696028, 13279, 1767, 29, 63, "Print"],
Cell[697798, 13310, 1114, 20, 44, "Print"],
Cell[698915, 13332, 1752, 28, 63, "Print"],
Cell[700670, 13362, 610, 11, 41, "Print"],
Cell[701283, 13375, 894, 15, 25, "Print"],
Cell[702180, 13392, 869, 15, 25, "Print"],
Cell[703052, 13409, 1403, 23, 44, "Print"],
Cell[704458, 13434, 881, 15, 25, "Print"],
Cell[705342, 13451, 1423, 24, 44, "Print"],
Cell[706768, 13477, 904, 15, 25, "Print"],
Cell[707675, 13494, 1443, 24, 44, "Print"],
Cell[709121, 13520, 926, 17, 44, "Print"],
Cell[710050, 13539, 1424, 23, 44, "Print"],
Cell[711477, 13564, 633, 12, 41, "Print"],
Cell[712113, 13578, 859, 15, 25, "Print"],
Cell[712975, 13595, 837, 15, 25, "Print"],
Cell[713815, 13612, 1401, 23, 44, "Print"],
Cell[715219, 13637, 869, 15, 25, "Print"],
Cell[716091, 13654, 1399, 23, 44, "Print"],
Cell[717493, 13679, 893, 15, 25, "Print"],
Cell[718389, 13696, 1417, 23, 44, "Print"],
Cell[719809, 13721, 948, 17, 25, "Print"],
Cell[720760, 13740, 1422, 23, 44, "Print"],
Cell[722185, 13765, 612, 11, 41, "Print"],
Cell[722800, 13778, 1067, 18, 44, "Print"],
Cell[723870, 13798, 1042, 18, 44, "Print"],
Cell[724915, 13818, 1764, 30, 63, "Print"],
Cell[726682, 13850, 1043, 18, 44, "Print"],
Cell[727728, 13870, 1764, 30, 63, "Print"],
Cell[729495, 13902, 1067, 18, 44, "Print"],
Cell[730565, 13922, 1782, 30, 63, "Print"],
Cell[732350, 13954, 1110, 20, 44, "Print"],
Cell[733463, 13976, 1783, 29, 63, "Print"],
Cell[735249, 14007, 635, 12, 41, "Print"],
Cell[735887, 14021, 1023, 18, 44, "Print"],
Cell[736913, 14041, 1033, 18, 44, "Print"],
Cell[737949, 14061, 1729, 29, 63, "Print"],
Cell[739681, 14092, 1044, 18, 44, "Print"],
Cell[740728, 14112, 1753, 30, 63, "Print"],
Cell[742484, 14144, 1068, 18, 44, "Print"],
Cell[743555, 14164, 1771, 30, 63, "Print"],
Cell[745329, 14196, 1112, 20, 44, "Print"],
Cell[746444, 14218, 1752, 28, 63, "Print"],
Cell[748199, 14248, 3631, 79, 81, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[751879, 14333, 175, 3, 38, "Subsection"],
Cell[752057, 14338, 6218, 109, 1435, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[758324, 14453, 57, 0, 73, "Section"],
Cell[758384, 14455, 960, 14, 90, "Text"],
Cell[759347, 14471, 31614, 521, 5570, "Input"],
Cell[790964, 14994, 1092, 16, 270, "Input"],
Cell[792059, 15012, 2529, 41, 550, "Input"],
Cell[794591, 15055, 3198, 53, 750, "Input"],
Cell[797792, 15110, 2520, 41, 550, "Input"],
Cell[800315, 15153, 3018, 51, 730, "Input"],
Cell[803336, 15206, 2578, 42, 550, "Input"],
Cell[805917, 15250, 4019, 67, 930, "Input"],
Cell[809939, 15319, 2587, 42, 550, "Input"],
Cell[812529, 15363, 4118, 68, 930, "Input"],

Cell[CellGroupData[{
Cell[816672, 15435, 97, 2, 38, "Subsection"],

Cell[CellGroupData[{
Cell[816794, 15441, 232, 4, 50, "Input"],
Cell[817029, 15447, 1613, 28, 44, "Print"],
Cell[818645, 15477, 623, 12, 41, "Print"],
Cell[819271, 15491, 858, 15, 25, "Print"],
Cell[820132, 15508, 868, 15, 25, "Print"],
Cell[821003, 15525, 1393, 23, 44, "Print"],
Cell[822399, 15550, 879, 15, 25, "Print"],
Cell[823281, 15567, 1415, 24, 44, "Print"],
Cell[824699, 15593, 901, 15, 25, "Print"],
Cell[825603, 15610, 1433, 24, 44, "Print"],
Cell[827039, 15636, 635, 12, 41, "Print"],
Cell[827677, 15650, 891, 15, 25, "Print"],
Cell[828571, 15667, 869, 15, 25, "Print"],
Cell[829443, 15684, 1401, 23, 44, "Print"],
Cell[830847, 15709, 868, 15, 25, "Print"],
Cell[831718, 15726, 1403, 23, 44, "Print"],
Cell[833124, 15751, 892, 15, 25, "Print"],
Cell[834019, 15768, 1419, 23, 44, "Print"],
Cell[835441, 15793, 625, 12, 41, "Print"],
Cell[836069, 15807, 1063, 18, 44, "Print"],
Cell[837135, 15827, 1013, 18, 44, "Print"],
Cell[838151, 15847, 1764, 30, 63, "Print"],
Cell[839918, 15879, 1046, 18, 44, "Print"],
Cell[840967, 15899, 1758, 29, 63, "Print"],
Cell[842728, 15930, 1064, 18, 44, "Print"],
Cell[843795, 15950, 1782, 30, 63, "Print"],
Cell[845580, 15982, 637, 12, 41, "Print"],
Cell[846220, 15996, 1053, 18, 44, "Print"],
Cell[847276, 16016, 1033, 18, 44, "Print"],
Cell[848312, 16036, 1729, 29, 63, "Print"],
Cell[850044, 16067, 1041, 18, 44, "Print"],
Cell[851088, 16087, 1753, 30, 63, "Print"],
Cell[852844, 16119, 1065, 18, 44, "Print"],
Cell[853912, 16139, 1771, 30, 63, "Print"],
Cell[855686, 16171, 614, 11, 41, "Print"],
Cell[856303, 16184, 888, 15, 25, "Print"],
Cell[857194, 16201, 868, 15, 25, "Print"],
Cell[858065, 16218, 1399, 23, 44, "Print"],
Cell[859467, 16243, 879, 15, 25, "Print"],
Cell[860349, 16260, 1423, 24, 44, "Print"],
Cell[861775, 16286, 903, 15, 25, "Print"],
Cell[862681, 16303, 1441, 24, 44, "Print"],
Cell[864125, 16329, 637, 12, 41, "Print"],
Cell[864765, 16343, 892, 15, 25, "Print"],
Cell[865660, 16360, 869, 15, 25, "Print"],
Cell[866532, 16377, 1399, 23, 44, "Print"],
Cell[867934, 16402, 840, 15, 25, "Print"],
Cell[868777, 16419, 1401, 23, 44, "Print"],
Cell[870181, 16444, 891, 15, 25, "Print"],
Cell[871075, 16461, 1421, 23, 44, "Print"],
Cell[872499, 16486, 616, 11, 41, "Print"],
Cell[873118, 16499, 1071, 18, 44, "Print"],
Cell[874192, 16519, 1039, 18, 44, "Print"],
Cell[875234, 16539, 1771, 30, 63, "Print"],
Cell[877008, 16571, 1048, 18, 44, "Print"],
Cell[878059, 16591, 1765, 29, 63, "Print"],
Cell[879827, 16622, 1070, 18, 44, "Print"],
Cell[880900, 16642, 1783, 29, 63, "Print"],
Cell[882686, 16673, 639, 12, 41, "Print"],
Cell[883328, 16687, 1053, 18, 44, "Print"],
Cell[884384, 16707, 1032, 18, 44, "Print"],
Cell[885419, 16727, 1731, 29, 63, "Print"],
Cell[887153, 16758, 1041, 18, 44, "Print"],
Cell[888197, 16778, 1753, 30, 63, "Print"],
Cell[889953, 16810, 1064, 18, 44, "Print"],
Cell[891020, 16830, 1771, 30, 63, "Print"],
Cell[892794, 16862, 2991, 65, 81, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[895834, 16933, 154, 3, 38, "Subsection"],
Cell[895991, 16938, 5205, 86, 1207, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[901245, 17030, 94, 2, 73, "Section"],
Cell[901342, 17034, 238, 5, 33, "Text"],
Cell[901583, 17041, 18334, 310, 2830, "Input"],
Cell[919920, 17353, 2520, 41, 550, "Input"],
Cell[922443, 17396, 3018, 51, 730, "Input"],

Cell[CellGroupData[{
Cell[925486, 17451, 94, 2, 38, "Subsection"],

Cell[CellGroupData[{
Cell[925605, 17457, 102, 2, 30, "Input"],
Cell[925710, 17461, 835, 15, 41, "Print"],
Cell[926548, 17478, 980, 16, 44, "Print"],
Cell[927531, 17496, 929, 15, 25, "Print"],
Cell[928463, 17513, 709, 13, 25, "Print"],
Cell[929175, 17528, 927, 15, 25, "Print"],
Cell[930105, 17545, 1409, 24, 44, "Print"],
Cell[931517, 17571, 1441, 25, 44, "Print"],
Cell[932961, 17598, 93, 1, 25, "Print"],
Cell[933057, 17601, 1441, 25, 44, "Print"],
Cell[934501, 17628, 92, 1, 25, "Print"],
Cell[934596, 17631, 1445, 25, 44, "Print"],
Cell[936044, 17658, 93, 1, 25, "Print"],
Cell[936140, 17661, 1089, 18, 44, "Print"],
Cell[937232, 17681, 860, 14, 25, "Print"],
Cell[938095, 17697, 683, 13, 41, "Print"],
Cell[938781, 17712, 77, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[938895, 17718, 107, 2, 30, "Input"],
Cell[939005, 17722, 845, 15, 41, "Print"],
Cell[939853, 17739, 1037, 18, 44, "Print"],
Cell[940893, 17759, 952, 16, 25, "Print"],
Cell[941848, 17777, 1447, 25, 44, "Print"],
Cell[943298, 17804, 1506, 27, 44, "Print"],
Cell[944807, 17833, 93, 1, 25, "Print"],
Cell[944903, 17836, 1130, 19, 44, "Print"],
Cell[946036, 17857, 887, 15, 25, "Print"],
Cell[946926, 17874, 689, 13, 41, "Print"],
Cell[947618, 17889, 79, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[947734, 17895, 105, 2, 30, "Input"],
Cell[947842, 17899, 849, 14, 41, "Print"],
Cell[948694, 17915, 1047, 18, 44, "Print"],
Cell[949744, 17935, 943, 16, 25, "Print"],
Cell[950690, 17953, 1458, 25, 44, "Print"],
Cell[952151, 17980, 1457, 26, 44, "Print"],
Cell[953611, 18008, 92, 1, 25, "Print"],
Cell[953706, 18011, 1099, 18, 44, "Print"],
Cell[954808, 18031, 876, 15, 25, "Print"],
Cell[955687, 18048, 701, 13, 41, "Print"],
Cell[956391, 18063, 80, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[956532, 18071, 90, 2, 73, "Section"],
Cell[956625, 18075, 941, 14, 90, "Text"],
Cell[957569, 18091, 9512, 163, 1870, "Input"],
Cell[967084, 18256, 18334, 310, 2830, "Input"],
Cell[985421, 18568, 2520, 41, 550, "Input"],
Cell[987944, 18611, 3018, 51, 730, "Input"],

Cell[CellGroupData[{
Cell[990987, 18666, 84, 1, 38, "Subsection"],
Cell[991074, 18669, 366, 7, 50, "Input"],
Cell[991443, 18678, 1460, 26, 44, "Print"],
Cell[992906, 18706, 892, 16, 25, "Print"],
Cell[993801, 18724, 891, 15, 25, "Print"],
Cell[994695, 18741, 922, 16, 25, "Print"],
Cell[995620, 18759, 917, 16, 25, "Print"],
Cell[996540, 18777, 884, 15, 25, "Print"],
Cell[997427, 18794, 919, 16, 25, "Print"],
Cell[998349, 18812, 918, 16, 25, "Print"],
Cell[999270, 18830, 922, 16, 25, "Print"],
Cell[1000195, 18848, 924, 16, 25, "Print"],
Cell[1001122, 18866, 914, 16, 25, "Print"],
Cell[1002039, 18884, 880, 15, 25, "Print"],
Cell[1002922, 18901, 917, 16, 25, "Print"],
Cell[1003842, 18919, 3912, 66, 239, "Print"],
Cell[1007757, 18987, 52, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1007846, 18993, 141, 3, 38, "Subsection"],
Cell[1007990, 18998, 998, 16, 295, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1009025, 19019, 141, 3, 38, "Subsection"],
Cell[1009169, 19024, 940, 14, 276, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

